(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   2418112,      44714]
NotebookOptionsPosition[   2389294,      44244]
NotebookOutlinePosition[   2389648,      44260]
CellTagsIndexPosition[   2389605,      44257]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Random walk based on energy model with pairwise interactions epistasis\
\>", "Section",
 CellChangeTimes->{{3.736775641768676*^9, 3.736775673976193*^9}, {
   3.7367757201893272`*^9, 3.736775731292768*^9}, {3.736775770005228*^9, 
   3.736775772379169*^9}, {3.7368024163226957`*^9, 3.736802423799531*^9}, 
   3.7409138183816338`*^9, {3.741534648706396*^9, 
   3.741534654734963*^9}},ExpressionUUID->"fe593be3-cf31-4429-a5f4-\
bf3d7063ee30"],

Cell[CellGroupData[{

Cell["Define functions", "Subsection",
 CellChangeTimes->{{3.733583759081191*^9, 
  3.73358376440517*^9}},ExpressionUUID->"30962d63-d6ac-485b-a49d-\
3a75475c5994"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Construct", " ", "an", " ", "orthonormal", " ", "basis", " ", "in", " ", 
    "the", " ", "subspace", " ", "of", " ", 
    RowBox[{"R", "^", "dim"}], " ", "defined", " ", "by", " ", "the", " ", 
    "constraint", " ", "that", " ", "a", " ", "dim", " ", "long", " ", 
    RowBox[{"vector", "'"}], "s", " ", "elements", " ", "sum", " ", "to", " ",
     "0"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"orthonormalBasisForSubspace1", "[", "alphabetSize_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "dim", ",", " ", "basis", ",", " ", "orthonormalBasis", ",", " ", 
        "basisForSubspace", ",", "randomVector"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", "=", "alphabetSize"}], ";", "\[IndentingNewLine]", 
       RowBox[{"basis", "=", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"1", ",", "dim"}], "]"}], "}"}], "~", "Join", "~", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"j", "==", "k"}], ",", "1", ",", "0"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"dim", "-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"orthonormalBasis", "=", 
          RowBox[{"Orthogonalize", "[", "basis", "]"}]}], ")"}], "//", 
        "MatrixForm"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{"basisForSubspace", "=", 
         RowBox[{"orthonormalBasis", "[", 
          RowBox[{"[", 
           RowBox[{"2", ";;"}], "]"}], "]"}]}], ")"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Draw", " ", "the", " ", "cofficients", " ", "for", " ", "the", " ", 
     "additive", " ", "terms", " ", "in", " ", "the", " ", "energy", " ", 
     "funciton"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"coeffsForOrder1", "[", 
     RowBox[{"alphabetSize_", ",", " ", "basis_", ",", " ", "std_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "randomVector", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"randomVector", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", ",", "std"}], "]"}], ",", 
          RowBox[{"alphabetSize", "-", "1"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"randomVector", ".", "basis"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Construct", " ", "an", " ", "orthonormal", " ", "basis", " ", "in", " ", 
     "the", " ", "subspace", " ", "of", " ", 
     RowBox[{"R", "^", 
      RowBox[{"(", 
       RowBox[{"dim", "^", "2"}], ")"}]}], " ", "defined", " ", "by", " ", 
     "the", " ", "constraint", " ", "that", " ", "all", " ", "row", " ", 
     "and", " ", "all", " ", "column", " ", "sums", " ", "of", " ", "a", " ", 
     "matrix", " ", "equal", " ", "0"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"orthonormalBasisForSubspace2", "[", "alphabetSize_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "dim", ",", "normal1", ",", "normal2", ",", "normal3", ",", 
        "allnormal", ",", " ", "stdBasis", ",", " ", "basis", ",", 
        "orthonormalBasis", ",", "basisForSubspace", ",", "randomVector"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", "=", "alphabetSize"}], ";", "\[IndentingNewLine]", 
       RowBox[{"normal1", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"SparseArray", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
                RowBox[{"i", "\[Equal]", "myi"}]}], "\[Rule]", "1"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"dim", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"myi", ",", "1", ",", 
             RowBox[{"dim", "-", "1"}]}], "}"}]}], "]"}], "//", "Normal"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"normal2", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"SparseArray", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
                RowBox[{"j", "\[Equal]", "myi"}]}], "\[Rule]", "1"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"dim", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"myi", ",", "1", ",", 
             RowBox[{"dim", "-", "1"}]}], "}"}]}], "]"}], "//", "Normal"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"normal3", "=", 
        RowBox[{"{", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"dim", ",", "dim"}], "}"}]}], "]"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"allnormal", "=", 
        RowBox[{
        "normal1", "~", "Join", "~", "normal2", "~", "Join", "~", 
         "normal3"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"stdBasis", "=", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"SparseArray", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
                  RowBox[{
                   RowBox[{"i", "\[Equal]", "myi"}], "&&", 
                   RowBox[{"j", "\[Equal]", "myj"}]}]}], "\[Rule]", "1"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"dim", ",", "dim"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"myi", ",", "1", ",", 
               RowBox[{"dim", "-", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"myj", ",", "1", ",", 
               RowBox[{"dim", "-", "1"}]}], "}"}]}], "]"}], ",", "1"}], "]"}],
          "//", "Normal"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{"basis", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Flatten", "/@", "allnormal"}], ")"}], "~", "Join", "~", 
          RowBox[{"(", 
           RowBox[{"Flatten", "/@", "stdBasis"}], ")"}]}]}], ")"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"orthonormalBasis", "=", 
          RowBox[{"Orthogonalize", "[", "basis", "]"}]}], ")"}], "//", 
        "MatrixForm"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{"basisForSubspace", "=", 
         RowBox[{"orthonormalBasis", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"2", "dim"}], ";;"}], "]"}], "]"}]}], ")"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Draw", " ", "the", " ", "cofficients", " ", "for", " ", "the", " ", 
     "epistatic", " ", "terms", " ", "in", " ", "the", " ", "energy", " ", 
     "funciton"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"coeffsForOrder2", "[", 
     RowBox[{"alphabetSize_", ",", " ", "basis_", ",", " ", "std_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "randomVector", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"randomVector", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", " ", ",", "std"}], "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"alphabetSize", "-", "1"}], ")"}], "^", "2"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"randomVector", ".", "basis"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"sequence", " ", "to", " ", "design", " ", 
      RowBox[{"matrix", ".", " ", "Converts"}], " ", "a", " ", "sequence", 
      " ", "of", " ", "integers", " ", "into", " ", "the", " ", "one"}], "-", 
     
     RowBox[{
     "hot", " ", "interaction", " ", "terms", " ", "of", " ", "order", " ", 
      "\"\<order\>\""}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"s2d", "[", 
     RowBox[{"seq_", ",", "l_", ",", "alpha_", ",", "order_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sub1", ",", "sub2", ",", "pos"}], "}"}], ",", 
      RowBox[{
       RowBox[{"sub1", "=", 
        RowBox[{"Subsets", "[", 
         RowBox[{"seq", ",", 
          RowBox[{"{", "order", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"sub2", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "i", "}"}], ",", 
            RowBox[{"sub1", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "sub1", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"pos", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"FromDigits", "[", 
            RowBox[{
             RowBox[{"Rest", "[", "#", "]"}], ",", "alpha"}], "]"}], "+", "1",
            "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"alpha", "^", "order"}], ")"}]}]}], "&"}], "/@", 
         "sub2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"SparseArray", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"pos", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "1"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Binomial", "[", 
            RowBox[{"l", ",", "order"}], "]"}], "*", 
           RowBox[{
            RowBox[{"(", "alpha", ")"}], "^", "order"}]}], "}"}]}], "]"}]}]}],
      "]"}]}], " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Calculate", " ", "energy", " ", "of", " ", "sequene"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CalcEnergy", "[", 
     RowBox[{
     "seq_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_"}], 
     "]"}], ":=", 
    RowBox[{
     RowBox[{"\[Beta]", ".", 
      RowBox[{"s2d", "[", 
       RowBox[{"seq", ",", "l", ",", "alpha", ",", "1"}], "]"}]}], "+", 
     RowBox[{"\[Gamma]", ".", 
      RowBox[{"s2d", "[", 
       RowBox[{"seq", ",", "l", ",", "alpha", ",", "2"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Generate", " ", "random", " ", "walk"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalk", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"length", ",", "old", ",", "new", ",", "mutate"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"length", "=", 
        RowBox[{"Length", "[", "start", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{"start", ",", 
          RowBox[{"CalcEnergy", "[", 
           RowBox[{
           "start", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}],
            "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "mutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "mutate"}], "]"}], "]"}], "}"}]}], "]"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", 
           RowBox[{"CalcEnergy", "[", 
            RowBox[{
             RowBox[{"new", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "l", ",", "alpha", ",", 
             "\[Beta]", ",", "\[Gamma]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"new", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "old"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Start", " ", "at", " ", "sequence", " ", "start", " ", "and", " ", 
      "evolve", " ", "at", " ", "energy", " ", "less", " ", "than", " ", 
      "cutoff", " ", "until", " ", "maxtime", " ", "mutations", " ", "have", 
      " ", "been", " ", "proposed"}], ";", " ", 
     RowBox[{"output", ":", " ", 
      RowBox[{
       RowBox[{"list", " ", "of", " ", "sequence"}], " ", "-", " ", 
       RowBox[{"energy", " ", "pairs", " ", "of", " ", "evolution"}]}]}]}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fastEnergy", "[", 
     RowBox[{"seq_", ",", "l_", ",", "alpha_", ",", "order_", " ", 
      RowBox[{"(*", 
       RowBox[{"order", " ", "of", " ", "interaction"}], "*)"}], ",", 
      "coeffs_"}], 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"corresponding", " ", "coefficients"}], ",", 
       RowBox[{
        RowBox[{"e", ".", "g", ".", "\[Beta]"}], " ", "or", " ", 
        "\[Gamma]"}]}], "*)"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sub1", ",", "sub2", ",", "pos"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sub1", "=", 
        RowBox[{"Subsets", "[", 
         RowBox[{"seq", ",", 
          RowBox[{"{", "order", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"sub2", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "i", "}"}], ",", 
            RowBox[{"sub1", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "sub1", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"pos", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"FromDigits", "[", 
            RowBox[{
             RowBox[{"Rest", "[", "#", "]"}], ",", "alpha"}], "]"}], "+", "1",
            "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"alpha", "^", "order"}], ")"}]}]}], "&"}], "/@", 
         "sub2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{"coeffs", "[", 
         RowBox[{"[", "pos", "]"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"**", "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
         "**"}], "**"}], "**"}], "**"}], "**"}], "*******)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "For", " ", "a", " ", "position", " ", "and", " ", "a", " ", "letter"}], 
     ",", " ", 
     RowBox[{
      RowBox[{"get", " ", "corresponding", " ", "index", " ", "in", " ", 
       RowBox[{"\[Beta]", ".", "\[IndentingNewLine]", "\[Beta]"}], " ", "is", 
       " ", "an", " ", "l", "*", "alpha"}], "-", 
      RowBox[{"long", " ", "vector"}]}], ",", " ", 
     RowBox[{
     "coordinates", " ", "are", " ", "in", " ", "the", " ", "following", " ", 
      
      RowBox[{"order", ":", " ", 
       RowBox[{"(", 
        RowBox[{"position1", ",", "letter1"}], ")"}]}]}], ",", "  ", 
     RowBox[{"(", 
      RowBox[{"position1", ",", "letter2"}], ")"}], ",", "...", ",", " ", 
     RowBox[{"(", 
      RowBox[{"position1", ",", "letterAlpha"}], ")"}], ",", "  ", 
     RowBox[{"(", 
      RowBox[{"position2", ",", "letter1"}], ")"}], ",", "  ", 
     RowBox[{"(", 
      RowBox[{"position2", ",", "letter2"}], ")"}], ",", "...", ",", " ", 
     RowBox[{"(", 
      RowBox[{"positionl", ",", "letterAlpha"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getIndexIn\[Beta]", "[", 
     RowBox[{"position_", ",", "letter_", ",", "l_", ",", "alpha_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "indexIn\[Beta]", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"indexIn\[Beta]", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"position", "-", "1"}], ")"}], "alpha"}], "+", "letter", 
        "+", "1"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]",
    "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "For", " ", "a", " ", "pair", " ", "of", " ", "positions", " ", "and", 
      " ", "a", " ", "pair", " ", "of", " ", "letters"}], ",", " ", 
     RowBox[{"get", " ", "corresponding", " ", "index", " ", "in", " ", 
      RowBox[{"\[Gamma]", ".", "\[IndentingNewLine]", "\[Gamma]"}], " ", "is",
       " ", "made", " ", "up", " ", "of", " ", "lchoose2", " ", "blocks"}], 
     ",", " ", 
     RowBox[{
      RowBox[{
      "each", " ", "corresponding", " ", "to", " ", "a", " ", "pair", " ", 
       "of", " ", "positions"}], ";", " ", 
      RowBox[{
      "the", " ", "blocks", " ", "are", " ", "in", " ", "the", " ", 
       "following", " ", 
       RowBox[{"order", ":", " ", 
        RowBox[{"(", 
         RowBox[{"pos1", ",", "pos2"}], ")"}]}]}]}], ",", 
     RowBox[{"(", 
      RowBox[{"pos1", ",", "pos3"}], ")"}], ",", "...", ",", 
     RowBox[{"(", 
      RowBox[{"pos1", ",", "posl"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"pos2", ",", "pos3"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"pos2", ",", "pos4"}], ")"}], ",", "...", ",", 
     RowBox[{"(", 
      RowBox[{"pos2", ",", "pos1"}], ")"}], ",", "...", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pos", 
         RowBox[{"(", 
          RowBox[{"l", "-", "1"}], ")"}]}], ",", "posl"}], ")"}], ";", " ", 
      RowBox[{
       RowBox[{"each", " ", "block", " ", "is", " ", "a", " ", 
        RowBox[{"alpha", "^", "2"}]}], "-", 
       RowBox[{"long", " ", "vector"}]}]}], ",", " ", 
     RowBox[{
     "each", " ", "coordinate", " ", "in", " ", "the", " ", "vector", " ", 
      "corresponds", " ", "to", " ", "a", " ", "pair", " ", "of", " ", 
      "letters"}], ",", " ", 
     RowBox[{
     "the", " ", "letters", " ", "are", " ", "in", " ", "the", " ", 
      "following", " ", 
      RowBox[{"order", ":", " ", 
       RowBox[{"(", 
        RowBox[{"letter1", ",", "letter1"}], ")"}]}]}], ",", 
     RowBox[{"(", 
      RowBox[{"letter1", ",", "letter2"}], ")"}], ",", "...", ",", 
     RowBox[{"(", 
      RowBox[{"letter1", ",", "letterAlpha"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"letter2", ",", "letter", ",", "1"}], ")"}], ",", "...", ",", 
     RowBox[{"(", 
      RowBox[{"letterAlpha", ",", "letterAlpha"}], ")"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getIndexIn\[Gamma]", "[", 
     RowBox[{
     "position1_", ",", "position2_", ",", "letter1_", ",", "letter2_", ",", 
      "l_", ",", "alpha_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"indexOfBlock", ",", "indexIn\[Gamma]"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"indexOfBlock", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"position1", "-", "1"}], ")"}], "l"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"position1", "-", "1"}], ")"}], 
          RowBox[{"position1", "/", "2"}]}], "+", "position2", "-", 
         "position1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"indexIn\[Gamma]", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"indexOfBlock", "-", "1"}], ")"}], 
          RowBox[{"alpha", "^", "2"}]}], "+", 
         RowBox[{"letter1", " ", "alpha"}], "+", "letter2", "+", "1"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnAdditiveEnergy", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "new", ",", "old\[Beta]", ",", " ", "new\[Beta]", ",", 
        "positionToMutate", ",", "energy", ",", "newEnergy"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"energy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"\[Beta]", ".", 
         RowBox[{"s2d", "[", 
          RowBox[{"start", ",", "l", ",", "alpha", ",", "1"}], "]"}]}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{"start", ",", "energy"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"positionToMutate", "=", 
            RowBox[{"RandomChoice", "[", 
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", "100"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"old\[Beta]", "=", 
            RowBox[{"\[Beta]", "[", 
             RowBox[{"[", 
              RowBox[{"getIndexIn\[Beta]", "[", 
               RowBox[{"positionToMutate", ",", 
                RowBox[{"old", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
                "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"new", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
            RowBox[{"RandomChoice", "[", 
             RowBox[{"Complement", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"new", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
                "}"}]}], "]"}], "]"}]}], ";"}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newEnergy", "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "old"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"output", " ", "is", " ", "timeseries", " ", "of", " ", 
     RowBox[{"{", 
      RowBox[{"sequence", ",", " ", 
       RowBox[{"additive", " ", "energy"}], ",", " ", 
       RowBox[{"epistatic", " ", "energy"}], ",", " ", 
       RowBox[{"total", " ", "energy"}]}], "}"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnTotalEnergy", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "old\[Beta]", ",", "old\[Gamma]indices", ",", "new", ",", 
        "positionToMutate", ",", "positionPairs", ",", "new\[Beta]", ",", 
        "new\[Gamma]indices", ",", "additiveEnergy", ",", "epistaticEnergy", 
        ",", "totalEnergy", ",", "newAdditiveEnergy", ",", 
        "newEpistaticEnergy", ",", "newTotalEnergy"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"additiveEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"\[Beta]", ".", 
          RowBox[{"s2d", "[", 
           RowBox[{"start", ",", "l", ",", "alpha", ",", "1"}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"epistaticEnergy", "=", 
        RowBox[{"+", 
         RowBox[{"fastEnergy", "[", 
          RowBox[{
          "start", ",", "l", ",", "alpha", ",", "2", ",", "\[Gamma]"}], 
          "]"}]}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"\[Gamma]", ".", 
          RowBox[{"s2d", "[", 
           RowBox[{"start", ",", "l", ",", "alpha", ",", "2"}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"totalEnergy", "=", 
        RowBox[{"additiveEnergy", "+", "epistaticEnergy"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{
         "start", ",", "additiveEnergy", ",", "epistaticEnergy", ",", 
          "totalEnergy"}], "}"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"positionToMutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positionPairs", "=", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos1", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
             "]"}], "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos2", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}],
                "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
               "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"new\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newAdditiveEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newEpistaticEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "-", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}], "+", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"newTotalEnergy", "=", 
           RowBox[{"newAdditiveEnergy", "+", "newEpistaticEnergy"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newAdditiveEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "=", "newEpistaticEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "=", " ", "newTotalEnergy"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newTotalEnergy", "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "old"}], ",", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"**", "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
         "**"}], "**"}], "**"}], "**"}], "**"}], "*******)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "calculate", " ", "mutational", " ", "effects", " ", "of", " ", "all", 
      " ", "single", " ", "mutants", " ", "around", " ", "target", " ", 
      "sequence"}], ";", " ", 
     RowBox[{"output", " ", "=", " ", 
      RowBox[{
       RowBox[{
       "matrix", " ", "of", " ", "energies", " ", "of", " ", "mutants"}], " ",
        "-", " ", 
       RowBox[{"energy", " ", "of", " ", "target", " ", "seq"}]}]}]}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"effectOfSingleMutations", "[", 
     RowBox[{
     "target_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_"}],
      "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"wt", ",", "singles"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"wt", "=", 
        RowBox[{"CalcEnergy", "[", 
         RowBox[{
         "target", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"singles", "=", 
        RowBox[{
         RowBox[{"ParallelTable", "[", " ", 
          RowBox[{
           RowBox[{"CalcEnergy", "[", 
            RowBox[{
             RowBox[{"ReplacePart", "[", 
              RowBox[{"target", ",", 
               RowBox[{"position", "\[Rule]", "letter"}]}], "]"}], ",", "l", 
             ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"position", ",", 
             RowBox[{"Length", "[", "target", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"letter", ",", "0", ",", 
             RowBox[{"alpha", "-", "1"}]}], "}"}]}], "]"}], "-", "wt"}]}]}]}],
      "\[IndentingNewLine]", "]"}]}], " ", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"effectOfDoubleMutations", "[", 
     RowBox[{
     "target_", ",", "l_", ",", " ", "alpha_", ",", "\[Beta]_", ",", 
      "\[Gamma]_", ",", "numOfDoubleMutants_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"wt", ",", "doubleMutants", ",", "mutations"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"wt", "=", 
        RowBox[{"CalcEnergy", "[", 
         RowBox[{
         "target", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"mutations", "=", 
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"RandomSample", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"1", ",", "l"}], "]"}], ",", "2"}], "]"}], ",", 
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"alpha", "-", "1"}]}], "}"}], "]"}], ",", 
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"alpha", "-", "1"}]}], "}"}], "]"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"first", " ", "site", " ", "to", " ", "mutate"}], ",", 
            " ", 
            RowBox[{"second", " ", "site", " ", "to", " ", "mutate"}], ",", 
            " ", 
            RowBox[{
            "position", " ", "of", " ", "first", " ", "mutation", " ", 
             "among", " ", "19", " ", "alternates"}], ",", " ", 
            RowBox[{
            "position", " ", "of", " ", "second", " ", "mutation", " ", 
             "among", " ", "19", " ", "alternates"}]}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"{", "numOfDoubleMutants", "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"CalcEnergy", "[", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"target", ",", " ", 
                RowBox[{
                 RowBox[{"current", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
                 RowBox[{
                  RowBox[{"Complement", "[", 
                   RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"target", "[", 
                    RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "}"}]}], 
                   "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"current", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}]}], 
               " ", "]"}], ",", "l", ",", " ", "alpha", ",", "\[Beta]", ",", 
              "\[Gamma]"}], "]"}], "+", 
            RowBox[{"CalcEnergy", "[", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"target", ",", 
                RowBox[{
                 RowBox[{"current", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "\[Rule]", 
                 RowBox[{
                  RowBox[{"Complement", "[", 
                   RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"target", "[", 
                    RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "}"}]}], 
                   "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"current", "[", 
                    RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}]}], 
               "]"}], ",", "l", ",", " ", "alpha", ",", "\[Beta]", ",", 
              "\[Gamma]"}], "]"}], "-", "wt"}], ",", "\[IndentingNewLine]", 
           RowBox[{"CalcEnergy", "[", 
            RowBox[{
             RowBox[{"ReplacePart", "[", 
              RowBox[{"target", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"current", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"Complement", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"target", "[", 
                    RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "}"}]}], 
                    "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"current", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"Complement", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"target", "[", 
                    RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "}"}]}], 
                    "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}]}], 
                "}"}]}], "]"}], ",", "l", ",", " ", "alpha", ",", "\[Beta]", 
             ",", "\[Gamma]"}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"current", ",", "mutations"}], "}"}]}], "]"}]}]}], " ", 
     RowBox[{"(*", 
      RowBox[{"List", " ", "is", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Energy", " ", "of", " ", "mut1"}], "+", " ", 
          RowBox[{"Energy", " ", "of", " ", "Mut2"}], "-", 
          RowBox[{"Energy", " ", "of", " ", "WT"}]}], ",", " ", 
         RowBox[{"Energy", " ", "of", " ", "double", " ", "mutant"}]}]}]}], 
      "*)"}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getAllSingleMutationEffectsInAdditiveEnergy", "[", 
     RowBox[{"seq_", ",", "l_", ",", "alpha_", ",", "\[Beta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "position", ",", "letter", ",", "old\[Beta]indices", ",", 
        "old\[Beta]s", ",", "new\[Beta]indices", ",", "new\[Beta]s"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"old\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             
             RowBox[{"seq", "[", 
              RowBox[{"[", "positionToMutate", "]"}], "]"}], "+", "1"}], ",", 
            
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             "letter", "+", "1"}], ",", 
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "new\[Beta]indices", "]"}], "]"}], "-", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "old\[Beta]indices", "]"}], "]"}]}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getAllSingleMutationEffectsInTotalEnergy", "[", 
     RowBox[{
     "seq_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "position", ",", "letter", ",", "old\[Beta]indices", ",", 
        "new\[Beta]indices", ",", "positionPairs", ",", "old\[Gamma]indices", 
        ",", "new\[Gamma]indices", ",", "t"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"old\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             
             RowBox[{"seq", "[", 
              RowBox[{"[", "positionToMutate", "]"}], "]"}], "+", "1"}], ",", 
            
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             "letter", "+", "1"}], ",", 
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"t", "=", 
        RowBox[{
         RowBox[{"Table", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"old\[Gamma]indices", "=", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"getIndexIn\[Gamma]", "[", 
                 RowBox[{"p", ",", "positionToMutate", ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "p", "]"}], "]"}], ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", 
                  ",", "alpha"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", "1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "}"}]}], "]"}], 
              "~", "Join", "~", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"getIndexIn\[Gamma]", "[", 
                 RowBox[{"positionToMutate", ",", "p", ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "p", "]"}], "]"}], ",", "l", ",", "alpha"}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", 
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "}"}]}],
                "]"}]}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"new\[Gamma]indices", "=", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"getIndexIn\[Gamma]", "[", 
                 RowBox[{"p", ",", "positionToMutate", ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "p", "]"}], "]"}], ",", "letter", ",", "l", 
                  ",", "alpha"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", "1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "}"}]}], "]"}], 
              "~", "Join", "~", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"getIndexIn\[Gamma]", "[", 
                 RowBox[{"positionToMutate", ",", "p", ",", "letter", ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "p", "]"}], "]"}], ",", "l", ",", "alpha"}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", 
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "}"}]}],
                "]"}]}]}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Total", "[", 
               RowBox[{"\[Gamma]", "[", 
                RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}]}], "+", 
             RowBox[{"Total", "[", 
              RowBox[{"\[Gamma]", "[", 
               RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"letter", ",", 
             RowBox[{"Complement", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"seq", "[", 
                 RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
              "]"}]}], "}"}]}], "]"}], "//", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"#", ",", "1"}], "]"}], "&"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "new\[Beta]indices", "]"}], "]"}], "-", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "old\[Beta]indices", "]"}], "]"}], "+", "t"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getSingleMutationsEffectInAdditiveEnergy", "[", 
     RowBox[{
     "seq_", ",", "positionToMutate_", ",", "newLetter_", ",", "l_", ",", 
      "alpha_", ",", "\[Beta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"old\[Beta]", ",", "new\[Beta]", ",", "mutEffect"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"old\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{"positionToMutate", ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{
           "positionToMutate", ",", "newLetter", ",", "l", ",", "alpha"}], 
           "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"mutEffect", "=", 
        RowBox[{
         RowBox[{"-", "old\[Beta]"}], "+", "new\[Beta]"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
     RowBox[{
     "seq_", ",", "positionToMutate_", ",", "newLetter_", ",", "l_", ",", 
      "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "newSeq", ",", "old\[Beta]", ",", "new\[Beta]", ",", "positionPairs", 
        ",", "old\[Gamma]indices", ",", "new\[Gamma]indices"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"newSeq", "=", "seq"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"newSeq", "[", 
         RowBox[{"[", "positionToMutate", "]"}], "]"}], "=", "newLetter"}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"old\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{"positionToMutate", ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{
           "positionToMutate", ",", "newLetter", ",", "l", ",", "alpha"}], 
           "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"positionPairs", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"pos1", ",", 
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", 
               RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
          "]"}], "~", "Join", "~", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"pos2", ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}], 
            "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"old\[Gamma]indices", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"getIndexIn\[Gamma]", "[", 
           RowBox[{
            RowBox[{"p", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"p", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", 
              RowBox[{"p", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", 
              RowBox[{"p", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"new\[Gamma]indices", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"getIndexIn\[Gamma]", "[", 
           RowBox[{
            RowBox[{"p", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"p", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"newSeq", "[", 
             RowBox[{"[", 
              RowBox[{"p", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
            RowBox[{"newSeq", "[", 
             RowBox[{"[", 
              RowBox[{"p", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "old\[Beta]"}], "+", "new\[Beta]", "-", 
        RowBox[{"Total", "[", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}], "+", 
        RowBox[{"Total", "[", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"output", " ", "is", " ", "timeseries", " ", "of", " ", 
     RowBox[{"{", 
      RowBox[{"sequence", ",", " ", 
       RowBox[{"additive", " ", "energy"}], ",", " ", 
       RowBox[{"epistatic", " ", "energy"}], ",", " ", 
       RowBox[{"total", " ", "energy"}], ",", " ", 
       RowBox[{
       "number", " ", "of", " ", "mutations", " ", "from", " ", "starting", 
        " ", "seq"}]}], "}"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnTotalEnergyUntilGivenSeqDivergence", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",",
       "\[Gamma]_", ",", "maxDist_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "old\[Beta]", ",", "old\[Gamma]indices", ",", "new", ",", 
        "positionToMutate", ",", "positionPairs", ",", "new\[Beta]", ",", 
        "new\[Gamma]indices", ",", "additiveEnergy", ",", "epistaticEnergy", 
        ",", "totalEnergy", ",", "newAdditiveEnergy", ",", 
        "newEpistaticEnergy", ",", "newTotalEnergy", ",", "distFromStart", 
        ",", "timeSeries"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"additiveEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"\[Beta]", ".", 
          RowBox[{"s2d", "[", 
           RowBox[{"start", ",", "l", ",", "alpha", ",", "1"}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"epistaticEnergy", "=", 
        RowBox[{"+", 
         RowBox[{"fastEnergy", "[", 
          RowBox[{
          "start", ",", "l", ",", "alpha", ",", "2", ",", "\[Gamma]"}], 
          "]"}]}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"\[Gamma]", ".", 
          RowBox[{"s2d", "[", 
           RowBox[{"start", ",", "l", ",", "alpha", ",", "2"}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"totalEnergy", "=", 
        RowBox[{"additiveEnergy", "+", "epistaticEnergy"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"distFromStart", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{
         "start", ",", "additiveEnergy", ",", "epistaticEnergy", ",", 
          "totalEnergy", ",", " ", "distFromStart"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"timeSeries", "=", 
        RowBox[{"{", "old", "}"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"distFromStart", "<", "maxDist"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"positionToMutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positionPairs", "=", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos1", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
             "]"}], "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos2", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}],
                "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
               "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"new\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newAdditiveEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newEpistaticEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "-", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}], "+", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"newTotalEnergy", "=", 
           RowBox[{"newAdditiveEnergy", "+", "newEpistaticEnergy"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newAdditiveEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "=", "newEpistaticEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "=", " ", "newTotalEnergy"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newTotalEnergy", "<", "cutoff"}], ",", 
            RowBox[{
             RowBox[{"old", "=", "new"}], ";", " ", 
             RowBox[{"distFromStart", "=", 
              RowBox[{"HammingDistance", "[", 
               RowBox[{"start", ",", 
                RowBox[{"old", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", " ", 
             RowBox[{
              RowBox[{"old", "[", 
               RowBox[{"[", "5", "]"}], "]"}], "=", "distFromStart"}]}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"timeSeries", ",", "old"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "timeSeries"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Draws", " ", "numDraws", " ", "random", " ", "sequences", " ", "and", 
      " ", "fits", " ", "a", " ", "bivariate", " ", "Gauss", " ", 
      "distribution", " ", "on", " ", "the", " ", "corresponding", " ", 
      RowBox[{"(", 
       RowBox[{"E1", ",", "E2"}], ")"}], "s"}], ";", " ", 
     RowBox[{"returns", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mean", " ", "of", " ", "fitted", " ", "Gauss"}], ",", " ", 
        RowBox[{
        "cov", " ", "matrix", " ", "of", " ", "fitted", " ", "Gauss"}]}], 
       "}"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitBivariateGaussToRandomSeq", "[", 
     RowBox[{
     "l_", ",", " ", "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", " ", 
      "numDraws_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "randSeqs", ",", "non", ",", " ", "seq", ",", "E1s", ",", " ", "E2s", 
        ",", " ", "meanVec", ",", "dataMatrix", ",", "covMatrix", ",", "c"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"randSeqs", "=", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"alpha", "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"numDraws", ",", "l"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"non", "=", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"alpha", "^", "2"}], " ", 
           RowBox[{"Binomial", "[", 
            RowBox[{"l", ",", "2"}], "]"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"E1s", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"fastEnergy", "[", 
           RowBox[{"seq", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"seq", ",", "randSeqs"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"E2s", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"fastEnergy", "[", 
           RowBox[{"seq", ",", "l", ",", "alpha", ",", "2", ",", "\[Gamma]"}],
            "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"seq", ",", "randSeqs"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"meanVec", "=", 
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"E1s", "//", "Total"}], "numDraws"], ",", 
          FractionBox[
           RowBox[{"E2s", "//", "Total"}], "numDraws"]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dataMatrix", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"E1s", "-", 
            RowBox[{"meanVec", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ",", 
           RowBox[{"E2s", "-", 
            RowBox[{"meanVec", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"covMatrix", "=", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"numDraws", "-", "1"}], ")"}]}], 
         RowBox[{
          RowBox[{"Transpose", "[", "dataMatrix", "]"}], ".", 
          "dataMatrix"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<parameters of numerically fitted bivariate normal distribution: \
\>\"", ",", "meanVec", ",", "\"\<, \>\"", ",", 
         RowBox[{"covMatrix", "//", "MatrixForm"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"c", "=", 
        RowBox[{"{", 
         RowBox[{"meanVec", ",", " ", "covMatrix"}], "}"}]}], ";", 
       "\[IndentingNewLine]", "c"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnTotalEnergyHoc", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_", ",", "\[Gamma]_", ",", "var_"}], "]"}], 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"add", " ", "a", " ", "parameter"}], ",", " ", 
      RowBox[{"HOC", " ", "variance"}]}], "*)"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "old\[Beta]", ",", "old\[Gamma]indices", ",", "new", ",", 
        "positionToMutate", ",", "positionPairs", ",", "new\[Beta]", ",", 
        "new\[Gamma]indices", ",", "newHocEnergy", ",", "additiveEnergy", ",",
         "epistaticEnergy", ",", "totalEnergy", ",", "newAdditiveEnergy", ",",
         "newEpistaticEnergy", ",", "newTotalEnergy", ",", "hocEnergy", ",", 
        "hocAssociation"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"additiveEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"epistaticEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "2", ",", "\[Gamma]"}],
          "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"hocEnergy", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", 
           RowBox[{"Sqrt", "[", "var", "]"}]}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{
        "draw", " ", "HOC", " ", "energy", " ", "from", " ", "Gaussian"}], 
        "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"totalEnergy", "=", 
        RowBox[{
        "additiveEnergy", "+", "epistaticEnergy", "+", "hocEnergy"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{
         "start", ",", "additiveEnergy", ",", "epistaticEnergy", ",", 
          "hocEnergy", ",", "totalEnergy"}], "}"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"hocAssociation", "=", 
        RowBox[{"Association", "[", 
         RowBox[{"start", "\[Rule]", "hocEnergy"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Make", " ", "association", " ", "to", " ", "keep", " ", "track", " ",
          "of", " ", "HOC", " ", "energies", " ", "from", " ", "previously", 
         " ", "observed", " ", "sequences"}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"positionToMutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positionPairs", "=", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos1", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
             "]"}], "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos2", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}],
                "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
               "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"new\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"newHocEnergy", "=", 
           RowBox[{"RandomVariate", "[", 
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0", ",", "\[Sigma]"}], "]"}], "]"}]}], ";", " ", 
          RowBox[{"(*", 
           RowBox[{"draw", " ", "new", " ", "hoc", " ", "term"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "/.", "hocAssociation"}], 
              ")"}], "!=", 
             RowBox[{"new", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"newHocEnergy", "=", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "/.", "hocAssociation"}], 
              ")"}]}], ",", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"hocAssociation", ",", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "newHocEnergy"}]}],
              "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "Check", " ", "if", " ", "this", " ", "is", " ", "a", " ", 
             "never", " ", "before", " ", "seen", " ", 
             RowBox[{"sequence", ".", " ", "If"}], " ", "so"}], ",", " ", 
            RowBox[{"add", " ", "it", " ", "to", " ", "the", " ", 
             RowBox[{"association", ".", " ", "If"}], " ", "not"}], ",", " ", 
            
            RowBox[{
            "use", " ", "the", " ", "HOC", " ", "energy", " ", "assigned", 
             " ", "to", " ", "it", " ", "previously"}]}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"newAdditiveEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newEpistaticEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "-", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}], "+", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"newTotalEnergy", "=", 
           RowBox[{
           "newAdditiveEnergy", "+", "newEpistaticEnergy", "+", 
            "newHocEnergy"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newAdditiveEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "=", "newEpistaticEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "=", "newHocEnergy"}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "=", " ", "newTotalEnergy"}], ";",
           " ", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "HOC", " ", "energy", " ", "is", " ", "in", " ", "position", " ", 
             "4"}], ",", " ", 
            RowBox[{
             RowBox[{
             "and", " ", "total", " ", "energy", " ", "is", " ", "moved", " ",
               "to", " ", "position", " ", 
              RowBox[{"5", " ", "--"}], " ", "note", " ", "for", " ", 
              "downstream", " ", 
              RowBox[{"processing", ".", " ", "Trying"}], " ", "to", " ", 
              "keep", " ", "total", " ", "energy", " ", "as"}], " ", "-", 
             RowBox[{"1", " ", "position"}]}]}], "*)"}], 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newTotalEnergy", "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "old"}], ",", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.7335838039573507`*^9, {3.7335881091210537`*^9, 3.733588206389267*^9}, {
   3.7335882692342176`*^9, 3.7335882699589863`*^9}, {3.733591445970196*^9, 
   3.733591482389825*^9}, {3.7335920247797956`*^9, 3.7335920407542048`*^9}, {
   3.733657839237068*^9, 3.733657858342669*^9}, {3.7336636827607822`*^9, 
   3.733663688888618*^9}, {3.733663750926791*^9, 3.733663754234226*^9}, {
   3.733665888064898*^9, 3.733665903000697*^9}, {3.733762961285969*^9, 
   3.733762967960169*^9}, {3.733763208245494*^9, 3.7337632506477127`*^9}, {
   3.733825708391815*^9, 3.733825709631165*^9}, {3.733832305680546*^9, 
   3.733832313432543*^9}, {3.7338330469778967`*^9, 3.733833086956789*^9}, {
   3.733833161554408*^9, 3.733833177836576*^9}, {3.733833348544345*^9, 
   3.733833353197398*^9}, 3.733833422163946*^9, {3.7338337733866158`*^9, 
   3.733833825333108*^9}, {3.733834112411557*^9, 3.7338341157916937`*^9}, {
   3.73383476762868*^9, 3.733834768007326*^9}, {3.733835008611196*^9, 
   3.733835010097033*^9}, {3.733838253860846*^9, 3.733838284569242*^9}, {
   3.733838370393547*^9, 3.7338383765698757`*^9}, {3.733838672591601*^9, 
   3.7338386820095663`*^9}, {3.733838840620441*^9, 3.733838846001631*^9}, {
   3.7338389279861183`*^9, 3.7338389283659277`*^9}, {3.733839126992887*^9, 
   3.733839255576483*^9}, {3.733840196870534*^9, 3.733840462690013*^9}, {
   3.7338405355633593`*^9, 3.733840567730377*^9}, {3.733840664210382*^9, 
   3.733840664790536*^9}, {3.733840719158998*^9, 3.733840781708859*^9}, {
   3.7338408174632683`*^9, 3.7338408230838327`*^9}, {3.733840859564704*^9, 
   3.733840867811428*^9}, {3.733841285525737*^9, 3.733841285990116*^9}, {
   3.733841348609192*^9, 3.7338413499985*^9}, {3.733841452447976*^9, 
   3.733841489468377*^9}, {3.7338417598954697`*^9, 3.733841812053845*^9}, {
   3.733841940495515*^9, 3.7338419408209267`*^9}, {3.734014900198317*^9, 
   3.734015003666304*^9}, {3.7340288800325603`*^9, 3.7340289143686247`*^9}, {
   3.734029138436696*^9, 3.734029164218816*^9}, {3.734029214576234*^9, 
   3.734029215047532*^9}, {3.7340292615254307`*^9, 3.734029261908684*^9}, {
   3.734029314333132*^9, 3.734029431112122*^9}, {3.734034123669182*^9, 
   3.7340341252565823`*^9}, {3.734039649144651*^9, 3.734039652089361*^9}, {
   3.734039702504858*^9, 3.7340397054516068`*^9}, {3.734731003536138*^9, 
   3.7347310109134703`*^9}, {3.734731118297139*^9, 3.7347311366247263`*^9}, {
   3.734791358186555*^9, 3.734791359209587*^9}, {3.734791646730743*^9, 
   3.734791654612185*^9}, 3.734791711839116*^9, {3.7347917424999113`*^9, 
   3.734791963498316*^9}, {3.7347927272799892`*^9, 3.7347927287699747`*^9}, {
   3.735034948116067*^9, 3.7350349581530037`*^9}, {3.735044706325698*^9, 
   3.7350447067298307`*^9}, {3.735044917841365*^9, 3.735044922259191*^9}, {
   3.735044971486087*^9, 3.735044976486824*^9}, {3.735049856620572*^9, 
   3.735049866284443*^9}, {3.735049907900181*^9, 3.735049908304809*^9}, {
   3.735049969774969*^9, 3.735049970214778*^9}, {3.735050552345709*^9, 
   3.7350505756756287`*^9}, {3.735050623079444*^9, 3.7350506241251307`*^9}, {
   3.735050662586749*^9, 3.735050686955811*^9}, {3.7350555011727343`*^9, 
   3.735055502338187*^9}, {3.735055729881488*^9, 3.735055737349206*^9}, {
   3.7350560442510567`*^9, 3.735056088955718*^9}, {3.7350561426660023`*^9, 
   3.735056201489633*^9}, {3.735056587585011*^9, 3.735056588087739*^9}, {
   3.7350568909664583`*^9, 3.735056910383957*^9}, {3.735074800077484*^9, 
   3.735074801697115*^9}, 3.735074868053438*^9, {3.7350749218890533`*^9, 
   3.735074933079638*^9}, {3.7351238414834137`*^9, 3.7351238709877043`*^9}, {
   3.73512390115114*^9, 3.735124017386944*^9}, {3.735124054764489*^9, 
   3.735124057802232*^9}, {3.735124127951929*^9, 3.735124387557212*^9}, {
   3.735124607775524*^9, 3.735124639964654*^9}, {3.735124796347507*^9, 
   3.7351248769970284`*^9}, {3.735124914347135*^9, 3.73512504139107*^9}, {
   3.735309782404928*^9, 3.735309796710352*^9}, 3.735313138304607*^9, 
   3.735313435835635*^9, {3.735338214510211*^9, 3.735338216110175*^9}, {
   3.7353385753896227`*^9, 3.735338578635257*^9}, {3.735338621425674*^9, 
   3.735338625888688*^9}, {3.7353386617055264`*^9, 3.7353386666098213`*^9}, {
   3.735338701288274*^9, 3.735338707439555*^9}, {3.735338772238963*^9, 
   3.7353387792903957`*^9}, {3.735338998773193*^9, 3.735339014051087*^9}, {
   3.735339431920115*^9, 3.735339433137787*^9}, {3.735339562709037*^9, 
   3.7353395829658117`*^9}, {3.735339709730977*^9, 3.7353397102048397`*^9}, {
   3.735339759804261*^9, 3.735339857061246*^9}, {3.7353398988161182`*^9, 
   3.7353399402839937`*^9}, {3.735340053827973*^9, 3.735340165229644*^9}, {
   3.735340350592531*^9, 3.735340405686103*^9}, {3.735340441018927*^9, 
   3.735340495890498*^9}, {3.735340622188092*^9, 3.735340684498999*^9}, {
   3.735340715466408*^9, 3.7353407508118963`*^9}, {3.735340788475519*^9, 
   3.7353408807396812`*^9}, 3.735341003602975*^9, {3.735343106727467*^9, 
   3.7353431079210997`*^9}, {3.735344394176355*^9, 3.735344394621315*^9}, {
   3.7353941575003223`*^9, 3.735394158339768*^9}, {3.7353973006828814`*^9, 
   3.735397381826803*^9}, 3.735397505974798*^9, {3.735397672434846*^9, 
   3.735397748976157*^9}, {3.735406277613699*^9, 3.7354062786087017`*^9}, {
   3.735406317153294*^9, 3.735406348019256*^9}, {3.7354064588305883`*^9, 
   3.7354064600336123`*^9}, {3.735406604649914*^9, 3.7354066059562807`*^9}, {
   3.7354066471004753`*^9, 3.735406648766555*^9}, {3.735410730194944*^9, 
   3.735410751974333*^9}, {3.7354107866867237`*^9, 3.735410819024682*^9}, 
   3.735425422050947*^9, {3.735998961126707*^9, 3.735998980792128*^9}, {
   3.735999239331464*^9, 3.735999259089415*^9}, {3.736002003362871*^9, 
   3.7360020343781033`*^9}, 3.73600268420627*^9, {3.736004431235854*^9, 
   3.73600444734855*^9}, {3.736004478827415*^9, 3.7360044790099993`*^9}, {
   3.7361693620888453`*^9, 3.7361693625634403`*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"886ee175-aea8-4d5b-bc03-1458b4c7d048"]
}, Closed]],

Cell[CellGroupData[{

Cell["length=400, Cutoff = -400, variance1=1, variance2=.0003", "Subsection",
 CellChangeTimes->{{3.736248028386547*^9, 3.73624806912971*^9}, {
   3.7362483362683687`*^9, 3.736248338690299*^9}, 3.736250687660479*^9, 
   3.736250724003316*^9, 3.7362507762117233`*^9, 3.736252731455212*^9, {
   3.73627118380672*^9, 3.736271190918107*^9}, {3.7362712249418993`*^9, 
   3.736271225173731*^9}, 3.736271798328224*^9, {3.736293012105565*^9, 
   3.7362930122483797`*^9}, {3.736293353326429*^9, 3.736293353518495*^9}, {
   3.7362942338077297`*^9, 3.736294233942877*^9}, {3.736294987306686*^9, 
   3.7362949877629557`*^9}, {3.736337369816305*^9, 3.736337415334573*^9}, 
   3.736777723200118*^9},ExpressionUUID->"91e4fa93-5340-4aca-a28f-\
542f7ac12593"],

Cell[CellGroupData[{

Cell["Set parameters and draw coefficients in energy function", \
"Subsubsection",
 CellChangeTimes->{{3.735039638758647*^9, 
  3.73503966086934*^9}},ExpressionUUID->"f4d3075d-28ac-432b-8516-\
bed5df28a6a8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SeedRandom", "[", "12345678", "]"}], ";"}], "\[IndentingNewLine]",
   "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"SET", " ", "PARAMETERS"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"l", "=", "400"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"length", " ", "of", " ", "sequence"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alpha", "=", "20"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"alleles", " ", "per", " ", "site"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"variance1", "=", 
    RowBox[{
     RowBox[{"alpha", "/", 
      RowBox[{"(", 
       RowBox[{"alpha", "-", "1"}], ")"}]}], "1"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"variance2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"alpha", "^", "2"}], "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"alpha", "-", "1"}], ")"}], "^", "2"}]}], " ", "*", 
     "0.0003"}], "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"energyCutoff", "=", 
   RowBox[{"-", "400"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wt", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", "l"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fontSize", "=", "13"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"for", " ", "axes", " ", "labels"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<sequence length = \>\"", ",", " ", "l"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<alphabet size = \>\"", ",", "  ", "alpha"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<variance1 = \>\"", ",", " ", "variance1"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<variance2 = \>\"", ",", " ", "variance2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<energy cutoff = \>\"", ",", " ", "energyCutoff"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<random walk started from wt=\>\"", ",", "wt"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "CALCULATE", " ", "FRACTION", " ", "OF", " ", "VARAIANCE", " ", "OF", " ", 
    "TOTAL", " ", "ENERGY", " ", "DUE", " ", "TO", " ", "ADDITIVE", " ", 
    "ENERGY"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"varAdditiveEnergy", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"alpha", "-", "1"}], ")"}], "/", "alpha"}], " ", "l", " ", 
    "variance1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"varEpistaticEnergy", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"alpha", "-", "1"}], ")"}], "^", "2"}], "/", 
     RowBox[{"alpha", "^", "2"}]}], "  ", 
    RowBox[{"Binomial", "[", 
     RowBox[{"l", ",", "2"}], "]"}], "variance2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<variance of additive energy = \>\"", ",", " ", "varAdditiveEnergy"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<variance of epistatic energy = \>\"", ",", " ", 
    "varEpistaticEnergy"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<fraction of total variance due to additive energy = \>\"", ",", 
   RowBox[{"varAdditiveEnergy", "/", 
    RowBox[{"(", 
     RowBox[{"varAdditiveEnergy", "+", "varEpistaticEnergy"}], ")"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<cutoff standard deviations from mean = \>\"", ",", 
   RowBox[{"energyCutoff", "/", 
    SqrtBox[
     RowBox[{"(", 
      RowBox[{"varAdditiveEnergy", "+", "varEpistaticEnergy"}], ")"}]]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "DRAW", " ", "COEFFICIENTS", " ", "IN", " ", "ENERGY", " ", "FUNCTION"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SeedRandom", "[", "12345678", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis1", "=", 
   RowBox[{"N", "[", 
    RowBox[{"orthonormalBasisForSubspace1", "[", "alpha", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis2", "=", 
   RowBox[{"N", "[", 
    RowBox[{"orthonormalBasisForSubspace2", "[", "alpha", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Drawing \[Beta]s...\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Beta]0", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"coeffsForOrder1", "[", 
          RowBox[{"alpha", ",", " ", "basis1", ",", " ", 
           RowBox[{"Sqrt", "[", "variance1", "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "l"}], "}"}]}], "]"}]}], ";"}], ")"}], "//",
     "AbsoluteTiming"}], " ", "//", "Print"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"\[Beta]", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Sort", "/@", "\[Beta]0"}], "]"}]}], ")"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Drawing \[Gamma]s...\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Gamma]", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"coeffsForOrder2", "[", 
           RowBox[{"alpha", ",", " ", "basis2", ",", " ", 
            RowBox[{"Sqrt", "[", "variance2", "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", 
            RowBox[{
             RowBox[{"Binomial", "[", 
              RowBox[{"l", ",", "2"}], "]"}], "//", "N"}]}], "}"}]}], "]"}], 
        "]"}]}], ";"}], ")"}], "//", "AbsoluteTiming"}], " ", "//", "Print"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"CALCULATE", " ", "ENERGY", " ", "OF", " ", "WT"}], "=", 
    RowBox[{"(", 
     RowBox[{"0", ",", "...", ",", "0"}], ")"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"non", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"alpha", "^", "2"}], " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{"l", ",", "2"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e1", "=", 
   RowBox[{"CalcEnergy", "[", 
    RowBox[{"wt", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "non"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e2", "=", 
   RowBox[{
    RowBox[{"CalcEnergy", "[", 
     RowBox[{"wt", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], 
     "]"}], "-", 
    RowBox[{"CalcEnergy", "[", 
     RowBox[{"wt", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "non"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<additive energy of wt = \>\"", ",", " ", "e1"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<epistatic energy of wt = \>\"", ",", " ", "e2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<total energy of wt = \>\"", ",", " ", 
    RowBox[{"e1", "+", "e2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.735039670215447*^9, 3.735039676885922*^9}, {
   3.735044800048231*^9, 3.735044803116219*^9}, {3.735045221971918*^9, 
   3.73504522959811*^9}, {3.735045269988558*^9, 3.7350452708141117`*^9}, {
   3.7350453365703077`*^9, 3.735045343485133*^9}, {3.735045417158849*^9, 
   3.7350454404247227`*^9}, 3.735046374306554*^9, {3.735049736725403*^9, 
   3.73504978076836*^9}, {3.73507499072913*^9, 3.735074991297587*^9}, {
   3.735313151518528*^9, 3.7353131526432467`*^9}, {3.735338338003683*^9, 
   3.735338359968875*^9}, {3.735338545344153*^9, 3.7353385505773697`*^9}, {
   3.735343479798663*^9, 3.73534354966885*^9}, 3.735345101844233*^9, 
   3.7353454660740137`*^9, {3.735382657299398*^9, 3.735382659006311*^9}, {
   3.735388042273129*^9, 3.7353880468572283`*^9}, {3.735392685124683*^9, 
   3.7353926853475657`*^9}, {3.735394536084243*^9, 3.7353945364713583`*^9}, 
   3.7353954158473263`*^9, 3.7354072879169703`*^9, {3.7354080776830397`*^9, 
   3.735408079783695*^9}, {3.735997989989833*^9, 3.73599799318114*^9}, {
   3.7360045807781267`*^9, 3.736004585310495*^9}, {3.736066744804278*^9, 
   3.736066748291823*^9}, {3.7360671047459307`*^9, 3.73606731962272*^9}, {
   3.736067487473854*^9, 3.736067505650632*^9}, {3.736067678222561*^9, 
   3.736067730033708*^9}, {3.736068091408441*^9, 3.736068092370936*^9}, 
   3.736068126746172*^9, {3.736068381446144*^9, 3.736068382198934*^9}, {
   3.736068444593129*^9, 3.7360684449737186`*^9}, {3.736068770850031*^9, 
   3.73606877140343*^9}, {3.736069116018488*^9, 3.73606911644902*^9}, {
   3.736069378772266*^9, 3.736069401519719*^9}, {3.736069898412277*^9, 
   3.736069901162999*^9}, {3.736070129825029*^9, 3.736070130130946*^9}, {
   3.736070485526927*^9, 3.7360704857940807`*^9}, {3.736115502167886*^9, 
   3.736115520737797*^9}, {3.7361155591524487`*^9, 3.736115559562126*^9}, {
   3.736115769811782*^9, 3.7361157702937717`*^9}, {3.7361695323703413`*^9, 
   3.7361695344088717`*^9}, {3.736248002082753*^9, 3.7362480053405848`*^9}, 
   3.736248063293035*^9, {3.7362711675400267`*^9, 3.736271173305934*^9}, {
   3.736271760077403*^9, 3.736271761097781*^9}, {3.736292843956057*^9, 
   3.736292844120399*^9}, {3.7362933421321163`*^9, 3.7362933422428637`*^9}, {
   3.736294022411599*^9, 3.736294022543172*^9}, {3.7362949767693167`*^9, 
   3.736294976917819*^9}, {3.736295875584177*^9, 3.736295898812854*^9}, {
   3.736337345211652*^9, 3.7363373600763817`*^9}, 3.7363374100997877`*^9, {
   3.7366226998584146`*^9, 3.7366227472464943`*^9}, {3.740916192529316*^9, 
   3.7409162159364777`*^9}, {3.740917006662414*^9, 3.740917007120431*^9}, {
   3.740917121492567*^9, 3.740917121796913*^9}, {3.740959626700404*^9, 
   3.740959627455364*^9}, {3.740962853137226*^9, 3.740962891171768*^9}, 
   3.740963601726838*^9},
 CellLabel->
  "In[129]:=",ExpressionUUID->"d56f1544-4f74-4bfd-b87c-cf81c55a58f3"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sequence length = \"\>", "\[InvisibleSpace]", "400"}],
  SequenceForm["sequence length = ", 400],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444348606*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"fefd9620-74a5-4417-ae5b-5c187f102406"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"alphabet size = \"\>", "\[InvisibleSpace]", "20"}],
  SequenceForm["alphabet size = ", 20],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444362134*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"52bc76fe-08d0-4616-89a8-e7efcfd1b89a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance1 = \"\>", "\[InvisibleSpace]", 
   FractionBox["20", "19"]}],
  SequenceForm["variance1 = ", 
   Rational[20, 19]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.7416894443831787`*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"dc8cb510-050c-4286-a25c-c2847a9fdc84"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance2 = \"\>", "\[InvisibleSpace]", 
   "0.00033240997229916895`"}],
  SequenceForm["variance2 = ", 0.00033240997229916895`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444391037*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"99d6698d-ae7f-4aa2-b154-a83efaa8cce0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"energy cutoff = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "400"}]}],
  SequenceForm["energy cutoff = ", -400],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444398684*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"627f049a-993f-4287-965b-12e26c3beb25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"random walk started from wt=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}],
  SequenceForm["random walk started from wt=", CompressedData["
1:eJxTTMoPSmJkYGCYACJGwaACAI1FAjk=
   "]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444407412*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"6d8ab2de-371b-4d9a-9a42-ca8dc4a1db34"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444415987*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"fc6dcd09-fa43-4ad0-8dd0-4b07441548f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance of additive energy = \"\>", "\[InvisibleSpace]", 
   "400"}],
  SequenceForm["variance of additive energy = ", 400],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444423581*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"def3182c-bbb9-4bb0-87ea-fb17dc94ae58"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance of epistatic energy = \"\>", "\[InvisibleSpace]", 
   "23.939999999999998`"}],
  SequenceForm["variance of epistatic energy = ", 23.939999999999998`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444431101*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"f873b53a-4ad8-4e9a-98f9-a8254938155f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"fraction of total variance due to additive energy = \"\>", 
   "\[InvisibleSpace]", "0.9435297447752041`"}],
  SequenceForm[
  "fraction of total variance due to additive energy = ", 0.9435297447752041],
  
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444438862*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"3d2831bb-08b8-4b9b-84bc-dbcb917ac58a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cutoff standard deviations from mean = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "19.427091854162878`"}]}],
  SequenceForm[
  "cutoff standard deviations from mean = ", -19.427091854162878`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444446607*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"8e6fbc6c-56b6-44f4-8d05-0baa44c54aed"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689444454321*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"cb6dc3c2-d576-4e07-aa7e-a1f4ed98111a"],

Cell[BoxData["\<\"Drawing \[Beta]s...\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689451611862*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"0807e1de-49f3-4888-8bd1-29f1c0104868"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.013103`", ",", "Null"}], "}"}]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.7416894517218657`*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"f94f13fb-f090-49b9-ad4e-a0a6f89bd510"],

Cell[BoxData["\<\"Drawing \[Gamma]s...\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.74168945173174*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"c7232721-8196-454c-9524-0f470dd6c070"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"71.239026`", ",", "Null"}], "}"}]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689522866433*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"56a9eb55-74fd-4c3b-8e63-8905b0ef38e8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689522875236*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"921f2430-fc7b-48e1-8601-1ef90bd9be96"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"additive energy of wt = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "753.2271507762175`"}]}],
  SequenceForm["additive energy of wt = ", -753.2271507762175],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.7416895245213137`*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"b7ed717b-461d-4ab7-b453-e9e5d347388a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"epistatic energy of wt = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1.447458020632439`"}]}],
  SequenceForm["epistatic energy of wt = ", -1.447458020632439],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.7416895245292463`*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"42884f7c-1690-4a99-bbb4-7f3da9460f6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"total energy of wt = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "754.67460879685`"}]}],
  SequenceForm["total energy of wt = ", -754.67460879685],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.74168952453679*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"fa50ce18-4e08-4dba-aa2a-29b8ccb33982"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.7363374262886047`*^9, 3.7366004063691883`*^9, 
   3.736600658338604*^9, 3.7366023112236977`*^9, 3.736605516160693*^9, 
   3.736622662513054*^9, 3.736629448131816*^9, 3.7366389244841623`*^9, 
   3.73677713978363*^9, 3.736777538580958*^9, 3.7408387988796883`*^9, 
   3.7409138121071377`*^9, 3.740916221923911*^9, 3.740917008088626*^9, 
   3.740917122554899*^9, 3.7409307481103153`*^9, 3.740959779244751*^9, 
   3.740962988300901*^9, 3.7409957206204557`*^9, 3.7409958082244663`*^9, 
   3.741000411007515*^9, 3.741433812740789*^9, 3.74152505112199*^9, 
   3.741689524544276*^9},
 CellLabel->
  "During evaluation of \
In[129]:=",ExpressionUUID->"0e6a5f50-6bbe-42c8-a270-ecb07924df58"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate random walk", "Subsubsection",
 CellChangeTimes->{{3.735309186184713*^9, 3.7353091913775187`*^9}, {
  3.735338921412415*^9, 
  3.7353389218467417`*^9}},ExpressionUUID->"8ffdcba4-206e-4abf-9c66-\
3331fca5a2c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"GENERATE", " ", "RANDOM", " ", "WALK"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SeedRandom", "[", "123456789", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numIter", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Generating random walk...\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"walk", "=", 
         RowBox[{"RandomWalkBasedOnTotalEnergy", "[", 
          RowBox[{
          "wt", ",", "energyCutoff", ",", "numIter", ",", "l", ",", "alpha", 
           ",", "\[Beta]", ",", "\[Gamma]"}], "]"}]}], ";"}], ")"}], "//", 
      "AbsoluteTiming"}], "//", "Print"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "PLOT", " ", "ADDITIVE", " ", "ENERGY", " ", "VS", " ", "TOTAL", " ", 
     "ENERGY"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPointsToPlot", "=", "numIter"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p11", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "2"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "2"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "energyCutoff", "}"}], ",", 
          RowBox[{"{", "energyCutoff", "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p12", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p11", ",", "p12", ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<E1\>\"", ",", " ", "\"\<E1+E2\>\""}], "}"}]}]}], "]"}]}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPointsToPlot", "=", "5000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p11", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "2"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "2"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "energyCutoff", "}"}], ",", 
          RowBox[{"{", "energyCutoff", "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p12", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p11", ",", "p12", ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<E1\>\"", ",", " ", "\"\<E1+E2\>\""}], "}"}]}]}], "]"}]}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.735338806149899*^9, 3.7353388968251534`*^9}, {
   3.735343562061551*^9, 3.735343562627553*^9}, {3.735343655162856*^9, 
   3.735343674790699*^9}, {3.7353456811309853`*^9, 3.735345681686078*^9}, {
   3.735382815428287*^9, 3.7353828162481003`*^9}, {3.735391784672995*^9, 
   3.735391797154351*^9}, {3.7353923070597143`*^9, 3.735392309692967*^9}, 
   3.735392417811624*^9, {3.735393101396289*^9, 3.735393102816099*^9}, 
   3.73539317818019*^9, {3.735395876694244*^9, 3.7353958770963287`*^9}, {
   3.7354061288171186`*^9, 3.7354061680853367`*^9}, {3.735408238071582*^9, 
   3.735408238199889*^9}, {3.735408568548231*^9, 3.7354085693554564`*^9}, {
   3.73540863029198*^9, 3.735408630836402*^9}, {3.7354087693724613`*^9, 
   3.735408769950099*^9}, {3.7354105737408657`*^9, 3.735410573968326*^9}, {
   3.735410631836471*^9, 3.7354106825868683`*^9}, {3.735425389476039*^9, 
   3.735425391975503*^9}, {3.735998225295422*^9, 3.735998258412681*^9}, {
   3.735998291281876*^9, 3.735998326668337*^9}, {3.736068339608787*^9, 
   3.7360683406522827`*^9}, {3.736069609384886*^9, 3.736069609807073*^9}, {
   3.736069992908252*^9, 3.736069993293927*^9}, {3.7361695823174477`*^9, 
   3.7361695869059896`*^9}, {3.7409596465971117`*^9, 3.740959652613059*^9}},
 CellLabel->
  "In[167]:=",ExpressionUUID->"32ea725d-e61a-4400-812e-6fe7506c55d9"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Generating random walk...\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAeJXwquf3bz62tFl4/lXINqr2/g9iN4wec6X20D6NHNK
3x0gXaVW+OA3kH6xT0XoD5BesmKNHIi+1adrDqJv/kxNBdF6UbFdIPrlrH/r
QPTEnqC9IPrGRau3IFri/jWev0Bah0nZS/jaa8czrwwaQPS8Xs/JukCawXLi
62AgvS9vGWsIkFbqTr8OoqtKbhSGgvgTTnqFAemVG6v144G0y4euFhC9rN3u
ciaQNpmwgy0LSN80uhUFog80hWeA6OyUi1dAdJXuXI9sIP1krteEeiD967yZ
BMP1145Z3Ws+gegJG9zqmYB0yG+Wq1xAWuXzMlc+IP0g0+eoEJCurjBzDAPS
klauxSA6u7CpRvQ+UJ9Im6wVkN6UOc3LGkj72k46AKJLtJOTnIB0z/zC/gAg
feu/oEIQiM/0XS0JSF/5vSE9BUh73N3LYvEA6J6ADxNTgHTA7hnXtgBpAH3a
7aY=
  "],
 CellLabel->
  "During evaluation of \
In[167]:=",ExpressionUUID->"01eeff84-f0be-4598-b5ae-f768675fbcfe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"326.283977`", ",", "Null"}], "}"}]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAeJXwquf3bz62tFl4/lXINqr2/g9iN4wec6X20D6NHNK
3x0gXaVW+OA3kH6xT0XoD5BesmKNHIi+1adrDqJv/kxNBdF6UbFdIPrlrH/r
QPTEnqC9IPrGRau3IFri/jWev0Bah0nZS/jaa8czrwwaQPS8Xs/JukCawXLi
62AgvS9vGWsIkFbqTr8OoqtKbhSGgvgTTnqFAemVG6v144G0y4euFhC9rN3u
ciaQNpmwgy0LSN80uhUFog80hWeA6OyUi1dAdJXuXI9sIP1krteEeiD967yZ
BMP1145Z3Ws+gegJG9zqmYB0yG+Wq1xAWuXzMlc+IP0g0+eoEJCurjBzDAPS
klauxSA6u7CpRvQ+UJ9Im6wVkN6UOc3LGkj72k46AKJLtJOTnIB0z/zC/gAg
feu/oEIQiM/0XS0JSF/5vSE9BUh73N3LYvEA6J6ADxNTgHTXv/j/W4A0AID2
7hM=
  "],
 CellLabel->
  "During evaluation of \
In[167]:=",ExpressionUUID->"818387ca-48ff-40f4-89e1-d1b6f877c182"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAeJXwquf3bz62tFl4/lXINqr2/g9iN4wec6X20D6NHNK
3x0gXaVW+OA3kH6xT0XoD5BesmKNHIi+1adrDqJv/kxNBdF6UbFdIPrlrH/r
QPTEnqC9IPrGRau3IFri/jWev0Bah0nZS/jaa8czrwwaQPS8Xs/JukCawXLi
62AgvS9vGWsIkFbqTr8OoqtKbhSGgvgTTnqFAemVG6v144G0y4euFhC9rN3u
ciaQNpmwgy0LSN80uhUFog80hWeA6OyUi1dAdJXuXI9sIP1krteEeiD967yZ
BMP1145Z3Ws+gegJG9zqmYB0yG+Wq1xAWuXzMlc+IP0g0+eoEJCurjBzDAPS
klauxSA6u7CpRvQ+UJ9Im6wVkN6UOc3LGkj72k46AKJLtJOTnIB0z/zC/gAg
feu/oEIQiM/0XS0JSF/5vSE9BUh73N3LYvEA6J6ADxNTgPSF6Qn/twBpAIBb
7fM=
  "],
 CellLabel->
  "During evaluation of \
In[167]:=",ExpressionUUID->"462acd55-5c61-473a-b833-9f5da9529fff"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.003666666666666667], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJzUvXk4VW0b/22eZcqceUiEKCIypGTKUEoZk6mSIdRa2zzPSZTMQ6lQphCJ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       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF1P8z03EcwPGF2Pl2p5Q4s2bcum4XndQuGnMrjjZactHhVqGcIju2G0vY
Zth8nCuluVFOKeawHeXK9YM6lS8p6tK6fal1mFUsX3buUt3l9f7heY//4Ek6
m8/JcsDhcKy//VPzuGl+Iwp7tmkjydbtE4EUVh/nhRxExqRurGdQkW/WznsM
7UJaD4WGli7WgZT+F0Vrd5HKPhtucSvygwLL4PfKwWbS8ksFrxbcN3mn0xBR
A+44Vz81MicDJeo4N0Z3FRg/E1PNPi0FdYFi0S28BFwlY2WFE5VgtotuxFhS
AWa0LRGN9HIw6EyS1R9/DRTN6x11l0TgMNYXp1oTglo73r+WLQDpSuunnz1F
4Iw6a6A4mgcSJVwSRVkALtw2sn4czQOtWpdisyUbJNHj+WMPueASJyfTUpUK
YoIG79ExFnj9/heFeC4MTNsjZOK2hEVv+vE9y+dyMxsskRlvqimpYGG183Lk
PBep32D2UnJA9sm36WbXPHBBNU41dRaAxLbd2P5gHvgo/6sTvqEI7OAHLWjC
BKDUc3IgqkMIDhrsv1pPiEAdA9tpGisDNeGvg6cDykHyrLudfKUCdDWJh0xd
lWCzfTDS3VECcpcfMO0cKaiiTdBT5FWgtKlvkWCQgWbGaOMpQg3IH1c9T0qu
BbWCEHV/uxy8kLsilRsUYPuqONn1G9Ik3h4osyDTW0KfVq4gOVO5NqF7HRhB
12depCE9t43QjtUjE1pSnIdvIGVU8zuGEukQ65B/5B5ytSSy/cATpMHc40We
RRJ4UfpWKzINN94VYENO+1li/X4jXyUGX/XyxkCXz5oEzBfJzI3x9SAih8SZ
Wvxe5LrX93JpCJLWUproFI4sproRKg4j/38L/APA3mgJ
        "]]},
      Annotation[#, "Charting`Private`Tag$10088225#1"]& ]}, {}, {}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{
    FormBox["\"E1\"", TraditionalForm], 
    FormBox["\"E1+E2\"", TraditionalForm]},
  AxesOrigin->{-359.63451857409956`, -382.28799447442685`},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{-400}, {-400}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-751.8803721838416, -365.6690701680956}, {-754.255121373545, \
-400.0007148029563}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVzVsoQwEYwPGDLFEWOqGosWItl7bm0kgdZWQPRziTFFo7y4bUzNqLRHOf
JHmRzZLSGsba07x7cHtx3SW3aSvHHiahTHzfw7/f479IPdLOJhEEIYNOZL6o
/5qjbkaXYuiWKhpHzy1NX0Fw16VcCYFmUVX4B7TYeWQCHItsClDZ0VA9up9h
0qPCMXYZreApvajFzR2jpULLOyoVhbN+wSl3P51zw1H0mXwa9Zz4bOXgXSDl
pwNMbCvITnD+bS+C5vXqJxmQ5Du7VWD1N1PTByo/F1fR5+DLkw4051aSetBI
sz2oVRcyoTaHOIwa8vO7BvFHEo4J0CFbKyZuOWr5+SCBxgvZ+WRQWua/Twet
AhedCYqzLi+ywfU0l1IFhj6042ipRzJLPnBUgbNBJAdbrximDpz0HJ6iLcGS
4UbwVaJYbwNNc0ZxO2gfSEjU4FPs1qABdwI9/NpHjpppZjY04EKq9s8L/gPG
q+qM
  "],
 CellLabel->"Out[175]=",ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzNvQd0nMXVP7zGlSRACMmbgAETakINJRBCQntDgARCNc3Y2LRQjIt6771Y
tlzk3mVbsnq1imVZvffee1m1Ve/6/efOM4+8kleytH6/c749Z9fe0eydO7fN
vfe5M/P2Jr3vvvlpk973X22653WdTdu++/4r3Xv+uVWHNS1dolAs+Y69N9yj
oP9DoZA/+Ot7+hBfrvH/1/k/S6HqakddYxv/dgP/XMY+plBfUYTk5BTUNHXI
zcN9nchKS0FWXhEGRyf/d7r3JGrKCnnv6sZ2ufdAdxvSU5ORU1iG0QncIMZr
ra/kPctqmhT/EF37OluRwQCnZ+Wjf2Rc7lpfWYKkFIZCs3IatZH+LmSmpyIz
l+EwNvEab16FQYZaTUMr5NfESD8KstKRlpmDnoFRGWIbGzwlOZkPvnomHTJi
fGHjegjj03T4OQoTw6CzVQfuHq7Yvt0Y2bUdmBrugqedGSztHGFhbICdR/0x
OgnFK/w3t3LapYZ7Q1fXAO47XKGro4/UsmaMqZrhaGoIO2cXmOjp4tD5KI5p
fXEKDNh3Fzc36OnqIjqrUvGqgNXTXAobg+2wdXGHg5UJrD2Oom9sAsUp4diu
ZwA3V2ds12d4VbZjclSFvc7mMLV1ho2pHtyPBGB0CoLGN6MyMwzmzqf5mFPj
QzizzwXGZlawszaHtet+9I5NobmU4bJtO9w83LB9qy5isirukKj0Mv/ntxgd
HkB7Wxva29vFuw2q/iEOtSYrDkYWTugcnhJMGMBOC0MEJhTzr2GndmHHkUCU
ZsTAxMIFvRPAcHsp9HUMUNzUo3hBcGJqagLdHUqCzzhBn7eho6sHw6ommOtu
QXxhE4cX57Mf7ofPIi3aD1ZO+zHG2rqqM6Cja4ZW1QDO7bXH/nPxvG9m+GmY
OB/ACOPUC2IuY8ODavNoR1tbO3oHhlEYGwTnfd4c3uSgEnZmBohOyIWXsyXO
xxZweBdO7ITz0VBUZV6Arqk7+tlchtqrYKqrh+w61fRcMMnm0tkxYy6dbC7t
DWUICghAQGAgDuy0w1ZdS8QlF6K9JhdGuiaoVTGAI0rYGBsisaASPrudcNDv
kjSXKG+Y2u/FCBvh9pnsqSxIgo2lJezt7fnbysoafmHp/GdjvQ0w09NDcqmk
JhO9dTAztUVVWz//Xp0ZA9edexEWdAq7jkYIRRrFATsTxBbUiSn9DuMjnfDy
cIatrR0fw87OBm67TqG5toCRfjtK2gb4L/NifeGy7xB8Tx/AUb8kSfBGe+Fh
YYT0inp42RohsbyDt6sasmFo4Yru4QmZO415cbC3sZ6eirWVFXwvZmJ8dBh9
jEtCxHDAzQrHzwbDzdYcxa2DvLWpMAaWrscQc/YAdnuHS12nhrDP3Q5RaVXT
U5kc6MAxRllreSo2Ntix/wQyUqPx1Tff4ci5ABzyYNzRMUdcYgGT3HBYOh9n
9k56+Xu5wjcyCu7OTkgukqSyi5HBxsoGbcNTs5gzNjKIDqUSHR0d4q1Um8kU
Ag46w9HLj0Of6GPMMbNHTavEnIbsS4w5nghmzNl9NEr8ZhwnnEwRmVt9Rd6Y
7vR0dRJ8Jm/0eRu6enrRx/Rs6+ZvYeW6FzHRETDcvhXno5IRfO4Ajp1PEbzu
xz4bIySV1uCggzGSqjt5c19rIQzN3NA9ODGtO+MjQ2rz6IBS2YG+wWG0lCbB
1s4esYlpiA06jR83GyAtuxA7bE1QrJTsREtFAiycjjLu7Mc+X1nQRuC10xmR
yeWz5tI1cy7dvYyO/Ti52xFnLqSjlnHaxu0sh1CaHgor51MQ1gcRh9zhHR4O
dxcXpBU2S4JWXwwHays0DU7JuvMG/+cWdDcWQH+bLjJr2LRHWmFuYonSll7+
s8q0C3DasQcRId7YcShIDDCMPVZGiCmsE8b/VxhoK4GBsTVCI8Kwx3M3QqKT
MDIxgdAz+3DgXJwgcw9cTQyQXlmPg/bGiCuW9LG7JhP6ps7oHpqQ1xJVcyG2
//AD7Nw84OrqjsScSowzmXUyN0R+kyQZ9TmRzK4fwaXzh7HjeNC0rHs6WeEC
k3V5Leln1snO3AIHju6HnbtEsfLMCJg7HOSWjl4+no7wuRCNnc6OiM+v522d
1bmwZOtE6/A0xf4pQNJi0MmY39PTifNHPKBnvQtdgwPwsjfBsbAUTEyM4oyX
I/Z4x6AmPx66RlZo7huBsiodOjpmqGrvn6bc5IgKOywMcP6SZGCjzh9HYGw6
ChKDYWDlCtXIGGpzY7DdwA5dA0PwP+gEt0PBGJsYR7T3PtjsPAG2gsmUG+9r
hwujEq28fb29UPX2MVM8BC9HMxwNTMTE+CjOedpj99kY1BdeYqupDVr6CbUs
GGw3RGnbgELyb36JsvQofL3xc9jsOCdpeD0TFB1dxgEVBjurYapviIzyJqa/
rnA7FshRij2/H5ZuJ4iys4hWkBzMzK4ZbJitsbAww/c//oSk8lY0MT/AzEAP
llbmMLR0RSWZZbaCntnjDCPW39DQEMeDEjDB1vRXBWY1+QkwYyuEpYUl9A3M
kFmhZH5ANw65WsOY8VrfwBB+sTkc6466YlibGcOCLQ+GxubIrmiRRQNTI/De
7wwDI3OGljVsnT3Q0D+JxuJUmBgReHOYWNqjsrUXU5PD8D6wA4Ym5jDS18WJ
wDhmhCGIdQtX2uCj7rBgrgZXxMlxRDEzbGhoDBMTQ3gwB4AtwuiuL4I90wIL
K0voMY3JKG9R3KFOqZ9haECF5qYmtLS0sHcrWlvbMDA8zmfTo2xBaVk5uvuH
Zc9wamIENZXlzA1soZH/IayIivmWJcWlUPb0K2Q3cGJ0EJXlZahvbic7w9sG
VR0oKy1De1ef8JluRJ+qm43aKt7tzI2VbIuqo5WP3tU3dMVnZsPXVlWgur6Z
LLjsmI4P96GppQNXXhNoqK1CRXU9xianveIBefTuPtkx5Z2v4cTfLn7e39/P
3Jc25OfnM1ePfd6AgoKCK/+7hf9lKQoLC+nrlX6z2m76/2k/9r+r+slt/1/1
KyoqWvBv8/LyUFtbq1gyky30pzNnziAmJoaBKCkpYW1BQUGIjo7m324SbYHM
C2R9+De5n7+/P+Li4ma0+fn5IT4+fsZvfX19cfny5Rn9fHx8kJSUNKPfuXPn
WNyVPKPf2bNnkZqaOqMf4Zuenj6j37Fjx5CRkTGjH7VlZmbO6Hf06FFkZ2fP
6HfkyBHk5OTM6Edtubm5M/odPnyYk1a9H7WROMzuR3RVbyP4Hh4eKC4uZibo
Sj/2/arfUhub42xWEbeJHHV1dWx4qY1QrKqq4t9uEm00vZqaGv7tZrW2xsbG
GW1Ewubm5hm/JVKTKVHvRyxRMqdQvR+xrrOz86p+PT09M/olJCSgt7d3Rr/I
yEj09fXN6Edtg4ODM/pFRERgeHj4qn6jo6Mz+oUzB2psbGxGv7CwMLa2T8zo
R21TU1NX9ROv6TaC7+3tzb/dItpCQ0Ov6ie3MRizWVVfX8//TAonD09sampq
mgGioqKCrx3qaKalpV3FvtLS0qtYwOSF+7Xq/UhEuru7Z/SjNpktcj/S0Nnw
SIrJSKv3I+2R225Sa5vNKtK8oaGhGf1CQkI09hsZGZnRj8RQZp+6aI6Pj1/V
T2ap3EbwT5w4QWydZhXRbzabs7KyZrPqDrVpE6qM5IrHRVt5eTlfq+jbu6KN
FFqW5Hc0TEduGxgYQHBwMEdpjWhjYsANANPe2cOTPSGhbmhokJbNB8UfiOxl
ZWX8mwyHxIrYyYznbDhk3mVDcBUcEhX69nv6XEJU0PBrebBr/ZrJ9f/prwsY
BbT/9eWkdFQwdmn3a9s9/sjKLdaSanZ7/aFjuQdl5ZVz/1rmHTGHxPAqGViG
xJQMfLLZFT86BKChnRtGPDAPKCYrfI24SgyWo7ioAGdDE/GN80Xo7opDk7Jf
Qu3+hU9sBWdoNXMU86s68YVNOPR3X0JLpxTM3bdw+t6oLhnILGnFButwmB1I
xtrPvsSfn3mGr4b8j/csBKpsHUZH5WgQ0/7yJItoJianBEWvHp1eaUUt2GR3
Aa9udMENK29CakryIkZfKTrVFKXg0HF/ipums7BdjWXwdHGApaUVXHYdREOn
lGDKTYiAraUZzK3sEZNSSE7/tDevrjWyh55c0IRN9tHYYHIadU3ti0Xul6jO
vcRCMXt0yxRi4dluO0M4HfIhvwGnPO3guNsbymYWFG7TQVRaAUMyFNt0TCnW
VcdNtiZLhVAk5jVhg80F2B1Px9pPNuCZZ57mUkivuxYiXYrforOpCN4nT+D0
6dP8fZLZ7ujLeRzGIIv+TVicmlfbJaE+OYKi/Bx0D/HlHt01OTA1tWGT9oOd
62FIUdYo9tiZISqrQuC5nFtUMuhkcMntqa6uFvRdjvicBjaHSLy8zg5Llq1C
WmqKYs4J3CV+VFlZyQHJANU0WHEbetoqEBoUyIekdxBzlFMySwX5x3DczQpe
viKvwsKuwuwM5JbVsvVhEmnh3jC2csWFCB+47AmYFubzu2xwPjFfTTSkaZFT
TmsTiQ1zJcSUl+FiZj1nzSYzbzS3dV5zRuQJEgwZlpohWSUkujo7Glt1zNDQ
PcLRPutpi6+/2wwba0v8tEUHMRnFyE7wh4On3zTaPjusZ6EtSRIRUJIhCd2Y
jFp8bhUJhxNp6BuUuHvnQiRIQo4W+nGc9nSA+7EQiuwZHY/D1uMkWx/r0Nqp
4gDL0i/A2NoD3AGZ6oOruTFic6s1qt9Kgd6FtBp8bBoMV+8srP34Mzz99FMy
Mrh9bgSvqKE0w1vRWpOPM0y+fVjks3+PK9at/xJJpU2oL0qEzlYjnPPzh8+5
s7iUVISRnmbYG23DYZ8Q+J/aBx1zd7T3jWlEdJVgYERKNdYxCr6w1hSKJcuQ
kZ6mWCyWv5zGkuIuH9/zTAx8UVinxGhvB8ICfDj251jAEZ9cyIG31xThiNce
7D18EuWNXcs0IHijYHFoYhVDMAL/tfLmD0YWjJsmn+JnAmjQ5Uqss4zAznPZ
GB6V9P932gL9ueC5/6VyrDUJxl6/PHz40Sd46qknubtNr98sFjizNTOAkxvq
e7GMY/3cO9tZ7yXIZE7jNYBf7WqQ9lMIzlRJ8QshBOTknosuxScWYdhqfxY9
qj7FnJDXiDaKOMhtVYsv1ccgC8NiQuE4L8ckG8M7qhifsQkcDC7AyOi4NMav
5xmDohwiM4v7Nbmpsjm4WRBpki3bJyOK8KlFODYa7MXTz/yZgZQWll8thkjq
7JWigVXcJzgWXoiPTEPx2KubuBu/Yf16PPnkk9O+wS1zDzK/DP2Sf65kg0zi
SCgNEoKTkcV4+OGHaXGg1UJxfSPcKmg0PjHJ6J/PRzDfFYCs7BwMSwGX9sB/
JZg8xoB7+edyJvvHV3EvRTvIsvzfJggzOj6BPX45XMH8L1Xgww8+wBNPPEEY
SCP8YjH8JQENCAjgSvBrQZiRsQl4+mQx3CPxxMvrZLLPCVyWUVr6KKKcQw8o
1cUCc8VvBInI3Oxkw3xoHMjc/gAKdueegDwGJVdI366hB//DP5dhaGQMO85k
8qUxNKl68fRR5+1vBeKDw2NwOZXOBCcY4cnVTNkmJcR/pq3U/E5QfmBoDE4n
07iZX/u1KR579FFGVUmjVmkL/HaBNrkFjifS8b6BP9Y8/g8WJOYqrg+yHGyp
BkbgcDwNHxgFICKp4vqArhbo9vSNwPpICj6zCEV8dgM5dxK6KxYLWdagOwWV
u3qHYXEwibt3763fjkceeViOd7FsbuCalYcStkwgp/3ATtUQA56M9/R8cMeD
f71CZU2Q14g2mjulCefQnIsXL1IGUXG3oLeyZxDmbAJrjfwRn1V9TfCUDiPN
uIbSrBHg27sGYeyVyOgTgQzxmHKpBvALUhop1FrJfMgBFvPG89g3u6wd77/7
Dh5l4k2GZ0pbWfm94GhzRz/0PC/hG8do3P/4i9xiFRQUaA33XsHMxvY+6DK4
Hxmdh3dgHMbGRrVH9j5B3vrWXmzfeQnfu15EUXXnouHJ4ny/QLK2RYWf3GPx
jcMFBq+DK8rE3EDDw8PnEGNmvxUPCKDVzT0M6EVstA7By29+hKqKMsX4PCJG
7l1KSgoleTVJMD3SaGtrUzwoaFDZ2I1NNsF484dDSM+vng8ypc5pyufPn59P
eB8SkAsqWvCj20X2jkVVU8+YtnL7B0GIsrpOfOt4AZvdYhi8bkxNTihGtBWB
PwqgxTUMqFM0NloF4IVX30JVZbliWFugDwugBVVKbLQJw+vf7kF2YSXHdGgh
QOUsjKqjGQXFlfQcU8SatKBNoqIgAxHhEcguqpqushjsaUN8TCSi4xKgVA1p
ilseEXhllTTjO5c4fMkm+5cXX2eiVK4YXAxepemRMLZww+DUlexQSXI4tm/V
x4HDB6C7ZTuistiER1S8Rs/WxQNuDlawdN4P1ciExqjvUSEuOWVt3CS99vUu
5JfULAgvKogbUqG2pho1tbU8E13D/t+ilGIyZVUOjAzNUdctheH0nN2LoeVz
MZd/zbhwGjbuR1GenwhjUwd0k/SPtMPK0ADJxY0z0JV1/TGBbnpRE75yiILR
3gS0UdHFnOheUXPmOTZXpsDRzhYOjo5wZG9bWxucPi/VyE2N9sDZzBAhySLB
QvVnVrbIq5YeX7eVZcDJyQ1RF87Dac+VzMQZD2sESFHsjIQKWRLyAmk9I4vy
qPhbelEL1luFwWjfZbR29DGvaULRpwF/eSEli0IwZFhqloXnJscwODBAjwbY
6PR5MwukpnOYSAg4BGP7/RimsqoxJWyt7JBfKc2oozwLLs4uiIw8D2dPf3lC
fnNkiOjBDuX5iM9UyveY+FtKYTO+sI3EF2Zn8fRzf0dVVaWid54J0dMPgiHD
UjNochJmtLcZ1ga6CE+nPGE/HCwtkVrOn2WhqTARtg7uzJQGwW7HCVGNNoHD
juYISi2aITbkIdO3P4mhk/IascE6Eq9+4SxpOKO9am7ZuWIZ5eTLyKAKDfX1
aGLud7jPQXynY476rj747nOE69EADDBR9D3gDLcj4Wivy4eejh7yGzrRXpUB
HR1jFDX0aFTDJwWC8dn1+NIhFhtNvfHkM8+zCZQpehaiizKCVbkxMDczg7W1
NazYW2e7DqKyq9DbUgkXSxMYGRvB1HYHL2YhmxbrewSGBgYwMDTCyZBEXl+j
CcGnBIKXsuqxnlHwlc/t8IdH/oRqxuzuhSO4FONjI1D19EClUjHp6u3tFREQ
vUaH+rmPNjAyNq1eVBrYqWxDe2c363k1Yk/zz2WIzajFRvtovLzOFqXlNQvC
SdMq8oyAR/m6z1n4QZFC/9BY12LhyRbrz4JwkSnV+JhF2M6n0njJ8OTEhKJj
bqCavROmKjy+fVYADWOhHOV/Ptc7iEcef5KtnxUKpQaga0QbfafH63N4J+LR
reI5AT44oZKHYC98YIT7H/wjaqqrFe3zgKcy4lkarU4SWRv/wj9XICC+Ahts
oxl4Q1RUVfO0NYshWxeikJpY97yA6xdXzvMNnr7ZeOmVV3H//feRsWnRViRk
uJRx84kt4zg/9842KJYQRYu1hvtXAXd8fAwf/+gokfp9Xdx7/wO0qDZfH1yy
pVP8ed7JiEKst4nCc2//xIwzo/PkJD3tbtQW/t/450qeJDwRXoRPLMJxKDgP
L730Eu67915eRNKgrb78XRCFkmtHQwt55u6p17/BsmUrmI9bMQ9czSpDBUJs
CVW8KJCmbNchke2y2x+B4ZEREjoiiKJuHtmmx1GJiYlzqQ7VIFGN7kvyMOOT
OBCYh08tw3H6QhFefPFF3Hvv7+kxu6J2nmGocoIexfv5+c2nQi8LKo2NTWKf
fw6n0hOvrGdUWkbrr6YRFqRCr/DP5Rgdm8Du8zk8teN+LJqKKDSivSB5kQot
l1GClye6CNmgy/MhOT+8/xWTHxoZh/uZDHxkEsxNFZVLMJms0hbuP8TkKa/l
ejqD6cwF/GeDAZoaGxSLBirL82sC2V5m878wOooPDAMQmlCOUYbs+Ph4xWLl
mYrbqJzrNSFopOR1ja1wPJnOl4I3Pt6C3//+Hl70UX4NeaYKqtOnT2uSZ/pT
Z2en2B+0HL0Do7Cn1JahPx585l9kn+YFT9VDZHuuIcdvCNFQ9Y/A7lgqY2UQ
YtKrNUFekPy+KajS3TcMq8PJPGmWkNuA0dERXghElTPF2srHvwQru3qHYH4g
kflBEXj1nS9xz5q70NjYoDXcfwsad/QMwexAEt7T98G9j7+MOkZjrYG+JSjb
3j0I0/1J+MQsCMl59YuGJ8vx2wJeW9cADPclsGAxgsouirSV3/8IYrZ0DPCU
1UYWfGaVtDAlHiYu5c8jW1SmRPZ2DtElK93V1SWqppajSUnJq3istwzBi298
zNS5XjEfeKo9pMdM1xDddwVB6lt6sNEyAO/qeiO9sF4T5AWJ7nsCXnltO0+L
feMYheKajjxtBeB9Aa+2WYXNrjE8eVNa25mrLbwPBLzqph78wOD91ykK5fVd
OQuBJ2UwbsFgTwuiI0IQGBSGqiYpCp0aG0JG4kUeLyek59M2Bv7q7WjEhZBA
BIdHU4GQQlNq5UMhRBWN3fjOORo/uESjrK4Dw8NDJESZC8FNjpxG+9uw09oY
Djv24cjeHbwsv76jB+Gnd2OroSUv2zTT3YrTockYG+rBDktjOO3ywh43e5ja
eaJ7eFxj5LRWiGFZfRe+d4nBOtPzePbvb6C5qUGxIAQVv8XwQBfKS0s5THqX
lpagsbULpenh0DezQy8Pgplj42CGgEtJ8PM+iqwqac9PbU4sjC2ckJwYC3Pa
d8gzAZ2wNTZAYlGDxjTLR4LXRTVKbLQOxdtbDqOoomkedGekWVqqUuHsYA8n
Z2c4s7e9vR3OB6cgL8kfuhaOUPFwbwwHHE3hezkX/b0qDIoYsLmIskG2CAzw
hste/+k48KyHDfw1pFnIv6OQhhYssitrBep55a34r3MMtnnEoaGtN0MD6nJC
guwJ/VwGo2ZX2C+mJif4Ys28CzYwfd7MnciCpABs+uobuO05hMN73bFVzxI1
yk6c3e/G5MEdYeEhsNLfhj2ngpEWHwCnKxmW8zuvzrAQ+anKmdK8FAN3d3cL
NqxAfqUSX9pFMrMQh7qWbv50lol36jxzYgaQg5HBMe1SzBL4vMsBsHA+gNSk
i/DxC0JRZT1Pplzy2ceF6vSp4/CPjOepo4LEQFi5HuMVMVQhc9DBHCGpxRqT
LZ8KFHLL23iO7jMjb/zp2ReZwDcqNKE8Z7Klhy2pxrq6SClpxkB3HWzNLVFQ
38ml3tx2H+qamtFQV4fW9h501OZBb7suMqta0ViShO06piht6tWokZ8JEaGq
Qcp5/vv7fSivbp4Ht6utBbldOZdDYGpsCH1dfew55ot+Zrq6G0rhaGECGzt7
WFla4ZRvPO+bEHQKRgYG0Dcygc+FdJ5b1oTbOoFbamETvrSPgjFbatkSnrIQ
3FYJcRns62Xio5rOUVNczSziDfzJ8vIZ6cE+VQ9UfQMaMyufC1Ro8+DnlmEM
FRbiqIaSF4KKpgVkvZCL5PwmDo9cnbZOSkNNKRIXC1S2VBsEkuTkUbpmvfFJ
1Dcp54Gn2S2hOiWqGN0gkBwdHcYba3/AWuMA2BxNIQdVkaAB6BrRRrUflD7R
4JPImk0avUGwiELn1la2GKZW4xPzUNgcSWEu9sjleUag2vtZmqzJLdkkJhCd
Xsd8vhA4HE9FZ3cfSYHi0txUmd83+VJQOZKhSyUEn+kfQlOrch5484vClwLJ
kZEhvL1en0dwrt6ZGBgeU8RdH1ApLUE55qDLFTzKdz+Tie6efv48MFZb4N8I
CgQyoESBT7bvRUub8jrhMQowT+W9L805op6+ObwIKkZbZfhGTbooF+cTU8Ij
+D0skh8Zm4herFLQjiC2OCq+E8iejS7l5TZeAblQ9UoUvTCPyNL+h0uXLs2l
FPSctKenZxo8oX36QjHWWV3A2h/d2BSU84KnnSfE6GtoxPcC/NDQINb+4MRJ
fTgknxZxRaS2/PteTdjalUocDS3gpDkWVojePok04doC/1FgPDExxTGlcsz3
v7XjuVmtgW4WQAcGB/HJFg9OBqL2JDMMYdcHVJK4tvYOLhlEhnMxpdQWqq0k
bxFwKQ+153w2h0nFjgSIkTZ4sZJM2/pIkrcKIoyMUmlXNk+5vr3BmA4mUGgC
qi7J9Ox+Dkmm53L0QGObkIrevgGs0/PCx2ahCIgv51vSaPMOpR8C5hmGweCK
GxAQoGmYcrEZRR6GMtItbR1wP5uJTy3C8PK73+Guu1bT0Qoah1kQS3UE8AGR
BfvQOAhPvvIpKivL2Rz6+Rz8tAWuK/jaPzgK51MZ+Iz5AX/91ybcufoOkm6t
4eoJvvYOjvAnNh8aBeCJFz+Esr1Ve2T1BSWk5FQaPmULdUx6Dd9RLwnilMJH
W+AGghI9fcOwPpyCdYwSf3ntU0aJ2yl5tmi4suYYCkpQcZfl4WR8YOCHR59/
i1G3bT5k51Yb5tkojHjbMl7UZX5QSqsl5TVqgrdG7eekMadOndIkyrSTjh7+
GQvIyp4hmHgl8CfjaUUt5+aBTDvlKE1+DSUxEYSgBJjBnni+PyiNedW9vSrF
GW25ZipEgqq4DPdexqdmgfjrax/Rg7dpkTilLXAzIRI8o2Thh7WGvnjkz69h
9R2/I+9vQXDlckPau9/FYoArNSxLMU4nsHR0YHj0Si1Ib3cXFXcLLlyNk7nA
qbqxE/p7EvCujjfue+wFVFaU0WRPLgSn6ZhpagwJod4wNDSAoZ4+vE4GYphF
lKrWCrhYGsPIxAim1m6oVhI+E4gNOAFDfT3o6hvhTOhlftCCppjJQnC6vq0X
ersTsNbAB39+6W06eUixIAQV0mNmei5GNaw38M9f8fiptSIdelt1kc3iyu62
KljpbsPlwioEH3CF68EA9A32wYce/h8JRkd9EQy36SOnph0tZWnQ2W6AooZu
TQkWS4FyVUMXNlkF4SMjH2QVN6BX1aM4sRAtVfwWbbWZ2L3TA56envzt4bED
wRcykZvgB2N7D7GJCfD1tINPdAxc7eyQVi6VMTYUJsLeaScu8yKKk6KIYhyH
nCwQnl6mUN/wRF4gpVvJkyNjYCFEoqxWiW074/GJsS+e/tsbfFcfE4ljGtC/
Sw0cgZHBqRkHxW0Y6GlGRppU6ULvNPb/ipoWFCQH4qvvtiAuswSVRWnQ3bod
celpcLJ3Rn7V1bUsLruvbHfSVMxCjKB9CpQjoWQvW52nGULZQyrIe2/7STz1
/Gvo7upQzDcjMkYEQ4alZpQksb8JuZf9oGNsjZ07nGDIwv+zofEYG+2CnbUt
cqr443q0lWbA0ZGhT8VFu32vFBe5W8EvqUAN/ZlGzkYobkFlK0M7FGv1vFFS
3aYJ4znVsiY3DsYWLmjvH8XoSB9io6LQ2N4CLwcLnLsk1WplRZ+BrfsxlOQl
wNBM1GqNKmFLB3TNSiLKamkrcCusasd3LjG8NrO2RXV0MbhNDffi8A4rNvZe
nDy0Gz9tN0Vt5yDKUkKhq2uIU96noK+rh4j0ata3B542Roz9B7HPwx6mTgeh
Gp7UiJudwI3qRL+2v4AtDDdmPo4sBDcpmX0jxod6cTGC+bo+gahqUgptm0JJ
djLTmXNIy6+Y3nw52N2CiEA/BIRFQ9k7rMnS2susrJKSfZS4bGrvO7wQlDSt
Jg5CQnMr2rHJNoIXHdc2Ux3LlOKgtkAdBZIZJc187Vtveg51zZ2LhifbQUeB
5EB/L17+9+f4xDRQTnkpDswNVLO3Qhl6MlASUCko6WbrW3J+I/MrwnnFXUfP
0H4NcNeo4RYbGzuX10JWg/1M4SLIkFLQzB038lyYb+Q1D2QKAchIBAYGzue1
uArISXlN+JzhTPX53b3D+7RlmJuAF55QzPzXEA6PuYZ7tYXnKmhL01lz9524
94n/Zd5gGKyYC9vdN7zn+uCu5HDvvvsu5vPcjmP+CRy2rci/7b4+4Ku4QJDB
pj2qd925Gvc//QYL0YL5k+fegVFPbaXYXSBPId7dd9+NOxls36hcjjzl31i0
o9i1WGmm02SysrIE8CvIi4MiEJlawwvKaJ8Mi9V2ziN7JLZ0ZMiJEyc0yZ44
iUPhKWQlLLmayUoYj/4Gh8c95oFMbZSYvIZUS5CX84D1ZEgWI3oIPM5mUQWH
Yoe2XPUUosgcehY1rcbDL6zFJwztXSyuHxmbcL8+uCs5oe9Zswa33norXv7g
J3xufQFeAXmUkxBqpTVwiZsk6zRIfV0tXnzvJ06Vg0H5tGfOVVv4e9WIQmUg
//jUgPEyHIdDCijh5XJ9cKV8F8W/3T0qnuuiWp5joYWYmJhUOGurP/uFeJAk
/eNTY85F2rU5OTmlcFqs3tDpSqQ3+wUlqNj03vvuxxtfWHJsT0cW0ywc55Fq
cj5pv/0c+kJHbVCl9X51mvT18nhLToCdjS4hYRersOZhyFxQDvMaynOIfy6T
cmF+OTyp5Btbpgnyglh5WMCjPYG2B+M4UfwvldtfH7zlbCrduGP1Xfjr+4a8
RDLocoXws7QGuoLTZ82au/Hb2+/ES5+Y4wu7aIQkVtleH1yJZ0T/hoZ6Xtr6
ymdW2MhghydXC6daCzk+JihBCn3rr36DFz+24A+lLqTWKKznBqp5Q50sxxLQ
VTw3uIatjA889AjMvS5hg00UA1zNz1Rls7G4PnkeHBycHkmmDWX7mlo78PZ3
O7GOCck/3v8vBvp65xuJfkaIXkOkTwpCdXd14uHHnsKHW/dzbycuq16hCfyC
WHtSiAyh39/fh1ZlD8+ASTVgjebawvUWcCmjZrY/gTt8l3PqoGxvo7FMFgJX
ihmY2z85hvbWZrS0KqnUfvr8w95u7pSoBobVTiGfhJJ1bW3vpPBcU8hwRpCR
0nKm+xPxkUkgXvr3evKmFQtCSw6zxvo7cWy3M/QNTWBkoI/dR89jaHwKFZmx
MNLTg7m5OT8eM6OUzhgbR8ip/TDQ14eevgGO+ERSzY7GMOusmEt9Sxe+MD+H
z8yDKQe3INwUS/mD6/GxMV59egP//BXfD1+eGQk9Uxs0qAbR11EDa30dRKVm
YY+TOU5dSOGVfpcDjsDccS8qS+lIaWOUtKjQVZ8HPR195Nd2aErKnBPYNrb1
8OQe1QZklbYaL0Rzmdq0VKXB1ckRLq6ucGVvR0cHnAtMxOhwPzq7VBJfb8J5
T1vsPX+Jn4s9Lh7R99Tm8vNnAvzPwnHXGfHkfgJHXSwRmlYyIx1DJw/S8XV0
vBzZh7Piby0d/XyPJsV66YWNaG9rFclgzZkLMgoEQ4alZhwUt2G4vwPFRYUo
Ki7mpaL0fLuuUYmO5gocOngMBdVNqClOh8HmHxCdXYK4cH/4RsRD2dGO8wfc
YOG8F5di/OG82/+auRg6/Eb2hahE4ZxQOCrc0/OM53nQZ195h3YHksLpzzMp
OrSNwMjggoKCZpe9qBqKoff9lzAyNoY+k9+j5yMxPDGJ0MMu+Pb7H2FmagxT
GxeUstlSKs1+l4/EJMYVbzeejpkh67JNOy9QqGroxCarQHxocA7PMayHBvoU
mlCeO+cx1AY7K2ukFdXz+YhTV5EZexZ2u87yB3jDI1INR01ePPSMbaEcYegN
NsPS0BAppc0aldFPkLW0uo0j+JmZPzLZGG2trURW3cXgSEbguJsdDM2ssMPd
Dc4u+9CgHEJLeQZ0fvwJzu474OzkBJ/AZEyO9OEg00xrJ3e42FvA2uMk+ken
NOLoL4hY0dCF7bsuY63BWTz74r8ZEfsVC0JQrjRsa6hCdo44WCmnAH1D45gY
HuCnPmVTG1vzKmqkCjm6VCHpUiwuJqZBNTSmMQ8eIGxDUVUrQ+oM1pn5obRW
uSCcNC0qAWKiXZ1KPP/K21hn6ofN7hdR1dgtnsBpDVRaAQfZ4l1U3c7LNLfs
iENpTfv2xcKVDWOwmHxuWTMX6w3mfqhu6to2NzzNLg0dQMqCTQGPrVts8n9/
fS3WmQdCb/dlVNQpxRPauf0YOv/w+PHjmrwL4jXZj+AZZBigqlxuQzaY+VL5
3JZ5RqCDJsl2qNkNTf5LqMy9DiVe/tdnbALBMGAToDrVn7TlXqg62oMDyChu
5lXWRvsSUN3QvllbuBECbnJ+Az4yDuALcUlFPVpammms768Xbicz+a+8/QXz
s0Lwnx/24pEn/oyhwYHrhkt0qKurxmvvf80PVvtY9wjViy0arnzY3AXBNKoD
uSwOa7M8lERpK1GCooUoRwvVuJRdz/Nr1oeTKFf133lkjB59ziPFdOzu8PCw
qAJahthMqZCLsmC9AyPfXkN6qf0a0hsrIEen13LI9MC8vqntG20ZdlEQNjyp
ih9xtk7/MKprG3jJ2VfXC7RD2Y631uvzGph1egeg6h24XqBS9FdfV4d3Nhpj
vfUFnotqbG5jGE+KAjotgF+alq8h+MeV88qrT7bvQW//oPZA46fJoMQHX1vy
JNRuX57gUmzUVhMkoMLSMGx9YkrFOWU5GBuf+EJbZUgQyBLcM9ElPI+zPzCP
wZwUlY/XpRGJAjy59y5HYngi5FAwz2uJ4lLN4OmgZwpM51ALmdSJgip0tNIv
bvoFnnnzv1jHyH0ktIB2I36uLQsThdBRqdo996wh/xpPv/kd3zZ5PLyQF2Ct
uz7gUsxOEeS9996Lp556mkUYmcwgh+MUz3bhM23hJwvkieYUitHG979/oMdY
G44zUVKO61NtgacKhlIl7EN/+CM+/NGdb1T1iS1dPFBZuNMEUNry1d3TC9Pd
ETzF5XexXPGJNpKdkZGhSBdAm5ub8Iubf4m/vKvHyRsQX6H4+BqSTUfez5bs
Gwhl9ndxwrMaNVbwkn3aKvrnZ//Ctzd+ZhlO2xs/mmcYAkOhAlOi+SQ8Q4xA
zBxhSlFSVgldtxBefhuWVLVWWz5mCri0a2rF8mVYfdc9sD2SyBPaESnVH14f
3JW87JkE+6/P/wXdqgG+YNGjj6i0WrEtSQvgWRIfxsfHpep3DI1OwulkBl8S
YzPqxAaqBQVEdFjfJEqzErBvtyc89x5AZgnfTIzJsQFEB3hj586dOBcci6Fx
qdSisTwHB/fshKfXERRUNWsKOXIEVemwcjoro7i0ClbMX6F68bis+vcWjt6t
aC5NxeYfN+Nc+EVEBZ2GzjYDlLX0IC30BPRMHBGfFA9bQx1mLjIwomrhGZXj
fkzuzhyCrrEdmlUjGuO1HMEhMj1Lly7FPXffBWVXH8NTyrsxP2v6lPP5sz2r
0NdZh0sXY3nVGL3pOWxuUS1aawsRFZck509Oshj8GKPkbntrRGVxnUdpahhs
nfchJy0aFraekG6VGoCrpTHicmtmoC7bCQn1VVzd7rvvPjz//PN8r0//8ASs
j6Ry9BPzm96ZG3u17M9tUNbn4qCXFw4cPIiD7O21bx/CojOZnvWhorJGumRo
YgB7bIxwMjAMTg7OyBdXTCnLs+Ds7IrISF84q53V67PTZlb1x/LpR4N0MwE9
06N1N1tMhSSFjrHnElNbi9zCcph4Xea7LVIKmv6jYSpy4oQMFYGTwaoZLLmO
pbUyG1u//QaO7rvgYmsBHSYXNY3VcLB1QJ5aGY6zkwsiaCZqqR/fOXY80WzI
X6L36OioIlfIE20dXrJkCX5/z91o7x6A+aEU/gg/vbhF7ETVPA26X0GGR281
gyirwnhPPaxNjXkpRkJSKtp7SVoG4WJphosF9XwaNdkxsHHchZSkCFg6eokb
okaw28YUEZllGlUhXzCBjBXJ07PPPkunoyArv4wfck71h5klrW8tRm0x2Q8P
G0sc9w1DZkY6kpIy0Dc0hugzu2HquAcVVeXYaWeMA/7JGFDWwGT7FoQn5yIz
LgBb9KxR1zGkEdcCgSsJC90HIZF6Depbe3idyEYWdmaXtf17IbjKGZeUcD/s
8PDAbmYBd+46jAblAEYHunD2kCdMzcyw97gfugckSpamxcLeygKWds5IyK3S
mHEpVKPn/fffjxdeoJvRJvmGYcO9ifjaIQp5Fe3/WgiO8unudNCDeF05YIa5
MCLDphEPvsP5BiKVnJmPT8nFRgt/hsEFqtZ5cyEYaFqBSoSwk7rSvsOVK5bh
zvsexU/uMdIhdjUdYoO8Fm5QiSAfHSZxww03cK/zpRf/hor6Dl6J9a1jFErr
ul6fG75mj+jQoUPcI5K63si9ZWLP3//+d/n2FNS19fOck9giLK60WpyHJKZD
Q5JhKJW4QIWZEsFonjXVVYhJzOHjfO8STafpiXMRNI9F+FEwcA03qVyQjhZd
WtSIfA89eD9Pp9Eu4x9dY1DdrPqHhpEWxPdyQTpyl8hSEGtWr17NpbuktpPv
/P7JjYrlesVZF1oMUiEGoZX5gQce4IeziCtOUFbfg6+o6m3HRap6Ewd0aDFI
pTpXyKukPTd0Unp+ZbvYsXqRDo8U54poMUK14AUdK0R0uuuuuzidqKpto20E
f+LR3NH/8vXBl3hBZHr55ZenyZRd2iauqIingm9xtosWulgjkYnFaPKp+jkV
HXw9M9wTj/augRfnhjy/FvLlStCe0jtE+6xS5fR+TWXPoDhRR7NG0MaVebSP
tr3QY7d6wQVKCMtcqKutnq5/M93P69/+Ns9IhOECdK9eTWzJrNBoa9ZwIEgr
budemcXBRKqJm74pc9FMbxCDkJfx0EMPcdtFp4LX1dXwE9hoowd52j19w+Iw
JS0GaRSDUGROgiDNhI6unUJcdgNz40PkbZ/ihCktBmkSbUSuP/zhD3jzzTen
HyDHZNTxCMz+WAqdefwXbceQz6Ei60mHEbLJTI9xMauRj+F4Io1OSXtusWPI
p5ZKY/xsWsCI5eS/0Xg1rI2Ol/6In56WTsfzPKutvkjj/JxzXtCL6w2Nec89
/IxeXEir57k7N+8MXqD252voD52dP4f+0FNTCjDb1ASOhiUrQ09Vq9kCFsi3
qQZjx9lMOghPHEA3txJRrH8NJZKOgFvFrTHNjArB6BWSVMvzfLt8smgH3NPa
SoRSTId8iz/+8Y945ZVX+HQqK6vgGyvlEmnP6ej4hDg4UItBOmdN4sEH+Zm8
fGvhWpMg7PPPpcTik9cHX5oEWRoq3BTiCJ+LFXwSBwPzeHbxT9oO0iUGIcA0
idtvv50fN1FeUYmzMeU8MUU7PCcmpxRPaKs8XUJ5aCZ0lLRsN0mg8/ILYLYr
CB/yvakFVFL3+NzjzK88PWIyMkfk9+/vvZef/0YUo/PgKKH52PUrTY/atB57
7DE88sgj/P3WW/+mLDUOBrEhjYP4JlZmZB+dZ0RyGMl8hYSEzKc30qm3y0ms
cDi0mHOH9jzTrq5HtBUBCegKPn52Th50nM9L21ljyyjuePh64ZKJlLhwP7wC
C6SbFi6VXyfcldzjIml6/fV/IiMrF1scfLmdCrpcKc5vvgZw6b6Wm5ARE4T0
UimwHuxqhvdhL7i6uOLw6QB0DUoBYXVBKna7O/Mb2LNK6jQGYsNiwvSdizeb
MN1pQBMOSaz6w0Jwmj7sZ2R4usTthLM5Tl5IY8Z1GIfczGHmdoBf87DH3pjf
19vb2QRL3e04GxaH6ICT2G5gjcZuzYH1sBrxSGbfeec/6Orpw4/2vvwJFpUX
PrQQRBW/hUpZhchwqUBHLtLJzK9A1OlDMLewhIuLI7Zs/hFb9U1wOa8EqYmX
0NQt3aTWUZEBEzM7REUGw9pxH6S4bAg7rEwQm1M1A3fZjIwJ6S9lntCyFTfi
1c9tsdEuhlcvLujuOsVt6GgswImjR0i1+fvokSO4mJCP9Mgz0GF0q6irx2Fn
CxwOiEHPwDDqqipQ2yplwYoTgmFk7oiw0HNw2XslC+a7S3MWjAokiSb05IjM
04iQD0poPMBM4JKlK/HiJ5b8uAbmC2m69U49+0VgZHAasl9TYwM47GaHs1Hp
CDngAr9E6abu0ztt8f0WPXh4uGHrjz/BLyYNWQn+cPRUy355aM5+0UowJtW3
8fMnR8UMKPB87LFH8eZb78L+eDo+t47Excw6TffsyTOgmEUGRW81Syff39bb
UgE7CyMY6GxFQLKEfXLwEVi6HkBOdhZKqhslPqSEwcx+r5CZYexiMnMhq0KT
uMt34rV19OBrKx9+k0R8dsOC7vGTz3ouTg7FFxs+k1mM8qxo6Ovb4OLlBMTF
xiI7v4bntsx0tyAgNhUJEWew1cAODV3DGlVwSlCEqteW33gLXv7cgeOVmNco
7jNYEGI38+2qoWePMH3hsTT62xtw8tA+eB04gH179yI0SrpsqSo3Ca4OtrB3
2Yn04gZNpmtKTTQfZ2bhX//5kO/EodgpOb/p9wtBS5Ot5uPLvjjfQs1ivs+l
LdQLuttvTqByoEp3YFAt5HrrcLoDY81igcqHcHCgywTQrr4xmOxPZmyhOzDa
7p4b6NwOSXp6ujqmK3hwmZ+fh7ikzOk6yNzydk131cmzuIYjQi4tqaXaMCu5
d0Krzx8eeoAXKNKZXJTpKKhUKjRdNCePJeflr+GCqI0lhdt0mdQHH/CnXGjt
HuEbnL+yj6Sdi6uvi8Mr1OmWl4vIuLTp6zNKajvv+D8AvpInEIhaD//xITR1
DmHbrss8W1dW1zXj9nZtR1jFQ2ui0VtvvYW83FyEMRNBo9C9FxUN3b+7rkFW
iWmQoeY+1j134VxQLD42OofNbhfpYg1xG9L1jSBN46mnnuLRIY107yPP4Uf3
OJ5GrWlW/c9iB5mhdz8T0yCvhAb59OO1yCpmkbuRL3Q8L6OuRaVY9JVx9JBr
WgnlO93y83LwqzsfwX+2nYL+nkQ6eU8x33VuC9DA6VulbhICS/7Kk0/+CW+8
vwmfmgXAYG8C5Rhvm2cYccDzgpTvFjGVvNxs/HrNE3hHx5sbq6LyesU8V8Yt
gNe3iAkQb55iE3j9/S8Z9DPYZHkebZ0Dt14X8FsF2hXlZXhv/RZ+GS1lAGkn
7S+vC7JEWGmzK+UszQ4k0jZara+G40B/LYDGplXiA0M/vn+0SzV882KBzpDz
X6ux7o6HXsC7ej78bBWq8LtpbsgLkG/5SjjKFdHNnZ/+15Rfg2B9OJnK/ea7
qe0aIk7dp0X8t4IqF7Pq8YVtFOz5xtSRn88DfjGiLV/cRhWQDnv9+D1ldAoP
7U/V+s42NcgrWNyUJZmvp/6F9w0D4MKgDwyP3fh/AHwlJ/5zzz3Ln6yu3+LA
D2+iPapDI2MKra9Z4yPcIQhDuVo6SZzn485k8HzcyuuCfKfgaERqPQ8Ad57L
otq9Rd/dNgPoakFtKvkh8bLY5cezo1QYODo2sXyxwMvVLzlfLahNITCx8okn
HoffpUq1AsFJxTy3w109wlXKJI2wanoE8ojp5X+ZbrOIxP4AntnTdNWaHD1R
MoVmLr/p6EZ5qV+AwlFCRw2VGzkFqADkiy++4HmBpORkGLn58vo/ui2AkoBy
NCfnwRlerC0lJYVxgjxS9ZQYPVVgToP8E8rZ0ml31Hkp/1w+fb81+V/0N5qC
rIQkh6TYjJjXVGrJe/453+TNn83cfTf0Xc7x6sjj4UXoUamQwqZDZKGnXDk5
OYy7rCfjIqEp8ML+/fuX8+YVPKdLTV5eXpL39vDDhN7PFyygEk6/4I1EVkqF
LF26HM+9vRlfOsZBz/ms9NTzjjs4q+js52eeeebXfPylfDyZJDcueFAp4PkZ
lzcCfgMb8Pl3tvEto8+8+S0US5bwdsohnj59+n/EYPRV8ELS9atzWCvR1daE
zl7p4nV6tTdUcYLXNimnn4VMjPSjKDcLuQUlGBiZ0BQHquG5im+7l+Vl6bIV
ePFDA3zrmoBn/vkVliy54XY1YtDxoUSMFZrxuxn+u+2mMxK1+QnQ37YdTq5O
2L6N9gM1AeODOL7TESbmVrAwNYLrPm8Mjk9p2sekhqOkF3Sp6pVU7/3Y6nCO
0TQGT722kQpHGEOuEJKiI4kauCqfNTE2hK7OTnR2dV05emdwCKWZKQgJDUFo
SBBsjPRg67EfFU0tOO5qjWMhvAAV8f4HYbfrNGpL0mFkYInmARZNqepgoqeP
jPJWhRyuyttAyGbQmzZzrOEH/Czj3+nvNJ/77rvvBoH28+/q4iunS3jy1Q2K
1aLtT3/6E+9OP7yB/reE/ruEHpVemU9zZTLsbaxhZ28Pe/amK5fOBVxGyCF3
/LBFH75+PrAw2A5L590oKC+Cg43d9Hk/LaVpcHRyR0yUHxw9r2wwO+VujaAU
+RKrFTx+2rVrFz/a5OTJk7w0iwsTs2J30wfjEX2nHDnVy1GRzF//+jyefOoZ
XqNK1bTPvr6JTYL9hcEjRVS3UzfeeCMef/zxW/m8V/GvmzZt4oEn5cFOnTpF
qkJ7A6kU9kqeb3x0AO2trbymmd5URKfqG0R3cxmsTSxR1NiD0P3O8E8mu62a
89oxl3m3B2pQngeFQtIJ6M8+9zy+tzmDjXaxiEznD3X5FaRL+WSX4qeffuIz
oW+/FG2bN2+WdfhqIZUzZfmXAmHl7IH9zlaSVk32wt7SChmVbRL3ilNh5+CK
mJgAOOz0FuVDkzjuYkFXwWnKSqkhv4KvMFVVlfwCE3JgRP3t3XPhQ5ko/0Ou
WPf5egSmFHFJOeZmhb2+sZicmkDkmd1w3OeHxopM6OmZoKZ7GAPtZTDUNUR2
tfIa+KxUX2H55SdOJ9M5TpEpNVKCUVPebkTVDFvjrfBN4CxDc1kGE3c9WNta
87Pzc+jevMlR+B10h5GJOUxNDOF5MgyjE9CYt1PDaNUMjOhF50XSSSr0rDk6
rfbO2UjJdrq7vRnKnv7p3/UoW5gOFaK1q+/KxuqJEVSVlaC0spY2Ls9ppzXl
vGUYdB0KbcihWuGLmXWrZ+Mz5yKlCahsvOicSRsWUNA+okvZDXdcF1A510Y3
oVgeTMJn5qG4nNtw+3UBXS6A0oZzCgP5OZD5jb+bC+hVrp8moCsEULr+xFTs
r08tbJYTEuS30M3cc7hz18RZ3npP50DSCVB0wmR6cctvJJyZp6U1NVYJyHQY
pHzCZGZJ62+0IrH8hxsFUPkqXyrFzClr+/V8JJZ/Kz/Zpe9kkembXH1NKwmd
zEDf5JpmeuwhdiBMt4mNMtxF/pnAha7/1dkZh022kVRyedtsXORMHj23oHMm
6C5jOZKnbA1Vp9A3OQYnr4LqBsF9lyu4UHpcvY0ITcfhqv+WXDU6xFK9H3kd
5FGo96P50uEh6v3E/XYz+hH9aMenej/aZ8q9B7V+1Ebx1ux+VKWi3o9W6Nn9
1Oks9yOxpgc16v2ojXLEs/uJgrTpNoJPSzLxSMoNrOCHX27zuMhzw4XM9GZm
pNHf1UHTSy2ikLlGyU0645HqeuTudCSI7BDKo5K/Kz8rvFmtjbKK6m3kuZM/
ov5bulpDlgK5H5W8UnGvej86GJL8idn9ZI7L/ejwSJnjcj8qXacThNT7UZs4
MGu6Hz3km81d6jeba8TJ2dwl6ZY5ebNam8xJ9X6zOUnwyaEirkkJo2WUeZWS
7o5R8DriLefUyPe6Brfokj0ZA5JhWXfk0WjTHOmjOqYUcM/mAkUhs7lAcj2b
CyRAs7lAnJ7NBQpVZL1T5/5sHYuOjr6KC9Q2mwtRUVE8RFbvFxkZeZXuUNts
itNTc1HyPd2P2sRrRr/ZbQSfvO4rbct4STudSvCdsSdK6rrVBY9eTLBmc4us
KWm/paUlw8Dd3Z21WVlZwdbWln+7Sa3Nzs6Of5P7sd/wuGKuNvm3FhYWcHBw
mNGP2uiC49n95Da5Hx3s4uTkNKOfepvcz8TEhN/ko95PvU29n4uLy1X95LZr
9aNzU2b3k9vU+7m5uc1oI1j6+vrULtqWYafHDhia2WLTt1uwzcBSBmlsbMzR
3rdv3/R5J0v+H+NTkTg=\
\>"],ExpressionUUID->"0853b278-d088-4bcf-b03c-06d3c47603ea"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.003666666666666667], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJzMvWk4le/f9m2exxAhQmgSMlcSkjJXKkPKFFEhldOSUoaoZKhoIEORsQnJ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       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF1P8z03EcwPGF2Pl2p5Q4s2bcum4XndQuGnMrjjZactHhVqGcIju2G0vY
Zth8nCuluVFOKeawHeXK9YM6lS8p6tK6fal1mFUsX3buUt3l9f7heY//4Ek6
m8/JcsDhcKy//VPzuGl+Iwp7tmkjydbtE4EUVh/nhRxExqRurGdQkW/WznsM
7UJaD4WGli7WgZT+F0Vrd5HKPhtucSvygwLL4PfKwWbS8ksFrxbcN3mn0xBR
A+44Vz81MicDJeo4N0Z3FRg/E1PNPi0FdYFi0S28BFwlY2WFE5VgtotuxFhS
AWa0LRGN9HIw6EyS1R9/DRTN6x11l0TgMNYXp1oTglo73r+WLQDpSuunnz1F
4Iw6a6A4mgcSJVwSRVkALtw2sn4czQOtWpdisyUbJNHj+WMPueASJyfTUpUK
YoIG79ExFnj9/heFeC4MTNsjZOK2hEVv+vE9y+dyMxsskRlvqimpYGG183Lk
PBep32D2UnJA9sm36WbXPHBBNU41dRaAxLbd2P5gHvgo/6sTvqEI7OAHLWjC
BKDUc3IgqkMIDhrsv1pPiEAdA9tpGisDNeGvg6cDykHyrLudfKUCdDWJh0xd
lWCzfTDS3VECcpcfMO0cKaiiTdBT5FWgtKlvkWCQgWbGaOMpQg3IH1c9T0qu
BbWCEHV/uxy8kLsilRsUYPuqONn1G9Ik3h4osyDTW0KfVq4gOVO5NqF7HRhB
12depCE9t43QjtUjE1pSnIdvIGVU8zuGEukQ65B/5B5ytSSy/cATpMHc40We
RRJ4UfpWKzINN94VYENO+1li/X4jXyUGX/XyxkCXz5oEzBfJzI3x9SAih8SZ
Wvxe5LrX93JpCJLWUproFI4sproRKg4j/38L/APA3mgJ
        "]]},
      Annotation[#, "Charting`Private`Tag$10088310#1"]& ]}, {}, {}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{
    FormBox["\"E1\"", TraditionalForm], 
    FormBox["\"E1+E2\"", TraditionalForm]},
  AxesOrigin->{-365.30759611302125`, -399.66050268773665`},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{-400}, {-400}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-388.8034096928534, -365.6690701680956}, {-406.8122905058315, \
-400.0010640124078}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVzVsoQwEYwPGDkiganVhRWNlaLm0dl0bqiJE9TDiTVmhtYkiNrb1IdFwW
WpKXZSwpaRhrT/PuYS4vmMsWtsnK4YGE2hHf9/Dv9/gv0o22G5IIgqCgAOWP
315xdHBs6Q3d1MTf0TO26TsE7rpVy2HQKqmMJUB2PZXkQfPzRiFKHQ3XofsZ
FiMqMhvsaHmqyoeyHu4YFYvYD1QuiQl+wWlPnzonyNHqU8UM6g34nWXgzV1K
ogPkt5RkJ2h73XtG83qMUwxIZu10a8CqH6a6F1R9Layg0dBTZBC05laQRnBc
bdCii4NhC+p0SWOoSSjsGsIfSbgmQRe1Wkxcc7Q9esCj7wUGWzIoL729TwcX
C93qTFAquDjPBh1pbpUGDH/2T6Bir2yOfODo/J16iQJsvWSYWnDKe3iCtoRK
RhrAF5nS0QZa5sel7eD6AC/TgZG3a5Me3L7TZtU8cvRsM7OmBxvFQ38+8B/F
h+pt
  "],
 CellLabel->"Out[179]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"5d5010c2-4dee-4b30-bc88-c8560f34cefa"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bivariate normal approximation - analytically", "Subsubsection",
 CellChangeTimes->{{3.736115679430572*^9, 
  3.73611568480398*^9}},ExpressionUUID->"9a15c958-6982-4c3c-9975-\
466b615358c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "FIT", " ", "BIVARIATE", " ", "NORMAL", " ", "DISTRIBUTION", " ", "TO", 
    " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ADDITIVE", " ", "ENERGY"}], ",", " ", 
      RowBox[{"EPISTATIC", " ", "ENERGY"}]}], "}"}], " ", "OF", " ", "A", " ",
     "RANDOMLY", " ", "DRAWN", " ", "SEQUENCE", " ", "USING", " ", 
    "ANALYTICAL", " ", "FORMULAS"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"varx", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"alpha", "-", "1"}], ")"}], "/", "alpha"}], " ", "l", " ", 
       "variance1"}], "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vary", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"alpha", "-", "1"}], ")"}], "^", "2"}], "/", 
        RowBox[{"alpha", "^", "2"}]}], " ", 
       RowBox[{"Binomial", "[", 
        RowBox[{"l", ",", "2"}], "]"}], "variance2"}], "//", "N"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<parameters of analitically fitted bivariate normal distribution =\>\
\"", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"meanVec", ",", "covMatrix"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"varx", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "vary"}], "}"}]}], "}"}]}], "}"}]}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vec", "=", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"unnormalizedCutGauss", "=", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"vec", "-", "meanVec"}], ")"}], ".", 
         RowBox[{"Inverse", "[", "covMatrix", "]"}], ".", 
         RowBox[{"(", 
          RowBox[{"vec", "-", "meanVec"}], ")"}]}]}], "]"}], " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"energyCutoff", "-", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"norm", "=", 
     RowBox[{
      RowBox[{"1", "/", "unnormalizedCutGauss"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "\[Rule]", 
         RowBox[{"Mean", "[", 
          RowBox[{"walk", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1000"}], ";;"}], ",", "2"}], "]"}], "]"}], 
          "]"}]}], ",", 
        RowBox[{"y", "\[Rule]", 
         RowBox[{"Mean", "[", 
          RowBox[{"walk", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1000"}], ";;"}], ",", "3"}], "]"}], "]"}], 
          "]"}]}]}], "}"}]}]}], 
    RowBox[{"(*", 
     RowBox[{"/", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{"unnormalizedCutGauss", ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "\[Infinity]"}], ",", 
          RowBox[{"energyCutoff", "-", "y"}]}], "}"}]}], "]"}]}], "*)"}], 
    ";"}], 
   RowBox[{"(*", 
    RowBox[{
    "Normalization", " ", "takes", " ", "too", " ", "long", " ", "on", " ", 
     "my", " ", "computer", " ", "for", " ", "some", " ", "reason"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"cutGaussDensity", "=", 
    RowBox[{"norm", " ", "unnormalizedCutGauss"}]}]}]}]], "Input",
 CellChangeTimes->{{3.735999069430941*^9, 3.735999110642622*^9}, {
  3.7359992935867023`*^9, 3.735999359812723*^9}, {3.7359993943534193`*^9, 
  3.735999407532209*^9}, {3.735999694503731*^9, 3.7359998463581743`*^9}, {
  3.7360000972615557`*^9, 3.736000117131439*^9}, {3.736003771134399*^9, 
  3.7360037719094963`*^9}, {3.7360043952201443`*^9, 3.736004397590323*^9}, {
  3.7360045137607727`*^9, 3.736004514163857*^9}, {3.736115720712201*^9, 
  3.7361157468623037`*^9}, {3.736248160711125*^9, 3.736248180838785*^9}, {
  3.736248834152248*^9, 3.73624886123881*^9}, {3.736248957835306*^9, 
  3.736249074599868*^9}, {3.736629890163179*^9, 3.7366298912005043`*^9}, {
  3.740963370027172*^9, 3.740963373984942*^9}, {3.74096350847267*^9, 
  3.7409635335148163`*^9}},
 CellLabel->
  "In[181]:=",ExpressionUUID->"cff6a22d-b895-4428-b294-a41793612ab2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"parameters of analitically fitted bivariate normal \
distribution =\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"400.`", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "23.939999999999998`"}], "}"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "parameters of analitically fitted bivariate normal distribution =", {{0, 
    0}, {{400., 0}, {0, 23.939999999999998`}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7409957046049547`*^9, 3.7409957810560904`*^9, 
  3.7409959847147408`*^9, 3.7410005996127872`*^9, 3.7414339793318644`*^9, 
  3.741525222370624*^9, 3.741689851588376*^9},
 CellLabel->
  "During evaluation of \
In[181]:=",ExpressionUUID->"9e5dd58e-6bef-4f52-9b25-7667536ed980"],

Cell[BoxData[
 RowBox[{"4.575134645628172`*^82", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.0025`", " ", "x"}]}], ")"}]}], " ", "x"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0.`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.041771094402673355`", " ", "y"}]}], ")"}], " ", "y"}]}], 
     ")"}]}]], " ", 
  RowBox[{"UnitStep", "[", 
   RowBox[{
    RowBox[{"-", "400"}], "-", "x", "-", "y"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.735999792820609*^9, 3.735999847607314*^9}, 
   3.73600011808501*^9, {3.736003749202795*^9, 3.7360037730798264`*^9}, 
   3.736067639513176*^9, 3.7361158747099457`*^9, 3.736178857012473*^9, 
   3.7362487381369753`*^9, 3.736248862251943*^9, {3.736248961040125*^9, 
   3.736248975144142*^9}, {3.7362490648838053`*^9, 3.736249075145441*^9}, 
   3.736250166027701*^9, 3.7362514041036654`*^9, 3.7362531343338623`*^9, 
   3.736271307580934*^9, 3.736272028868565*^9, 3.736293545960244*^9, 
   3.736294327545326*^9, 3.736295194022214*^9, 3.7362961217306843`*^9, 
   3.736337664515617*^9, 3.736338759260745*^9, 3.7366009704053392`*^9, 
   3.7366026098737383`*^9, 3.736605981426526*^9, 3.7366296318362837`*^9, 
   3.736629891798617*^9, 3.736639095005768*^9, 3.7367773098253613`*^9, 
   3.7367777314517603`*^9, 3.740838971620656*^9, 3.740913989379446*^9, 
   3.74091650973635*^9, 3.7409173445439367`*^9, 3.740930923004965*^9, 
   3.740959955704997*^9, 3.740963156344762*^9, 3.740963438666407*^9, 
   3.7409957047083693`*^9, 3.740995781117268*^9, 3.74099598472509*^9, 
   3.741000599626882*^9, 3.7414339793420353`*^9, 3.7415252224151278`*^9, 
   3.741689851598675*^9},
 CellLabel->
  "Out[187]=",ExpressionUUID->"2ad6f1d3-f546-4669-a962-96a987a355dd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "PLOTS", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"numPointsToPlot", "=", "5000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"walk", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], "]"}],
        "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ";;", "10"}], "]"}], "]"}], "-", 
      "energyCutoff"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"walk", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], "]"}],
        "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ";;", "10"}], "]"}], "]"}], "-", 
      "energyCutoff"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"E1", ",", "E2"}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"plot", " ", "diagonal"}], ",", " ", "vertical", ",", " ", 
     RowBox[{"and", " ", "horizontal", " ", "lines"}], ",", " ", 
     RowBox[{"set", " ", "axes", " ", "settings"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p21", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"GrayLevel", "[", "0.05", "]"}], "]"}]}], "}"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"GrayLevel", "[", "0.05", "]"}], "]"}]}], "}"}], 
           "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<\!\(\*SubscriptBox[\(\[CapitalDelta]G\), \(add\)]\) \
(kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\[CapitalDelta]G (kcal/mol)\>\"", ",", "fontSize"}], 
           "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRangePadding", "\[Rule]", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"plot", " ", "data", " ", "from", " ", "random", " ", "walk"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "plot", " ", "level", " ", "curve", " ", "corresponding", " ", "to", " ", 
     "the", " ", "bivariate", " ", "normal", " ", "distribution", " ", 
     "having", " ", "95", "%", " ", "of", " ", "the", " ", "total", " ", 
     "mass", " ", "within", " ", "the", " ", "curve"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p23", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", "vary", "]"}]}], " ", 
            RowBox[{"Sqrt", "[", " ", 
             RowBox[{
              RowBox[{"rr", "^", "2"}], "-", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", "varx"}]}], "]"}]}], "+", 
           "xpx"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "vary", "]"}], " ", 
            RowBox[{"Sqrt", "[", " ", 
             RowBox[{
              RowBox[{"rr", "^", "2"}], "-", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", "varx"}]}], "]"}]}], "+", 
           "xpx"}]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"rr", "\[Rule]", "19.65"}], ",", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{"xpx", "+", "energyCutoff"}]}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"xpx", ",", 
         RowBox[{"-", "100"}], ",", "100"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", " ", "Dashed", ",", "Thick"}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "0"}], "}"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"p2", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p21", ",", "p22", ",", "p23"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<means = (\>\"", ",", " ", 
      RowBox[{"Mean", "[", "E1", "]"}], ",", "\"\<, \>\"", ",", 
      RowBox[{"Mean", "[", "E2", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", " ", 
      RowBox[{"r", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.736767654198523*^9, 3.736767654640686*^9}, {
   3.7367677024238462`*^9, 3.736767710259255*^9}, {3.73677462866743*^9, 
   3.736774650932276*^9}, {3.736774692303574*^9, 3.736774822254427*^9}, {
   3.736775292859318*^9, 3.736775407961176*^9}, {3.736777432508523*^9, 
   3.7367774348607597`*^9}, {3.736777485313849*^9, 3.7367774861524477`*^9}, {
   3.73677809585435*^9, 3.7367780964082327`*^9}, {3.740839593013956*^9, 
   3.7408396089448223`*^9}, 3.740913727054641*^9, {3.740916144141958*^9, 
   3.7409161816097097`*^9}, 3.740960243907769*^9, 3.7409986235192127`*^9, {
   3.741000787457712*^9, 3.741000823214897*^9}},
 CellLabel->
  "In[188]:=",ExpressionUUID->"1cf07552-30d1-4e08-871c-48a74e7f835e"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[{{-15., -15.}, {5., 5.}}]},
      Annotation[#, "Charting`Private`Tag$10088357#1"]& ]}, {}, {}}, {{}, {{}, 
     {GrayLevel[0], PointSize[0.0055000000000000005`], AbsoluteThickness[1.6],
       PointBox[CompressedData["
1:eJxlmXk8lN/3wB9K2dL0ydIiTUVpEYlo40m0KpM2LWqoUImhElKNFtFmSos2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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], Thickness[Large], Opacity[1.], Dashing[{Small, Small}],
        LineBox[CompressedData["
1:eJw9lgk01ekbx6/9Zr2/H0UZuq5rv7iLa18eu0wmWaJlSkYxUhTdqJSpG6ZF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        "]]},
      Annotation[#, "Charting`Private`Tag$10088440#1"]& ]}, {}, {}}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox["\"\[CapitalDelta]G (kcal/mol)\"", 13, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]G\\), \\(add\\)]\\) \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
     Automatic, {{-15., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-13., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-11., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-9., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {24., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {26., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {28., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {32., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {34., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {36., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {38., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{{{0, 
      Directive[
       GrayLevel[0.05]]}}, {{0, 
      Directive[
       GrayLevel[0.05]]}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-15, 40}, {-15, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7367773099344387`*^9, 3.736777400932513*^9, 3.7367774358283873`*^9, 
   3.736777499760138*^9, 3.7367777346834307`*^9, 3.736778097384582*^9, 
   3.740838971773521*^9, 3.7408396102249317`*^9, 3.740913989728567*^9, 
   3.74091651184699*^9, 3.740917344726437*^9, 3.7409309231116323`*^9, 
   3.740959955807604*^9, 3.740960250553104*^9, 3.740963156448593*^9, 
   3.740963438828855*^9, 3.740995984851409*^9, 3.740998624891507*^9, 
   3.7410005997543077`*^9, {3.741000789098858*^9, 3.741000823679537*^9}, 
   3.741433979478341*^9, 3.74152522296004*^9, 3.741689851762527*^9},
 CellLabel->
  "Out[195]=",ExpressionUUID->"94d564a4-62a2-45bb-b746-ff0a042a3bf3"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"means = (\"\>", "\[InvisibleSpace]", "25.467097537745467`", 
   "\[InvisibleSpace]", "\<\", \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.9753804088496364`"}], "\[InvisibleSpace]", "\<\")\"\>"}],
  SequenceForm[
  "means = (", 25.467097537745467`, ", ", -0.9753804088496364, ")"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7367773100517597`*^9, 3.7367774010459547`*^9, 3.736777435938799*^9, 
   3.736777499770802*^9, 3.736777734795144*^9, 3.736778097455991*^9, 
   3.7408389717828217`*^9, 3.7408396103330708`*^9, 3.740913989756065*^9, 
   3.740916512063154*^9, 3.740917344736402*^9, 3.740930923121519*^9, 
   3.740959955817459*^9, 3.7409602506628838`*^9, 3.74096315645883*^9, 
   3.7409634388412848`*^9, 3.7409959849109592`*^9, 3.740998624986567*^9, 
   3.7410005997669983`*^9, {3.741000789206996*^9, 3.741000823787705*^9}, 
   3.741433979487583*^9, 3.741525222970533*^9, 3.74168985177194*^9},
 CellLabel->
  "During evaluation of \
In[188]:=",ExpressionUUID->"68417eee-b4e8-4147-af0a-b1626975f434"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", "0.23626107437284136`"}],
  SequenceForm["r = ", 0.23626107437284136`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7367773100517597`*^9, 3.7367774010459547`*^9, 3.736777435938799*^9, 
   3.736777499770802*^9, 3.736777734795144*^9, 3.736778097455991*^9, 
   3.7408389717828217`*^9, 3.7408396103330708`*^9, 3.740913989756065*^9, 
   3.740916512063154*^9, 3.740917344736402*^9, 3.740930923121519*^9, 
   3.740959955817459*^9, 3.7409602506628838`*^9, 3.74096315645883*^9, 
   3.7409634388412848`*^9, 3.7409959849109592`*^9, 3.740998624986567*^9, 
   3.7410005997669983`*^9, {3.741000789206996*^9, 3.741000823787705*^9}, 
   3.741433979487583*^9, 3.741525222970533*^9, 3.74168985177689*^9},
 CellLabel->
  "During evaluation of \
In[188]:=",ExpressionUUID->"44ea66f5-99b2-47af-bf24-2cb02a15b3d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.05581929526380928`"}],
  SequenceForm["r^2 = ", 0.05581929526380928],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7367773100517597`*^9, 3.7367774010459547`*^9, 3.736777435938799*^9, 
   3.736777499770802*^9, 3.736777734795144*^9, 3.736778097455991*^9, 
   3.7408389717828217`*^9, 3.7408396103330708`*^9, 3.740913989756065*^9, 
   3.740916512063154*^9, 3.740917344736402*^9, 3.740930923121519*^9, 
   3.740959955817459*^9, 3.7409602506628838`*^9, 3.74096315645883*^9, 
   3.7409634388412848`*^9, 3.7409959849109592`*^9, 3.740998624986567*^9, 
   3.7410005997669983`*^9, {3.741000789206996*^9, 3.741000823787705*^9}, 
   3.741433979487583*^9, 3.741525222970533*^9, 3.7416898517939177`*^9},
 CellLabel->
  "During evaluation of \
In[188]:=",ExpressionUUID->"f8155ae1-c5b9-401c-9ecd-49ba5e11aa39"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distribution of free energy of folding", "Subsubsection",
 CellChangeTimes->{{3.735393260543401*^9, 3.735393271562666*^9}, {
   3.7354274237432413`*^9, 3.735427424207309*^9}, 3.7408382808116913`*^9, {
   3.740916818069399*^9, 
   3.7409168233297157`*^9}},ExpressionUUID->"5fe804c3-839c-4c9c-88f7-\
a07f39eb3790"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"numPointsToPlot", "=", "5000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"walk", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Histogram", "[", 
    RowBox[{"data", ",", "50", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\[CapitalDelta]G\>\"", ",", "\"\<p(\[CapitalDelta]G)\>\""}], 
       "}"}]}]}], "]"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"p3", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{
    RowBox[{"data", "-", "energyCutoff"}], ",", "50", ",", "\"\<PDF\>\"", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\[CapitalDelta]G of folding (kcal/mol)\>\"", ",", "fontSize"}], 
        "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Probability density\>\"", ",", "fontSize"}], "]"}]}], 
      "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<mean = \>\"", ",", " ", 
    RowBox[{"data", "//", "Mean"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<std = \>\"", ",", " ", 
    RowBox[{"data", "//", "StandardDeviation"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NotebookSave", "[", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.735391937106286*^9, 3.735391944632491*^9}, {
   3.7353920061842947`*^9, 3.735392055768449*^9}, {3.735392108783545*^9, 
   3.7353921370371437`*^9}, {3.735392195288419*^9, 3.735392213868832*^9}, {
   3.7353924998610764`*^9, 3.735392500127347*^9}, {3.735392582469503*^9, 
   3.735392594878294*^9}, {3.735392640276363*^9, 3.735392653813802*^9}, {
   3.73542546739634*^9, 3.7354254719487133`*^9}, {3.735997773271573*^9, 
   3.7359978108729057`*^9}, {3.735998422293809*^9, 3.735998426499139*^9}, {
   3.735998583562201*^9, 3.735998583930787*^9}, {3.736068997207417*^9, 
   3.73606901598698*^9}, {3.736116103608083*^9, 3.736116103791065*^9}, {
   3.736116317646946*^9, 3.736116346830327*^9}, {3.736116457766818*^9, 
   3.736116477465858*^9}, {3.7361697813583384`*^9, 3.7361697900768147`*^9}, 
   3.736169993961195*^9, {3.736338461321774*^9, 3.736338464483549*^9}, {
   3.7366009891555967`*^9, 3.736601044339031*^9}, {3.736777163042076*^9, 
   3.736777166930168*^9}, {3.740916524533087*^9, 3.740916545533498*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"40b39378-b1fb-4735-a377-b40a4a79da9c"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.85], EdgeForm[{Opacity[0.196], Thickness[Small]}], {}, 
    {GrayLevel[0.85], EdgeForm[{Opacity[0.196], Thickness[Small]}], 
     RectangleBox[{-7., 0}, {-6.9, 0.004},
      RoundingRadius->0], RectangleBox[{-6.9, 0}, {-6.8, 0.002},
      RoundingRadius->0], RectangleBox[{-6.7, 0}, {-6.6, 0.002},
      RoundingRadius->0], RectangleBox[{-6.6, 0}, {-6.5, 0.002},
      RoundingRadius->0], RectangleBox[{-6.5, 0}, {-6.4, 0.002},
      RoundingRadius->0], RectangleBox[{-6.4, 0}, {-6.3, 0.002},
      RoundingRadius->0], RectangleBox[{-6.3, 0}, {-6.2, 0.004},
      RoundingRadius->0], RectangleBox[{-6.1, 0}, {-6., 0.002},
      RoundingRadius->0], RectangleBox[{-5.9, 0}, {-5.8, 0.002},
      RoundingRadius->0], RectangleBox[{-5.5, 0}, {-5.4, 0.008},
      RoundingRadius->0], RectangleBox[{-5.4, 0}, {-5.3, 0.002},
      RoundingRadius->0], RectangleBox[{-5.3, 0}, {-5.2, 0.002},
      RoundingRadius->0], RectangleBox[{-5.2, 0}, {-5.1, 0.006},
      RoundingRadius->0], RectangleBox[{-5.1, 0}, {-5., 0.004},
      RoundingRadius->0], RectangleBox[{-5., 0}, {-4.9, 0.002},
      RoundingRadius->0], RectangleBox[{-4.9, 0}, {-4.8, 0.004},
      RoundingRadius->0], RectangleBox[{-4.8, 0}, {-4.7, 0.014},
      RoundingRadius->0], RectangleBox[{-4.7, 0}, {-4.6, 0.012},
      RoundingRadius->0], RectangleBox[{-4.6, 0}, {-4.5, 0.012},
      RoundingRadius->0], RectangleBox[{-4.5, 0}, {-4.4, 0.026},
      RoundingRadius->0], RectangleBox[{-4.4, 0}, {-4.3, 0.014},
      RoundingRadius->0], RectangleBox[{-4.3, 0}, {-4.2, 0.006},
      RoundingRadius->0], RectangleBox[{-4.2, 0}, {-4.1, 0.012},
      RoundingRadius->0], RectangleBox[{-4.1, 0}, {-4., 0.014},
      RoundingRadius->0], RectangleBox[{-4., 0}, {-3.9, 0.022},
      RoundingRadius->0], RectangleBox[{-3.9, 0}, {-3.8, 0.012},
      RoundingRadius->0], RectangleBox[{-3.8, 0}, {-3.7, 0.02},
      RoundingRadius->0], RectangleBox[{-3.7, 0}, {-3.6, 0.032},
      RoundingRadius->0], RectangleBox[{-3.6, 0}, {-3.5, 0.05},
      RoundingRadius->0], RectangleBox[{-3.5, 0}, {-3.4, 0.022},
      RoundingRadius->0], RectangleBox[{-3.4, 0}, {-3.3, 0.022},
      RoundingRadius->0], RectangleBox[{-3.3, 0}, {-3.2, 0.04},
      RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3.1, 0.06},
      RoundingRadius->0], RectangleBox[{-3.1, 0}, {-3., 0.056},
      RoundingRadius->0], RectangleBox[{-3., 0}, {-2.9, 0.046},
      RoundingRadius->0], RectangleBox[{-2.9, 0}, {-2.8, 0.032},
      RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.7, 0.05},
      RoundingRadius->0], RectangleBox[{-2.7, 0}, {-2.6, 0.078},
      RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.5, 0.066},
      RoundingRadius->0], RectangleBox[{-2.5, 0}, {-2.4, 0.064},
      RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.3, 0.088},
      RoundingRadius->0], RectangleBox[{-2.3, 0}, {-2.2, 0.124},
      RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2.1, 0.106},
      RoundingRadius->0], RectangleBox[{-2.1, 0}, {-2., 0.138},
      RoundingRadius->0], RectangleBox[{-2., 0}, {-1.9, 0.186},
      RoundingRadius->0], RectangleBox[{-1.9, 0}, {-1.8, 0.126},
      RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.7, 0.194},
      RoundingRadius->0], RectangleBox[{-1.7, 0}, {-1.6, 0.208},
      RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.5, 0.254},
      RoundingRadius->0], RectangleBox[{-1.5, 0}, {-1.4, 0.224},
      RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.3, 0.236},
      RoundingRadius->0], RectangleBox[{-1.3, 0}, {-1.2, 0.244},
      RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1.1, 0.262},
      RoundingRadius->0], RectangleBox[{-1.1, 0}, {-1., 0.32},
      RoundingRadius->0], RectangleBox[{-1., 0}, {-0.9, 0.404},
      RoundingRadius->0], RectangleBox[{-0.9, 0}, {-0.8, 0.38},
      RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.7, 0.408},
      RoundingRadius->0], RectangleBox[{-0.7, 0}, {-0.6, 0.532},
      RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.5, 0.478},
      RoundingRadius->0], RectangleBox[{-0.5, 0}, {-0.4, 0.666},
      RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.3, 0.798},
      RoundingRadius->0], RectangleBox[{-0.3, 0}, {-0.2, 0.806},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {-0.1, 0.836},
      RoundingRadius->0], RectangleBox[{-0.1, 0}, {0., 1.15},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-7.14, 0},
  Frame->True,
  FrameLabel->{{
     FormBox[
      StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\[CapitalDelta]G of folding (kcal/mol)\"", 13, StripOnInput -> 
       False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-7, 0}, {0, 1}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.736601011782799*^9, 3.7366010447113953`*^9}, 
   3.736629902077896*^9, 3.7366390957661467`*^9, 3.7367777426799107`*^9, 
   3.740838973376061*^9, 3.740913991980603*^9, 3.740916547791523*^9, 
   3.7409173468827887`*^9, 3.740930923904811*^9, {3.740959245353772*^9, 
   3.7409592712405787`*^9}, 3.740959956532015*^9, 3.740963157092988*^9, 
   3.740963439720015*^9, 3.741000600263175*^9, 3.741433979825056*^9, 
   3.741525224955037*^9, 3.741689852137233*^9},
 CellLabel->
  "Out[203]=",ExpressionUUID->"483d314b-8132-49f1-854b-9e5ae335a26d"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "400.96410592098573`"}]}],
  SequenceForm["mean = ", -400.96410592098573`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7366010118003407`*^9, 3.736601044729257*^9}, 
   3.736629902094693*^9, 3.736639095775461*^9, 3.736777742697877*^9, 
   3.74083897338544*^9, 3.740913991999518*^9, 3.740916547808998*^9, 
   3.740917346926599*^9, 3.740930923916378*^9, {3.740959245439521*^9, 
   3.740959271259877*^9}, 3.740959956541974*^9, 3.740963157103231*^9, 
   3.740963439734139*^9, 3.741000600274238*^9, 3.741433979835924*^9, 
   3.741525224968115*^9, 3.741689852148027*^9},
 CellLabel->
  "During evaluation of \
In[201]:=",ExpressionUUID->"95d681ab-fe31-46b4-a031-f54ef23785e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"std = \"\>", "\[InvisibleSpace]", "0.9723493410049089`"}],
  SequenceForm["std = ", 0.9723493410049089],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7366010118003407`*^9, 3.736601044729257*^9}, 
   3.736629902094693*^9, 3.736639095775461*^9, 3.736777742697877*^9, 
   3.74083897338544*^9, 3.740913991999518*^9, 3.740916547808998*^9, 
   3.740917346926599*^9, 3.740930923916378*^9, {3.740959245439521*^9, 
   3.740959271259877*^9}, 3.740959956541974*^9, 3.740963157103231*^9, 
   3.740963439734139*^9, 3.741000600274238*^9, 3.741433979835924*^9, 
   3.741525224968115*^9, 3.7416898521534224`*^9},
 CellLabel->
  "During evaluation of \
In[201]:=",ExpressionUUID->"eb9a3fc5-561c-461f-8af4-2aafb945560e"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distribution of mutational effects of random mutations", "Subsubsection",
 CellChangeTimes->{{3.7354788693450317`*^9, 3.735478877368379*^9}, {
  3.740838243351634*^9, 
  3.740838273934759*^9}},ExpressionUUID->"5a36ffe4-1ae1-4b00-a625-\
f473c3d935a7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "12345", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numMutants", "=", "5000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutationalEffects", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"seq", "=", 
       RowBox[{"walk", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"-", "k"}], ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"mutant", "=", "seq"}], ";", "\[IndentingNewLine]", 
      RowBox[{"positionToMutate", "=", 
       RowBox[{"RandomChoice", "[", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"mutant", "[", 
        RowBox[{"[", "positionToMutate", "]"}], "]"}], "=", 
       RowBox[{"RandomChoice", "[", 
        RowBox[{"Complement", "[", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", 
            RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"mutant", "[", 
            RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutEffect", "=", 
       RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
        RowBox[{"seq", ",", "positionToMutate", ",", 
         RowBox[{"mutant", "[", 
          RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", ",", 
         "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"mutationalEffects", ",", "mutEffect"}], "]"}], ";"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "numMutants"}], "}"}]}], "]"}], ",", "k"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutationalEffects", ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Histogram", "[", 
    RowBox[{"mutationalEffects", ",", "50", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\[CapitalDelta]\[CapitalDelta]G due to single mutations\>\"", 
        ",", "\"\<p(\[CapitalDelta]G)\>\""}], "}"}]}]}], "]"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"p4", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{"mutationalEffects", ",", "50", ",", "\"\<PDF\>\"", ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.35"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\[CapitalDelta]\[CapitalDelta]G of random mutations (kcal/mol)\>\
\"", ",", "fontSize"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Probability density\>\"", ",", "fontSize"}], "]"}]}], 
      "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<mean = \>\"", ",", " ", 
    RowBox[{"mutationalEffects", "//", "Mean"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<std = \>\"", ",", " ", 
    RowBox[{"mutationalEffects", "//", "StandardDeviation"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NotebookSave", "[", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.735479510187269*^9, 3.7354796214564333`*^9}, {
   3.7354796739130898`*^9, 3.7354796807718973`*^9}, {3.7359978971653214`*^9, 
   3.735997897569105*^9}, {3.735998471104659*^9, 3.735998480606639*^9}, {
   3.7361164982476788`*^9, 3.736116534834334*^9}, {3.736169956860944*^9, 
   3.736169982233983*^9}, {3.736206458079257*^9, 3.736206532628809*^9}, {
   3.7362065717564707`*^9, 3.736206593402062*^9}, 3.736248306310055*^9, {
   3.7363386195895977`*^9, 3.73633862166341*^9}, {3.7366011074574337`*^9, 
   3.736601120721856*^9}, {3.736601163975389*^9, 3.736601164413031*^9}, {
   3.73677718111275*^9, 3.736777192571426*^9}, {3.736777762873351*^9, 
   3.7367777639516478`*^9}, {3.740838317232752*^9, 3.740838328880559*^9}, {
   3.740916553828636*^9, 3.740916571324912*^9}},
 CellLabel->
  "In[207]:=",ExpressionUUID->"56a159f6-8251-45de-938d-3e7f2e4a75b4"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.85], EdgeForm[{Opacity[0.33599999999999997`], Thickness[
    Small]}], {}, 
    {GrayLevel[0.85], EdgeForm[{Opacity[0.33599999999999997`], Thickness[
     Small]}], RectangleBox[{-4.2, 0}, {-4., 0.001},
      RoundingRadius->0], RectangleBox[{-4., 0}, {-3.8, 0.001},
      RoundingRadius->0], RectangleBox[{-3.4, 0}, {-3.2, 0.001},
      RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3., 0.007},
      RoundingRadius->0], RectangleBox[{-3., 0}, {-2.8, 0.008},
      RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.6, 0.01},
      RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.4, 0.01},
      RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.2, 0.011},
      RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 0.03},
      RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 0.042},
      RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.6, 0.033},
      RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.4, 0.052},
      RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.2, 0.054},
      RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 0.091},
      RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 0.105},
      RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.6, 0.121},
      RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.4, 0.169},
      RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.2, 0.159},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 0.158},
      RoundingRadius->0], RectangleBox[{0., 0}, {0.2, 0.205},
      RoundingRadius->0], RectangleBox[{0.2, 0}, {0.4, 0.23},
      RoundingRadius->0], RectangleBox[{0.4, 0}, {0.6, 0.244},
      RoundingRadius->0], RectangleBox[{0.6, 0}, {0.8, 0.289},
      RoundingRadius->0], RectangleBox[{0.8, 0}, {1., 0.256},
      RoundingRadius->0], RectangleBox[{1., 0}, {1.2, 0.289},
      RoundingRadius->0], RectangleBox[{1.2, 0}, {1.4, 0.304},
      RoundingRadius->0], RectangleBox[{1.4, 0}, {1.6, 0.239},
      RoundingRadius->0], RectangleBox[{1.6, 0}, {1.8, 0.245},
      RoundingRadius->0], RectangleBox[{1.8, 0}, {2., 0.243},
      RoundingRadius->0], RectangleBox[{2., 0}, {2.2, 0.2},
      RoundingRadius->0], RectangleBox[{2.2, 0}, {2.4, 0.215},
      RoundingRadius->0], RectangleBox[{2.4, 0}, {2.6, 0.173},
      RoundingRadius->0], RectangleBox[{2.6, 0}, {2.8, 0.167},
      RoundingRadius->0], RectangleBox[{2.8, 0}, {3., 0.144},
      RoundingRadius->0], RectangleBox[{3., 0}, {3.2, 0.093},
      RoundingRadius->0], RectangleBox[{3.2, 0}, {3.4, 0.087},
      RoundingRadius->0], RectangleBox[{3.4, 0}, {3.6, 0.083},
      RoundingRadius->0], RectangleBox[{3.6, 0}, {3.8, 0.055},
      RoundingRadius->0], RectangleBox[{3.8, 0}, {4., 0.038},
      RoundingRadius->0], RectangleBox[{4., 0}, {4.2, 0.039},
      RoundingRadius->0], RectangleBox[{4.2, 0}, {4.4, 0.035},
      RoundingRadius->0], RectangleBox[{4.4, 0}, {4.6, 0.018},
      RoundingRadius->0], RectangleBox[{4.6, 0}, {4.8, 0.017},
      RoundingRadius->0], RectangleBox[{4.8, 0}, {5., 0.009},
      RoundingRadius->0], RectangleBox[{5., 0}, {5.2, 0.005},
      RoundingRadius->0], RectangleBox[{5.2, 0}, {5.4, 0.004},
      RoundingRadius->0], RectangleBox[{5.4, 0}, {5.6, 0.008},
      RoundingRadius->0], RectangleBox[{6., 0}, {6.2, 0.002},
      RoundingRadius->0], RectangleBox[{6.2, 0}, {6.4, 0.001},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-4.2, 0},
  Frame->True,
  FrameLabel->{{
     FormBox[
      StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\[CapitalDelta]\[CapitalDelta]G of random mutations (kcal/mol)\"", 
       13, StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-4, 6}, {0, 0.35}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.735479601639977*^9, {3.7354796621306343`*^9, 3.735479681564712*^9}, 
   3.735998446613748*^9, 3.735998481291547*^9, 3.735999971259182*^9, 
   3.736004114132079*^9, 3.736067923995982*^9, 3.736068689837146*^9, 
   3.7360690329944363`*^9, 3.736069319275001*^9, 3.736069815496855*^9, 
   3.73607008282407*^9, 3.73607033027465*^9, 3.7361165357037897`*^9, {
   3.7361699602848787`*^9, 3.736169983676572*^9}, 3.7362070048404627`*^9, 
   3.736249159830214*^9, 3.736250179037937*^9, 3.7362514173567877`*^9, 
   3.7362531471236973`*^9, 3.7362713489449863`*^9, 3.736272042373336*^9, 
   3.736293561273551*^9, 3.736294340060359*^9, 3.7362952064502172`*^9, 
   3.7362961344385567`*^9, 3.736337678624757*^9, 3.736338773886529*^9, {
   3.736601100064889*^9, 3.736601129786034*^9}, 3.736601173211384*^9, 
   3.73660263372001*^9, 3.7366299268769503`*^9, 3.736639103174268*^9, 
   3.736777754360633*^9, 3.7367778040580883`*^9, 3.74083901421622*^9, 
   3.740914033210424*^9, 3.740916617372773*^9, 3.740917390687689*^9, 
   3.740930965601551*^9, 3.740959997933139*^9, 3.740963196623488*^9, 
   3.740963481517864*^9, 3.7410006424219027`*^9, 3.741434018129076*^9, 
   3.741525267211825*^9, 3.741689893159243*^9},
 CellLabel->
  "Out[212]=",ExpressionUUID->"01e546f6-9b2d-47d4-83b5-33f30f635396"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean = \"\>", "\[InvisibleSpace]", "1.148805605470458`"}],
  SequenceForm["mean = ", 1.148805605470458],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7359984466227503`*^9, 3.7359984813002977`*^9, 3.735999971269041*^9, 
   3.736004114141719*^9, 3.736067924007407*^9, 3.736068689847459*^9, 
   3.7360690330049677`*^9, 3.736069319285524*^9, 3.736069815507266*^9, 
   3.736070082834591*^9, 3.73607033028447*^9, 3.736116535712811*^9, {
   3.736169960388398*^9, 3.736169983687249*^9}, 3.736207004851611*^9, 
   3.73624915983884*^9, 3.736250179052711*^9, 3.736251417374339*^9, 
   3.736253147137295*^9, 3.736271348953846*^9, 3.736272042385462*^9, 
   3.736293561290567*^9, 3.7362943400693827`*^9, 3.73629520646871*^9, 
   3.736296134456689*^9, 3.736337678653816*^9, 3.736338773903768*^9, {
   3.736601100074278*^9, 3.7366011297949457`*^9}, 3.736601173219514*^9, 
   3.736602633729*^9, 3.7366299268886957`*^9, 3.73663910318207*^9, 
   3.736777754370474*^9, 3.736777804068645*^9, 3.740839014223497*^9, 
   3.740914033220375*^9, 3.740916617381555*^9, 3.740917390695032*^9, 
   3.740930965637142*^9, 3.74095999794096*^9, 3.7409631966354094`*^9, 
   3.740963481525931*^9, 3.741000642430913*^9, 3.741434018136655*^9, 
   3.741525267219821*^9, 3.7416898931694317`*^9},
 CellLabel->
  "During evaluation of \
In[207]:=",ExpressionUUID->"7dc28dfa-77b0-4259-aa40-24ff6bbcc807"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"std = \"\>", "\[InvisibleSpace]", "1.459289870099174`"}],
  SequenceForm["std = ", 1.459289870099174],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7359984466227503`*^9, 3.7359984813002977`*^9, 3.735999971269041*^9, 
   3.736004114141719*^9, 3.736067924007407*^9, 3.736068689847459*^9, 
   3.7360690330049677`*^9, 3.736069319285524*^9, 3.736069815507266*^9, 
   3.736070082834591*^9, 3.73607033028447*^9, 3.736116535712811*^9, {
   3.736169960388398*^9, 3.736169983687249*^9}, 3.736207004851611*^9, 
   3.73624915983884*^9, 3.736250179052711*^9, 3.736251417374339*^9, 
   3.736253147137295*^9, 3.736271348953846*^9, 3.736272042385462*^9, 
   3.736293561290567*^9, 3.7362943400693827`*^9, 3.73629520646871*^9, 
   3.736296134456689*^9, 3.736337678653816*^9, 3.736338773903768*^9, {
   3.736601100074278*^9, 3.7366011297949457`*^9}, 3.736601173219514*^9, 
   3.736602633729*^9, 3.7366299268886957`*^9, 3.73663910318207*^9, 
   3.736777754370474*^9, 3.736777804068645*^9, 3.740839014223497*^9, 
   3.740914033220375*^9, 3.740916617381555*^9, 3.740917390695032*^9, 
   3.740930965637142*^9, 3.74095999794096*^9, 3.7409631966354094`*^9, 
   3.740963481525931*^9, 3.741000642430913*^9, 3.741434018136655*^9, 
   3.741525267219821*^9, 3.7416898931776133`*^9},
 CellLabel->
  "During evaluation of \
In[207]:=",ExpressionUUID->"e9347e00-3afb-42ae-8d13-00e868e74e7d"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Distribution of mutational effects of fixed mutations (i.e. effect of \
mutations along the random walk)\
\>", "Subsubsection",
 CellChangeTimes->{{3.736257539929187*^9, 3.736257565982624*^9}, {
  3.7366214047533207`*^9, 3.736621444401938*^9}, {3.7366214964111547`*^9, 
  3.736621510110113*^9}},ExpressionUUID->"f689051e-54a0-437d-99db-\
a842552775fa"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Differences", "[", 
   RowBox[{
    RowBox[{"Split", "[", 
     RowBox[{"walk", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"5000", ";;"}], ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"p8", " ", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{"%", ",", "50", ",", "\"\<PDF\>\"", ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\[CapitalDelta]\[CapitalDelta]G of fixed mutations \
(kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Probability density\>\"", ",", "fontSize"}], "]"}]}], 
      "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<mean = \>\"", ",", 
   RowBox[{"Mean", "[", "%%", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<std = \>\"", ",", 
   RowBox[{"StandardDeviation", "[", "%%%", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.736257690925364*^9, 3.736257741938539*^9}, {
   3.736257934159856*^9, 3.7362579345062513`*^9}, {3.73625797897139*^9, 
   3.73625800057959*^9}, {3.736258440634775*^9, 3.736258443480323*^9}, {
   3.7362707698107243`*^9, 3.7362708190894327`*^9}, {3.736337641136549*^9, 
   3.7363376419926434`*^9}, {3.7363378754858513`*^9, 3.736337877851149*^9}, {
   3.736338933586541*^9, 3.736338937582765*^9}, {3.736601509447646*^9, 
   3.7366015333540277`*^9}, 3.73660210735041*^9, {3.7408383400740757`*^9, 
   3.740838343232292*^9}, {3.740916631145307*^9, 3.740916644694256*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"8d3c4fbd-37db-45a7-aa98-917f23fa43cd"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.85], EdgeForm[{Opacity[0.40599999999999997`], Thickness[
    Small]}], {}, 
    {GrayLevel[0.85], EdgeForm[{Opacity[0.40599999999999997`], Thickness[
     Small]}], RectangleBox[{-3.8, 0}, {-3.6, 0.006690454950936664},
      RoundingRadius->0], 
     RectangleBox[{-3.6, 0}, {-3.4, 0.011150758251561105},
      RoundingRadius->0], 
     RectangleBox[{-3.4, 0}, {-3.2, 0.0044603033006244425},
      RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3., 0.02007136485280999},
      RoundingRadius->0], 
     RectangleBox[{-3., 0}, {-2.8, 0.015611061552185548},
      RoundingRadius->0], 
     RectangleBox[{-2.8, 0}, {-2.6, 0.01784121320249777},
      RoundingRadius->0], 
     RectangleBox[{-2.6, 0}, {-2.4, 0.024531668153434435},
      RoundingRadius->0], 
     RectangleBox[{-2.4, 0}, {-2.2, 0.03345227475468332},
      RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 0.05575379125780553},
      RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 0.10927743086529884},
      RoundingRadius->0], 
     RectangleBox[{-1.8, 0}, {-1.6, 0.12934879571810884},
      RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.4, 0.1271186440677966},
      RoundingRadius->0], 
     RectangleBox[{-1.4, 0}, {-1.2, 0.16057091882247992},
      RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 0.18510258697591436},
      RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 0.18287243532560213},
      RoundingRadius->0], 
     RectangleBox[{-0.8, 0}, {-0.6, 0.28768956289027653},
      RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.4, 0.2943800178412132},
      RoundingRadius->0], 
     RectangleBox[{-0.4, 0}, {-0.2, 0.33006244424620873},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 0.43487957181088316},
      RoundingRadius->0], RectangleBox[{0., 0}, {0.2, 0.4304192685102587},
      RoundingRadius->0], RectangleBox[{0.2, 0}, {0.4, 0.41480820695807313},
      RoundingRadius->0], RectangleBox[{0.4, 0}, {0.6, 0.33006244424620873},
      RoundingRadius->0], RectangleBox[{0.6, 0}, {0.8, 0.2832292595896521},
      RoundingRadius->0], RectangleBox[{0.8, 0}, {1., 0.2586975914362177},
      RoundingRadius->0], RectangleBox[{1., 0}, {1.2, 0.18510258697591436},
      RoundingRadius->0], RectangleBox[{1.2, 0}, {1.4, 0.1694915254237288},
      RoundingRadius->0], RectangleBox[{1.4, 0}, {1.6, 0.1271186440677966},
      RoundingRadius->0], RectangleBox[{1.6, 0}, {1.8, 0.11819803746654772},
      RoundingRadius->0], RectangleBox[{1.8, 0}, {2., 0.0735950044603033},
      RoundingRadius->0], RectangleBox[{2., 0}, {2.2, 0.05352363960749331},
      RoundingRadius->0], RectangleBox[{2.2, 0}, {2.4, 0.03568242640499554},
      RoundingRadius->0], RectangleBox[{2.4, 0}, {2.6, 0.024531668153434435},
      RoundingRadius->0], RectangleBox[{2.6, 0}, {2.8, 0.026761819803746655},
      RoundingRadius->0], RectangleBox[{2.8, 0}, {3., 0.008920606601248885},
      RoundingRadius->0], RectangleBox[{3., 0}, {3.2, 0.011150758251561105},
      RoundingRadius->0], RectangleBox[{3.2, 0}, {3.4, 0.006690454950936664},
      RoundingRadius->0], 
     RectangleBox[{3.4, 0}, {3.6, 0.0022301516503122213},
      RoundingRadius->0], 
     RectangleBox[{3.6, 0}, {3.8, 0.0022301516503122213},
      RoundingRadius->0], RectangleBox[{3.8, 0}, {4., 0.0022301516503122213},
      RoundingRadius->0], RectangleBox[{4., 0}, {4.2, 0.0044603033006244425},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-5.2, 0},
  Frame->True,
  FrameLabel->{{
     FormBox[
      StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\[CapitalDelta]\[CapitalDelta]G of fixed mutations (kcal/mol)\"", 13,
        StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-5, 5}, {0, 0.5}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.736630009796743*^9, 3.7366391766301737`*^9, 
  3.736778005127383*^9, 3.740839014704914*^9, 3.7409140350052032`*^9, 
  3.740916645163166*^9, 3.740917391302363*^9, 3.740930967546418*^9, 
  3.740959718507141*^9, 3.740959998509995*^9, 3.7409631997706623`*^9, 
  3.7409634822163143`*^9, 3.741000642901009*^9, 3.7414340184373713`*^9, 
  3.741525267797327*^9, 3.7416898934778757`*^9},
 CellLabel->
  "Out[217]=",ExpressionUUID->"e435c740-f3ca-4f57-89b5-2ecf4b01f380"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0007408240764790768`"}]}],
  SequenceForm["mean = ", -0.0007408240764790768],
  Editable->False]], "Print",
 CellChangeTimes->{3.736630009812327*^9, 3.736639176645504*^9, 
  3.7367780051438227`*^9, 3.74083901471509*^9, 3.74091403501597*^9, 
  3.740916645178637*^9, 3.740917391312904*^9, 3.740930967560513*^9, 
  3.7409597185237217`*^9, 3.740959998520899*^9, 3.740963199815481*^9, 
  3.740963482227716*^9, 3.741000642914898*^9, 3.741434018447562*^9, 
  3.7415252678113813`*^9, 3.7416898934875526`*^9},
 CellLabel->
  "During evaluation of \
In[216]:=",ExpressionUUID->"5fbd9f8b-e8cd-4406-823c-845d1de35431"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"std = \"\>", "\[InvisibleSpace]", "1.1219011050320176`"}],
  SequenceForm["std = ", 1.1219011050320176`],
  Editable->False]], "Print",
 CellChangeTimes->{3.736630009812327*^9, 3.736639176645504*^9, 
  3.7367780051438227`*^9, 3.74083901471509*^9, 3.74091403501597*^9, 
  3.740916645178637*^9, 3.740917391312904*^9, 3.740930967560513*^9, 
  3.7409597185237217`*^9, 3.740959998520899*^9, 3.740963199815481*^9, 
  3.740963482227716*^9, 3.741000642914898*^9, 3.741434018447562*^9, 
  3.7415252678113813`*^9, 3.741689893492428*^9},
 CellLabel->
  "During evaluation of \
In[216]:=",ExpressionUUID->"a426f9bb-716a-41f2-9b08-75e47a54940d"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Expected (= sum of single mutant \[CapitalDelta]\[CapitalDelta]Gs) vs. \
observed (= double mutant \[CapitalDelta]\[CapitalDelta]G) energy differences \
for random double mutants\
\>", "Subsubsection",
 CellChangeTimes->{{3.7347161083276777`*^9, 3.734716108595784*^9}, {
   3.734731381514855*^9, 3.7347313835474052`*^9}, {3.7353090522954483`*^9, 
   3.735309083691112*^9}, {3.735339452129043*^9, 3.735339457534835*^9}, {
   3.7353410385182667`*^9, 3.735341039879836*^9}, 3.735341393623418*^9, 
   3.735427415517058*^9, 3.73542893054351*^9, {3.7361162819342957`*^9, 
   3.736116285699304*^9}, {3.7367666926718597`*^9, 3.736766724038699*^9}, {
   3.736769180223175*^9, 3.736769181154467*^9}, {3.740838413081863*^9, 
   3.7408384765613956`*^9}, 
   3.740838534721156*^9},ExpressionUUID->"9b85df32-362b-40c2-8394-\
323064b2510f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"energy", " ", "of", " ", "double", " ", "mutant"}], " ", "-", 
    " ", 
    RowBox[{"energy", " ", "of", " ", "initial", " ", "seq", " ", 
     RowBox[{"vs", ".", " ", "energy"}], " ", "of", " ", "mut1"}], " ", "+", 
    " ", 
    RowBox[{"energy", " ", "of", " ", "mut2"}], " ", "-", " ", 
    RowBox[{
    "2", " ", "x", " ", "energy", " ", "of", " ", "initial", " ", "seq"}]}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SeedRandom", "[", "1234", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numOfDoubleMutants", "=", "500"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"seq", "=", 
     RowBox[{"walk", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eSeq", "=", 
     RowBox[{"walk", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "4"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"pos1", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"pos2", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], ",", 
            RowBox[{"{", "pos1", "}"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newletter1", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", 
              RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"seq", "[", 
              RowBox[{"[", "pos1", "]"}], "]"}], "}"}]}], "]"}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"newletter2", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", 
              RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"seq", "[", 
              RowBox[{"[", "pos2", "]"}], "]"}], "}"}]}], "]"}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"eMut1", "=", 
         RowBox[{"eSeq", "+", 
          RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
           RowBox[{
           "seq", ",", "pos1", ",", "newletter1", ",", "l", ",", "alpha", ",",
             "\[Beta]", ",", "\[Gamma]"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"eMut2", "=", 
         RowBox[{"eSeq", "+", 
          RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
           RowBox[{
           "seq", ",", "pos2", ",", "newletter2", ",", "l", ",", "alpha", ",",
             "\[Beta]", ",", "\[Gamma]"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"eDoubleMut", "=", 
         RowBox[{"eSeq", "+", 
          RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
           RowBox[{
           "seq", ",", "pos1", ",", "newletter1", ",", "l", ",", "alpha", ",",
             "\[Beta]", ",", "\[Gamma]"}], "]"}], "+", 
          RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
           RowBox[{
            RowBox[{"ReplacePart", "[", 
             RowBox[{"seq", ",", 
              RowBox[{"pos1", "\[Rule]", "newletter1"}]}], "]"}], ",", "pos2",
             ",", "newletter2", ",", "l", ",", "alpha", ",", "\[Beta]", ",", 
            "\[Gamma]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"data", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"eDoubleMut", "-", "eSeq"}], ",", 
            RowBox[{"eMut1", "+", "eMut2", "-", 
             RowBox[{"2", "eSeq"}]}]}], "}"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", "numOfDoubleMutants", "}"}]}], "]"}], ",", 
     "numOfDoubleMutants"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p61", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "Small", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "9"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "9"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Sum of single mutant \[CapitalDelta]\[CapitalDelta]Gs \
(kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Double mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\>\"",
             ",", "fontSize"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p62", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "9"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p6", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p61", ",", "p62"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r2", "=", " ", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r2"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", 
      RowBox[{"r2", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<mean difference = \>\"", ",", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<RMS error = \>\"", ",", 
      SqrtBox[
       RowBox[{"Mean", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ")"}], "^", "2"}], 
        "]"}]]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.735406686971858*^9, 3.7354067168543043`*^9}, {
   3.73540678345205*^9, 3.735406826739255*^9}, {3.73540685901604*^9, 
   3.735406859746942*^9}, {3.7354069399079123`*^9, 3.735407274974471*^9}, {
   3.73540736062433*^9, 3.735407421088765*^9}, {3.73540749252798*^9, 
   3.73540763371446*^9}, {3.735407677655581*^9, 3.7354077606036663`*^9}, {
   3.735407813247394*^9, 3.735407813658518*^9}, {3.735407853576527*^9, 
   3.735407854677855*^9}, {3.7354079265357723`*^9, 3.7354079278991413`*^9}, {
   3.735407981005075*^9, 3.735407989270031*^9}, {3.735425651859332*^9, 
   3.73542565942015*^9}, {3.7354265837063923`*^9, 3.7354265974561167`*^9}, {
   3.735426638421446*^9, 3.7354266744583406`*^9}, 3.735428959303252*^9, {
   3.735429006669067*^9, 3.7354290095521917`*^9}, {3.736001792360701*^9, 
   3.736001819156699*^9}, {3.736004287271104*^9, 3.736004311783555*^9}, {
   3.736170047728489*^9, 3.7361700642962627`*^9}, {3.736170108209219*^9, 
   3.736170135840767*^9}, {3.7361791248422318`*^9, 3.736179131073225*^9}, {
   3.736179162999592*^9, 3.736179165825145*^9}, {3.7364620759833803`*^9, 
   3.736462114421009*^9}, {3.736462191949552*^9, 3.736462205635243*^9}, {
   3.7364622698407784`*^9, 3.736462270014674*^9}, {3.7365318341467533`*^9, 
   3.736531864920845*^9}, {3.736601417562611*^9, 3.7366014179599733`*^9}, {
   3.736602039262439*^9, 3.7366020723638487`*^9}, {3.736602185127561*^9, 
   3.73660218961693*^9}, {3.736621817399724*^9, 3.7366218178882723`*^9}, {
   3.736624307159446*^9, 3.736624315854735*^9}, {3.73676672764604*^9, 
   3.7367667296275673`*^9}, {3.736767127866691*^9, 3.736767134118078*^9}, {
   3.736777899769003*^9, 3.7367779314808292`*^9}, {3.740838521393578*^9, 
   3.740838542529643*^9}, {3.740916670261145*^9, 3.740916690889975*^9}, {
   3.740959726356773*^9, 3.740959731658957*^9}, {3.7416893477171593`*^9, 
   3.741689353343567*^9}},
 CellLabel->
  "In[220]:=",ExpressionUUID->"160cea86-ed3e-4bba-b356-bb2ddb70dda7"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJwVmHlcTV0UhneD5lIkKRo06NMgUyXpHGNF0aikSYQISaUSjoRISSqRBoQQ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       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxFxW0w03EcAPDlIVvyMKdFeTxZx0ltnZqn/l7oqIisG0PTxGnJw5m4CicP
l84L4TJd3EkvdC2r02pMeajOcu6kabdjhPOsZiM226xVL/b9vfjcxzs9LyHT
AofDxf7zfz45Y8pkchgwf/lWSKlMi/7zydGDr0InsD+kMWbQ+iek+Zd96HPE
4VVmKXrZcEz7Rm8P+3zTEq9v28GTwXQ3RZ8tTGkOujfRSYDxx9M4tA4b2KMq
ntxeaA3LRr+E87Is4RE53p8XuAeuoHqdVJmM/eYFbWGSIaUOZtauWAkrt+FI
drtWlLEBs+JlczrhGkyRVx19pZ6DbTltAp/qcViafCnK0NgCX/u9w4jAvmLm
7VJPnfadmoFpZOao3/sVeOtZ6Qjhjhq+SMP2riq34OcpBSE2sTp4sJHXY882
woKOpqjyJVyEeUXdpFypsYBrMPmCftcK1pzY724MtIE/B4j13FACTL/RZjnL
tYXT87AHP5/awWNlicLsFw4wboVena9yhCWPaJWLGiIc13Eb89c5waIJRj2H
6AzH1auD5kkHYAmHnJ9IJcF5EhejdehBWF6TFV11xgX2yk7wMya6ws1SXepr
1iF4IzmczLp7GN4XNd2paHCD6d3BNY08d7jkPHXnbJcHLGMvi6liT7god7e1
mOUFc8PofuNraHws/sdIjjesr7spcM5HK6VjZVcK0NKkx56qInRLhj/bqRxN
KYlZSGpAJ/Mfri2+Q8esb4kDe9AYhVlb3Is+IvIOIAyg1z925QQMoysmv6sL
FOhC9+DB3ml01tXWeqtZdMxSJrVpAU3a1HB7lGh8UEqkhRptKO53vrCJnjXe
fzulQY9H/Kr21aGHKuMZuQZ095CQLDKi+QRXrcmE/gujClCz
        "]]},
      Annotation[#, "Charting`Private`Tag$15696382#1"]& ]}, {}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
      "\"Double mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\"", 13, 
       StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"Sum of single mutant \[CapitalDelta]\[CapitalDelta]Gs (kcal/mol)\"", 
       13, StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-4, 9}, {-4, 9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7359984939286013`*^9, 3.7359986330975847`*^9, 3.736000018885736*^9, 
   3.7360042949939117`*^9, 3.736068046739109*^9, 3.7361700872658377`*^9, 
   3.736170131563964*^9, 3.73617900705114*^9, 3.736179146717245*^9, 
   3.736179184283957*^9, 3.736249260071485*^9, 3.7362502824138737`*^9, 
   3.7362515120791883`*^9, 3.736253243647138*^9, 3.73627139210008*^9, 
   3.736272136434506*^9, 3.736293660869244*^9, 3.736294429733201*^9, 
   3.736295296251067*^9, 3.7362962260284777`*^9, {3.736462187462098*^9, 
   3.7364622158817377`*^9}, {3.7364622657670317`*^9, 3.7364622705720673`*^9}, 
   3.736531869153141*^9, 3.736601852726087*^9, 3.736601915987453*^9, {
   3.736602040515409*^9, 3.7366020730089197`*^9}, 3.736602190236808*^9, 
   3.736631157854828*^9, 3.736632232137513*^9, 3.736638706470945*^9, 
   3.736725039118054*^9, 3.736766948150887*^9, 3.736767235781179*^9, 
   3.736769441551003*^9, 3.7367779500762577`*^9, 3.740839031225012*^9, 
   3.74091405126163*^9, 3.7409167078913803`*^9, 3.740917407762827*^9, 
   3.740930983945451*^9, 3.7409600149684477`*^9, 3.740963217019248*^9, 
   3.740963497875451*^9, 3.74100065967587*^9, 3.741434033487118*^9, 
   3.741525283774901*^9, 3.741689909326332*^9},
 CellLabel->
  "Out[228]=",ExpressionUUID->"43ad24e9-206f-4480-8868-942e612aac3c"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", "0.9998326007546892`"}],
  SequenceForm["r = ", 0.9998326007546892],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736179184302801*^9, 3.7362492600838842`*^9, 3.736250282427156*^9, 
   3.736251512092272*^9, 3.7362532436607313`*^9, 3.7362713921135187`*^9, 
   3.736272136445224*^9, 3.736293660886195*^9, 3.736294429745225*^9, 
   3.736295296264433*^9, 3.736296226044639*^9, {3.736462188137496*^9, 
   3.736462216111224*^9}, {3.73646226578023*^9, 3.7364622705860987`*^9}, 
   3.736531869164776*^9, 3.736601852734989*^9, 3.7366019159958887`*^9, {
   3.736602040524077*^9, 3.736602073017405*^9}, 3.736602190245657*^9, 
   3.736631157865602*^9, 3.736632232146834*^9, 3.736638706483376*^9, 
   3.736725039131948*^9, 3.736766948159587*^9, 3.736767235790229*^9, 
   3.736769441559609*^9, 3.736777950085758*^9, 3.740839031232018*^9, 
   3.7409140512698717`*^9, 3.7409167079020042`*^9, 3.7409174077702837`*^9, 
   3.740930983953047*^9, 3.740960014976223*^9, 3.740963217027467*^9, 
   3.740963497883237*^9, 3.741000659683422*^9, 3.741434033498352*^9, 
   3.7415252837828093`*^9, 3.741689909334606*^9},
 CellLabel->
  "During evaluation of \
In[220]:=",ExpressionUUID->"f45fb495-b823-49bd-86b7-b81f23faade3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.9996652295318856`"}],
  SequenceForm["r^2 = ", 0.9996652295318856],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736179184302801*^9, 3.7362492600838842`*^9, 3.736250282427156*^9, 
   3.736251512092272*^9, 3.7362532436607313`*^9, 3.7362713921135187`*^9, 
   3.736272136445224*^9, 3.736293660886195*^9, 3.736294429745225*^9, 
   3.736295296264433*^9, 3.736296226044639*^9, {3.736462188137496*^9, 
   3.736462216111224*^9}, {3.73646226578023*^9, 3.7364622705860987`*^9}, 
   3.736531869164776*^9, 3.736601852734989*^9, 3.7366019159958887`*^9, {
   3.736602040524077*^9, 3.736602073017405*^9}, 3.736602190245657*^9, 
   3.736631157865602*^9, 3.736632232146834*^9, 3.736638706483376*^9, 
   3.736725039131948*^9, 3.736766948159587*^9, 3.736767235790229*^9, 
   3.736769441559609*^9, 3.736777950085758*^9, 3.740839031232018*^9, 
   3.7409140512698717`*^9, 3.7409167079020042`*^9, 3.7409174077702837`*^9, 
   3.740930983953047*^9, 3.740960014976223*^9, 3.740963217027467*^9, 
   3.740963497883237*^9, 3.741000659683422*^9, 3.741434033498352*^9, 
   3.7415252837828093`*^9, 3.7416899093424807`*^9},
 CellLabel->
  "During evaluation of \
In[220]:=",ExpressionUUID->"e14f4de5-14ab-4ef5-ac19-9fe473db044f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean difference = \"\>", "\[InvisibleSpace]", 
   "0.00034388161810443307`"}],
  SequenceForm["mean difference = ", 0.00034388161810443307`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736179184302801*^9, 3.7362492600838842`*^9, 3.736250282427156*^9, 
   3.736251512092272*^9, 3.7362532436607313`*^9, 3.7362713921135187`*^9, 
   3.736272136445224*^9, 3.736293660886195*^9, 3.736294429745225*^9, 
   3.736295296264433*^9, 3.736296226044639*^9, {3.736462188137496*^9, 
   3.736462216111224*^9}, {3.73646226578023*^9, 3.7364622705860987`*^9}, 
   3.736531869164776*^9, 3.736601852734989*^9, 3.7366019159958887`*^9, {
   3.736602040524077*^9, 3.736602073017405*^9}, 3.736602190245657*^9, 
   3.736631157865602*^9, 3.736632232146834*^9, 3.736638706483376*^9, 
   3.736725039131948*^9, 3.736766948159587*^9, 3.736767235790229*^9, 
   3.736769441559609*^9, 3.736777950085758*^9, 3.740839031232018*^9, 
   3.7409140512698717`*^9, 3.7409167079020042`*^9, 3.7409174077702837`*^9, 
   3.740930983953047*^9, 3.740960014976223*^9, 3.740963217027467*^9, 
   3.740963497883237*^9, 3.741000659683422*^9, 3.741434033498352*^9, 
   3.7415252837828093`*^9, 3.741689909352858*^9},
 CellLabel->
  "During evaluation of \
In[220]:=",ExpressionUUID->"571d9079-8299-4379-b728-e045d485644b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RMS error = \"\>", "\[InvisibleSpace]", 
   "0.03739225346988149`"}],
  SequenceForm["RMS error = ", 0.03739225346988149],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736179184302801*^9, 3.7362492600838842`*^9, 3.736250282427156*^9, 
   3.736251512092272*^9, 3.7362532436607313`*^9, 3.7362713921135187`*^9, 
   3.736272136445224*^9, 3.736293660886195*^9, 3.736294429745225*^9, 
   3.736295296264433*^9, 3.736296226044639*^9, {3.736462188137496*^9, 
   3.736462216111224*^9}, {3.73646226578023*^9, 3.7364622705860987`*^9}, 
   3.736531869164776*^9, 3.736601852734989*^9, 3.7366019159958887`*^9, {
   3.736602040524077*^9, 3.736602073017405*^9}, 3.736602190245657*^9, 
   3.736631157865602*^9, 3.736632232146834*^9, 3.736638706483376*^9, 
   3.736725039131948*^9, 3.736766948159587*^9, 3.736767235790229*^9, 
   3.736769441559609*^9, 3.736777950085758*^9, 3.740839031232018*^9, 
   3.7409140512698717`*^9, 3.7409167079020042`*^9, 3.7409174077702837`*^9, 
   3.740930983953047*^9, 3.740960014976223*^9, 3.740963217027467*^9, 
   3.740963497883237*^9, 3.741000659683422*^9, 3.741434033498352*^9, 
   3.7415252837828093`*^9, 3.7416899093604507`*^9},
 CellLabel->
  "During evaluation of \
In[220]:=",ExpressionUUID->"736cb7d2-8802-430d-9a46-b4ab430f7986"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Difference in effect of fixed mutations at 50% sequence divergence\
\>", "Subsubsection",
 CellChangeTimes->{{3.7353395164645443`*^9, 3.735339536648769*^9}, {
   3.7354274025280952`*^9, 3.735427404516264*^9}, {3.735427511841661*^9, 
   3.735427515072527*^9}, {3.740838599380863*^9, 3.7408386336032467`*^9}, 
   3.740838663703212*^9},ExpressionUUID->"bf451520-7dca-44fe-be1e-\
43d3319e5533"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"seq1", " ", "=", " ", 
     RowBox[{
     "drawn", " ", "from", " ", "stationary", " ", "dist", " ", "of", " ", 
      "random", " ", "walk"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"seq2", " ", "=", " ", 
     RowBox[{
     "random", " ", "walk", " ", "continued", " ", "from", " ", "seq1", " ", 
      "until", " ", "seq1", " ", "and", " ", "seq2", " ", "differ", " ", "in",
       " ", "half", " ", "of", " ", "sites"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"data", " ", "=", " ", 
     RowBox[{"list", " ", "of", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mutEffect", " ", "on", " ", "energy", " ", "of", " ", "seq1"}], ",", 
        " ", 
        RowBox[{
        "mutEffect", " ", "on", " ", "energy", " ", "of", " ", "seq2"}]}], 
       "}"}], " ", "pairs", " ", "for", " ", "mutations", " ", "specified", 
      " ", "by", " ", "the", " ", "sites", " ", "that", " ", "differ", " ", 
      "in", " ", "the", " ", "two", " ", "sequences"}]}]}], " ", 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SeedRandom", "[", "12345678", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPairsOfSeqs", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numDifferentSites", "=", 
     RowBox[{"l", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Monitor", "[", 
      RowBox[{
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"seq1", "=", 
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"seq2", "=", 
           RowBox[{
            RowBox[{
            "RandomWalkBasedOnTotalEnergyUntilGivenSeqDivergence", "[", 
             RowBox[{
             "seq1", ",", "energyCutoff", ",", "l", ",", "alpha", ",", 
              "\[Beta]", ",", "\[Gamma]", ",", "numDifferentSites"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positions", "=", 
           RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"seq1", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "\[NotEqual]", 
               RowBox[{"seq2", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], ",", " ", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"positions", ",", "k"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "1", ",", "l"}], "}"}]}], "]"}], ";", " ", 
          RowBox[{"(*", 
           RowBox[{
           "list", " ", "of", " ", "positions", " ", "in", " ", "which", " ", 
            "seq1", " ", "and", " ", "seq2", " ", "differ"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"data", "=", 
           RowBox[{"data", "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
                 RowBox[{"seq1", ",", 
                  RowBox[{"positions", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], ",", 
                  RowBox[{"seq2", "[", 
                   RowBox[{"[", 
                    RowBox[{"positions", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], "]"}], ",", 
                  "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], "]"}],
                 ",", 
                RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
                 RowBox[{"seq2", ",", 
                  RowBox[{"positions", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], ",", 
                  RowBox[{"seq1", "[", 
                   RowBox[{"[", 
                    RowBox[{"positions", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], "]"}], ",", 
                  "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], 
                 "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "1", ",", "numDifferentSites"}], "}"}]}], 
             "]"}]}]}], ";"}], "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "numPairsOfSeqs"}], "}"}]}], "]"}], ",",
        "n"}], "]"}], ";"}], "//", "AbsoluteTiming"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"scatter", " ", "plot", " ", "of", " ", 
     RowBox[{"(", 
      RowBox[{"mutEffect", " ", "on", " ", "energy", " ", "of", " ", "seq1"}],
       ")"}], " ", 
     RowBox[{"vs", ".", " ", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
        "mutEffect", " ", "on", " ", "energy", " ", "of", " ", "seq2"}], 
        ")"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"data", ".", 
      RowBox[{"(", GridBox[{
         {"1", "0"},
         {"0", 
          RowBox[{"-", "1"}]}
        }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"p71", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"data", ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"PointSize", "[", "Small", "]"}]}], "}"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Single mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\\n \
in background 1\>\"", ",", "fontSize"}], "]"}], ",", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Single mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\\n \
in background 2 \>\"", ",", "fontSize"}], "]"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p71", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "Small", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Single mutant \[CapitalDelta]\[CapitalDelta]G background \
1\>\"", ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Single mutant \[CapitalDelta]\[CapitalDelta]G background 2 \>\
\"", ",", "fontSize"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p72", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p7", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p71", ",", "p72"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", " ", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", 
      RowBox[{"r", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<mean difference = \>\"", ",", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<RMS error = \>\"", ",", 
      SqrtBox[
       RowBox[{"Mean", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ")"}], "^", "2"}], 
        "]"}]]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.736206709882655*^9, 3.7362067874243593`*^9}, {
   3.7362068442805643`*^9, 3.736206890573965*^9}, 3.736206961713521*^9, 
   3.736248118577738*^9, {3.73633802170438*^9, 3.736338023088297*^9}, {
   3.73662188425014*^9, 3.736621954888335*^9}, {3.736621985961336*^9, 
   3.736622156567801*^9}, {3.7366222439684477`*^9, 3.736622245673703*^9}, {
   3.73662235624082*^9, 3.736622499787359*^9}, 3.736622551270679*^9, {
   3.7366225929351587`*^9, 3.7366226334717607`*^9}, 3.736622966836672*^9, {
   3.7366230822409563`*^9, 3.736623120976296*^9}, {3.736623446640052*^9, 
   3.736623452370851*^9}, {3.736623560840127*^9, 3.736623561050066*^9}, 
   3.736624329134158*^9, 3.736624419304886*^9, {3.7367779850189133`*^9, 
   3.736777985782564*^9}, {3.740838646154624*^9, 3.740838659350313*^9}, {
   3.740839460398666*^9, 3.7408394651845913`*^9}, {3.740916861485692*^9, 
   3.740916880224134*^9}, {3.740959452983892*^9, 3.740959499111898*^9}, {
   3.74095974235343*^9, 3.7409597428380213`*^9}, {3.741433781251788*^9, 
   3.7414338082417088`*^9}, {3.741525039980011*^9, 3.7415250450439863`*^9}, {
   3.741689365461298*^9, 3.7416893708809643`*^9}, {3.74169042747841*^9, 
   3.7416904278619204`*^9}},ExpressionUUID->"49859d39-60ff-4cce-9a44-\
30019168fa94"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.500958`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.7415253621632147`*^9, 3.741689918224368*^9},
 CellLabel->
  "Out[239]=",ExpressionUUID->"2119b27c-5fbf-4c5a-b77e-513600e8c886"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJwVlvk71AsbxsfYxtIiRWiRtKAkSbZ6hjpSRFnrVAjVIZWikmTLOVpROnJk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       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxF1O0vFAAcwPG74xhxL7rO1tku7nba0fQwT3MqTDFjxSHWVbccye6mmTw1
mkZcoZuhOi21PBNJWapDXDqTTrFMGi4x5yHGdWd3nGrrfr8X333+g6/zxZTI
BBKBQAj/2z/j26SrOzvWvWb3GOku3C1UcbKWn76Jukx1DS6voYt2s08m1OiV
ZM/Yjn40l/2tN7EQlVWxyoYpaPV0UUqEjRXoMMI7xaGRQeVpXtAQ2xIM4bDT
WEwL0LeVX6c6SAINtxKpRzhE8Le+puL8fgKoYJZ5dItNPWa55OsdbsItsNzf
2zsgxwDGP4idW6zeBFX1DBuiTAcy7J4d7unUgrZO8ypN0zooiiq419CwBgr6
p4cYZSsg86gp4n2eBmxM6lC/6ZwDkzfa+bdlatA9lxxnxZoEqVljuyqrRsFx
oci1bXYAzMh2LR2saAWb7vj41xx6etxs6eW8r4IbH0B7bRi3JWIUnEkb8EjP
nwR/dYX3ZSjVYF3hY4FQMgeydc3UzCoNOPV8n5ybtAJG350pWpKugQ9ri+Vh
leug5VnxCjlLC34SNNZH5uvAl/b0c3rRJugic16wDjOAhvT87WbeFrhkcKQ0
+JjAR5cKxxxZBH+z0oCPxXvZRJCS0hzYTyOB3UGv5J10C3BbfMErhmIJEq2/
3HfbRr1CUvtCCVag4XvLAm0dDRIppeE6tMQ461NgQJ3ojhItyRoMPiPhjFLR
8s8JyVJP1H2AsWybhWZG+5YH5qDvfkb7ZeehURYlxRoJes3feEApQ5Wvx8UF
b9HdoRs0eS/Kn6B0axXoqv4ERTiMOni+aA2cQgUKVUz2D7SRt2Rqn0f9Upmn
nFfRm8Rj+tgNdEQaVy3Vo3Snq8FKI/r/W+AfYipULQ==
        "]]},
      Annotation[#, "Charting`Private`Tag$16524874#1"]& ]}, {}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
      "\"Single mutant \[CapitalDelta]\[CapitalDelta]G background 2 \"", 13, 
       StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"Single mutant \[CapitalDelta]\[CapitalDelta]G background 1\"", 13, 
       StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-3, 3}, {-3, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7415253621632147`*^9, 3.7416899183394547`*^9},
 CellLabel->
  "Out[243]=",ExpressionUUID->"65b1f6ea-4428-4edd-acbd-6adb15d8f8bd"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", "0.9317518810917661`"}],
  SequenceForm["r = ", 0.9317518810917661],
  Editable->False]], "Print",
 CellChangeTimes->{3.741525358976334*^9, 3.741689918350226*^9},
 CellLabel->
  "During evaluation of \
In[235]:=",ExpressionUUID->"be6940cc-5d14-499d-8928-b822a2f50933"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.8681615679180447`"}],
  SequenceForm["r^2 = ", 0.8681615679180447],
  Editable->False]], "Print",
 CellChangeTimes->{3.741525358976334*^9, 3.741689918358083*^9},
 CellLabel->
  "During evaluation of \
In[235]:=",ExpressionUUID->"159be604-15de-45b0-a2aa-b8fe76fc97e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean difference = \"\>", "\[InvisibleSpace]", 
   "0.11131466516241026`"}],
  SequenceForm["mean difference = ", 0.11131466516241026`],
  Editable->False]], "Print",
 CellChangeTimes->{3.741525358976334*^9, 3.741689918368806*^9},
 CellLabel->
  "During evaluation of \
In[235]:=",ExpressionUUID->"3a5e41c1-968f-4509-8da7-dae03ee9e25d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RMS error = \"\>", "\[InvisibleSpace]", "0.497655166977359`"}],
  
  SequenceForm["RMS error = ", 0.497655166977359],
  Editable->False]], "Print",
 CellChangeTimes->{3.741525358976334*^9, 3.741689918376421*^9},
 CellLabel->
  "During evaluation of \
In[235]:=",ExpressionUUID->"0f43f056-d934-4666-8940-9004594178be"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Expected vs. observed energy differences for random single mutants\
\>", "Subsubsection",
 CellChangeTimes->{{3.7347161083276777`*^9, 3.734716108595784*^9}, {
   3.734731381514855*^9, 3.7347313835474052`*^9}, {3.7353090522954483`*^9, 
   3.735309083691112*^9}, {3.735339452129043*^9, 3.735339457534835*^9}, {
   3.7353410385182667`*^9, 3.735341039879836*^9}, 3.735341393623418*^9, 
   3.735427415517058*^9, 3.73542893054351*^9, {3.7361162819342957`*^9, 
   3.736116285699304*^9}, 
   3.736767870333599*^9},ExpressionUUID->"7f509ed3-5979-4fad-9ea3-\
f02e1f3873f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "additive", " ", "energy", " ", "of", " ", "single", " ", "mutant"}], 
      " ", "-", " ", 
      RowBox[{
      "additive", " ", "energy", " ", "of", " ", "initial", " ", "seq"}]}], 
     ")"}], " ", "vs", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "total", " ", "energy", " ", "of", " ", "single", " ", "mutant"}], " ", 
      "-", " ", 
      RowBox[{
      "total", " ", "energy", " ", "of", " ", "initial", " ", "seq"}]}], 
     ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"getAllSingleMutationEffectsInTotalEnergy", "[", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], ",", "l", ",", 
           "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], "]"}], ",", 
         RowBox[{"getAllSingleMutationEffectsInAdditiveEnergy", "[", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], ",", "l", ",", 
           "alpha", ",", "\[Beta]"}], "]"}]}], "}"}], "]"}]}], ";"}], "//", 
    "AbsoluteTiming"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p51", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"GrayLevel", "[", 
           RowBox[{"0", ",", ".3"}], "]"}], ",", 
          RowBox[{"PointSize", "[", "Small", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Single mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\>\"",
             ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Single mutant \!\(\*SubscriptBox[\(\[CapitalDelta]\
\[CapitalDelta]G\), \(add\)]\) (kcal/mol)\>\"", ",", "fontSize"}], "]"}]}], 
         "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p52", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p5", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p51", ",", "p52"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r1", "=", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r1"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", " ", 
      RowBox[{"r1", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.736777830658575*^9, 3.7367778362605543`*^9}, {
  3.740838691678451*^9, 3.7408386922220373`*^9}, {3.740838771622575*^9, 
  3.7408387731865597`*^9}, {3.740916906694397*^9, 3.7409169202380857`*^9}, {
  3.7416893819249353`*^9, 3.741689386735137*^9}},
 CellLabel->
  "In[250]:=",ExpressionUUID->"1f21178e-89b3-434c-8a7e-0e554c6a4ae3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"50.114459`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.736769440844256*^9, 3.736777818384892*^9, 
  3.736777886315172*^9, 3.740839209440606*^9, 3.740914117903694*^9, 
  3.740916972926309*^9, 3.740917474028191*^9, 3.740931047796743*^9, 
  3.740960078713025*^9, 3.740963281316945*^9, 3.74096355937424*^9, 
  3.741000722424354*^9, 3.741434092517158*^9, 3.741525344985045*^9, 
  3.741689968820064*^9},
 CellLabel->
  "Out[250]=",ExpressionUUID->"cacb99eb-7d76-4677-9c1f-1d8a9564bda4"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], Opacity[0.3], 
      PointBox[CompressedData["
1:eJwUl3c8le8fxo9jb0pooZSVJESoPrcSEZKRUsgqhNKgSJS+DSFJEcpIQpKV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       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxFxX0w03EcAOCZbWymNWEn3eXl7HTsOpzVvGSdnF+Y3YaTuOtyrXOuQziU
lC62K91yCTHruopoiavzUqgV2R1ZS3GVOkq2Zi4va5mX86v+2Of7x3OPd2au
WEIkEAiCf/6/rlX8wHGG2vab1cD5njW00uv5Yq4Zzc+fWZ/Wo6Vufkz1GJqZ
8SiyXIH2N6rrCPvQqfZ6zC5nG+w0Ij8R/IwOszurPh3ydYKbpaEa8Q0qXLoY
eap61gHuLW7M7hBS4MTrKV5bDSQ4VjmQiC0Q4RbNmcmCdDu433FPwC0R/sL2
hpqSwWJvwnjagfMy2hr8hBXCSFVZYK6rTmysXIHHs5Np3bxf8MucfpFMZoCF
S4VbX7Fv8NkiIdNAnoD9GA9neK/UcLK4b3IA64qy3cZJcL/9ehwur8IWyOJp
OCGg1b64SA/zaqZUEt0C/LapfX9I5TIsiu8M/DD3Gyb10XIe062wA6WVH1S8
AcfkmbyfvtuCPwui/aPWCHzbPFGwY76KCAeFjskH+SRY49/X5KElw+Qrceao
Mgd4arRyqYJBhdNKM7mNgzQ4z8nkoz1Kh31Vw3WUeWf4Qm90EkPBgMOSuOmK
+u2w40XPoPp8JtzMfRBXe9gFln+R9/i47IDjeUPYTRM6WSrkKLtd4cD0ipR7
ZW7wRz31Tk2KO6zLnDvospsFz5LuW2t90H9asjo82GhPk2mXNwd9smBldW84
euMS3i5IRbObPXZevobmxU7p6DXoBGOTrLoOfZrjZalXovu72LoWFVo8HCId
0qAlWZYIbBRdQusxj2rRysSw4+8n0D8n+RHfZ9HrJUSzxIB29hxqM86jg4/F
spaX0TF2VG2hBX3k7kiF1YrOjrkafm4TXWYQrOA4+i88TTkH
        "]]},
      Annotation[#, "Charting`Private`Tag$22589770#1"]& ]}, {}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
      "\"Single mutant \
\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]\[CapitalDelta]G\\), \\(add\\)]\\) \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"Single mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\"", 13, 
       StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-4, 6}, {-4, 6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.736769440844256*^9, 3.736777818384892*^9, 
  3.736777886315172*^9, 3.740839209440606*^9, 3.740914117903694*^9, 
  3.740916972926309*^9, 3.740917474028191*^9, 3.740931047796743*^9, 
  3.740960078713025*^9, 3.740963281316945*^9, 3.74096355937424*^9, 
  3.741000722424354*^9, 3.741434092517158*^9, 3.741525344985045*^9, 
  3.741689968929277*^9},
 CellLabel->"Out[253]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"e7db313c-1782-4ed3-92b8-2f972511c0ca"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", "0.9421339894019485`"}],
  SequenceForm["r = ", 0.9421339894019485],
  Editable->False]], "Print",
 CellChangeTimes->{3.7367694409909363`*^9, 3.736777819874146*^9, 
  3.736777886436615*^9, 3.740839209534237*^9, 3.740914118029724*^9, 
  3.740916973061141*^9, 3.740917474148041*^9, 3.7409310479047213`*^9, 
  3.740960078859006*^9, 3.7409632814550743`*^9, 3.7409635594686003`*^9, 
  3.741000722570197*^9, 3.741434092593259*^9, 3.7415253451374283`*^9, 
  3.74168996893748*^9},
 CellLabel->
  "During evaluation of \
In[250]:=",ExpressionUUID->"db5b0f82-4e31-4416-89b9-9c2a17f51b9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.8876164539864307`"}],
  SequenceForm["r^2 = ", 0.8876164539864307],
  Editable->False]], "Print",
 CellChangeTimes->{3.7367694409909363`*^9, 3.736777819874146*^9, 
  3.736777886436615*^9, 3.740839209534237*^9, 3.740914118029724*^9, 
  3.740916973061141*^9, 3.740917474148041*^9, 3.7409310479047213`*^9, 
  3.740960078859006*^9, 3.7409632814550743`*^9, 3.7409635594686003`*^9, 
  3.741000722570197*^9, 3.741434092593259*^9, 3.7415253451374283`*^9, 
  3.741689968945096*^9},
 CellLabel->
  "During evaluation of \
In[250]:=",ExpressionUUID->"a5b80f1e-7e26-4840-890c-92ed4137a73f"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics for paper", "Subsubsection",
 CellChangeTimes->{{3.7362499101622057`*^9, 
  3.736249912896838*^9}},ExpressionUUID->"975a4972-3b6a-4873-9e71-\
d3509a8afec9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p3", ",", "p4", ",", "p8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p6", ",", "p7", ",", "p5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p2", ",", "SpanFromLeft", ",", "SpanFromLeft"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "900"}]}], "]"}]], "Input",
 CellLabel->
  "In[258]:=",ExpressionUUID->"6d8771b1-b807-4a13-a0a0-558cdb31726f"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {GrayLevel[0.85], EdgeForm[{Opacity[0.196], Thickness[Small]}], {}, 
         {GrayLevel[0.85], EdgeForm[{Opacity[0.196], Thickness[Small]}], 
          RectangleBox[{-7., 0}, {-6.9, 0.004},
           RoundingRadius->0], RectangleBox[{-6.9, 0}, {-6.8, 0.002},
           RoundingRadius->0], RectangleBox[{-6.7, 0}, {-6.6, 0.002},
           RoundingRadius->0], RectangleBox[{-6.6, 0}, {-6.5, 0.002},
           RoundingRadius->0], RectangleBox[{-6.5, 0}, {-6.4, 0.002},
           RoundingRadius->0], RectangleBox[{-6.4, 0}, {-6.3, 0.002},
           RoundingRadius->0], RectangleBox[{-6.3, 0}, {-6.2, 0.004},
           RoundingRadius->0], RectangleBox[{-6.1, 0}, {-6., 0.002},
           RoundingRadius->0], RectangleBox[{-5.9, 0}, {-5.8, 0.002},
           RoundingRadius->0], RectangleBox[{-5.5, 0}, {-5.4, 0.008},
           RoundingRadius->0], RectangleBox[{-5.4, 0}, {-5.3, 0.002},
           RoundingRadius->0], RectangleBox[{-5.3, 0}, {-5.2, 0.002},
           RoundingRadius->0], RectangleBox[{-5.2, 0}, {-5.1, 0.006},
           RoundingRadius->0], RectangleBox[{-5.1, 0}, {-5., 0.004},
           RoundingRadius->0], RectangleBox[{-5., 0}, {-4.9, 0.002},
           RoundingRadius->0], RectangleBox[{-4.9, 0}, {-4.8, 0.004},
           RoundingRadius->0], RectangleBox[{-4.8, 0}, {-4.7, 0.014},
           RoundingRadius->0], RectangleBox[{-4.7, 0}, {-4.6, 0.012},
           RoundingRadius->0], RectangleBox[{-4.6, 0}, {-4.5, 0.012},
           RoundingRadius->0], RectangleBox[{-4.5, 0}, {-4.4, 0.026},
           RoundingRadius->0], RectangleBox[{-4.4, 0}, {-4.3, 0.014},
           RoundingRadius->0], RectangleBox[{-4.3, 0}, {-4.2, 0.006},
           RoundingRadius->0], RectangleBox[{-4.2, 0}, {-4.1, 0.012},
           RoundingRadius->0], RectangleBox[{-4.1, 0}, {-4., 0.014},
           RoundingRadius->0], RectangleBox[{-4., 0}, {-3.9, 0.022},
           RoundingRadius->0], RectangleBox[{-3.9, 0}, {-3.8, 0.012},
           RoundingRadius->0], RectangleBox[{-3.8, 0}, {-3.7, 0.02},
           RoundingRadius->0], RectangleBox[{-3.7, 0}, {-3.6, 0.032},
           RoundingRadius->0], RectangleBox[{-3.6, 0}, {-3.5, 0.05},
           RoundingRadius->0], RectangleBox[{-3.5, 0}, {-3.4, 0.022},
           RoundingRadius->0], RectangleBox[{-3.4, 0}, {-3.3, 0.022},
           RoundingRadius->0], RectangleBox[{-3.3, 0}, {-3.2, 0.04},
           RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3.1, 0.06},
           RoundingRadius->0], RectangleBox[{-3.1, 0}, {-3., 0.056},
           RoundingRadius->0], RectangleBox[{-3., 0}, {-2.9, 0.046},
           RoundingRadius->0], RectangleBox[{-2.9, 0}, {-2.8, 0.032},
           RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.7, 0.05},
           RoundingRadius->0], RectangleBox[{-2.7, 0}, {-2.6, 0.078},
           RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.5, 0.066},
           RoundingRadius->0], RectangleBox[{-2.5, 0}, {-2.4, 0.064},
           RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.3, 0.088},
           RoundingRadius->0], RectangleBox[{-2.3, 0}, {-2.2, 0.124},
           RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2.1, 0.106},
           RoundingRadius->0], RectangleBox[{-2.1, 0}, {-2., 0.138},
           RoundingRadius->0], RectangleBox[{-2., 0}, {-1.9, 0.186},
           RoundingRadius->0], RectangleBox[{-1.9, 0}, {-1.8, 0.126},
           RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.7, 0.194},
           RoundingRadius->0], RectangleBox[{-1.7, 0}, {-1.6, 0.208},
           RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.5, 0.254},
           RoundingRadius->0], RectangleBox[{-1.5, 0}, {-1.4, 0.224},
           RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.3, 0.236},
           RoundingRadius->0], RectangleBox[{-1.3, 0}, {-1.2, 0.244},
           RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1.1, 0.262},
           RoundingRadius->0], RectangleBox[{-1.1, 0}, {-1., 0.32},
           RoundingRadius->0], RectangleBox[{-1., 0}, {-0.9, 0.404},
           RoundingRadius->0], RectangleBox[{-0.9, 0}, {-0.8, 0.38},
           RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.7, 0.408},
           RoundingRadius->0], RectangleBox[{-0.7, 0}, {-0.6, 0.532},
           RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.5, 0.478},
           RoundingRadius->0], RectangleBox[{-0.5, 0}, {-0.4, 0.666},
           RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.3, 0.798},
           RoundingRadius->0], RectangleBox[{-0.3, 0}, {-0.2, 0.806},
           RoundingRadius->0], RectangleBox[{-0.2, 0}, {-0.1, 0.836},
           RoundingRadius->0], RectangleBox[{-0.1, 0}, {0., 1.15},
           
           RoundingRadius->
            0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-7.14, 0},
       Frame->True,
       FrameLabel->{{
          FormBox[
           StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\[CapitalDelta]G of folding (kcal/mol)\"", 13, StripOnInput -> 
            False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{-7, 0}, {0, 1}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {193.5, -155.18137409255002}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}], InsetBox[
      GraphicsBox[{
        {GrayLevel[0.85], EdgeForm[{Opacity[0.33599999999999997`], Thickness[
         Small]}], {}, 
         {GrayLevel[0.85], EdgeForm[{Opacity[0.33599999999999997`], Thickness[
          Small]}], RectangleBox[{-4.2, 0}, {-4., 0.001},
           RoundingRadius->0], RectangleBox[{-4., 0}, {-3.8, 0.001},
           RoundingRadius->0], RectangleBox[{-3.4, 0}, {-3.2, 0.001},
           RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3., 0.007},
           RoundingRadius->0], RectangleBox[{-3., 0}, {-2.8, 0.008},
           RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.6, 0.01},
           RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.4, 0.01},
           RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.2, 0.011},
           RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 0.03},
           RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 0.042},
           RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.6, 0.033},
           RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.4, 0.052},
           RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.2, 0.054},
           RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 0.091},
           RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 0.105},
           RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.6, 0.121},
           RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.4, 0.169},
           RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.2, 0.159},
           RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 0.158},
           RoundingRadius->0], RectangleBox[{0., 0}, {0.2, 0.205},
           RoundingRadius->0], RectangleBox[{0.2, 0}, {0.4, 0.23},
           RoundingRadius->0], RectangleBox[{0.4, 0}, {0.6, 0.244},
           RoundingRadius->0], RectangleBox[{0.6, 0}, {0.8, 0.289},
           RoundingRadius->0], RectangleBox[{0.8, 0}, {1., 0.256},
           RoundingRadius->0], RectangleBox[{1., 0}, {1.2, 0.289},
           RoundingRadius->0], RectangleBox[{1.2, 0}, {1.4, 0.304},
           RoundingRadius->0], RectangleBox[{1.4, 0}, {1.6, 0.239},
           RoundingRadius->0], RectangleBox[{1.6, 0}, {1.8, 0.245},
           RoundingRadius->0], RectangleBox[{1.8, 0}, {2., 0.243},
           RoundingRadius->0], RectangleBox[{2., 0}, {2.2, 0.2},
           RoundingRadius->0], RectangleBox[{2.2, 0}, {2.4, 0.215},
           RoundingRadius->0], RectangleBox[{2.4, 0}, {2.6, 0.173},
           RoundingRadius->0], RectangleBox[{2.6, 0}, {2.8, 0.167},
           RoundingRadius->0], RectangleBox[{2.8, 0}, {3., 0.144},
           RoundingRadius->0], RectangleBox[{3., 0}, {3.2, 0.093},
           RoundingRadius->0], RectangleBox[{3.2, 0}, {3.4, 0.087},
           RoundingRadius->0], RectangleBox[{3.4, 0}, {3.6, 0.083},
           RoundingRadius->0], RectangleBox[{3.6, 0}, {3.8, 0.055},
           RoundingRadius->0], RectangleBox[{3.8, 0}, {4., 0.038},
           RoundingRadius->0], RectangleBox[{4., 0}, {4.2, 0.039},
           RoundingRadius->0], RectangleBox[{4.2, 0}, {4.4, 0.035},
           RoundingRadius->0], RectangleBox[{4.4, 0}, {4.6, 0.018},
           RoundingRadius->0], RectangleBox[{4.6, 0}, {4.8, 0.017},
           RoundingRadius->0], RectangleBox[{4.8, 0}, {5., 0.009},
           RoundingRadius->0], RectangleBox[{5., 0}, {5.2, 0.005},
           RoundingRadius->0], RectangleBox[{5.2, 0}, {5.4, 0.004},
           RoundingRadius->0], RectangleBox[{5.4, 0}, {5.6, 0.008},
           RoundingRadius->0], RectangleBox[{6., 0}, {6.2, 0.002},
           RoundingRadius->0], RectangleBox[{6.2, 0}, {6.4, 0.001},
           RoundingRadius->
            0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-4.2, 0},
       Frame->True,
       FrameLabel->{{
          FormBox[
           StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\[CapitalDelta]\[CapitalDelta]G of random mutations \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{-4, 6}, {0, 0.35}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {580.5, -155.18137409255002}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}], InsetBox[
      GraphicsBox[{
        {GrayLevel[0.85], EdgeForm[{Opacity[0.40599999999999997`], Thickness[
         Small]}], {}, 
         {GrayLevel[0.85], EdgeForm[{Opacity[0.40599999999999997`], Thickness[
          Small]}], RectangleBox[{-3.8, 0}, {-3.6, 0.006690454950936664},
           RoundingRadius->0], 
          RectangleBox[{-3.6, 0}, {-3.4, 0.011150758251561105},
           RoundingRadius->0], 
          RectangleBox[{-3.4, 0}, {-3.2, 0.0044603033006244425},
           RoundingRadius->0], 
          RectangleBox[{-3.2, 0}, {-3., 0.02007136485280999},
           RoundingRadius->0], 
          RectangleBox[{-3., 0}, {-2.8, 0.015611061552185548},
           RoundingRadius->0], 
          RectangleBox[{-2.8, 0}, {-2.6, 0.01784121320249777},
           RoundingRadius->0], 
          RectangleBox[{-2.6, 0}, {-2.4, 0.024531668153434435},
           RoundingRadius->0], 
          RectangleBox[{-2.4, 0}, {-2.2, 0.03345227475468332},
           RoundingRadius->0], 
          RectangleBox[{-2.2, 0}, {-2., 0.05575379125780553},
           RoundingRadius->0], 
          RectangleBox[{-2., 0}, {-1.8, 0.10927743086529884},
           RoundingRadius->0], 
          RectangleBox[{-1.8, 0}, {-1.6, 0.12934879571810884},
           RoundingRadius->0], 
          RectangleBox[{-1.6, 0}, {-1.4, 0.1271186440677966},
           RoundingRadius->0], 
          RectangleBox[{-1.4, 0}, {-1.2, 0.16057091882247992},
           RoundingRadius->0], 
          RectangleBox[{-1.2, 0}, {-1., 0.18510258697591436},
           RoundingRadius->0], 
          RectangleBox[{-1., 0}, {-0.8, 0.18287243532560213},
           RoundingRadius->0], 
          RectangleBox[{-0.8, 0}, {-0.6, 0.28768956289027653},
           RoundingRadius->0], 
          RectangleBox[{-0.6, 0}, {-0.4, 0.2943800178412132},
           RoundingRadius->0], 
          RectangleBox[{-0.4, 0}, {-0.2, 0.33006244424620873},
           RoundingRadius->0], 
          RectangleBox[{-0.2, 0}, {0., 0.43487957181088316},
           RoundingRadius->0], 
          RectangleBox[{0., 0}, {0.2, 0.4304192685102587},
           RoundingRadius->0], 
          RectangleBox[{0.2, 0}, {0.4, 0.41480820695807313},
           RoundingRadius->0], 
          RectangleBox[{0.4, 0}, {0.6, 0.33006244424620873},
           RoundingRadius->0], 
          RectangleBox[{0.6, 0}, {0.8, 0.2832292595896521},
           RoundingRadius->0], 
          RectangleBox[{0.8, 0}, {1., 0.2586975914362177},
           RoundingRadius->0], 
          RectangleBox[{1., 0}, {1.2, 0.18510258697591436},
           RoundingRadius->0], 
          RectangleBox[{1.2, 0}, {1.4, 0.1694915254237288},
           RoundingRadius->0], 
          RectangleBox[{1.4, 0}, {1.6, 0.1271186440677966},
           RoundingRadius->0], 
          RectangleBox[{1.6, 0}, {1.8, 0.11819803746654772},
           RoundingRadius->0], 
          RectangleBox[{1.8, 0}, {2., 0.0735950044603033},
           RoundingRadius->0], 
          RectangleBox[{2., 0}, {2.2, 0.05352363960749331},
           RoundingRadius->0], 
          RectangleBox[{2.2, 0}, {2.4, 0.03568242640499554},
           RoundingRadius->0], 
          RectangleBox[{2.4, 0}, {2.6, 0.024531668153434435},
           RoundingRadius->0], 
          RectangleBox[{2.6, 0}, {2.8, 0.026761819803746655},
           RoundingRadius->0], 
          RectangleBox[{2.8, 0}, {3., 0.008920606601248885},
           RoundingRadius->0], 
          RectangleBox[{3., 0}, {3.2, 0.011150758251561105},
           RoundingRadius->0], 
          RectangleBox[{3.2, 0}, {3.4, 0.006690454950936664},
           RoundingRadius->0], 
          RectangleBox[{3.4, 0}, {3.6, 0.0022301516503122213},
           RoundingRadius->0], 
          RectangleBox[{3.6, 0}, {3.8, 0.0022301516503122213},
           RoundingRadius->0], 
          RectangleBox[{3.8, 0}, {4., 0.0022301516503122213},
           RoundingRadius->0], 
          RectangleBox[{4., 0}, {4.2, 0.0044603033006244425},
           
           RoundingRadius->
            0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-5.2, 0},
       Frame->True,
       FrameLabel->{{
          FormBox[
           StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\[CapitalDelta]\[CapitalDelta]G of fixed mutations \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{-5, 5}, {0, 0.5}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {967.5, -155.18137409255002}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}]}, {InsetBox[
      GraphicsBox[{{{}, {{}, 
          {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVmHlcTV0UhneD5lIkKRo06NMgUyXpHGNF0aikSYQISaUSjoRISSqRBoQQ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            "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJxFxW0w03EcAPDlIVvyMKdFeTxZx0ltnZqn/l7oqIisG0PTxGnJw5m4CicP
l84L4TJd3EkvdC2r02pMeajOcu6kabdjhPOsZiM226xVL/b9vfjcxzs9LyHT
AofDxf7zfz45Y8pkchgwf/lWSKlMi/7zydGDr0InsD+kMWbQ+iek+Zd96HPE
4VVmKXrZcEz7Rm8P+3zTEq9v28GTwXQ3RZ8tTGkOujfRSYDxx9M4tA4b2KMq
ntxeaA3LRr+E87Is4RE53p8XuAeuoHqdVJmM/eYFbWGSIaUOZtauWAkrt+FI
drtWlLEBs+JlczrhGkyRVx19pZ6DbTltAp/qcViafCnK0NgCX/u9w4jAvmLm
7VJPnfadmoFpZOao3/sVeOtZ6Qjhjhq+SMP2riq34OcpBSE2sTp4sJHXY882
woKOpqjyJVyEeUXdpFypsYBrMPmCftcK1pzY724MtIE/B4j13FACTL/RZjnL
tYXT87AHP5/awWNlicLsFw4wboVena9yhCWPaJWLGiIc13Eb89c5waIJRj2H
6AzH1auD5kkHYAmHnJ9IJcF5EhejdehBWF6TFV11xgX2yk7wMya6ws1SXepr
1iF4IzmczLp7GN4XNd2paHCD6d3BNY08d7jkPHXnbJcHLGMvi6liT7god7e1
mOUFc8PofuNraHws/sdIjjesr7spcM5HK6VjZVcK0NKkx56qInRLhj/bqRxN
KYlZSGpAJ/Mfri2+Q8esb4kDe9AYhVlb3Is+IvIOIAyg1z925QQMoysmv6sL
FOhC9+DB3ml01tXWeqtZdMxSJrVpAU3a1HB7lGh8UEqkhRptKO53vrCJnjXe
fzulQY9H/Kr21aGHKuMZuQZ095CQLDKi+QRXrcmE/gujClCz
             "]]},
           Annotation[#, "Charting`Private`Tag$15696382#1"]& ]}, {}, {}}},
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Double mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\"", 13,
             StripOnInput -> False], TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"Sum of single mutant \[CapitalDelta]\[CapitalDelta]Gs \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{-4, 9}, {-4, 9}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {193.5, -465.54412227765005}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}], InsetBox[
      GraphicsBox[{{{}, {{}, 
          {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVlvk71AsbxsfYxtIiRWiRtKAkSbZ6hjpSRFnrVAjVIZWikmTLOVpROnJk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            "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJxF1O0vFAAcwPG74xhxL7rO1tku7nba0fQwT3MqTDFjxSHWVbccye6mmTw1
mkZcoZuhOi21PBNJWapDXDqTTrFMGi4x5yHGdWd3nGrrfr8X333+g6/zxZTI
BBKBQAj/2z/j26SrOzvWvWb3GOku3C1UcbKWn76Jukx1DS6voYt2s08m1OiV
ZM/Yjn40l/2tN7EQlVWxyoYpaPV0UUqEjRXoMMI7xaGRQeVpXtAQ2xIM4bDT
WEwL0LeVX6c6SAINtxKpRzhE8Le+puL8fgKoYJZ5dItNPWa55OsdbsItsNzf
2zsgxwDGP4idW6zeBFX1DBuiTAcy7J4d7unUgrZO8ypN0zooiiq419CwBgr6
p4cYZSsg86gp4n2eBmxM6lC/6ZwDkzfa+bdlatA9lxxnxZoEqVljuyqrRsFx
oci1bXYAzMh2LR2saAWb7vj41xx6etxs6eW8r4IbH0B7bRi3JWIUnEkb8EjP
nwR/dYX3ZSjVYF3hY4FQMgeydc3UzCoNOPV8n5ybtAJG350pWpKugQ9ri+Vh
leug5VnxCjlLC34SNNZH5uvAl/b0c3rRJugic16wDjOAhvT87WbeFrhkcKQ0
+JjAR5cKxxxZBH+z0oCPxXvZRJCS0hzYTyOB3UGv5J10C3BbfMErhmIJEq2/
3HfbRr1CUvtCCVag4XvLAm0dDRIppeE6tMQ461NgQJ3ojhItyRoMPiPhjFLR
8s8JyVJP1H2AsWybhWZG+5YH5qDvfkb7ZeehURYlxRoJes3feEApQ5Wvx8UF
b9HdoRs0eS/Kn6B0axXoqv4ERTiMOni+aA2cQgUKVUz2D7SRt2Rqn0f9Upmn
nFfRm8Rj+tgNdEQaVy3Vo3Snq8FKI/r/W+AfYipULQ==
             "]]},
           Annotation[#, "Charting`Private`Tag$16524874#1"]& ]}, {}, {}}},
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Single mutant \[CapitalDelta]\[CapitalDelta]G background 2 \"", 
            13, StripOnInput -> False], TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"Single mutant \[CapitalDelta]\[CapitalDelta]G background 1\"", 
            13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{-3, 3}, {-3, 3}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {580.5, -465.54412227765005}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}], InsetBox[
      GraphicsBox[{{{}, {{}, 
          {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], Opacity[
           0.3], PointBox[CompressedData["
1:eJwUl3c8le8fxo9jb0pooZSVJESoPrcSEZKRUsgqhNKgSJS+DSFJEcpIQpKV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            "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJxFxX0w03EcAOCZbWymNWEn3eXl7HTsOpzVvGSdnF+Y3YaTuOtyrXOuQziU
lC62K91yCTHruopoiavzUqgV2R1ZS3GVOkq2Zi4va5mX86v+2Of7x3OPd2au
WEIkEAiCf/6/rlX8wHGG2vab1cD5njW00uv5Yq4Zzc+fWZ/Wo6Vufkz1GJqZ
8SiyXIH2N6rrCPvQqfZ6zC5nG+w0Ij8R/IwOszurPh3ydYKbpaEa8Q0qXLoY
eap61gHuLW7M7hBS4MTrKV5bDSQ4VjmQiC0Q4RbNmcmCdDu433FPwC0R/sL2
hpqSwWJvwnjagfMy2hr8hBXCSFVZYK6rTmysXIHHs5Np3bxf8MucfpFMZoCF
S4VbX7Fv8NkiIdNAnoD9GA9neK/UcLK4b3IA64qy3cZJcL/9ehwur8IWyOJp
OCGg1b64SA/zaqZUEt0C/LapfX9I5TIsiu8M/DD3Gyb10XIe062wA6WVH1S8
AcfkmbyfvtuCPwui/aPWCHzbPFGwY76KCAeFjskH+SRY49/X5KElw+Qrceao
Mgd4arRyqYJBhdNKM7mNgzQ4z8nkoz1Kh31Vw3WUeWf4Qm90EkPBgMOSuOmK
+u2w40XPoPp8JtzMfRBXe9gFln+R9/i47IDjeUPYTRM6WSrkKLtd4cD0ipR7
ZW7wRz31Tk2KO6zLnDvospsFz5LuW2t90H9asjo82GhPk2mXNwd9smBldW84
euMS3i5IRbObPXZevobmxU7p6DXoBGOTrLoOfZrjZalXovu72LoWFVo8HCId
0qAlWZYIbBRdQusxj2rRysSw4+8n0D8n+RHfZ9HrJUSzxIB29hxqM86jg4/F
spaX0TF2VG2hBX3k7kiF1YrOjrkafm4TXWYQrOA4+i88TTkH
             "]]},
           Annotation[#, "Charting`Private`Tag$22589770#1"]& ]}, {}, {}}},
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Single mutant \\!\\(\\*SubscriptBox[\\(\[CapitalDelta]\
\[CapitalDelta]G\\), \\(add\\)]\\) (kcal/mol)\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"Single mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\"", 13,
             StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{-4, 6}, {-4, 6}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {967.5, -465.54412227765005}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}]}, {InsetBox[
      GraphicsBox[{{{{}, {}, 
          TagBox[
           {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[{{-15., -15.}, {5., 5.}}]},
           
           Annotation[#, 
            "Charting`Private`Tag$10088357#1"]& ]}, {}, {}}, {{}, {{}, 
          {GrayLevel[0], PointSize[0.0055000000000000005`], AbsoluteThickness[
           1.6], PointBox[CompressedData["
1:eJxlmXk8lN/3wB9K2dL0ydIiTUVpEYlo40m0KpM2LWqoUImhElKNFtFmSos2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            
            "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0.5], Thickness[Large], Opacity[1.], 
            Dashing[{Small, Small}], LineBox[CompressedData["
1:eJw9lgk01ekbx6/9Zr2/H0UZuq5rv7iLa18eu0wmWaJlSkYxUhTdqJSpG6ZF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             "]]},
           Annotation[#, "Charting`Private`Tag$10088440#1"]& ]}, {}, {}}},
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"\[CapitalDelta]G (kcal/mol)\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]G\\), \\(add\\)]\\) \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->FrontEndValueCache[{{Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
          Automatic, {{-15., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {-10., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {-5., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {5., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {-14., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-13., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-12., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-11., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-9., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-8., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-7., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-6., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-4., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-3., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {3., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {4., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}, {Automatic, {{-10., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {10., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {20., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {30., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {40., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {-20., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-18., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-16., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-14., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-12., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-8., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-6., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-4., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {4., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {6., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {8., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {12., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {14., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {16., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {18., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {22., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {24., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {26., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {28., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {32., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {34., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {36., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {38., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}}],
       GridLines->{{{0, 
           Directive[
            GrayLevel[0.05]]}}, {{0, 
           Directive[
            GrayLevel[0.05]]}}},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       Method->{
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{-15, 40}, {-15, 5}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {580.5, -775.90687046275}, 
      ImageScaled[{0.5, 0.5}], {1134., 288.70953319544185}], {}, {}}}, {}},
  ContentSelectable->True,
  ImageSize->900,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.740963282423924*^9, 3.7409635601023197`*^9, 
  3.74100072330678*^9, 3.7410008400408783`*^9, 3.7414340929332323`*^9, 
  3.741525345977097*^9, 3.741689969525148*^9},
 CellLabel->"Out[258]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"071c91ba-3e01-4939-9396-84b1bdb10ccc"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Random walk based on energy model with independent HOC epistasis\
\>", "Section",
 CellChangeTimes->{{3.736775734341078*^9, 3.7367757863664827`*^9}, {
  3.7368024262546883`*^9, 
  3.7368024347007427`*^9}},ExpressionUUID->"095f0ade-4f0c-46e5-a6d4-\
ab3f9475f734"],

Cell[CellGroupData[{

Cell["Define functions", "Subsection",
 CellChangeTimes->{
  3.7367769343664827`*^9},ExpressionUUID->"a896100c-1d30-4d88-bed2-\
d2b59e696c63"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Construct", " ", "an", " ", "orthonormal", " ", "basis", " ", "in", " ", 
    "the", " ", "subspace", " ", "of", " ", 
    RowBox[{"R", "^", "dim"}], " ", "defined", " ", "by", " ", "the", " ", 
    "constraint", " ", "that", " ", "a", " ", "dim", " ", "long", " ", 
    RowBox[{"vector", "'"}], "s", " ", "elements", " ", "sum", " ", "to", " ",
     "0"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"orthonormalBasisForSubspace1", "[", "alphabetSize_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "dim", ",", " ", "basis", ",", " ", "orthonormalBasis", ",", " ", 
        "basisForSubspace", ",", "randomVector"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", "=", "alphabetSize"}], ";", "\[IndentingNewLine]", 
       RowBox[{"basis", "=", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"1", ",", "dim"}], "]"}], "}"}], "~", "Join", "~", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"j", "==", "k"}], ",", "1", ",", "0"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"dim", "-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"orthonormalBasis", "=", 
          RowBox[{"Orthogonalize", "[", "basis", "]"}]}], ")"}], "//", 
        "MatrixForm"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{"basisForSubspace", "=", 
         RowBox[{"orthonormalBasis", "[", 
          RowBox[{"[", 
           RowBox[{"2", ";;"}], "]"}], "]"}]}], ")"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Draw", " ", "the", " ", "cofficients", " ", "for", " ", "the", " ", 
     "additive", " ", "terms", " ", "in", " ", "the", " ", "energy", " ", 
     "funciton"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"coeffsForOrder1", "[", 
     RowBox[{"alphabetSize_", ",", " ", "basis_", ",", " ", "std_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "randomVector", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"randomVector", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", ",", "std"}], "]"}], ",", 
          RowBox[{"alphabetSize", "-", "1"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"randomVector", ".", "basis"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Construct", " ", "an", " ", "orthonormal", " ", "basis", " ", "in", " ", 
     "the", " ", "subspace", " ", "of", " ", 
     RowBox[{"R", "^", 
      RowBox[{"(", 
       RowBox[{"dim", "^", "2"}], ")"}]}], " ", "defined", " ", "by", " ", 
     "the", " ", "constraint", " ", "that", " ", "all", " ", "row", " ", 
     "and", " ", "all", " ", "column", " ", "sums", " ", "of", " ", "a", " ", 
     "matrix", " ", "equal", " ", "0"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"orthonormalBasisForSubspace2", "[", "alphabetSize_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "dim", ",", "normal1", ",", "normal2", ",", "normal3", ",", 
        "allnormal", ",", " ", "stdBasis", ",", " ", "basis", ",", 
        "orthonormalBasis", ",", "basisForSubspace", ",", "randomVector"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", "=", "alphabetSize"}], ";", "\[IndentingNewLine]", 
       RowBox[{"normal1", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"SparseArray", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
                RowBox[{"i", "\[Equal]", "myi"}]}], "\[Rule]", "1"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"dim", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"myi", ",", "1", ",", 
             RowBox[{"dim", "-", "1"}]}], "}"}]}], "]"}], "//", "Normal"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"normal2", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"SparseArray", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
                RowBox[{"j", "\[Equal]", "myi"}]}], "\[Rule]", "1"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"dim", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"myi", ",", "1", ",", 
             RowBox[{"dim", "-", "1"}]}], "}"}]}], "]"}], "//", "Normal"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"normal3", "=", 
        RowBox[{"{", 
         RowBox[{"ConstantArray", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"dim", ",", "dim"}], "}"}]}], "]"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"allnormal", "=", 
        RowBox[{
        "normal1", "~", "Join", "~", "normal2", "~", "Join", "~", 
         "normal3"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"stdBasis", "=", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"SparseArray", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"i_", ",", "j_"}], "}"}], "/;", 
                  RowBox[{
                   RowBox[{"i", "\[Equal]", "myi"}], "&&", 
                   RowBox[{"j", "\[Equal]", "myj"}]}]}], "\[Rule]", "1"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"dim", ",", "dim"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"myi", ",", "1", ",", 
               RowBox[{"dim", "-", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"myj", ",", "1", ",", 
               RowBox[{"dim", "-", "1"}]}], "}"}]}], "]"}], ",", "1"}], "]"}],
          "//", "Normal"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{"basis", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Flatten", "/@", "allnormal"}], ")"}], "~", "Join", "~", 
          RowBox[{"(", 
           RowBox[{"Flatten", "/@", "stdBasis"}], ")"}]}]}], ")"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"orthonormalBasis", "=", 
          RowBox[{"Orthogonalize", "[", "basis", "]"}]}], ")"}], "//", 
        "MatrixForm"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{"basisForSubspace", "=", 
         RowBox[{"orthonormalBasis", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"2", "dim"}], ";;"}], "]"}], "]"}]}], ")"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Draw", " ", "the", " ", "cofficients", " ", "for", " ", "the", " ", 
     "epistatic", " ", "terms", " ", "in", " ", "the", " ", "energy", " ", 
     "funciton"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"coeffsForOrder2", "[", 
     RowBox[{"alphabetSize_", ",", " ", "basis_", ",", " ", "std_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "randomVector", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"randomVector", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", " ", ",", "std"}], "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"alphabetSize", "-", "1"}], ")"}], "^", "2"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"randomVector", ".", "basis"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"sequence", " ", "to", " ", "design", " ", 
      RowBox[{"matrix", ".", " ", "Converts"}], " ", "a", " ", "sequence", 
      " ", "of", " ", "integers", " ", "into", " ", "the", " ", "one"}], "-", 
     
     RowBox[{
     "hot", " ", "interaction", " ", "terms", " ", "of", " ", "order", " ", 
      "\"\<order\>\""}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"s2d", "[", 
     RowBox[{"seq_", ",", "l_", ",", "alpha_", ",", "order_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sub1", ",", "sub2", ",", "pos"}], "}"}], ",", 
      RowBox[{
       RowBox[{"sub1", "=", 
        RowBox[{"Subsets", "[", 
         RowBox[{"seq", ",", 
          RowBox[{"{", "order", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"sub2", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "i", "}"}], ",", 
            RowBox[{"sub1", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "sub1", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"pos", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"FromDigits", "[", 
            RowBox[{
             RowBox[{"Rest", "[", "#", "]"}], ",", "alpha"}], "]"}], "+", "1",
            "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"alpha", "^", "order"}], ")"}]}]}], "&"}], "/@", 
         "sub2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"SparseArray", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"pos", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "1"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Binomial", "[", 
            RowBox[{"l", ",", "order"}], "]"}], "*", 
           RowBox[{
            RowBox[{"(", "alpha", ")"}], "^", "order"}]}], "}"}]}], "]"}]}]}],
      "]"}]}], " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Calculate", " ", "energy", " ", "of", " ", "sequene"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CalcEnergy", "[", 
     RowBox[{
     "seq_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_"}], 
     "]"}], ":=", 
    RowBox[{
     RowBox[{"\[Beta]", ".", 
      RowBox[{"s2d", "[", 
       RowBox[{"seq", ",", "l", ",", "alpha", ",", "1"}], "]"}]}], "+", 
     RowBox[{"\[Gamma]", ".", 
      RowBox[{"s2d", "[", 
       RowBox[{"seq", ",", "l", ",", "alpha", ",", "2"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Generate", " ", "random", " ", "walk"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalk", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"length", ",", "old", ",", "new", ",", "mutate"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"length", "=", 
        RowBox[{"Length", "[", "start", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{"start", ",", 
          RowBox[{"CalcEnergy", "[", 
           RowBox[{
           "start", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}],
            "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "mutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "mutate"}], "]"}], "]"}], "}"}]}], "]"}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", 
           RowBox[{"CalcEnergy", "[", 
            RowBox[{
             RowBox[{"new", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "l", ",", "alpha", ",", 
             "\[Beta]", ",", "\[Gamma]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"new", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "old"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Start", " ", "at", " ", "sequence", " ", "start", " ", "and", " ", 
      "evolve", " ", "at", " ", "energy", " ", "less", " ", "than", " ", 
      "cutoff", " ", "until", " ", "maxtime", " ", "mutations", " ", "have", 
      " ", "been", " ", "proposed"}], ";", " ", 
     RowBox[{"output", ":", " ", 
      RowBox[{
       RowBox[{"list", " ", "of", " ", "sequence"}], " ", "-", " ", 
       RowBox[{"energy", " ", "pairs", " ", "of", " ", "evolution"}]}]}]}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fastEnergy", "[", 
     RowBox[{"seq_", ",", "l_", ",", "alpha_", ",", "order_", " ", 
      RowBox[{"(*", 
       RowBox[{"order", " ", "of", " ", "interaction"}], "*)"}], ",", 
      "coeffs_"}], 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"corresponding", " ", "coefficients"}], ",", 
       RowBox[{
        RowBox[{"e", ".", "g", ".", "\[Beta]"}], " ", "or", " ", 
        "\[Gamma]"}]}], "*)"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sub1", ",", "sub2", ",", "pos"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sub1", "=", 
        RowBox[{"Subsets", "[", 
         RowBox[{"seq", ",", 
          RowBox[{"{", "order", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"sub2", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "i", "}"}], ",", 
            RowBox[{"sub1", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "sub1", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"pos", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"FromDigits", "[", 
            RowBox[{
             RowBox[{"Rest", "[", "#", "]"}], ",", "alpha"}], "]"}], "+", "1",
            "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"alpha", "^", "order"}], ")"}]}]}], "&"}], "/@", 
         "sub2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{"coeffs", "[", 
         RowBox[{"[", "pos", "]"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"**", "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
         "**"}], "**"}], "**"}], "**"}], "**"}], "*******)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "For", " ", "a", " ", "position", " ", "and", " ", "a", " ", "letter"}], 
     ",", " ", 
     RowBox[{
      RowBox[{"get", " ", "corresponding", " ", "index", " ", "in", " ", 
       RowBox[{"\[Beta]", ".", "\[IndentingNewLine]", "\[Beta]"}], " ", "is", 
       " ", "an", " ", "l", "*", "alpha"}], "-", 
      RowBox[{"long", " ", "vector"}]}], ",", " ", 
     RowBox[{
     "coordinates", " ", "are", " ", "in", " ", "the", " ", "following", " ", 
      
      RowBox[{"order", ":", " ", 
       RowBox[{"(", 
        RowBox[{"position1", ",", "letter1"}], ")"}]}]}], ",", "  ", 
     RowBox[{"(", 
      RowBox[{"position1", ",", "letter2"}], ")"}], ",", "...", ",", " ", 
     RowBox[{"(", 
      RowBox[{"position1", ",", "letterAlpha"}], ")"}], ",", "  ", 
     RowBox[{"(", 
      RowBox[{"position2", ",", "letter1"}], ")"}], ",", "  ", 
     RowBox[{"(", 
      RowBox[{"position2", ",", "letter2"}], ")"}], ",", "...", ",", " ", 
     RowBox[{"(", 
      RowBox[{"positionl", ",", "letterAlpha"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getIndexIn\[Beta]", "[", 
     RowBox[{"position_", ",", "letter_", ",", "l_", ",", "alpha_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "indexIn\[Beta]", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"indexIn\[Beta]", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"position", "-", "1"}], ")"}], "alpha"}], "+", "letter", 
        "+", "1"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "For", " ", "a", " ", "pair", " ", "of", " ", "positions", " ", "and", 
      " ", "a", " ", "pair", " ", "of", " ", "letters"}], ",", " ", 
     RowBox[{"get", " ", "corresponding", " ", "index", " ", "in", " ", 
      RowBox[{"\[Gamma]", ".", "\[IndentingNewLine]", "\[Gamma]"}], " ", "is",
       " ", "made", " ", "up", " ", "of", " ", "lchoose2", " ", "blocks"}], 
     ",", " ", 
     RowBox[{
      RowBox[{
      "each", " ", "corresponding", " ", "to", " ", "a", " ", "pair", " ", 
       "of", " ", "positions"}], ";", " ", 
      RowBox[{
      "the", " ", "blocks", " ", "are", " ", "in", " ", "the", " ", 
       "following", " ", 
       RowBox[{"order", ":", " ", 
        RowBox[{"(", 
         RowBox[{"pos1", ",", "pos2"}], ")"}]}]}]}], ",", 
     RowBox[{"(", 
      RowBox[{"pos1", ",", "pos3"}], ")"}], ",", "...", ",", 
     RowBox[{"(", 
      RowBox[{"pos1", ",", "posl"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"pos2", ",", "pos3"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"pos2", ",", "pos4"}], ")"}], ",", "...", ",", 
     RowBox[{"(", 
      RowBox[{"pos2", ",", "pos1"}], ")"}], ",", "...", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pos", 
         RowBox[{"(", 
          RowBox[{"l", "-", "1"}], ")"}]}], ",", "posl"}], ")"}], ";", " ", 
      RowBox[{
       RowBox[{"each", " ", "block", " ", "is", " ", "a", " ", 
        RowBox[{"alpha", "^", "2"}]}], "-", 
       RowBox[{"long", " ", "vector"}]}]}], ",", " ", 
     RowBox[{
     "each", " ", "coordinate", " ", "in", " ", "the", " ", "vector", " ", 
      "corresponds", " ", "to", " ", "a", " ", "pair", " ", "of", " ", 
      "letters"}], ",", " ", 
     RowBox[{
     "the", " ", "letters", " ", "are", " ", "in", " ", "the", " ", 
      "following", " ", 
      RowBox[{"order", ":", " ", 
       RowBox[{"(", 
        RowBox[{"letter1", ",", "letter1"}], ")"}]}]}], ",", 
     RowBox[{"(", 
      RowBox[{"letter1", ",", "letter2"}], ")"}], ",", "...", ",", 
     RowBox[{"(", 
      RowBox[{"letter1", ",", "letterAlpha"}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{"letter2", ",", "letter", ",", "1"}], ")"}], ",", "...", ",", 
     RowBox[{"(", 
      RowBox[{"letterAlpha", ",", "letterAlpha"}], ")"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"getIndexIn\[Gamma]", "[", 
     RowBox[{
     "position1_", ",", "position2_", ",", "letter1_", ",", "letter2_", ",", 
      "l_", ",", "alpha_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"indexOfBlock", ",", "indexIn\[Gamma]"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"indexOfBlock", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"position1", "-", "1"}], ")"}], "l"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"position1", "-", "1"}], ")"}], 
          RowBox[{"position1", "/", "2"}]}], "+", "position2", "-", 
         "position1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"indexIn\[Gamma]", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"indexOfBlock", "-", "1"}], ")"}], 
          RowBox[{"alpha", "^", "2"}]}], "+", 
         RowBox[{"letter1", " ", "alpha"}], "+", "letter2", "+", "1"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnAdditiveEnergy", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "new", ",", "old\[Beta]", ",", " ", "new\[Beta]", ",", 
        "positionToMutate", ",", "energy", ",", "newEnergy"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"energy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"\[Beta]", ".", 
         RowBox[{"s2d", "[", 
          RowBox[{"start", ",", "l", ",", "alpha", ",", "1"}], "]"}]}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{"start", ",", "energy"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"positionToMutate", "=", 
            RowBox[{"RandomChoice", "[", 
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", "100"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"old\[Beta]", "=", 
            RowBox[{"\[Beta]", "[", 
             RowBox[{"[", 
              RowBox[{"getIndexIn\[Beta]", "[", 
               RowBox[{"positionToMutate", ",", 
                RowBox[{"old", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
                "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"new", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
            RowBox[{"RandomChoice", "[", 
             RowBox[{"Complement", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"new", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
                "}"}]}], "]"}], "]"}]}], ";"}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newEnergy", "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "old"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"output", " ", "is", " ", "timeseries", " ", "of", " ", 
     RowBox[{"{", 
      RowBox[{"sequence", ",", " ", 
       RowBox[{"additive", " ", "energy"}], ",", " ", 
       RowBox[{"epistatic", " ", "energy"}], ",", " ", 
       RowBox[{"total", " ", "energy"}]}], "}"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnTotalEnergy", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "old\[Beta]", ",", "old\[Gamma]indices", ",", "new", ",", 
        "positionToMutate", ",", "positionPairs", ",", "new\[Beta]", ",", 
        "new\[Gamma]indices", ",", "additiveEnergy", ",", "epistaticEnergy", 
        ",", "totalEnergy", ",", "newAdditiveEnergy", ",", 
        "newEpistaticEnergy", ",", "newTotalEnergy"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"additiveEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"\[Beta]", ".", 
          RowBox[{"s2d", "[", 
           RowBox[{"start", ",", "l", ",", "alpha", ",", "1"}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"epistaticEnergy", "=", 
        RowBox[{"+", 
         RowBox[{"fastEnergy", "[", 
          RowBox[{
          "start", ",", "l", ",", "alpha", ",", "2", ",", "\[Gamma]"}], 
          "]"}]}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"\[Gamma]", ".", 
          RowBox[{"s2d", "[", 
           RowBox[{"start", ",", "l", ",", "alpha", ",", "2"}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"totalEnergy", "=", 
        RowBox[{"additiveEnergy", "+", "epistaticEnergy"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{
         "start", ",", "additiveEnergy", ",", "epistaticEnergy", ",", 
          "totalEnergy"}], "}"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"positionToMutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positionPairs", "=", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos1", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
             "]"}], "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos2", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}],
                "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
               "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"new\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newAdditiveEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newEpistaticEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "-", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}], "+", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"newTotalEnergy", "=", 
           RowBox[{"newAdditiveEnergy", "+", "newEpistaticEnergy"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newAdditiveEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "=", "newEpistaticEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "=", " ", "newTotalEnergy"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newTotalEnergy", "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "old"}], ",", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"**", "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
         "**"}], "**"}], "**"}], "**"}], "**"}], "*******)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "calculate", " ", "mutational", " ", "effects", " ", "of", " ", "all", 
      " ", "single", " ", "mutants", " ", "around", " ", "target", " ", 
      "sequence"}], ";", " ", 
     RowBox[{"output", " ", "=", " ", 
      RowBox[{
       RowBox[{
       "matrix", " ", "of", " ", "energies", " ", "of", " ", "mutants"}], " ",
        "-", " ", 
       RowBox[{"energy", " ", "of", " ", "target", " ", "seq"}]}]}]}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"effectOfSingleMutations", "[", 
     RowBox[{
     "target_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_"}],
      "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"wt", ",", "singles"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"wt", "=", 
        RowBox[{"CalcEnergy", "[", 
         RowBox[{
         "target", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"singles", "=", 
        RowBox[{
         RowBox[{"ParallelTable", "[", " ", 
          RowBox[{
           RowBox[{"CalcEnergy", "[", 
            RowBox[{
             RowBox[{"ReplacePart", "[", 
              RowBox[{"target", ",", 
               RowBox[{"position", "\[Rule]", "letter"}]}], "]"}], ",", "l", 
             ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"position", ",", 
             RowBox[{"Length", "[", "target", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"letter", ",", "0", ",", 
             RowBox[{"alpha", "-", "1"}]}], "}"}]}], "]"}], "-", "wt"}]}]}]}],
      "\[IndentingNewLine]", "]"}]}], " ", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"effectOfDoubleMutations", "[", 
     RowBox[{
     "target_", ",", "l_", ",", " ", "alpha_", ",", "\[Beta]_", ",", 
      "\[Gamma]_", ",", "numOfDoubleMutants_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"wt", ",", "doubleMutants", ",", "mutations"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"wt", "=", 
        RowBox[{"CalcEnergy", "[", 
         RowBox[{
         "target", ",", "l", ",", "alpha", ",", "\[Beta]", ",", "\[Gamma]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"mutations", "=", 
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"RandomSample", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"1", ",", "l"}], "]"}], ",", "2"}], "]"}], ",", 
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"alpha", "-", "1"}]}], "}"}], "]"}], ",", 
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"alpha", "-", "1"}]}], "}"}], "]"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"first", " ", "site", " ", "to", " ", "mutate"}], ",", 
            " ", 
            RowBox[{"second", " ", "site", " ", "to", " ", "mutate"}], ",", 
            " ", 
            RowBox[{
            "position", " ", "of", " ", "first", " ", "mutation", " ", 
             "among", " ", "19", " ", "alternates"}], ",", " ", 
            RowBox[{
            "position", " ", "of", " ", "second", " ", "mutation", " ", 
             "among", " ", "19", " ", "alternates"}]}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"{", "numOfDoubleMutants", "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"CalcEnergy", "[", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"target", ",", " ", 
                RowBox[{
                 RowBox[{"current", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
                 RowBox[{
                  RowBox[{"Complement", "[", 
                   RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"target", "[", 
                    RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "}"}]}], 
                   "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"current", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}]}], 
               " ", "]"}], ",", "l", ",", " ", "alpha", ",", "\[Beta]", ",", 
              "\[Gamma]"}], "]"}], "+", 
            RowBox[{"CalcEnergy", "[", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"target", ",", 
                RowBox[{
                 RowBox[{"current", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "\[Rule]", 
                 RowBox[{
                  RowBox[{"Complement", "[", 
                   RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"target", "[", 
                    RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "}"}]}], 
                   "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"current", "[", 
                    RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}]}], 
               "]"}], ",", "l", ",", " ", "alpha", ",", "\[Beta]", ",", 
              "\[Gamma]"}], "]"}], "-", "wt"}], ",", "\[IndentingNewLine]", 
           RowBox[{"CalcEnergy", "[", 
            RowBox[{
             RowBox[{"ReplacePart", "[", 
              RowBox[{"target", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"current", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"Complement", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"target", "[", 
                    RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "}"}]}], 
                    "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"current", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"Complement", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"target", "[", 
                    RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "}"}]}], 
                    "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"current", "[", 
                    RowBox[{"[", "4", "]"}], "]"}], " ", "]"}], "]"}]}]}], 
                "}"}]}], "]"}], ",", "l", ",", " ", "alpha", ",", "\[Beta]", 
             ",", "\[Gamma]"}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"current", ",", "mutations"}], "}"}]}], "]"}]}]}], " ", 
     RowBox[{"(*", 
      RowBox[{"List", " ", "is", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Energy", " ", "of", " ", "mut1"}], "+", " ", 
          RowBox[{"Energy", " ", "of", " ", "Mut2"}], "-", 
          RowBox[{"Energy", " ", "of", " ", "WT"}]}], ",", " ", 
         RowBox[{"Energy", " ", "of", " ", "double", " ", "mutant"}]}]}]}], 
      "*)"}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getAllSingleMutationEffectsInAdditiveEnergy", "[", 
     RowBox[{"seq_", ",", "l_", ",", "alpha_", ",", "\[Beta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "position", ",", "letter", ",", "old\[Beta]indices", ",", 
        "old\[Beta]s", ",", "new\[Beta]indices", ",", "new\[Beta]s"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"old\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             
             RowBox[{"seq", "[", 
              RowBox[{"[", "positionToMutate", "]"}], "]"}], "+", "1"}], ",", 
            
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             "letter", "+", "1"}], ",", 
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "new\[Beta]indices", "]"}], "]"}], "-", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "old\[Beta]indices", "]"}], "]"}]}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getAllSingleMutationEffectsInTotalEnergy", "[", 
     RowBox[{
     "seq_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "position", ",", "letter", ",", "old\[Beta]indices", ",", 
        "new\[Beta]indices", ",", "positionPairs", ",", "old\[Gamma]indices", 
        ",", "new\[Gamma]indices", ",", "t"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"old\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             
             RowBox[{"seq", "[", 
              RowBox[{"[", "positionToMutate", "]"}], "]"}], "+", "1"}], ",", 
            
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             "letter", "+", "1"}], ",", 
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"t", "=", 
        RowBox[{
         RowBox[{"Table", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"old\[Gamma]indices", "=", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"getIndexIn\[Gamma]", "[", 
                 RowBox[{"p", ",", "positionToMutate", ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "p", "]"}], "]"}], ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", 
                  ",", "alpha"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", "1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "}"}]}], "]"}], 
              "~", "Join", "~", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"getIndexIn\[Gamma]", "[", 
                 RowBox[{"positionToMutate", ",", "p", ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "p", "]"}], "]"}], ",", "l", ",", "alpha"}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", 
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "}"}]}],
                "]"}]}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"new\[Gamma]indices", "=", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"getIndexIn\[Gamma]", "[", 
                 RowBox[{"p", ",", "positionToMutate", ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "p", "]"}], "]"}], ",", "letter", ",", "l", 
                  ",", "alpha"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", "1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "}"}]}], "]"}], 
              "~", "Join", "~", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"getIndexIn\[Gamma]", "[", 
                 RowBox[{"positionToMutate", ",", "p", ",", "letter", ",", 
                  RowBox[{"seq", "[", 
                   RowBox[{"[", "p", "]"}], "]"}], ",", "l", ",", "alpha"}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", 
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "}"}]}],
                "]"}]}]}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Total", "[", 
               RowBox[{"\[Gamma]", "[", 
                RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}]}], "+", 
             RowBox[{"Total", "[", 
              RowBox[{"\[Gamma]", "[", 
               RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"letter", ",", 
             RowBox[{"Complement", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"seq", "[", 
                 RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
              "]"}]}], "}"}]}], "]"}], "//", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"#", ",", "1"}], "]"}], "&"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "new\[Beta]indices", "]"}], "]"}], "-", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "old\[Beta]indices", "]"}], "]"}], "+", "t"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getSingleMutationsEffectInAdditiveEnergy", "[", 
     RowBox[{
     "seq_", ",", "positionToMutate_", ",", "newLetter_", ",", "l_", ",", 
      "alpha_", ",", "\[Beta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"old\[Beta]", ",", "new\[Beta]", ",", "mutEffect"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"old\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{"positionToMutate", ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{
           "positionToMutate", ",", "newLetter", ",", "l", ",", "alpha"}], 
           "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"mutEffect", "=", 
        RowBox[{
         RowBox[{"-", "old\[Beta]"}], "+", "new\[Beta]"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getSingleMutationsEffectInTotalEnergy", "[", 
     RowBox[{
     "seq_", ",", "positionToMutate_", ",", "newLetter_", ",", "l_", ",", 
      "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "newSeq", ",", "old\[Beta]", ",", "new\[Beta]", ",", "positionPairs", 
        ",", "old\[Gamma]indices", ",", "new\[Gamma]indices"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"newSeq", "=", "seq"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"newSeq", "[", 
         RowBox[{"[", "positionToMutate", "]"}], "]"}], "=", "newLetter"}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"old\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{"positionToMutate", ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{
           "positionToMutate", ",", "newLetter", ",", "l", ",", "alpha"}], 
           "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"positionPairs", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"pos1", ",", 
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", 
               RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
          "]"}], "~", "Join", "~", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"pos2", ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}], 
            "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"old\[Gamma]indices", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"getIndexIn\[Gamma]", "[", 
           RowBox[{
            RowBox[{"p", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"p", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", 
              RowBox[{"p", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", 
              RowBox[{"p", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"new\[Gamma]indices", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"getIndexIn\[Gamma]", "[", 
           RowBox[{
            RowBox[{"p", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"p", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"newSeq", "[", 
             RowBox[{"[", 
              RowBox[{"p", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
            RowBox[{"newSeq", "[", 
             RowBox[{"[", 
              RowBox[{"p", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "old\[Beta]"}], "+", "new\[Beta]", "-", 
        RowBox[{"Total", "[", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}], "+", 
        RowBox[{"Total", "[", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"output", " ", "is", " ", "timeseries", " ", "of", " ", 
     RowBox[{"{", 
      RowBox[{"sequence", ",", " ", 
       RowBox[{"additive", " ", "energy"}], ",", " ", 
       RowBox[{"epistatic", " ", "energy"}], ",", " ", 
       RowBox[{"total", " ", "energy"}], ",", " ", 
       RowBox[{
       "number", " ", "of", " ", "mutations", " ", "from", " ", "starting", 
        " ", "seq"}]}], "}"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnTotalEnergyUntilGivenSeqDivergence", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",",
       "\[Gamma]_", ",", "maxDist_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "old\[Beta]", ",", "old\[Gamma]indices", ",", "new", ",", 
        "positionToMutate", ",", "positionPairs", ",", "new\[Beta]", ",", 
        "new\[Gamma]indices", ",", "additiveEnergy", ",", "epistaticEnergy", 
        ",", "totalEnergy", ",", "newAdditiveEnergy", ",", 
        "newEpistaticEnergy", ",", "newTotalEnergy", ",", "distFromStart", 
        ",", "timeSeries"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"additiveEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"\[Beta]", ".", 
          RowBox[{"s2d", "[", 
           RowBox[{"start", ",", "l", ",", "alpha", ",", "1"}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"epistaticEnergy", "=", 
        RowBox[{"+", 
         RowBox[{"fastEnergy", "[", 
          RowBox[{
          "start", ",", "l", ",", "alpha", ",", "2", ",", "\[Gamma]"}], 
          "]"}]}]}], ";", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"\[Gamma]", ".", 
          RowBox[{"s2d", "[", 
           RowBox[{"start", ",", "l", ",", "alpha", ",", "2"}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"totalEnergy", "=", 
        RowBox[{"additiveEnergy", "+", "epistaticEnergy"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"distFromStart", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{
         "start", ",", "additiveEnergy", ",", "epistaticEnergy", ",", 
          "totalEnergy", ",", " ", "distFromStart"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"timeSeries", "=", 
        RowBox[{"{", "old", "}"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"distFromStart", "<", "maxDist"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"positionToMutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positionPairs", "=", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos1", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
             "]"}], "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos2", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}],
                "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
               "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"new\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newAdditiveEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newEpistaticEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "-", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}], "+", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"newTotalEnergy", "=", 
           RowBox[{"newAdditiveEnergy", "+", "newEpistaticEnergy"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newAdditiveEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "=", "newEpistaticEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "=", " ", "newTotalEnergy"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newTotalEnergy", "<", "cutoff"}], ",", 
            RowBox[{
             RowBox[{"old", "=", "new"}], ";", " ", 
             RowBox[{"distFromStart", "=", 
              RowBox[{"HammingDistance", "[", 
               RowBox[{"start", ",", 
                RowBox[{"old", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", " ", 
             RowBox[{
              RowBox[{"old", "[", 
               RowBox[{"[", "5", "]"}], "]"}], "=", "distFromStart"}]}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"timeSeries", ",", "old"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "timeSeries"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Draws", " ", "numDraws", " ", "random", " ", "sequences", " ", "and", 
      " ", "fits", " ", "a", " ", "bivariate", " ", "Gauss", " ", 
      "distribution", " ", "on", " ", "the", " ", "corresponding", " ", 
      RowBox[{"(", 
       RowBox[{"E1", ",", "E2"}], ")"}], "s"}], ";", " ", 
     RowBox[{"returns", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mean", " ", "of", " ", "fitted", " ", "Gauss"}], ",", " ", 
        RowBox[{
        "cov", " ", "matrix", " ", "of", " ", "fitted", " ", "Gauss"}]}], 
       "}"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitBivariateGaussToRandomSeq", "[", 
     RowBox[{
     "l_", ",", " ", "alpha_", ",", "\[Beta]_", ",", "\[Gamma]_", ",", " ", 
      "numDraws_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "randSeqs", ",", "non", ",", " ", "seq", ",", "E1s", ",", " ", "E2s", 
        ",", " ", "meanVec", ",", "dataMatrix", ",", "covMatrix", ",", "c"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"randSeqs", "=", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"alpha", "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"numDraws", ",", "l"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"non", "=", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"alpha", "^", "2"}], " ", 
           RowBox[{"Binomial", "[", 
            RowBox[{"l", ",", "2"}], "]"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"E1s", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"fastEnergy", "[", 
           RowBox[{"seq", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"seq", ",", "randSeqs"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"E2s", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"fastEnergy", "[", 
           RowBox[{"seq", ",", "l", ",", "alpha", ",", "2", ",", "\[Gamma]"}],
            "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"seq", ",", "randSeqs"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"meanVec", "=", 
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"E1s", "//", "Total"}], "numDraws"], ",", 
          FractionBox[
           RowBox[{"E2s", "//", "Total"}], "numDraws"]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dataMatrix", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"E1s", "-", 
            RowBox[{"meanVec", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ",", 
           RowBox[{"E2s", "-", 
            RowBox[{"meanVec", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"covMatrix", "=", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"numDraws", "-", "1"}], ")"}]}], 
         RowBox[{
          RowBox[{"Transpose", "[", "dataMatrix", "]"}], ".", 
          "dataMatrix"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<parameters of numerically fitted bivariate normal distribution: \
\>\"", ",", "meanVec", ",", "\"\<, \>\"", ",", 
         RowBox[{"covMatrix", "//", "MatrixForm"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"c", "=", 
        RowBox[{"{", 
         RowBox[{"meanVec", ",", " ", "covMatrix"}], "}"}]}], ";", 
       "\[IndentingNewLine]", "c"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**"}], "*******)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnTotalEnergyHoc", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_", ",", "\[Gamma]_", ",", "var_"}], "]"}], 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"add", " ", "a", " ", "parameter"}], ",", " ", 
      RowBox[{"HOC", " ", "variance"}]}], "*)"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "old\[Beta]", ",", "old\[Gamma]indices", ",", "new", ",", 
        "positionToMutate", ",", "positionPairs", ",", "new\[Beta]", ",", 
        "new\[Gamma]indices", ",", "newHocEnergy", ",", "additiveEnergy", ",",
         "epistaticEnergy", ",", "totalEnergy", ",", "newAdditiveEnergy", ",",
         "newEpistaticEnergy", ",", "newTotalEnergy", ",", "hocEnergy", ",", 
        "hocAssociation"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"additiveEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"epistaticEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "2", ",", "\[Gamma]"}],
          "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"hocEnergy", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", 
           RowBox[{"Sqrt", "[", "var", "]"}]}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{
        "draw", " ", "HOC", " ", "energy", " ", "from", " ", "Gaussian"}], 
        "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"totalEnergy", "=", 
        RowBox[{
        "additiveEnergy", "+", "epistaticEnergy", "+", "hocEnergy"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{
         "start", ",", "additiveEnergy", ",", "epistaticEnergy", ",", 
          "hocEnergy", ",", "totalEnergy"}], "}"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"hocAssociation", "=", 
        RowBox[{"Association", "[", 
         RowBox[{"start", "\[Rule]", "hocEnergy"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Make", " ", "association", " ", "to", " ", "keep", " ", "track", " ",
          "of", " ", "HOC", " ", "energies", " ", "from", " ", "previously", 
         " ", "observed", " ", "sequences"}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"positionToMutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positionPairs", "=", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos1", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
             "]"}], "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos2", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}],
                "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
               "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"new\[Gamma]indices", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"getIndexIn\[Gamma]", "[", 
              RowBox[{
               RowBox[{"p", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"p", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", 
                  RowBox[{"p", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], ",", "l", 
               ",", "alpha"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "positionPairs"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"newHocEnergy", "=", 
           RowBox[{"RandomVariate", "[", 
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0", ",", 
              RowBox[{"Sqrt", "[", "var", "]"}]}], "]"}], "]"}]}], ";", " ", 
          RowBox[{"(*", 
           RowBox[{"draw", " ", "new", " ", "hoc", " ", "term"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "/.", "hocAssociation"}], 
              ")"}], "!=", 
             RowBox[{"new", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"newHocEnergy", "=", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "/.", "hocAssociation"}], 
              ")"}]}], ",", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"hocAssociation", ",", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "newHocEnergy"}]}],
              "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "Check", " ", "if", " ", "this", " ", "is", " ", "a", " ", 
             "never", " ", "before", " ", "seen", " ", 
             RowBox[{"sequence", ".", " ", "If"}], " ", "so"}], ",", " ", 
            RowBox[{"add", " ", "it", " ", "to", " ", "the", " ", 
             RowBox[{"association", ".", " ", "If"}], " ", "not"}], ",", " ", 
            
            RowBox[{
            "use", " ", "the", " ", "HOC", " ", "energy", " ", "assigned", 
             " ", "to", " ", "it", " ", "previously"}]}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"newAdditiveEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newEpistaticEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "-", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "old\[Gamma]indices", "]"}], "]"}], "]"}], "+", 
            RowBox[{"Total", "[", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"[", "new\[Gamma]indices", "]"}], "]"}], "]"}]}]}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"newTotalEnergy", "=", 
           RowBox[{
           "newAdditiveEnergy", "+", "newEpistaticEnergy", "+", 
            "newHocEnergy"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newAdditiveEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "=", "newEpistaticEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "=", "newHocEnergy"}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "=", " ", "newTotalEnergy"}], ";",
           " ", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "HOC", " ", "energy", " ", "is", " ", "in", " ", "position", " ", 
             "4"}], ",", " ", 
            RowBox[{
             RowBox[{
             "and", " ", "total", " ", "energy", " ", "is", " ", "moved", " ",
               "to", " ", "position", " ", 
              RowBox[{"5", " ", "--"}], " ", "note", " ", "for", " ", 
              "downstream", " ", 
              RowBox[{"processing", ".", " ", "Trying"}], " ", "to", " ", 
              "keep", " ", "total", " ", "energy", " ", "as"}], " ", "-", 
             RowBox[{"1", " ", "position"}]}]}], "*)"}], 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newTotalEnergy", "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "old"}], ",", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"output", " ", "is", " ", "timeseries", " ", "of", " ", 
     RowBox[{"{", 
      RowBox[{"sequence", ",", " ", 
       RowBox[{"additive", " ", "energy"}], ",", " ", 
       RowBox[{"hoc", " ", "energy"}], ",", " ", 
       RowBox[{"total", " ", "energy"}]}], "}"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnTotalEnergyHocFast", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "maxtime_", ",", "l_", ",", "alpha_", ",",
       "\[Beta]_", ",", "\[Sigma]_"}], "]"}], 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"add", " ", "a", " ", "parameter"}], ",", " ", 
      RowBox[{"HOC", " ", "standard", " ", "deviation"}]}], "*)"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "old\[Beta]", ",", "old\[Gamma]indices", ",", "new", ",", 
        "positionToMutate", ",", "positionPairs", ",", "new\[Beta]", ",", 
        "new\[Gamma]indices", ",", "newHocEnergy", ",", "additiveEnergy", ",",
         "epistaticEnergy", ",", "totalEnergy", ",", "newAdditiveEnergy", ",",
         "newEpistaticEnergy", ",", "newTotalEnergy", ",", "hocEnergy"}], 
       RowBox[{"(*", 
        RowBox[{",", "hocAssociation"}], "*)"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"additiveEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"newHocEnergy", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "\[Sigma]"}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{
        "draw", " ", "HOC", " ", "energy", " ", "from", " ", "Gaussian"}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"KeyExistsQ", "[", 
           RowBox[{"hocAssociation", ",", "start"}], "]"}], "\[Equal]", 
          "True"}], ",", " ", 
         RowBox[{"hocEnergy", "=", 
          RowBox[{"(", 
           RowBox[{"start", "/.", "hocAssociation"}], ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"hocEnergy", "=", "newHocEnergy"}], ";", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"hocAssociation", ",", 
            RowBox[{"start", "\[Rule]", "newHocEnergy"}]}], "]"}]}]}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"totalEnergy", "=", 
        RowBox[{"additiveEnergy", "+", "hocEnergy"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{
         "start", ",", "additiveEnergy", ",", "hocEnergy", ",", 
          "totalEnergy"}], "}"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"positionToMutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positionPairs", "=", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"pos1", ",", "positionToMutate"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos1", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"positionToMutate", "-", "1"}]}], "]"}]}], "}"}]}], 
             "]"}], "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"positionToMutate", ",", "pos2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"pos2", ",", 
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"positionToMutate", "+", "1"}], ",", "l"}], "]"}]}],
                "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"old\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
               "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newHocEnergy", "=", 
           RowBox[{"RandomVariate", "[", 
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0", ",", "\[Sigma]"}], "]"}], "]"}]}], ";", " ", 
          RowBox[{"(*", 
           RowBox[{"draw", " ", "new", " ", "hoc", " ", "term"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "/.", "hocAssociation"}], 
              ")"}], "!=", 
             RowBox[{"new", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"newHocEnergy", "=", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "/.", "hocAssociation"}], 
              ")"}]}], ",", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"hocAssociation", ",", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "newHocEnergy"}]}],
              "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "Check", " ", "if", " ", "this", " ", "is", " ", "a", " ", 
             "never", " ", "before", " ", "seen", " ", 
             RowBox[{"sequence", ".", " ", "If"}], " ", "so"}], ",", " ", 
            RowBox[{"add", " ", "it", " ", "to", " ", "the", " ", 
             RowBox[{"association", ".", " ", "If"}], " ", "not"}], ",", " ", 
            
            RowBox[{
            "use", " ", "the", " ", "HOC", " ", "energy", " ", "assigned", 
             " ", "to", " ", "it", " ", "previously"}]}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"newAdditiveEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"newTotalEnergy", "=", 
           RowBox[{"newAdditiveEnergy", "+", "newHocEnergy"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newAdditiveEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "=", "newHocEnergy"}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "=", " ", "newTotalEnergy"}], ";",
           " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newTotalEnergy", "<", "cutoff"}], ",", 
            RowBox[{"old", "=", "new"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "old"}], ",", 
         RowBox[{"{", "maxtime", "}"}]}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getSingleMutationsEffectInTotalEnergyHoc", "[", 
     RowBox[{
     "seq_", ",", "positionToMutate_", ",", "newLetter_", ",", "l_", ",", 
      "alpha_", ",", "\[Beta]_", ",", "varHoc_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "newSeq", ",", "old\[Beta]", ",", "new\[Beta]", ",", "positionPairs", 
        ",", "seqHocEnergy", ",", "newSeqHocEnergy"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"newSeq", "=", "seq"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"newSeq", "[", 
         RowBox[{"[", "positionToMutate", "]"}], "]"}], "=", "newLetter"}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"old\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{"positionToMutate", ",", 
            RowBox[{"seq", "[", 
             RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", ",", 
            "alpha"}], "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]", "=", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", 
          RowBox[{"getIndexIn\[Beta]", "[", 
           RowBox[{
           "positionToMutate", ",", "newLetter", ",", "l", ",", "alpha"}], 
           "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"seqHocEnergy", "=", 
        RowBox[{"seq", "/.", "hocAssociation"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"KeyExistsQ", "[", 
           RowBox[{"hocAssociation", ",", "newSeq"}], "]"}], "\[Equal]", 
          "True"}], ",", " ", 
         RowBox[{"newSeqHocEnergy", "=", 
          RowBox[{"(", 
           RowBox[{"newSeq", "/.", "hocAssociation"}], ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"newSeqHocEnergy", "=", 
           RowBox[{"RandomVariate", "[", 
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0", ",", 
              RowBox[{"Sqrt", "[", "varHoc", "]"}]}], "]"}], "]"}]}], ";", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"hocAssociation", ",", 
            RowBox[{"newSeq", "\[Rule]", "newSeqHocEnergy"}]}], "]"}]}]}], 
        "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "old\[Beta]"}], "+", "new\[Beta]", "-", "seqHocEnergy", 
        "+", "newSeqHocEnergy"}]}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getAllSingleMutationEffectsInTotalEnergyHoc", "[", 
     RowBox[{
     "seq_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",", "varHoc_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "position", ",", "letter", ",", "old\[Beta]indices", ",", 
        "new\[Beta]indices", ",", "seqHocEnergy", ",", "newSeq", ",", 
        "newSeqHocEnergy", ",", "t"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"old\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             
             RowBox[{"seq", "[", 
              RowBox[{"[", "positionToMutate", "]"}], "]"}], "+", "1"}], ",", 
            
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"new\[Beta]indices", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"positionToMutate", "-", "1"}], ")"}], "alpha"}], "+", 
             "letter", "+", "1"}], ",", 
            RowBox[{"{", 
             RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"letter", ",", 
              RowBox[{"Complement", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"seq", "[", 
                  RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
               "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"seqHocEnergy", "=", 
        RowBox[{"seq", "/.", "hocAssociation"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"t", "=", 
        RowBox[{
         RowBox[{"Table", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"newSeq", "=", "seq"}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"newSeq", "[", 
              RowBox[{"[", "positionToMutate", "]"}], "]"}], "=", "letter"}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"KeyExistsQ", "[", 
                RowBox[{"hocAssociation", ",", "newSeq"}], "]"}], "\[Equal]", 
               "True"}], ",", " ", 
              RowBox[{"newSeqHocEnergy", "=", 
               RowBox[{"(", 
                RowBox[{"newSeq", "/.", "hocAssociation"}], ")"}]}], ",", " ", 
              RowBox[{
               RowBox[{"newSeqHocEnergy", "=", 
                RowBox[{"RandomVariate", "[", 
                 RowBox[{"NormalDistribution", "[", 
                  RowBox[{"0", ",", 
                   RowBox[{"Sqrt", "[", "varHoc", "]"}]}], "]"}], "]"}]}], 
               ";", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"hocAssociation", ",", 
                 RowBox[{"newSeq", "\[Rule]", "newSeqHocEnergy"}]}], 
                "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"-", "seqHocEnergy"}], "+", "newSeqHocEnergy"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"positionToMutate", ",", "1", ",", "l"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"letter", ",", 
             RowBox[{"Complement", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"seq", "[", 
                 RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], 
              "]"}]}], "}"}]}], "]"}], "//", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"#", ",", "1"}], "]"}], "&"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "new\[Beta]indices", "]"}], "]"}], "-", 
        RowBox[{"\[Beta]", "[", 
         RowBox[{"[", "old\[Beta]indices", "]"}], "]"}], "+", "t"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"output", " ", "is", " ", "timeseries", " ", "of", " ", 
     RowBox[{"{", 
      RowBox[{"sequence", ",", " ", 
       RowBox[{"additive", " ", "energy"}], ",", " ", 
       RowBox[{"epistatic", " ", "energy"}], ",", " ", 
       RowBox[{"total", " ", "energy"}], ",", " ", 
       RowBox[{
       "number", " ", "of", " ", "mutations", " ", "from", " ", "starting", 
        " ", "seq"}]}], "}"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RandomWalkBasedOnTotalEnergyHocUntilGivenSeqDivergence", "[", 
     RowBox[{
     "start_", ",", "cutoff_", ",", "l_", ",", "alpha_", ",", "\[Beta]_", ",",
       "varHoc_", ",", "maxDist_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "old", ",", "old\[Beta]", ",", "old\[Gamma]indices", ",", "new", ",", 
        "positionToMutate", ",", "positionPairs", ",", "new\[Beta]", ",", 
        "new\[Gamma]indices", ",", "additiveEnergy", ",", "epistaticEnergy", 
        ",", "totalEnergy", ",", "newAdditiveEnergy", ",", "hocEnergy", ",", 
        "newTotalEnergy", ",", "distFromStart", ",", "timeSeries", ",", 
        "newHocEnergy"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"additiveEnergy", "=", 
        RowBox[{"fastEnergy", "[", 
         RowBox[{"start", ",", "l", ",", "alpha", ",", "1", ",", "\[Beta]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"KeyExistsQ", "[", 
           RowBox[{"hocAssociation", ",", "start"}], "]"}], "\[Equal]", 
          "True"}], ",", " ", 
         RowBox[{"hocEnergy", "=", 
          RowBox[{"(", 
           RowBox[{"start", "/.", "hocAssociation"}], ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"hocEnergy", "=", 
           RowBox[{"RandomVariate", "[", 
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0", ",", 
              RowBox[{"Sqrt", "[", "varHoc", "]"}]}], "]"}], "]"}]}], ";", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"hocAssociation", ",", 
            RowBox[{"start", "\[Rule]", "hocEnergy"}]}], "]"}]}]}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"totalEnergy", "=", 
        RowBox[{"additiveEnergy", "+", "hocEnergy"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"distFromStart", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"old", "=", 
        RowBox[{"{", 
         RowBox[{
         "start", ",", "additiveEnergy", ",", "hocEnergy", ",", "totalEnergy",
           ",", " ", "distFromStart"}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"timeSeries", "=", 
        RowBox[{"{", "old", "}"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"distFromStart", "<", "maxDist"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"positionToMutate", "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"old\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"old", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"new", "=", "old"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], "=", 
           RowBox[{"RandomChoice", "[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], 
               "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"new\[Beta]", "=", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"[", 
             RowBox[{"getIndexIn\[Beta]", "[", 
              RowBox[{"positionToMutate", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "positionToMutate"}], "]"}], "]"}], ",", 
               "l", ",", "alpha"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"newAdditiveEnergy", "=", 
           RowBox[{
            RowBox[{"old", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "old\[Beta]", "+", 
            "new\[Beta]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"KeyExistsQ", "[", 
              RowBox[{"hocAssociation", ",", 
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "\[Equal]", "True"}],
             ",", " ", 
            RowBox[{"newHocEnergy", "=", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"new", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "/.", "hocAssociation"}], 
              ")"}]}], ",", " ", 
            RowBox[{
             RowBox[{"newHocEnergy", "=", 
              RowBox[{"RandomVariate", "[", 
               RowBox[{"NormalDistribution", "[", 
                RowBox[{"0", ",", 
                 RowBox[{"Sqrt", "[", "varHoc", "]"}]}], "]"}], "]"}]}], ";", 
             
             RowBox[{"AppendTo", "[", 
              RowBox[{"hocAssociation", ",", 
               RowBox[{
                RowBox[{"new", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
                "newHocEnergy"}]}], "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"newTotalEnergy", "=", 
           RowBox[{"newAdditiveEnergy", "+", "newHocEnergy"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "=", "newAdditiveEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "=", "newHocEnergy"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"new", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "=", " ", "newTotalEnergy"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"newTotalEnergy", "<", "cutoff"}], ",", 
            RowBox[{
             RowBox[{"old", "=", "new"}], ";", " ", 
             RowBox[{"distFromStart", "=", 
              RowBox[{"HammingDistance", "[", 
               RowBox[{"start", ",", 
                RowBox[{"old", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", " ", 
             RowBox[{
              RowBox[{"old", "[", 
               RowBox[{"[", "5", "]"}], "]"}], "=", "distFromStart"}]}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"timeSeries", ",", "old"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "timeSeries"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.7335838039573507`*^9, {3.7335881091210537`*^9, 3.733588206389267*^9}, {
   3.7335882692342176`*^9, 3.7335882699589863`*^9}, {3.733591445970196*^9, 
   3.733591482389825*^9}, {3.7335920247797956`*^9, 3.7335920407542048`*^9}, {
   3.733657839237068*^9, 3.733657858342669*^9}, {3.7336636827607822`*^9, 
   3.733663688888618*^9}, {3.733663750926791*^9, 3.733663754234226*^9}, {
   3.733665888064898*^9, 3.733665903000697*^9}, {3.733762961285969*^9, 
   3.733762967960169*^9}, {3.733763208245494*^9, 3.7337632506477127`*^9}, {
   3.733825708391815*^9, 3.733825709631165*^9}, {3.733832305680546*^9, 
   3.733832313432543*^9}, {3.7338330469778967`*^9, 3.733833086956789*^9}, {
   3.733833161554408*^9, 3.733833177836576*^9}, {3.733833348544345*^9, 
   3.733833353197398*^9}, 3.733833422163946*^9, {3.7338337733866158`*^9, 
   3.733833825333108*^9}, {3.733834112411557*^9, 3.7338341157916937`*^9}, {
   3.73383476762868*^9, 3.733834768007326*^9}, {3.733835008611196*^9, 
   3.733835010097033*^9}, {3.733838253860846*^9, 3.733838284569242*^9}, {
   3.733838370393547*^9, 3.7338383765698757`*^9}, {3.733838672591601*^9, 
   3.7338386820095663`*^9}, {3.733838840620441*^9, 3.733838846001631*^9}, {
   3.7338389279861183`*^9, 3.7338389283659277`*^9}, {3.733839126992887*^9, 
   3.733839255576483*^9}, {3.733840196870534*^9, 3.733840462690013*^9}, {
   3.7338405355633593`*^9, 3.733840567730377*^9}, {3.733840664210382*^9, 
   3.733840664790536*^9}, {3.733840719158998*^9, 3.733840781708859*^9}, {
   3.7338408174632683`*^9, 3.7338408230838327`*^9}, {3.733840859564704*^9, 
   3.733840867811428*^9}, {3.733841285525737*^9, 3.733841285990116*^9}, {
   3.733841348609192*^9, 3.7338413499985*^9}, {3.733841452447976*^9, 
   3.733841489468377*^9}, {3.7338417598954697`*^9, 3.733841812053845*^9}, {
   3.733841940495515*^9, 3.7338419408209267`*^9}, {3.734014900198317*^9, 
   3.734015003666304*^9}, {3.7340288800325603`*^9, 3.7340289143686247`*^9}, {
   3.734029138436696*^9, 3.734029164218816*^9}, {3.734029214576234*^9, 
   3.734029215047532*^9}, {3.7340292615254307`*^9, 3.734029261908684*^9}, {
   3.734029314333132*^9, 3.734029431112122*^9}, {3.734034123669182*^9, 
   3.7340341252565823`*^9}, {3.734039649144651*^9, 3.734039652089361*^9}, {
   3.734039702504858*^9, 3.7340397054516068`*^9}, {3.734731003536138*^9, 
   3.7347310109134703`*^9}, {3.734731118297139*^9, 3.7347311366247263`*^9}, {
   3.734791358186555*^9, 3.734791359209587*^9}, {3.734791646730743*^9, 
   3.734791654612185*^9}, 3.734791711839116*^9, {3.7347917424999113`*^9, 
   3.734791963498316*^9}, {3.7347927272799892`*^9, 3.7347927287699747`*^9}, {
   3.735034948116067*^9, 3.7350349581530037`*^9}, {3.735044706325698*^9, 
   3.7350447067298307`*^9}, {3.735044917841365*^9, 3.735044922259191*^9}, {
   3.735044971486087*^9, 3.735044976486824*^9}, {3.735049856620572*^9, 
   3.735049866284443*^9}, {3.735049907900181*^9, 3.735049908304809*^9}, {
   3.735049969774969*^9, 3.735049970214778*^9}, {3.735050552345709*^9, 
   3.7350505756756287`*^9}, {3.735050623079444*^9, 3.7350506241251307`*^9}, {
   3.735050662586749*^9, 3.735050686955811*^9}, {3.7350555011727343`*^9, 
   3.735055502338187*^9}, {3.735055729881488*^9, 3.735055737349206*^9}, {
   3.7350560442510567`*^9, 3.735056088955718*^9}, {3.7350561426660023`*^9, 
   3.735056201489633*^9}, {3.735056587585011*^9, 3.735056588087739*^9}, {
   3.7350568909664583`*^9, 3.735056910383957*^9}, {3.735074800077484*^9, 
   3.735074801697115*^9}, 3.735074868053438*^9, {3.7350749218890533`*^9, 
   3.735074933079638*^9}, {3.7351238414834137`*^9, 3.7351238709877043`*^9}, {
   3.73512390115114*^9, 3.735124017386944*^9}, {3.735124054764489*^9, 
   3.735124057802232*^9}, {3.735124127951929*^9, 3.735124387557212*^9}, {
   3.735124607775524*^9, 3.735124639964654*^9}, {3.735124796347507*^9, 
   3.7351248769970284`*^9}, {3.735124914347135*^9, 3.73512504139107*^9}, {
   3.735309782404928*^9, 3.735309796710352*^9}, 3.735313138304607*^9, 
   3.735313435835635*^9, {3.735338214510211*^9, 3.735338216110175*^9}, {
   3.7353385753896227`*^9, 3.735338578635257*^9}, {3.735338621425674*^9, 
   3.735338625888688*^9}, {3.7353386617055264`*^9, 3.7353386666098213`*^9}, {
   3.735338701288274*^9, 3.735338707439555*^9}, {3.735338772238963*^9, 
   3.7353387792903957`*^9}, {3.735338998773193*^9, 3.735339014051087*^9}, {
   3.735339431920115*^9, 3.735339433137787*^9}, {3.735339562709037*^9, 
   3.7353395829658117`*^9}, {3.735339709730977*^9, 3.7353397102048397`*^9}, {
   3.735339759804261*^9, 3.735339857061246*^9}, {3.7353398988161182`*^9, 
   3.7353399402839937`*^9}, {3.735340053827973*^9, 3.735340165229644*^9}, {
   3.735340350592531*^9, 3.735340405686103*^9}, {3.735340441018927*^9, 
   3.735340495890498*^9}, {3.735340622188092*^9, 3.735340684498999*^9}, {
   3.735340715466408*^9, 3.7353407508118963`*^9}, {3.735340788475519*^9, 
   3.7353408807396812`*^9}, 3.735341003602975*^9, {3.735343106727467*^9, 
   3.7353431079210997`*^9}, {3.735344394176355*^9, 3.735344394621315*^9}, {
   3.7353941575003223`*^9, 3.735394158339768*^9}, {3.7353973006828814`*^9, 
   3.735397381826803*^9}, 3.735397505974798*^9, {3.735397672434846*^9, 
   3.735397748976157*^9}, {3.735406277613699*^9, 3.7354062786087017`*^9}, {
   3.735406317153294*^9, 3.735406348019256*^9}, {3.7354064588305883`*^9, 
   3.7354064600336123`*^9}, {3.735406604649914*^9, 3.7354066059562807`*^9}, {
   3.7354066471004753`*^9, 3.735406648766555*^9}, {3.735410730194944*^9, 
   3.735410751974333*^9}, {3.7354107866867237`*^9, 3.735410819024682*^9}, 
   3.735425422050947*^9, {3.735998961126707*^9, 3.735998980792128*^9}, {
   3.735999239331464*^9, 3.735999259089415*^9}, {3.736002003362871*^9, 
   3.7360020343781033`*^9}, 3.73600268420627*^9, {3.736004431235854*^9, 
   3.73600444734855*^9}, {3.736004478827415*^9, 3.7360044790099993`*^9}, {
   3.7361693620888453`*^9, 3.7361693625634403`*^9}, {3.7363315253619347`*^9, 
   3.73633152881708*^9}, {3.736332791346212*^9, 3.736332819522718*^9}, {
   3.736336491410892*^9, 3.736336494658093*^9}, {3.736352742277339*^9, 
   3.7363527806928368`*^9}, {3.7363627768909388`*^9, 3.736362816334771*^9}, {
   3.7363630203973627`*^9, 3.736363034934495*^9}, {3.736363176569811*^9, 
   3.736363199030788*^9}, 3.7363699751872597`*^9, {3.7363704346501102`*^9, 
   3.736370450836563*^9}, {3.7363705082561398`*^9, 3.736370568479851*^9}, {
   3.736370610598143*^9, 3.736370721757888*^9}, 3.73637167372472*^9, {
   3.736461204458119*^9, 3.7364612223732986`*^9}, {3.736461287710086*^9, 
   3.736461471231564*^9}, {3.736461522986638*^9, 3.736461582361581*^9}, {
   3.736461753171729*^9, 3.736461763869479*^9}, {3.736461859640239*^9, 
   3.736461861605551*^9}, {3.7364619231807957`*^9, 3.736462033190921*^9}, {
   3.7364622312672462`*^9, 3.7364622319544153`*^9}, {3.7364624613247433`*^9, 
   3.736462476800579*^9}, {3.736462510378688*^9, 3.736462616070443*^9}, {
   3.7364627097776814`*^9, 3.736462714108374*^9}, {3.736462744679323*^9, 
   3.7364628452741632`*^9}, {3.741523982412292*^9, 3.741523998149802*^9}, {
   3.7415255491225843`*^9, 3.741525549531345*^9}, {3.741525624066141*^9, 
   3.7415256293241663`*^9}, {3.741525974169331*^9, 3.741525979829336*^9}, {
   3.7415274119197702`*^9, 3.741527420086671*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"92975bbb-56f4-40bf-9d5c-e52ae81537f0"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Large HOC variance: length=400, Cutoff = -400, variance1=1, variancehoc=23.94\
\
\>", "Subsection",
 CellChangeTimes->{
  3.7367762094813757`*^9, {3.736776949939015*^9, 3.736776983110684*^9}, {
   3.741443830943851*^9, 
   3.741443832456159*^9}},ExpressionUUID->"f94a2216-bf30-4caa-8492-\
0b296dfb0c83"],

Cell[CellGroupData[{

Cell["Set parameters and draw coefficients in energy function", \
"Subsubsection",
 CellChangeTimes->{
  3.736776251695663*^9},ExpressionUUID->"ba2c611a-9093-42cb-accc-\
f217cd4b85ad"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SeedRandom", "[", "12345678", "]"}], ";"}], "\[IndentingNewLine]",
   "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"SET", " ", "PARAMETERS"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"l", "=", "400"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"length", " ", "of", " ", "sequence"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alpha", "=", "20"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"alleles", " ", "per", " ", "site"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"variance1", "=", 
   RowBox[{
    RowBox[{"alpha", "/", 
     RowBox[{"(", 
      RowBox[{"alpha", "-", "1"}], ")"}]}], "1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"variancehoc", "=", "23.94"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"energyCutoff", "=", 
   RowBox[{"-", "400"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wt", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", "l"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fontSize", "=", "13"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<sequence length = \>\"", ",", " ", "l"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<alphabet size = \>\"", ",", "  ", "alpha"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<variance1 = \>\"", ",", " ", "variance1"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<variancehoc = \>\"", ",", " ", "variancehoc"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<energy cutoff = \>\"", ",", " ", "energyCutoff"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<random walk started from wt=\>\"", ",", "wt"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "CALCULATE", " ", "FRACTION", " ", "OF", " ", "VARAIANCE", " ", "OF", " ", 
    "TOTAL", " ", "ENERGY", " ", "DUE", " ", "TO", " ", "ADDITIVE", " ", 
    "ENERGY"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"varAdditiveEnergy", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"alpha", "-", "1"}], ")"}], "/", "alpha"}], " ", "l", " ", 
    "variance1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"varEpistaticEnergy", "=", "variancehoc"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<variance of additive energy = \>\"", ",", " ", "varAdditiveEnergy"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<variance of epistatic energy = \>\"", ",", " ", 
    "varEpistaticEnergy"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<fraction of total variance due to additive energy = \>\"", ",", 
   RowBox[{"varAdditiveEnergy", "/", 
    RowBox[{"(", 
     RowBox[{"varAdditiveEnergy", "+", "varEpistaticEnergy"}], ")"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<cutoff standard deviations from mean = \>\"", ",", 
   RowBox[{"energyCutoff", "/", 
    SqrtBox[
     RowBox[{"(", 
      RowBox[{"varAdditiveEnergy", "+", "varEpistaticEnergy"}], ")"}]]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "DRAW", " ", "COEFFICIENTS", " ", "IN", " ", "ENERGY", " ", "FUNCTION"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SeedRandom", "[", "12345678", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis1", "=", 
   RowBox[{"N", "[", 
    RowBox[{"orthonormalBasisForSubspace1", "[", "alpha", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis2", "=", 
   RowBox[{"N", "[", 
    RowBox[{"orthonormalBasisForSubspace2", "[", "alpha", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Drawing \[Beta]s...\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Beta]0", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"coeffsForOrder1", "[", 
          RowBox[{"alpha", ",", " ", "basis1", ",", " ", 
           RowBox[{"Sqrt", "[", "variance1", "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "l"}], "}"}]}], "]"}]}], ";"}], ")"}], "//",
     "AbsoluteTiming"}], " ", "//", "Print"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"\[Beta]", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Sort", "/@", "\[Beta]0"}], "]"}]}], ")"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "DEFINE", " ", "HASH", " ", "TABLE", " ", "FOR", " ", "HOC", " ", 
    "ENERGIES"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hocAssociation", "=", 
   RowBox[{"Association", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Hash table created for HOC energies.\>\"", "]"}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.735039670215447*^9, 3.735039676885922*^9}, {
   3.735044800048231*^9, 3.735044803116219*^9}, {3.735045221971918*^9, 
   3.73504522959811*^9}, {3.735045269988558*^9, 3.7350452708141117`*^9}, {
   3.7350453365703077`*^9, 3.735045343485133*^9}, {3.735045417158849*^9, 
   3.7350454404247227`*^9}, 3.735046374306554*^9, {3.735049736725403*^9, 
   3.73504978076836*^9}, {3.73507499072913*^9, 3.735074991297587*^9}, {
   3.735313151518528*^9, 3.7353131526432467`*^9}, {3.735338338003683*^9, 
   3.735338359968875*^9}, {3.735338545344153*^9, 3.7353385505773697`*^9}, {
   3.735343479798663*^9, 3.73534354966885*^9}, 3.735345101844233*^9, 
   3.7353454660740137`*^9, {3.735382657299398*^9, 3.735382659006311*^9}, {
   3.735388042273129*^9, 3.7353880468572283`*^9}, {3.735392685124683*^9, 
   3.7353926853475657`*^9}, {3.735394536084243*^9, 3.7353945364713583`*^9}, 
   3.7353954158473263`*^9, 3.7354072879169703`*^9, {3.7354080776830397`*^9, 
   3.735408079783695*^9}, {3.735997989989833*^9, 3.73599799318114*^9}, {
   3.7360045807781267`*^9, 3.736004585310495*^9}, {3.736066744804278*^9, 
   3.736066748291823*^9}, {3.7360671047459307`*^9, 3.73606731962272*^9}, {
   3.736067487473854*^9, 3.736067505650632*^9}, {3.736067678222561*^9, 
   3.736067730033708*^9}, {3.736068091408441*^9, 3.736068092370936*^9}, 
   3.736068126746172*^9, {3.736068381446144*^9, 3.736068382198934*^9}, {
   3.736068444593129*^9, 3.7360684449737186`*^9}, {3.736068770850031*^9, 
   3.73606877140343*^9}, {3.736069116018488*^9, 3.73606911644902*^9}, {
   3.736069378772266*^9, 3.736069401519719*^9}, {3.736069898412277*^9, 
   3.736069901162999*^9}, {3.736070129825029*^9, 3.736070130130946*^9}, {
   3.736070485526927*^9, 3.7360704857940807`*^9}, {3.736115502167886*^9, 
   3.736115520737797*^9}, {3.7361155591524487`*^9, 3.736115559562126*^9}, {
   3.736115769811782*^9, 3.7361157702937717`*^9}, {3.7361695323703413`*^9, 
   3.7361695344088717`*^9}, {3.736248002082753*^9, 3.7362480053405848`*^9}, 
   3.736248063293035*^9, {3.7362711675400267`*^9, 3.736271173305934*^9}, {
   3.736271760077403*^9, 3.736271761097781*^9}, {3.736292843956057*^9, 
   3.736292844120399*^9}, {3.7362933421321163`*^9, 3.7362933422428637`*^9}, {
   3.736294022411599*^9, 3.736294022543172*^9}, {3.7362949767693167`*^9, 
   3.736294976917819*^9}, {3.736295875584177*^9, 3.736295898812854*^9}, {
   3.736332177823905*^9, 3.736332178972733*^9}, {3.736332350608768*^9, 
   3.7363323694308643`*^9}, {3.736332411150791*^9, 3.736332412694128*^9}, {
   3.7363324445582247`*^9, 3.736332454940785*^9}, {3.736332502145953*^9, 
   3.73633250515546*^9}, {3.736332540731299*^9, 3.736332541026455*^9}, {
   3.736336298343137*^9, 3.736336376803233*^9}, {3.736336589783226*^9, 
   3.736336598334139*^9}, {3.7363368063618*^9, 3.736336806611711*^9}, {
   3.7363702317379627`*^9, 3.73637024114611*^9}, {3.736370743355846*^9, 
   3.736370779096711*^9}, {3.736533754942284*^9, 3.7365337571140013`*^9}, {
   3.736767575247055*^9, 3.7367675757370653`*^9}, {3.7409598303932457`*^9, 
   3.7409598345220337`*^9}, {3.740962918565811*^9, 3.740962937900728*^9}, {
   3.741443841264131*^9, 3.741443844450786*^9}},
 CellLabel->
  "In[391]:=",ExpressionUUID->"1ee6d2ca-df5a-42c2-a30d-ee9daa0e2312"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sequence length = \"\>", "\[InvisibleSpace]", "400"}],
  SequenceForm["sequence length = ", 400],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.7414438530491953`*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"4d50fc40-6ca7-44e1-b83c-06f34533447b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"alphabet size = \"\>", "\[InvisibleSpace]", "20"}],
  SequenceForm["alphabet size = ", 20],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853064232*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"092b4515-8079-4edd-8794-08a9bb89c465"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance1 = \"\>", "\[InvisibleSpace]", 
   FractionBox["20", "19"]}],
  SequenceForm["variance1 = ", 
   Rational[20, 19]],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853085424*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"fd1035ab-ff76-4446-8864-454956306ce1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variancehoc = \"\>", "\[InvisibleSpace]", "23.94`"}],
  SequenceForm["variancehoc = ", 23.94],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853093677*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"5c5edaea-201d-4de5-8102-7f94cbe5de88"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"energy cutoff = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "400"}]}],
  SequenceForm["energy cutoff = ", -400],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853102065*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"947dbb3d-075b-4693-a78f-58e28db0e1b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"random walk started from wt=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}],
  SequenceForm["random walk started from wt=", CompressedData["
1:eJxTTMoPSmJkYGCYACJGwaACAI1FAjk=
   "]],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853110896*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"a5cd18da-9fd0-4ce8-b21a-779314aa0cf8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853119816*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"24c46b62-10b1-45fa-adc6-c0ce8f186c82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance of additive energy = \"\>", "\[InvisibleSpace]", 
   "400"}],
  SequenceForm["variance of additive energy = ", 400],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853127849*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"b474b105-8cc2-4de1-a941-bc04bbb89f11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance of epistatic energy = \"\>", "\[InvisibleSpace]", 
   "23.94`"}],
  SequenceForm["variance of epistatic energy = ", 23.94],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853135778*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"13014cfe-0086-489a-b16d-53eeb45abcfd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"fraction of total variance due to additive energy = \"\>", 
   "\[InvisibleSpace]", "0.9435297447752041`"}],
  SequenceForm[
  "fraction of total variance due to additive energy = ", 0.9435297447752041],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.7414438531439734`*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"8366f6dc-c688-44ce-8f67-e99663f9f9d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cutoff standard deviations from mean = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "19.427091854162878`"}]}],
  SequenceForm[
  "cutoff standard deviations from mean = ", -19.427091854162878`],
  Editable->False]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.7414438531521597`*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"4d04e80a-dba9-473b-8b13-8f9a6b05d212"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443853160055*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"497bb5a0-831e-4665-b8fa-ed2b143beeff"],

Cell[BoxData["\<\"Drawing \[Beta]s...\"\>"], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443861359384*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"5ef2c1fa-6ee2-483d-a6e9-785e946abd20"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.011923`", ",", "Null"}], "}"}]], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443861449242*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"e2b9d275-d9eb-4401-a9a7-635b882514ee"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443861459701*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"1bfda0d2-9d39-45f3-afef-7a19bfa8dead"],

Cell[BoxData["\<\"Hash table created for HOC energies.\"\>"], "Print",
 CellChangeTimes->{3.740840929397978*^9, 3.740914119665197*^9, 
  3.7409603106418343`*^9, 3.740963282733498*^9, 3.741000875816023*^9, 
  3.741434245669739*^9, 3.741443863181959*^9},
 CellLabel->
  "During evaluation of \
In[391]:=",ExpressionUUID->"8b431093-bd56-4387-b2c9-c15cd9787ec7"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate random walk", "Subsubsection",
 CellChangeTimes->{
  3.736776260513404*^9},ExpressionUUID->"f62bbd2c-eb3e-49e4-a346-\
ea588c9ff5a6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"GENERATE", " ", "RANDOM", " ", "WALK"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SeedRandom", "[", "123456789", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numIter", "=", "10000000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Generating random walk...\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"walk", "=", 
         RowBox[{"RandomWalkBasedOnTotalEnergyHocFast", "[", 
          RowBox[{
          "wt", ",", "energyCutoff", ",", "numIter", ",", "l", ",", "alpha", 
           ",", "\[Beta]", ",", 
           SqrtBox["variancehoc"]}], "]"}]}], ";"}], ")"}], "//", 
      "AbsoluteTiming"}], "//", "Print"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "PLOT", " ", "ADDITIVE", " ", "ENERGY", " ", "VS", " ", "TOTAL", " ", 
     "ENERGY"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPointsToPlot", "=", "numIter"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p11", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "10000"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "10000"}], "]"}], "]"}]}], "}"}], "]"}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "energyCutoff", "}"}], ",", 
          RowBox[{"{", "energyCutoff", "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p12", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p11", ",", "p12", ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<E1\>\"", ",", " ", "\"\<E1+E2\>\""}], "}"}]}]}], "]"}]}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPointsToPlot", "=", 
     RowBox[{"numIter", "-", "10000"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p11", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "10000"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "10000"}], "]"}], "]"}]}], "}"}], "]"}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "energyCutoff", "}"}], ",", 
          RowBox[{"{", "energyCutoff", "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p12", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p11", ",", "p12", ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<E1\>\"", ",", " ", "\"\<E1+E2\>\""}], "}"}]}]}], "]"}]}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.735338806149899*^9, 3.7353388968251534`*^9}, {
   3.735343562061551*^9, 3.735343562627553*^9}, {3.735343655162856*^9, 
   3.735343674790699*^9}, {3.7353456811309853`*^9, 3.735345681686078*^9}, {
   3.735382815428287*^9, 3.7353828162481003`*^9}, {3.735391784672995*^9, 
   3.735391797154351*^9}, {3.7353923070597143`*^9, 3.735392309692967*^9}, 
   3.735392417811624*^9, {3.735393101396289*^9, 3.735393102816099*^9}, 
   3.73539317818019*^9, {3.735395876694244*^9, 3.7353958770963287`*^9}, {
   3.7354061288171186`*^9, 3.7354061680853367`*^9}, {3.735408238071582*^9, 
   3.735408238199889*^9}, {3.735408568548231*^9, 3.7354085693554564`*^9}, {
   3.73540863029198*^9, 3.735408630836402*^9}, {3.7354087693724613`*^9, 
   3.735408769950099*^9}, {3.7354105737408657`*^9, 3.735410573968326*^9}, {
   3.735410631836471*^9, 3.7354106825868683`*^9}, {3.735425389476039*^9, 
   3.735425391975503*^9}, {3.735998225295422*^9, 3.735998258412681*^9}, {
   3.735998291281876*^9, 3.735998326668337*^9}, {3.736068339608787*^9, 
   3.7360683406522827`*^9}, {3.736069609384886*^9, 3.736069609807073*^9}, {
   3.736069992908252*^9, 3.736069993293927*^9}, {3.7361695823174477`*^9, 
   3.7361695869059896`*^9}, {3.736332563327745*^9, 3.736332584424817*^9}, {
   3.736336438223412*^9, 3.736336466362225*^9}, {3.736370829563974*^9, 
   3.736370839283512*^9}, {3.736371154952077*^9, 3.736371156765463*^9}, {
   3.736371724958716*^9, 3.736371757887183*^9}, 3.736372713072393*^9, {
   3.736372756505062*^9, 3.736372770391078*^9}, 3.73644827644027*^9, {
   3.736459177382196*^9, 3.736459189733861*^9}, {3.73653440202625*^9, 
   3.736534404389469*^9}, {3.7366367523348093`*^9, 3.7366367557806587`*^9}, {
   3.736639400322304*^9, 3.7366394089817657`*^9}, {3.736687422306202*^9, 
   3.736687428168548*^9}, {3.740959793741743*^9, 3.740959796831256*^9}},
 CellLabel->
  "In[422]:=",ExpressionUUID->"d41ea980-71e7-455a-8229-65ed2153c46b"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Generating random walk...\"\>"], "Print",
 CellChangeTimes->{3.736459190347023*^9, 3.736460339598674*^9, 
  3.736534416189781*^9, 3.736636768095921*^9, 3.7366374780719357`*^9, 
  3.73663815590235*^9, 3.736639424321453*^9, 3.736643055609611*^9, 
  3.736687525534514*^9, 3.736699179723057*^9, 3.736768052212088*^9, 
  3.740840938733057*^9, 3.740914181373332*^9, 3.74096032982113*^9, 
  3.740963301882575*^9, 3.741000889157412*^9, 3.741434253468528*^9, 
  3.741443863267844*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"1a19149e-2782-4e75-8298-e0bf87a97a3a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1373.97816`", ",", "Null"}], "}"}]], "Print",
 CellChangeTimes->{3.736459190347023*^9, 3.736460339598674*^9, 
  3.736534416189781*^9, 3.736636768095921*^9, 3.7366374780719357`*^9, 
  3.73663815590235*^9, 3.736639424321453*^9, 3.736643055609611*^9, 
  3.736687525534514*^9, 3.736699179723057*^9, 3.736768052212088*^9, 
  3.740840938733057*^9, 3.740914181373332*^9, 3.74096032982113*^9, 
  3.740963301882575*^9, 3.741000889157412*^9, 3.741434253468528*^9, 
  3.741445237246134*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"eaee2bc8-de06-4533-879c-3bb91dfc3ea3"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.736459190347023*^9, 3.736460339598674*^9, 
  3.736534416189781*^9, 3.736636768095921*^9, 3.7366374780719357`*^9, 
  3.73663815590235*^9, 3.736639424321453*^9, 3.736643055609611*^9, 
  3.736687525534514*^9, 3.736699179723057*^9, 3.736768052212088*^9, 
  3.740840938733057*^9, 3.740914181373332*^9, 3.74096032982113*^9, 
  3.740963301882575*^9, 3.741000889157412*^9, 3.741434253468528*^9, 
  3.741445237263014*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"3074956b-054f-4431-8105-e8efe6d117c2"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.0055000000000000005`], AbsoluteThickness[1.6],
       PointBox[CompressedData["
1:eJztm3k0VXv4/4/hmOd5ykwDCZHI0IyMiVSSMqRCZGjvTepqLqUSKhrRcBMZ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       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF1P8z03EcwPGF2Pl2p5Q4s2bcum4XndQuGnMrjjZactHhVqGcIju2G0vY
Zth8nCuluVFOKeawHeXK9YM6lS8p6tK6fal1mFUsX3buUt3l9f7heY//4Ek6
m8/JcsDhcKy//VPzuGl+Iwp7tmkjydbtE4EUVh/nhRxExqRurGdQkW/WznsM
7UJaD4WGli7WgZT+F0Vrd5HKPhtucSvygwLL4PfKwWbS8ksFrxbcN3mn0xBR
A+44Vz81MicDJeo4N0Z3FRg/E1PNPi0FdYFi0S28BFwlY2WFE5VgtotuxFhS
AWa0LRGN9HIw6EyS1R9/DRTN6x11l0TgMNYXp1oTglo73r+WLQDpSuunnz1F
4Iw6a6A4mgcSJVwSRVkALtw2sn4czQOtWpdisyUbJNHj+WMPueASJyfTUpUK
YoIG79ExFnj9/heFeC4MTNsjZOK2hEVv+vE9y+dyMxsskRlvqimpYGG183Lk
PBep32D2UnJA9sm36WbXPHBBNU41dRaAxLbd2P5gHvgo/6sTvqEI7OAHLWjC
BKDUc3IgqkMIDhrsv1pPiEAdA9tpGisDNeGvg6cDykHyrLudfKUCdDWJh0xd
lWCzfTDS3VECcpcfMO0cKaiiTdBT5FWgtKlvkWCQgWbGaOMpQg3IH1c9T0qu
BbWCEHV/uxy8kLsilRsUYPuqONn1G9Ik3h4osyDTW0KfVq4gOVO5NqF7HRhB
12depCE9t43QjtUjE1pSnIdvIGVU8zuGEukQ65B/5B5ytSSy/cATpMHc40We
RRJ4UfpWKzINN94VYENO+1li/X4jXyUGX/XyxkCXz5oEzBfJzI3x9SAih8SZ
Wvxe5LrX93JpCJLWUproFI4sproRKg4j/38L/APA3mgJ
        "]]},
      Annotation[#, "Charting`Private`Tag$62623096#1"]& ]}, {}, {}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{
    FormBox["\"E1\"", TraditionalForm], 
    FormBox["\"E1+E2\"", TraditionalForm]},
  AxesOrigin->{-371.92684705750725`, -382.6478651712793},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{-400}, {-400}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-750.6819891667781, -377.7538492438037}, {-747.0438302590283, \
-400.00005398498166`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.736459987684371*^9, 3.736460522185501*^9, 
  3.736534549774275*^9, 3.736636898336666*^9, 3.736637601619873*^9, 
  3.736638273621417*^9, 3.7366407310964003`*^9, 3.7366446619862556`*^9, 
  3.736688875732299*^9, 3.736699191072319*^9, 3.7367694344792852`*^9, 
  3.740842344402627*^9, 3.7409156352419*^9, 3.7409617738664722`*^9, 
  3.7409633814728317`*^9, 3.74100226759326*^9, 3.741435494574699*^9, 
  3.741445237931374*^9},
 CellLabel->
  "Out[430]=",ExpressionUUID->"829bbedc-d377-4d63-b3cf-16fe3293340e"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJztm3k0VXv4/4/hmOd5ykyFhKjI0IyMiVSSMqRCZGjvTepqLqUSKhrRcDNk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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF1P8z03EcwPGF2Pl2p5Q4s2bcum4XndQuGnMrjjZactHhVqGcIju2G0vY
Zth8nCuluVFOKeawHeXK9YM6lS8p6tK6fal1mFUsX3buUt3l9f7heY//4Ek6
m8/JcsDhcKy//VPzuGl+Iwp7tmkjydbtE4EUVh/nhRxExqRurGdQkW/WznsM
7UJaD4WGli7WgZT+F0Vrd5HKPhtucSvygwLL4PfKwWbS8ksFrxbcN3mn0xBR
A+44Vz81MicDJeo4N0Z3FRg/E1PNPi0FdYFi0S28BFwlY2WFE5VgtotuxFhS
AWa0LRGN9HIw6EyS1R9/DRTN6x11l0TgMNYXp1oTglo73r+WLQDpSuunnz1F
4Iw6a6A4mgcSJVwSRVkALtw2sn4czQOtWpdisyUbJNHj+WMPueASJyfTUpUK
YoIG79ExFnj9/heFeC4MTNsjZOK2hEVv+vE9y+dyMxsskRlvqimpYGG183Lk
PBep32D2UnJA9sm36WbXPHBBNU41dRaAxLbd2P5gHvgo/6sTvqEI7OAHLWjC
BKDUc3IgqkMIDhrsv1pPiEAdA9tpGisDNeGvg6cDykHyrLudfKUCdDWJh0xd
lWCzfTDS3VECcpcfMO0cKaiiTdBT5FWgtKlvkWCQgWbGaOMpQg3IH1c9T0qu
BbWCEHV/uxy8kLsilRsUYPuqONn1G9Ik3h4osyDTW0KfVq4gOVO5NqF7HRhB
12depCE9t43QjtUjE1pSnIdvIGVU8zuGEukQ65B/5B5ytSSy/cATpMHc40We
RRJ4UfpWKzINN94VYENO+1li/X4jXyUGX/XyxkCXz5oEzBfJzI3x9SAih8SZ
Wvxe5LrX93JpCJLWUproFI4sproRKg4j/38L/APA3mgJ
        "]]},
      Annotation[#, "Charting`Private`Tag$62623181#1"]& ]}, {}, {}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{
    FormBox["\"E1\"", TraditionalForm], 
    FormBox["\"E1+E2\"", TraditionalForm]},
  AxesOrigin->{-377.5377356402092, -399.5560047250385},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{-400}, {-400}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-391.5851198738589, -377.7538492438037}, \
{-408.88103918384405`, -400.00005398498166`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.736459987684371*^9, 3.736460522185501*^9, 
  3.736534549774275*^9, 3.736636898336666*^9, 3.736637601619873*^9, 
  3.736638273621417*^9, 3.7366407310964003`*^9, 3.7366446619862556`*^9, 
  3.736688875732299*^9, 3.736699191072319*^9, 3.7367694344792852`*^9, 
  3.740842344402627*^9, 3.7409156352419*^9, 3.7409617738664722`*^9, 
  3.7409633814728317`*^9, 3.74100226759326*^9, 3.741435494574699*^9, 
  3.741445238477186*^9},
 CellLabel->
  "Out[434]=",ExpressionUUID->"fb22c61d-639e-4bf8-b094-ed0bca33ce26"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bivariate normal approximation - analytically", "Subsubsection",
 CellChangeTimes->{
  3.736776268057625*^9},ExpressionUUID->"6faea0e3-acfa-48f7-9b77-\
0e1046efcfa9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "FIT", " ", "BIVARIATE", " ", "NORMAL", " ", "DISTRIBUTION", " ", "TO", 
    " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ADDITIVE", " ", "ENERGY"}], ",", " ", 
      RowBox[{"EPISTATIC", " ", "ENERGY"}]}], "}"}], " ", "OF", " ", "A", " ",
     "RANDOMLY", " ", "DRAWN", " ", "SEQUENCE", " ", "USING", " ", 
    "ANALYTICAL", " ", "FORMULAS"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"varx", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"alpha", "-", "1"}], ")"}], "/", "alpha"}], " ", "l", " ", 
       "variance1"}], "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vary", "=", 
     RowBox[{"variancehoc", "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<parameters of analitically fitted bivariate normal distribution =\>\
\"", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"meanVec", ",", "covMatrix"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"varx", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "vary"}], "}"}]}], "}"}]}], "}"}]}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vec", "=", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"unnormalizedCutGauss", "=", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"vec", "-", "meanVec"}], ")"}], ".", 
         RowBox[{"Inverse", "[", "covMatrix", "]"}], ".", 
         RowBox[{"(", 
          RowBox[{"vec", "-", "meanVec"}], ")"}]}]}], "]"}], " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"energyCutoff", "-", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"norm", "=", 
     RowBox[{
      RowBox[{"1", "/", "unnormalizedCutGauss"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "\[Rule]", 
         RowBox[{"Mean", "[", 
          RowBox[{"walk", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1000"}], ";;"}], ",", "2"}], "]"}], "]"}], 
          "]"}]}], ",", 
        RowBox[{"y", "\[Rule]", 
         RowBox[{"Mean", "[", 
          RowBox[{"walk", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1000"}], ";;"}], ",", "3"}], "]"}], "]"}], 
          "]"}]}]}], "}"}]}]}], 
    RowBox[{"(*", 
     RowBox[{"/", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{"unnormalizedCutGauss", ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "\[Infinity]"}], ",", 
          RowBox[{"energyCutoff", "-", "y"}]}], "}"}]}], "]"}]}], "*)"}], 
    ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Normalization", " ", "takes", " ", "too", " ", "long", " ", "on", " ", 
      "my", " ", "computer", " ", "for", " ", "some", " ", "reason"}], ",", 
     " ", 
     RowBox[{
     "so", " ", "just", " ", "set", " ", "density", " ", "at", " ", 
      "expected", " ", "mean", " ", "to", " ", "1"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"cutGaussDensity", "=", 
    RowBox[{"norm", " ", "unnormalizedCutGauss"}]}]}]}]], "Input",
 CellChangeTimes->{{3.735999069430941*^9, 3.735999110642622*^9}, {
   3.7359992935867023`*^9, 3.735999359812723*^9}, {3.7359993943534193`*^9, 
   3.735999407532209*^9}, {3.735999694503731*^9, 3.7359998463581743`*^9}, {
   3.7360000972615557`*^9, 3.736000117131439*^9}, {3.736003771134399*^9, 
   3.7360037719094963`*^9}, {3.7360043952201443`*^9, 3.736004397590323*^9}, {
   3.7360045137607727`*^9, 3.736004514163857*^9}, {3.736115720712201*^9, 
   3.7361157468623037`*^9}, {3.736248160711125*^9, 3.736248180838785*^9}, {
   3.736248834152248*^9, 3.73624886123881*^9}, {3.736248957835306*^9, 
   3.736249074599868*^9}, {3.736332660394045*^9, 3.73633266219065*^9}, {
   3.7363328518437843`*^9, 3.736332862848887*^9}, 3.740963405447132*^9, 
   3.740963632348925*^9},
 CellLabel->
  "In[436]:=",ExpressionUUID->"14ed8d0c-a9f0-4e16-ba84-385408ca3757"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"parameters of analitically fitted bivariate normal \
distribution =\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"400.`", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "23.94`"}], "}"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "parameters of analitically fitted bivariate normal distribution =", {{0, 
    0}, {{400., 0}, {0, 23.94}}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7360001180711193`*^9, {3.736003748626285*^9, 3.7360037729071417`*^9}, 
   3.736067638386717*^9, 3.736115873577963*^9, 3.736178856999033*^9, 
   3.736248738122796*^9, 3.736248862242145*^9, {3.736248961029578*^9, 
   3.736248975134996*^9}, {3.7362490647743607`*^9, 3.736249075133238*^9}, 
   3.736250166017733*^9, 3.736251404095696*^9, 3.736253134325486*^9, 
   3.7362713075673122`*^9, 3.736272028861128*^9, 3.736293545943941*^9, 
   3.736294327538059*^9, 3.736295194014512*^9, 3.736296121723184*^9, 
   3.736332669825014*^9, 3.736336528824416*^9, 3.736336689334441*^9, 
   3.736337042172803*^9, 3.73637195938169*^9, 3.7364482442651587`*^9, 
   3.7365349458164988`*^9, 3.736637034631816*^9, 3.736637683053668*^9, 
   3.7366382745389757`*^9, 3.736641023028145*^9, 3.7366446640743217`*^9, 
   3.736644907265678*^9, 3.736688878756802*^9, 3.736769435511703*^9, 
   3.7408423464886217`*^9, 3.740915640048027*^9, 3.740961776023226*^9, 
   3.741002269021559*^9, 3.7414354955739517`*^9, 3.741445239076268*^9},
 CellLabel->
  "During evaluation of \
In[436]:=",ExpressionUUID->"160c7dd4-1e52-4f0f-a00e-65908e6313e7"],

Cell[BoxData[
 RowBox[{"2.8334596730014047`*^82", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.0025`", " ", "x"}]}], ")"}]}], " ", "x"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0.`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.04177109440267335`", " ", "y"}]}], ")"}], " ", "y"}]}], 
     ")"}]}]], " ", 
  RowBox[{"UnitStep", "[", 
   RowBox[{
    RowBox[{"-", "400"}], "-", "x", "-", "y"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.735999792820609*^9, 3.735999847607314*^9}, 
   3.73600011808501*^9, {3.736003749202795*^9, 3.7360037730798264`*^9}, 
   3.736067639513176*^9, 3.7361158747099457`*^9, 3.736178857012473*^9, 
   3.7362487381369753`*^9, 3.736248862251943*^9, {3.736248961040125*^9, 
   3.736248975144142*^9}, {3.7362490648838053`*^9, 3.736249075145441*^9}, 
   3.736250166027701*^9, 3.7362514041036654`*^9, 3.7362531343338623`*^9, 
   3.736271307580934*^9, 3.736272028868565*^9, 3.736293545960244*^9, 
   3.736294327545326*^9, 3.736295194022214*^9, 3.7362961217306843`*^9, 
   3.736332669836027*^9, 3.736336528836916*^9, 3.7363366893454514`*^9, 
   3.736337042181262*^9, 3.736371960569446*^9, 3.736448244277129*^9, 
   3.7365349458284893`*^9, 3.736637034646146*^9, 3.736637683066127*^9, 
   3.7366382745498867`*^9, 3.736641023039665*^9, 3.736644664099845*^9, 
   3.736644907289588*^9, 3.7366888799796*^9, 3.736769435522829*^9, 
   3.740842346501637*^9, 3.740915640098103*^9, 3.740961776038773*^9, 
   3.741002269034506*^9, 3.741435495584344*^9, 3.741445239090046*^9},
 CellLabel->
  "Out[442]=",ExpressionUUID->"cab82c63-ab51-4fba-ac4f-e137749c64d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "PLOTS", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fontSize", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPointsToPlot", "=", 
     RowBox[{"numIter", "-", "10000"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"walk", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], "]"}],
        "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ";;", "1000"}], "]"}], "]"}], "-", 
      "energyCutoff"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"walk", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], "]"}],
        "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ";;", "1000"}], "]"}], "]"}], "-", 
      "energyCutoff"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"E1", ",", "E2"}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"plot", " ", "diagonal"}], ",", " ", "vertical", ",", " ", 
     RowBox[{"and", " ", "horizontal", " ", "lines"}], ",", " ", 
     RowBox[{"set", " ", "axes", " ", "settings"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p21", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"GrayLevel", "[", "0.05", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"18.8", ",", 
              RowBox[{"Directive", "[", " ", 
               RowBox[{
                RowBox[{"GrayLevel", "[", "0.05", "]"}], ",", "Dashed", ",", 
                " ", "Thick"}], "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"GrayLevel", "[", "0.05", "]"}], "]"}]}], "}"}], 
           "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<\!\(\*SubscriptBox[\(\[CapitalDelta]G\), \(add\)]\) \
(kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\[CapitalDelta]G (kcal/mol)\>\"", ",", "fontSize"}], 
           "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRangePadding", "\[Rule]", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"plot", " ", "data", " ", "from", " ", "random", " ", "walk"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "plot", " ", "level", " ", "curve", " ", "corresponding", " ", "to", " ", 
     "the", " ", "bivariate", " ", "normal", " ", "distribution", " ", 
     "having", " ", "95", "%", " ", "of", " ", "the", " ", "total", " ", 
     "mass", " ", "within", " ", "the", " ", "curve"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p23", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", "vary", "]"}]}], " ", 
            RowBox[{"Sqrt", "[", " ", 
             RowBox[{
              RowBox[{"rr", "^", "2"}], "-", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", "varx"}]}], "]"}]}], "+", 
           "xpx"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "vary", "]"}], " ", 
            RowBox[{"Sqrt", "[", " ", 
             RowBox[{
              RowBox[{"rr", "^", "2"}], "-", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", "varx"}]}], "]"}]}], "+", 
           "xpx"}]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"rr", "\[Rule]", "19.65"}], ",", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{"xpx", "+", "energyCutoff"}]}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"xpx", ",", 
         RowBox[{"-", "100"}], ",", "100"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", " ", "Dashed", ",", "Thick"}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "0"}], "}"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"p2", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p21", ",", "p22", ",", "p23"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<means = (\>\"", ",", " ", 
      RowBox[{"Mean", "[", "E1", "]"}], ",", "\"\<, \>\"", ",", 
      RowBox[{"Mean", "[", "E2", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", " ", 
      RowBox[{"r", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.736767654198523*^9, 3.736767654640686*^9}, {
   3.7367677024238462`*^9, 3.736767710259255*^9}, {3.73677462866743*^9, 
   3.736774650932276*^9}, {3.736774692303574*^9, 3.736774822254427*^9}, {
   3.736775292859318*^9, 3.736775407961176*^9}, {3.7408397461532497`*^9, 
   3.74083974977544*^9}, 3.740913746560237*^9, {3.7409598518825693`*^9, 
   3.740959869498075*^9}, {3.7409986675345993`*^9, 3.740998668271826*^9}, 
   3.7410008663678293`*^9, {3.741445181374611*^9, 3.741445183459021*^9}, {
   3.7414464897543383`*^9, 3.741446492163075*^9}},
 CellLabel->
  "In[490]:=",ExpressionUUID->"7d94ed0a-12fb-4d8e-aaa2-1477751986c8"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[{{-15., -15.}, {5., 5.}}]},
      Annotation[#, "Charting`Private`Tag$62633002#1"]& ]}, {}, {}}, {{}, {{}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[1, 360], 0.002777777777777778]], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJzs3Xk0Ve3fMPBtVpKhEoWOQuYpUypdzaFBM40nGjRLJQ1qN5cmREmDUzRq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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], Thickness[Large], Opacity[1.], Dashing[{Small, Small}],
        LineBox[CompressedData["
1:eJw91gk0lekbAHC7m/V+H0VZsu/LXVxreOwymWSJypSMYrS4RUIpUze0CRlE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        "]]},
      Annotation[#, "Charting`Private`Tag$62633085#1"]& ]}, {}, {}}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox["\"\[CapitalDelta]G (kcal/mol)\"", 10, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]G\\), \\(add\\)]\\) \
(kcal/mol)\"", 10, StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
     Automatic, {{-15., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-13., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-11., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-9., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {24., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {26., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {28., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {32., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {34., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {36., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {38., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{{{0, 
      Directive[
       GrayLevel[0.05]]}, {18.8, 
      Directive[
       GrayLevel[0.05], 
       Dashing[{Small, Small}], 
       Thickness[Large]]}}, {{0, 
      Directive[
       GrayLevel[0.05]]}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-15, 40}, {-15, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7367746463658743`*^9, 3.7367746522833757`*^9}, {
   3.736774697700227*^9, 3.7367747282875633`*^9}, {3.736774758575988*^9, 
   3.736774823801586*^9}, {3.7367753010500813`*^9, 3.736775334982546*^9}, {
   3.736775373634037*^9, 3.73677540955173*^9}, 3.7408423471744204`*^9, 
   3.740915640983391*^9, 3.740961776917556*^9, 3.74100226974559*^9, 
   3.7414354962070932`*^9, 3.741445239699223*^9, 3.741445412571372*^9, 
   3.74144649379978*^9},
 CellLabel->"Out[498]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"f9f5e4fa-096b-4289-8d75-0280b405c259"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"means = (\"\>", "\[InvisibleSpace]", "18.829872861969307`", 
   "\[InvisibleSpace]", "\<\", \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1.0743842260307037`"}], "\[InvisibleSpace]", "\<\")\"\>"}],
  SequenceForm[
  "means = (", 18.829872861969307`, ", ", -1.0743842260307037`, ")"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736688881739079*^9, 3.7367694362020597`*^9, {3.736774646706378*^9, 
   3.736774652388369*^9}, {3.736774697811241*^9, 3.736774728395351*^9}, {
   3.736774758687276*^9, 3.736774823912871*^9}, {3.736775301160074*^9, 
   3.736775335091127*^9}, {3.7367753737459917`*^9, 3.736775409657984*^9}, 
   3.740842347335149*^9, 3.740915640995763*^9, 3.740961777007524*^9, 
   3.741002269756773*^9, 3.7414354962170973`*^9, 3.7414452398094797`*^9, 
   3.741445412675991*^9, 3.7414464939074097`*^9},
 CellLabel->
  "During evaluation of \
In[490]:=",ExpressionUUID->"bfa3645a-871b-4c7f-bc98-550470edaa9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", "0.20195638356322865`"}],
  SequenceForm["r = ", 0.20195638356322865`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736688881739079*^9, 3.7367694362020597`*^9, {3.736774646706378*^9, 
   3.736774652388369*^9}, {3.736774697811241*^9, 3.736774728395351*^9}, {
   3.736774758687276*^9, 3.736774823912871*^9}, {3.736775301160074*^9, 
   3.736775335091127*^9}, {3.7367753737459917`*^9, 3.736775409657984*^9}, 
   3.740842347335149*^9, 3.740915640995763*^9, 3.740961777007524*^9, 
   3.741002269756773*^9, 3.7414354962170973`*^9, 3.7414452398094797`*^9, 
   3.741445412675991*^9, 3.741446493915626*^9},
 CellLabel->
  "During evaluation of \
In[490]:=",ExpressionUUID->"aafd517b-0ca0-45d2-882b-2055a0d726b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.04078638086193793`"}],
  SequenceForm["r^2 = ", 0.04078638086193793],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736688881739079*^9, 3.7367694362020597`*^9, {3.736774646706378*^9, 
   3.736774652388369*^9}, {3.736774697811241*^9, 3.736774728395351*^9}, {
   3.736774758687276*^9, 3.736774823912871*^9}, {3.736775301160074*^9, 
   3.736775335091127*^9}, {3.7367753737459917`*^9, 3.736775409657984*^9}, 
   3.740842347335149*^9, 3.740915640995763*^9, 3.740961777007524*^9, 
   3.741002269756773*^9, 3.7414354962170973`*^9, 3.7414452398094797`*^9, 
   3.741445412675991*^9, 3.741446493928679*^9},
 CellLabel->
  "During evaluation of \
In[490]:=",ExpressionUUID->"bfb61ec3-db6f-4041-ab19-c1d5a48fad02"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "variancehoc"}], " ", 
  RowBox[{"Inverse", "[", 
   RowBox[{"CDF", "[", 
    RowBox[{"NormalDistribution", "[", 
     RowBox[{
      RowBox[{"[", 
       RowBox[{"0", ",", "1"}], "]"}], ",", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"400", " ", "19"}], ")"}]}]}], "]"}], "]"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.741445452989349*^9, 3.741445457230729*^9}, {
  3.7414454959471903`*^9, 3.74144556320651*^9}},
 EmphasizeSyntaxErrors->True,
 CellLabel->
  "In[473]:=",ExpressionUUID->"154fa66f-6100-40a1-aa33-84f2f2312b16"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "/", 
   RowBox[{"(", 
    RowBox[{"400", " ", "19"}], ")"}]}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.741445728262843*^9, 3.74144572886425*^9}},
 CellLabel->
  "In[478]:=",ExpressionUUID->"0f089365-e66e-49bd-b7ac-56c8ddea9fc5"],

Cell[BoxData["0.00013157894736842105`"], "Output",
 CellChangeTimes->{3.741445729181404*^9},
 CellLabel->
  "Out[478]=",ExpressionUUID->"77e72420-a982-4980-88cc-265dce0e0794"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"CDF", "[", 
       RowBox[{
        RowBox[{"NormalDistribution", "[", 
         RowBox[{"0", ",", "1"}], "]"}], ",", "x"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "4"}], ",", 
      RowBox[{"-", "3"}], ",", "0.01"}], "}"}]}], "]"}], "//", "N"}]], "Input",\

 CellChangeTimes->{
  3.741445582678026*^9, {3.741445616477499*^9, 3.741445644891913*^9}, {
   3.741445685783105*^9, 3.74144576352801*^9}, {3.741445794478305*^9, 
   3.741445837443282*^9}},
 CellLabel->
  "In[485]:=",ExpressionUUID->"a524c213-c64e-4b4e-a8ab-944874a2a541"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.`"}], ",", "0.000031671241833119985`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.99`"}], ",", "0.00003303664762940245`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.98`"}], ",", "0.00003445763411505313`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.97`"}], ",", "0.00003593631590285383`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.96`"}], ",", "0.00003747488169107353`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.95`"}], ",", "0.00003907559659778757`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.94`"}], ",", "0.00004074080455855083`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.93`"}], ",", "0.00004247293078876127`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.92`"}], ",", "0.00004427448431207083`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.91`"}], ",", "0.00004614806055620889`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.9`"}], ",", "0.00004809634401760274`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.89`"}], ",", "0.00005012211099618849`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.88`"}], ",", "0.000052228232401820216`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.87`"}], ",", "0.00005441767663369976`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.86`"}], ",", "0.0000566935125342567`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.85`"}], ",", "0.00005905891241892256`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.84`"}], ",", "0.00006151715518325539`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.83`"}], ",", "0.00006407162948887462`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.82`"}], ",", "0.00006672583702968484`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.81`"}], ",", "0.00006948339587986525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.8`"}], ",", "0.00007234804392512014`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.79`"}], ",", "0.00007532364237868343`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.78`"}], ",", "0.0000784141793835852`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.77`"}], ",", "0.00008162377370268622`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.76`"}], ",", "0.00008495667849799815`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.75`"}], ",", "0.00008841728520080404`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.74`"}], ",", "0.00009201012747410558`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.73`"}], ",", "0.00009573988526891472`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.7199999999999998`"}], ",", "0.00009961138897591671`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.71`"}], ",", "0.00010362962367403132`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.7`"}], ",", "0.00010779973347738849`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.69`"}], ",", "0.00011212702598224712`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.68`"}], ",", "0.00011661697681536842`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.67`"}], ",", "0.00012127523428535803`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.66`"}], ",", "0.00012610762413848675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.65`"}], ",", "0.0001311201544204847`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.64`"}], ",", "0.00013631902044580204`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.63`"}], ",", "0.00014171060987581936`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.62`"}], ",", "0.0001473015079074726`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.61`"}], ",", "0.0001530985025737555`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6`"}], ",", "0.00015910859015753396`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.59`"}], ",", "0.00016533898072011006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.58`"}], ",", "0.00017179710374593102`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.57`"}], ",", "0.00017849061390484775`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.56`"}], ",", "0.00018542739693327824`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.55`"}], ",", "0.0001926155756356337`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.54`"}], ",", "0.00020006351600732053`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.53`"}], ",", "0.00020777983348062203`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.52`"}], ",", "0.00021577339929471797`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.51`"}], ",", "0.00022405334699109305`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.5`"}], ",", "0.00023262907903552548`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.49`"}], ",", "0.00024151027356783658`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.48`"}], ",", "0.00025070689128053766`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.4699999999999998`"}], ",", "0.00026022918242746723`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.46`"}], ",", "0.00027008769396347486`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.45`"}], ",", "0.00028029327681617744`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.44`"}], ",", "0.0002908570932907434`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.4299999999999997`"}], ",", "0.00030179062460863805`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.42`"}], ",", "0.0003131056785812005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.41`"}], ",", "0.00032481439741887806`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.4`"}], ",", "0.0003369292656768814`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.39`"}], ",", "0.0003494631183379716`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.38`"}], ",", "0.0003624291490330445`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.37`"}], ",", "0.0003758409184000838`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.36`"}], ",", "0.0003897123625820324`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.35`"}], ",", "0.0004040578018640215`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.34`"}], ",", "0.00041889194945037055`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.33`"}], ",", "0.00043422992038165626`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.32`"}], ",", "0.0004500872405921175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.31`"}], ",", "0.00046647985610755004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.3`"}], ",", "0.0004834241423837775`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.29`"}], ",", "0.0005009369137857223`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.2800000000000002`"}], ",", "0.0005190354332069734`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.27`"}], ",", "0.000537737421829695`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.26`"}], ",", "0.0005570610690246225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.25`"}], ",", "0.0005770250423907671`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.24`"}], ",", "0.0005976484979344156`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.23`"}], ",", "0.0006189510903868356`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.2199999999999998`"}], ",", "0.0006409529836600576`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.21`"}], ",", "0.0006636748614399684`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.2`"}], ",", "0.0006871379379158483`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.19`"}], ",", "0.0007113639686453649`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.1799999999999997`"}], ",", "0.0007363752615539326`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.17`"}], ",", "0.0007621946880672364`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.16`"}], ",", "0.0007888456943755742`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.15`"}], ",", "0.0008163523128285641`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.14`"}], ",", "0.0008447391734586279`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.13`"}], ",", "0.0008740315156315694`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.12`"}], ",", "0.0009042551998223411`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.11`"}], ",", "0.0009354367195141005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.1`"}], ",", "0.000967603213218358`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.09`"}], ",", "0.0010007824766140115`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.08`"}], ",", "0.0010350029748028417`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.07`"}], ",", "0.0010702938546789246`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.06`"}], ",", "0.001106684957409247`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.05`"}], ",", "0.0011442068310227`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.04`"}], ",", "0.0011828907431044066`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.0300000000000002`"}], ",", "0.0012227686935922595`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.02`"}], ",", "0.0012638734276722995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.01`"}], ",", "0.00130623844876947`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.`"}], ",", "0.0013498980316300959`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.741445627397562*^9, 3.741445645504096*^9}, {
  3.7414456977537107`*^9, 3.741445764117797*^9}, {3.741445798739934*^9, 
  3.7414458377532787`*^9}},
 CellLabel->
  "Out[485]=",ExpressionUUID->"95d0aa70-3977-447f-8d7b-d8bcae57e66d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["variancehoc"], "Input",
 CellChangeTimes->{{3.741445963805378*^9, 3.7414459661181717`*^9}},
 CellLabel->
  "In[487]:=",ExpressionUUID->"aa56f9da-ba35-4a85-ab7a-0f583cae51c9"],

Cell[BoxData["23.94`"], "Output",
 CellChangeTimes->{3.741445966526683*^9},
 CellLabel->
  "Out[487]=",ExpressionUUID->"551cc91d-8226-483b-bc23-1abb23c158ca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "3.65"}], " ", "21"}]], "Input",
 CellChangeTimes->{{3.7414459744133053`*^9, 3.741445976796013*^9}},
 CellLabel->
  "In[488]:=",ExpressionUUID->"9e02516a-1cd1-4230-bb02-1709b6ecd796"],

Cell[BoxData[
 RowBox[{"-", "76.64999999999999`"}]], "Output",
 CellChangeTimes->{3.741445977202856*^9},
 CellLabel->
  "Out[488]=",ExpressionUUID->"00048bd1-1328-4eec-b63b-70fb7920d5f0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "3.65"}], " ", "variancehoc"}]], "Input",
 CellChangeTimes->{{3.741445857352414*^9, 3.741445887388421*^9}},
 CellLabel->
  "In[486]:=",ExpressionUUID->"340ab8c2-1233-4e31-a414-3dfccc56e731"],

Cell[BoxData[
 RowBox[{"-", "87.381`"}]], "Output",
 CellChangeTimes->{3.741445887830776*^9},
 CellLabel->
  "Out[486]=",ExpressionUUID->"6c9737ce-fa5c-4078-968c-68779b43681c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"16.96", "/", "21.6"}], "*", "23.94"}]], "Input",
 CellChangeTimes->{{3.741446427594782*^9, 3.741446457275416*^9}},
 CellLabel->
  "In[489]:=",ExpressionUUID->"f23040ff-0180-44b7-bd58-0079c9c0d0a8"],

Cell[BoxData["18.797333333333334`"], "Output",
 CellChangeTimes->{3.74144645761961*^9},
 CellLabel->
  "Out[489]=",ExpressionUUID->"56896ecd-44a8-4926-a039-4a85646f3cfe"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics for paper", "Subsubsection",
 CellChangeTimes->{
  3.736776318321474*^9},ExpressionUUID->"7ff62521-3f1b-43f8-81f9-\
2c2b8171857e"],

Cell[CellGroupData[{

Cell[BoxData["p2"], "Input",
 CellChangeTimes->{{3.7361792613318977`*^9, 3.736179261460334*^9}, {
   3.736249845890774*^9, 3.736249875230681*^9}, {3.736258448448031*^9, 
   3.73625848629482*^9}, {3.736258569324698*^9, 3.736258581276569*^9}, {
   3.7362587236486607`*^9, 3.7362587244404488`*^9}, {3.7362588778048477`*^9, 
   3.736258885459972*^9}, {3.736259000675259*^9, 3.736259027320492*^9}, {
   3.736259345763562*^9, 3.736259346432063*^9}, {3.736259383743086*^9, 
   3.736259474748727*^9}, 3.736637742834111*^9, {3.736768010828999*^9, 
   3.7367680155845013`*^9}, 3.736775213611095*^9, {3.7409137887377043`*^9, 
   3.740913790977921*^9}},
 CellLabel->
  "In[472]:=",ExpressionUUID->"a4b954dd-3e80-43ba-9626-dbe9f70bbd07"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[{{-15., -15.}, {5., 5.}}]},
      Annotation[#, "Charting`Private`Tag$62624303#1"]& ]}, {}, {}}, {{}, {{}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[1, 360], 0.002777777777777778]], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJzs3Xk0Ve3fMPBtVpKhEoWOQuYpUypdzaFBM40nGjRLJQ1qN5cmREmDUzRq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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], Thickness[Large], Opacity[1.], Dashing[{Small, Small}],
        LineBox[CompressedData["
1:eJw91gk0lekbAHC7m/V+H0VZsu/LXVxreOwymWSJypSMYrS4RUIpUze0CRlE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        "]]},
      Annotation[#, "Charting`Private`Tag$62624386#1"]& ]}, {}, {}}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox["\"\[CapitalDelta]G (kcal/mol)\"", 10, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]G\\), \\(add\\)]\\) \
(kcal/mol)\"", 10, StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
     Automatic, {{-15., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-13., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-11., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-9., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {24., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {26., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {28., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {32., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {34., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {36., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {38., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{{{0, 
      Directive[
       GrayLevel[0.05]]}, {16.96, 
      Directive[
       GrayLevel[0.05], 
       Dashing[{Small, Small}], 
       Thickness[Large]]}}, {{0, 
      Directive[
       GrayLevel[0.05]]}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-15, 40}, {-15, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7410022704189663`*^9, 3.741435496625084*^9, 
  3.7414452405491753`*^9, 3.741445418518317*^9},
 CellLabel->"Out[472]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"bb1cc43b-5864-4440-8086-6778ee8345cf"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Small HOC variance: length=400, Cutoff = -400, variance1=1, variancehoc=0.01\
\>", "Subsection",
 CellChangeTimes->{
  3.7367762094813757`*^9, {3.7367763274494553`*^9, 3.73677632950679*^9}, {
   3.736776987451582*^9, 
   3.736776998575726*^9}},ExpressionUUID->"2b8b4376-df99-4a78-aa2c-\
1d0c65e2cefa"],

Cell[CellGroupData[{

Cell["Set parameters and draw coefficients in energy function", \
"Subsubsection",
 CellChangeTimes->{
  3.736776251695663*^9},ExpressionUUID->"53738ac6-22f5-494a-bb20-\
ac729b83b0f2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SeedRandom", "[", "1234", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"SET", " ", "PARAMETERS"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"l", "=", "400"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"length", " ", "of", " ", "sequence"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alpha", "=", "20"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"alleles", " ", "per", " ", "site"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"variance1", "=", 
   RowBox[{
    RowBox[{"alpha", "/", 
     RowBox[{"(", 
      RowBox[{"alpha", "-", "1"}], ")"}]}], "1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"variancehoc", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"energyCutoff", "=", 
   RowBox[{"-", "400"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wt", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", "l"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fontSize", "=", "13"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<sequence length = \>\"", ",", " ", "l"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<alphabet size = \>\"", ",", "  ", "alpha"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<variance1 = \>\"", ",", " ", "variance1"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<variancehoc = \>\"", ",", " ", "variancehoc"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<energy cutoff = \>\"", ",", " ", "energyCutoff"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<random walk started from wt=\>\"", ",", "wt"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "CALCULATE", " ", "FRACTION", " ", "OF", " ", "VARAIANCE", " ", "OF", " ", 
    "TOTAL", " ", "ENERGY", " ", "DUE", " ", "TO", " ", "ADDITIVE", " ", 
    "ENERGY"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"varAdditiveEnergy", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"alpha", "-", "1"}], ")"}], "/", "alpha"}], " ", "l", " ", 
    "variance1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"varEpistaticEnergy", "=", "variancehoc"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<variance of additive energy = \>\"", ",", " ", "varAdditiveEnergy"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<variance of epistatic energy = \>\"", ",", " ", 
    "varEpistaticEnergy"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<fraction of total variance due to additive energy = \>\"", ",", 
   RowBox[{"varAdditiveEnergy", "/", 
    RowBox[{"(", 
     RowBox[{"varAdditiveEnergy", "+", "varEpistaticEnergy"}], ")"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<cutoff standard deviations from mean = \>\"", ",", 
   RowBox[{"energyCutoff", "/", 
    SqrtBox[
     RowBox[{"(", 
      RowBox[{"varAdditiveEnergy", "+", "varEpistaticEnergy"}], ")"}]]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "DRAW", " ", "COEFFICIENTS", " ", "IN", " ", "ENERGY", " ", "FUNCTION"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SeedRandom", "[", "12345678", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis1", "=", 
   RowBox[{"N", "[", 
    RowBox[{"orthonormalBasisForSubspace1", "[", "alpha", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis2", "=", 
   RowBox[{"N", "[", 
    RowBox[{"orthonormalBasisForSubspace2", "[", "alpha", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Drawing \[Beta]s...\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Beta]0", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"coeffsForOrder1", "[", 
          RowBox[{"alpha", ",", " ", "basis1", ",", " ", 
           RowBox[{"Sqrt", "[", "variance1", "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "l"}], "}"}]}], "]"}]}], ";"}], ")"}], "//",
     "AbsoluteTiming"}], " ", "//", "Print"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"\[Beta]", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Sort", "/@", "\[Beta]0"}], "]"}]}], ")"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "DEFINE", " ", "HASH", " ", "TABLE", " ", "FOR", " ", "HOC", " ", 
    "ENERGIES"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hocAssociation", "=", 
   RowBox[{"Association", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Hash table created for HOC energies.\>\"", "]"}],
   ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.735039670215447*^9, 3.735039676885922*^9}, {
   3.735044800048231*^9, 3.735044803116219*^9}, {3.735045221971918*^9, 
   3.73504522959811*^9}, {3.735045269988558*^9, 3.7350452708141117`*^9}, {
   3.7350453365703077`*^9, 3.735045343485133*^9}, {3.735045417158849*^9, 
   3.7350454404247227`*^9}, 3.735046374306554*^9, {3.735049736725403*^9, 
   3.73504978076836*^9}, {3.73507499072913*^9, 3.735074991297587*^9}, {
   3.735313151518528*^9, 3.7353131526432467`*^9}, {3.735338338003683*^9, 
   3.735338359968875*^9}, {3.735338545344153*^9, 3.7353385505773697`*^9}, {
   3.735343479798663*^9, 3.73534354966885*^9}, 3.735345101844233*^9, 
   3.7353454660740137`*^9, {3.735382657299398*^9, 3.735382659006311*^9}, {
   3.735388042273129*^9, 3.7353880468572283`*^9}, {3.735392685124683*^9, 
   3.7353926853475657`*^9}, {3.735394536084243*^9, 3.7353945364713583`*^9}, 
   3.7353954158473263`*^9, 3.7354072879169703`*^9, {3.7354080776830397`*^9, 
   3.735408079783695*^9}, {3.735997989989833*^9, 3.73599799318114*^9}, {
   3.7360045807781267`*^9, 3.736004585310495*^9}, {3.736066744804278*^9, 
   3.736066748291823*^9}, {3.7360671047459307`*^9, 3.73606731962272*^9}, {
   3.736067487473854*^9, 3.736067505650632*^9}, {3.736067678222561*^9, 
   3.736067730033708*^9}, {3.736068091408441*^9, 3.736068092370936*^9}, 
   3.736068126746172*^9, {3.736068381446144*^9, 3.736068382198934*^9}, {
   3.736068444593129*^9, 3.7360684449737186`*^9}, {3.736068770850031*^9, 
   3.73606877140343*^9}, {3.736069116018488*^9, 3.73606911644902*^9}, {
   3.736069378772266*^9, 3.736069401519719*^9}, {3.736069898412277*^9, 
   3.736069901162999*^9}, {3.736070129825029*^9, 3.736070130130946*^9}, {
   3.736070485526927*^9, 3.7360704857940807`*^9}, {3.736115502167886*^9, 
   3.736115520737797*^9}, {3.7361155591524487`*^9, 3.736115559562126*^9}, {
   3.736115769811782*^9, 3.7361157702937717`*^9}, {3.7361695323703413`*^9, 
   3.7361695344088717`*^9}, {3.736248002082753*^9, 3.7362480053405848`*^9}, 
   3.736248063293035*^9, {3.7362711675400267`*^9, 3.736271173305934*^9}, {
   3.736271760077403*^9, 3.736271761097781*^9}, {3.736292843956057*^9, 
   3.736292844120399*^9}, {3.7362933421321163`*^9, 3.7362933422428637`*^9}, {
   3.736294022411599*^9, 3.736294022543172*^9}, {3.7362949767693167`*^9, 
   3.736294976917819*^9}, {3.736295875584177*^9, 3.736295898812854*^9}, {
   3.736332177823905*^9, 3.736332178972733*^9}, {3.736332350608768*^9, 
   3.7363323694308643`*^9}, {3.736332411150791*^9, 3.736332412694128*^9}, {
   3.7363324445582247`*^9, 3.736332454940785*^9}, {3.736332502145953*^9, 
   3.73633250515546*^9}, {3.736332540731299*^9, 3.736332541026455*^9}, {
   3.736336298343137*^9, 3.736336376803233*^9}, {3.736336589783226*^9, 
   3.736336598334139*^9}, {3.7363368063618*^9, 3.736336806611711*^9}, {
   3.7363702317379627`*^9, 3.73637024114611*^9}, {3.736370743355846*^9, 
   3.736370779096711*^9}, {3.736459133449058*^9, 3.736459134155307*^9}, {
   3.736765559172419*^9, 3.736765584597967*^9}, {3.736765764468499*^9, 
   3.7367657727622643`*^9}, {3.740959882133697*^9, 3.7409598849933653`*^9}, 
   3.740962951400262*^9, 3.7415275417498827`*^9, 3.7415279032630987`*^9, 
   3.741529326412787*^9, 3.741529647245325*^9},
 CellLabel->
  "In[284]:=",ExpressionUUID->"2e1494eb-f7ce-4f63-93d5-522c111553f5"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"sequence length = \"\>", "\[InvisibleSpace]", "400"}],
  SequenceForm["sequence length = ", 400],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.7416903074920387`*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"9a118b8c-65c7-4dbb-979d-f46dae4f7e98"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"alphabet size = \"\>", "\[InvisibleSpace]", "20"}],
  SequenceForm["alphabet size = ", 20],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690307503645*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"f474c6ce-8f03-48e1-996c-80c5cee47af5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance1 = \"\>", "\[InvisibleSpace]", 
   FractionBox["20", "19"]}],
  SequenceForm["variance1 = ", 
   Rational[20, 19]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.7416903075237513`*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"18207e67-ae37-42cc-ade8-248c05bea6c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variancehoc = \"\>", "\[InvisibleSpace]", "0.01`"}],
  SequenceForm["variancehoc = ", 0.01],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.74169030753156*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"52ea7e28-c140-41e7-b240-d331a8ba1d9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"energy cutoff = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "400"}]}],
  SequenceForm["energy cutoff = ", -400],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690307539371*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"cedd14b3-4678-4929-839a-301a96d4a7e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"random walk started from wt=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
      ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}],
  SequenceForm["random walk started from wt=", CompressedData["
1:eJxTTMoPSmJkYGCYACJGwaACAI1FAjk=
   "]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.74169030754799*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"ac880304-7754-4ee6-bdc8-18f449048aa3"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690307556573*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"cb03944f-57f6-42f4-add0-d362316d1a74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance of additive energy = \"\>", "\[InvisibleSpace]", 
   "400"}],
  SequenceForm["variance of additive energy = ", 400],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690307563931*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"96973102-c732-42af-a279-e3dc2a675b72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"variance of epistatic energy = \"\>", "\[InvisibleSpace]", 
   "0.01`"}],
  SequenceForm["variance of epistatic energy = ", 0.01],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690307571519*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"4b9d1662-9376-4552-a951-40897ec033b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"fraction of total variance due to additive energy = \"\>", 
   "\[InvisibleSpace]", "0.9999750006249845`"}],
  SequenceForm[
  "fraction of total variance due to additive energy = ", 0.9999750006249845],
  
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690307579121*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"46feecf3-9fd0-4dc4-abf0-0e794608e8a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"cutoff standard deviations from mean = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "19.999750004687407`"}]}],
  SequenceForm[
  "cutoff standard deviations from mean = ", -19.999750004687407`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690307586728*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"5d5b703c-cff5-4f2f-a604-ff072c7f26bc"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690307594186*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"80e8dce6-357b-40ab-97fb-db88c44b7b20"],

Cell[BoxData["\<\"Drawing \[Beta]s...\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.74169031476931*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"3f57ae6b-5b0b-49e8-88ba-36df05cf702a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.013051`", ",", "Null"}], "}"}]], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690314890431*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"588d0442-26fc-46ca-a17c-f5fb92158718"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690314903955*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"661e2f3e-9a9b-4f50-9252-903c4f7ff446"],

Cell[BoxData["\<\"Hash table created for HOC energies.\"\>"], "Print",
 CellChangeTimes->{
  3.735382673627714*^9, 3.735388062426894*^9, 3.735391357519676*^9, 
   3.7353926872382717`*^9, 3.735394165256373*^9, 3.735394537633944*^9, 
   3.735395420081561*^9, 3.735395745518631*^9, 3.735407288597036*^9, 
   3.735408086207677*^9, 3.735412436637061*^9, 3.735412616390746*^9, 
   3.73542592505088*^9, 3.7359979954491987`*^9, 3.7360025938620577`*^9, 
   3.736002695340371*^9, 3.736004585957478*^9, 3.736066769764813*^9, 
   3.736067174095707*^9, {3.736067254507588*^9, 3.736067280541039*^9}, 
   3.736067348304616*^9, 3.73606750640825*^9, 3.7360677319890623`*^9, 
   3.7360680938294897`*^9, 3.736068138428609*^9, 3.736068383348001*^9, 
   3.7360684455802803`*^9, 3.736068772093019*^9, 3.736069117133256*^9, {
   3.736069391284852*^9, 3.7360694018299437`*^9}, 3.736069901912217*^9, 
   3.7360701305218973`*^9, 3.7360704862388487`*^9, {3.7361155388860817`*^9, 
   3.736115561005211*^9}, 3.736116116694306*^9, 3.736169538494328*^9, 
   3.736248013246139*^9, 3.736248075079945*^9, 3.736271174604198*^9, 
   3.73627177798464*^9, 3.73629285309208*^9, 3.736293344640085*^9, 
   3.736294028844275*^9, 3.73629411603975*^9, 3.736294983006432*^9, 
   3.736295903911272*^9, 3.736332466421068*^9, 3.7363325061937647`*^9, 
   3.736336304142641*^9, 3.7363365030203943`*^9, 3.736336664149179*^9, 
   3.736336807310649*^9, {3.7363369982168407`*^9, 3.736337021752255*^9}, 
   3.7363529643505983`*^9, 3.7363710320953493`*^9, 3.736371706415319*^9, 
   3.7364477527321053`*^9, {3.736459124437028*^9, 3.736459146366469*^9}, 
   3.736460305035853*^9, 3.736592091132419*^9, 3.736601587944685*^9, 
   3.7366044875057287`*^9, 3.736610197384069*^9, 3.7366244652026043`*^9, 
   3.7366301528337727`*^9, 3.736638509117774*^9, 3.736723975209051*^9, 
   3.736765521725832*^9, {3.736765742911249*^9, 3.7367657683152018`*^9}, 
   3.73676652397526*^9, 3.7367754481625834`*^9, 3.7408403701449833`*^9, 
   3.74091564434728*^9, 3.74096192063566*^9, 3.74099873674581*^9, 
   3.7409987726976624`*^9, 3.7410022705011883`*^9, 3.741435555227132*^9, 
   3.74152242657587*^9, 3.741523209316416*^9, 3.7415256512195473`*^9, 
   3.741526370891633*^9, 3.741526686203367*^9, 3.741527218484498*^9, 
   3.741527545938191*^9, 3.741527906749505*^9, 3.741529330561963*^9, 
   3.741529657016601*^9, 3.741688675988955*^9, 3.741690315873898*^9},
 CellLabel->
  "During evaluation of \
In[284]:=",ExpressionUUID->"7f933427-18de-4257-99a7-bc0294d57e72"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate random walk", "Subsubsection",
 CellChangeTimes->{
  3.736776260513404*^9},ExpressionUUID->"057ce5e3-8bfe-4f3e-a748-\
7618486898d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"GENERATE", " ", "RANDOM", " ", "WALK"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SeedRandom", "[", "1234567", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numIter", "=", "1000000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Generating random walk...\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"walk", "=", 
         RowBox[{"RandomWalkBasedOnTotalEnergyHocFast", "[", 
          RowBox[{
          "wt", ",", "energyCutoff", ",", "numIter", ",", "l", ",", "alpha", 
           ",", "\[Beta]", ",", 
           SqrtBox["variancehoc"]}], "]"}]}], ";"}], ")"}], "//", 
      "AbsoluteTiming"}], "//", "Print"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "PLOT", " ", "ADDITIVE", " ", "ENERGY", " ", "VS", " ", "TOTAL", " ", 
     "ENERGY"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPointsToPlot", "=", "numIter"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p11", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "1000"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "1000"}], "]"}], "]"}]}], "}"}], "]"}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "energyCutoff", "}"}], ",", 
          RowBox[{"{", "energyCutoff", "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p12", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p11", ",", "p12", ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<E1\>\"", ",", " ", "\"\<E1+E2\>\""}], "}"}]}]}], "]"}]}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPointsToPlot", "=", 
     RowBox[{"numIter", "-", "10000"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p11", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "1000"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], 
            "]"}], "[", 
           RowBox[{"[", 
            RowBox[{";;", " ", ";;", "1000"}], "]"}], "]"}]}], "}"}], "]"}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"All", ",", "All"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "energyCutoff", "}"}], ",", 
          RowBox[{"{", "energyCutoff", "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p12", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p11", ",", "p12", ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<E1\>\"", ",", " ", "\"\<E1+E2\>\""}], "}"}]}]}], "]"}]}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.735338806149899*^9, 3.7353388968251534`*^9}, {
   3.735343562061551*^9, 3.735343562627553*^9}, {3.735343655162856*^9, 
   3.735343674790699*^9}, {3.7353456811309853`*^9, 3.735345681686078*^9}, {
   3.735382815428287*^9, 3.7353828162481003`*^9}, {3.735391784672995*^9, 
   3.735391797154351*^9}, {3.7353923070597143`*^9, 3.735392309692967*^9}, 
   3.735392417811624*^9, {3.735393101396289*^9, 3.735393102816099*^9}, 
   3.73539317818019*^9, {3.735395876694244*^9, 3.7353958770963287`*^9}, {
   3.7354061288171186`*^9, 3.7354061680853367`*^9}, {3.735408238071582*^9, 
   3.735408238199889*^9}, {3.735408568548231*^9, 3.7354085693554564`*^9}, {
   3.73540863029198*^9, 3.735408630836402*^9}, {3.7354087693724613`*^9, 
   3.735408769950099*^9}, {3.7354105737408657`*^9, 3.735410573968326*^9}, {
   3.735410631836471*^9, 3.7354106825868683`*^9}, {3.735425389476039*^9, 
   3.735425391975503*^9}, {3.735998225295422*^9, 3.735998258412681*^9}, {
   3.735998291281876*^9, 3.735998326668337*^9}, {3.736068339608787*^9, 
   3.7360683406522827`*^9}, {3.736069609384886*^9, 3.736069609807073*^9}, {
   3.736069992908252*^9, 3.736069993293927*^9}, {3.7361695823174477`*^9, 
   3.7361695869059896`*^9}, {3.736332563327745*^9, 3.736332584424817*^9}, {
   3.736336438223412*^9, 3.736336466362225*^9}, {3.736370829563974*^9, 
   3.736370839283512*^9}, {3.736371154952077*^9, 3.736371156765463*^9}, {
   3.736371724958716*^9, 3.736371757887183*^9}, 3.736372713072393*^9, {
   3.736372756505062*^9, 3.736372770391078*^9}, 3.73644827644027*^9, {
   3.736459177382196*^9, 3.736459189733861*^9}, {3.736630431494936*^9, 
   3.736630434416581*^9}, {3.736630789336096*^9, 3.736630791236909*^9}, {
   3.73672400399959*^9, 3.736724007787999*^9}, {3.740959892400402*^9, 
   3.740959896089673*^9}, 3.741527213039342*^9, 3.74152747804601*^9},
 CellLabel->
  "In[315]:=",ExpressionUUID->"7c8db446-9298-4ab6-9ac1-468238bd6af8"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Generating random walk...\"\>"], "Print",
 CellChangeTimes->{3.736459190347023*^9, 3.736460339598674*^9, 
  3.7365921251145363`*^9, 3.736601616564351*^9, 3.736604543169541*^9, 
  3.7366244943524923`*^9, 3.736630162080859*^9, 3.7366304860556297`*^9, 
  3.7366307936847763`*^9, 3.736638517100883*^9, 3.7367240155811367`*^9, 
  3.736765540677375*^9, 3.736766614241338*^9, 3.736775490638187*^9, 
  3.740840378802609*^9, 3.740915685693144*^9, 3.740961971031702*^9, 
  3.7409987454746103`*^9, 3.740998791774345*^9, 3.7410023020123577`*^9, 
  3.7414355759005003`*^9, 3.741522480163137*^9, 3.7415232188482037`*^9, 
  3.741525662812602*^9, 3.7415263807681828`*^9, 3.741526695533071*^9, 
  3.74152722817258*^9, 3.7415296650600433`*^9, 3.74168868443331*^9, 
  3.741690316011197*^9},
 CellLabel->
  "During evaluation of \
In[315]:=",ExpressionUUID->"1d07de75-2f87-40b2-851e-819f0181a8b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"185.467653`", ",", "Null"}], "}"}]], "Print",
 CellChangeTimes->{3.736459190347023*^9, 3.736460339598674*^9, 
  3.7365921251145363`*^9, 3.736601616564351*^9, 3.736604543169541*^9, 
  3.7366244943524923`*^9, 3.736630162080859*^9, 3.7366304860556297`*^9, 
  3.7366307936847763`*^9, 3.736638517100883*^9, 3.7367240155811367`*^9, 
  3.736765540677375*^9, 3.736766614241338*^9, 3.736775490638187*^9, 
  3.740840378802609*^9, 3.740915685693144*^9, 3.740961971031702*^9, 
  3.7409987454746103`*^9, 3.740998791774345*^9, 3.7410023020123577`*^9, 
  3.7414355759005003`*^9, 3.741522480163137*^9, 3.7415232188482037`*^9, 
  3.741525662812602*^9, 3.7415263807681828`*^9, 3.741526695533071*^9, 
  3.74152722817258*^9, 3.7415296650600433`*^9, 3.74168868443331*^9, 
  3.741690501467268*^9},
 CellLabel->
  "During evaluation of \
In[315]:=",ExpressionUUID->"9d30e56a-c86c-4ddc-9f17-d0b05a6bc9ab"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.736459190347023*^9, 3.736460339598674*^9, 
  3.7365921251145363`*^9, 3.736601616564351*^9, 3.736604543169541*^9, 
  3.7366244943524923`*^9, 3.736630162080859*^9, 3.7366304860556297`*^9, 
  3.7366307936847763`*^9, 3.736638517100883*^9, 3.7367240155811367`*^9, 
  3.736765540677375*^9, 3.736766614241338*^9, 3.736775490638187*^9, 
  3.740840378802609*^9, 3.740915685693144*^9, 3.740961971031702*^9, 
  3.7409987454746103`*^9, 3.740998791774345*^9, 3.7410023020123577`*^9, 
  3.7414355759005003`*^9, 3.741522480163137*^9, 3.7415232188482037`*^9, 
  3.741525662812602*^9, 3.7415263807681828`*^9, 3.741526695533071*^9, 
  3.74152722817258*^9, 3.7415296650600433`*^9, 3.74168868443331*^9, 
  3.7416905014790087`*^9},
 CellLabel->
  "During evaluation of \
In[315]:=",ExpressionUUID->"e3e9c2e3-78be-4187-8eda-fe1f04b63472"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.0055000000000000005`], AbsoluteThickness[1.6],
       PointBox[CompressedData["
1:eJwdW3c8l18bJptU9ogyQ6mEflFKRkRmdoSWsiPhayQadsksZJSVEVF2fFOU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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF1P8z03EcwPGF2Pl2p5Q4s2bcum4XndQuGnMrjjZactHhVqGcIju2G0vY
Zth8nCuluVFOKeawHeXK9YM6lS8p6tK6fal1mFUsX3buUt3l9f7heY//4Ek6
m8/JcsDhcKy//VPzuGl+Iwp7tmkjydbtE4EUVh/nhRxExqRurGdQkW/WznsM
7UJaD4WGli7WgZT+F0Vrd5HKPhtucSvygwLL4PfKwWbS8ksFrxbcN3mn0xBR
A+44Vz81MicDJeo4N0Z3FRg/E1PNPi0FdYFi0S28BFwlY2WFE5VgtotuxFhS
AWa0LRGN9HIw6EyS1R9/DRTN6x11l0TgMNYXp1oTglo73r+WLQDpSuunnz1F
4Iw6a6A4mgcSJVwSRVkALtw2sn4czQOtWpdisyUbJNHj+WMPueASJyfTUpUK
YoIG79ExFnj9/heFeC4MTNsjZOK2hEVv+vE9y+dyMxsskRlvqimpYGG183Lk
PBep32D2UnJA9sm36WbXPHBBNU41dRaAxLbd2P5gHvgo/6sTvqEI7OAHLWjC
BKDUc3IgqkMIDhrsv1pPiEAdA9tpGisDNeGvg6cDykHyrLudfKUCdDWJh0xd
lWCzfTDS3VECcpcfMO0cKaiiTdBT5FWgtKlvkWCQgWbGaOMpQg3IH1c9T0qu
BbWCEHV/uxy8kLsilRsUYPuqONn1G9Ik3h4osyDTW0KfVq4gOVO5NqF7HRhB
12depCE9t43QjtUjE1pSnIdvIGVU8zuGEukQ65B/5B5ytSSy/cATpMHc40We
RRJ4UfpWKzINN94VYENO+1li/X4jXyUGX/XyxkCXz5oEzBfJzI3x9SAih8SZ
Wvxe5LrX93JpCJLWUproFI4sproRKg4j/38L/APA3mgJ
        "]]},
      Annotation[#, "Charting`Private`Tag$24591144#1"]& ]}, {}, {}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{
    FormBox["\"E1\"", TraditionalForm], 
    FormBox["\"E1+E2\"", TraditionalForm]},
  AxesOrigin->{-394.28518345046535`, -382.475987174019},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{-400}, {-400}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-750.5565092787385, -399.76628077090027`}, \
{-750.5025665807136, -400.00106238386155`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.736630677730234*^9, 3.736630986832107*^9, 
  3.7366387003700323`*^9, 3.736724199069169*^9, 3.736765730998663*^9, 
  3.7367668031345453`*^9, 3.736775682876808*^9, 3.7408407931987333`*^9, 
  3.740915883357717*^9, 3.740962184263089*^9, 3.740998747018326*^9, 
  3.74099899361908*^9, 3.741002526690631*^9, 3.741435763066152*^9, 
  3.741522682275696*^9, 3.741523412733993*^9, 3.741525856873981*^9, 
  3.741526574468322*^9, 3.7415268867360573`*^9, 3.741527426144527*^9, 
  3.741529858973494*^9, 3.741688985964484*^9, 3.74169050163876*^9},
 CellLabel->
  "Out[323]=",ExpressionUUID->"05d76dbc-46e6-4e81-bda0-e2448cc8bca8"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.0055000000000000005`], AbsoluteThickness[1.6],
       PointBox[CompressedData["
1:eJwdW3c8l18bJptU9ojsUCqhH4pkZGVmp9BSdiR8jUTDLpmFUFkZEWUlvinK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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF1P8z03EcwPGF2Pl2p5Q4s2bcum4XndQuGnMrjjZactHhVqGcIju2G0vY
Zth8nCuluVFOKeawHeXK9YM6lS8p6tK6fal1mFUsX3buUt3l9f7heY//4Ek6
m8/JcsDhcKy//VPzuGl+Iwp7tmkjydbtE4EUVh/nhRxExqRurGdQkW/WznsM
7UJaD4WGli7WgZT+F0Vrd5HKPhtucSvygwLL4PfKwWbS8ksFrxbcN3mn0xBR
A+44Vz81MicDJeo4N0Z3FRg/E1PNPi0FdYFi0S28BFwlY2WFE5VgtotuxFhS
AWa0LRGN9HIw6EyS1R9/DRTN6x11l0TgMNYXp1oTglo73r+WLQDpSuunnz1F
4Iw6a6A4mgcSJVwSRVkALtw2sn4czQOtWpdisyUbJNHj+WMPueASJyfTUpUK
YoIG79ExFnj9/heFeC4MTNsjZOK2hEVv+vE9y+dyMxsskRlvqimpYGG183Lk
PBep32D2UnJA9sm36WbXPHBBNU41dRaAxLbd2P5gHvgo/6sTvqEI7OAHLWjC
BKDUc3IgqkMIDhrsv1pPiEAdA9tpGisDNeGvg6cDykHyrLudfKUCdDWJh0xd
lWCzfTDS3VECcpcfMO0cKaiiTdBT5FWgtKlvkWCQgWbGaOMpQg3IH1c9T0qu
BbWCEHV/uxy8kLsilRsUYPuqONn1G9Ik3h4osyDTW0KfVq4gOVO5NqF7HRhB
12depCE9t43QjtUjE1pSnIdvIGVU8zuGEukQ65B/5B5ytSSy/cATpMHc40We
RRJ4UfpWKzINN94VYENO+1li/X4jXyUGX/XyxkCXz5oEzBfJzI3x9SAih8SZ
Wvxe5LrX93JpCJLWUproFI4sproRKg4j/38L/APA3mgJ
        "]]},
      Annotation[#, "Charting`Private`Tag$24591229#1"]& ]}, {}, {}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{
    FormBox["\"E1\"", TraditionalForm], 
    FormBox["\"E1+E2\"", TraditionalForm]},
  AxesOrigin->{-399.6742618178276, -399.72072380300796`},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{-400}, {-400}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-405.6554937675537, -399.76628077090027`}, \
{-405.60783400093464`, -400.00106238386155`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.736630677730234*^9, 3.736630986832107*^9, 
  3.7366387003700323`*^9, 3.736724199069169*^9, 3.736765730998663*^9, 
  3.7367668031345453`*^9, 3.736775682876808*^9, 3.7408407931987333`*^9, 
  3.740915883357717*^9, 3.740962184263089*^9, 3.740998747018326*^9, 
  3.74099899361908*^9, 3.741002526690631*^9, 3.741435763066152*^9, 
  3.741522682275696*^9, 3.741523412733993*^9, 3.741525856873981*^9, 
  3.741526574468322*^9, 3.7415268867360573`*^9, 3.741527426144527*^9, 
  3.741529858973494*^9, 3.741688985964484*^9, 3.7416905018018093`*^9},
 CellLabel->
  "Out[327]=",ExpressionUUID->"f9bb1f34-ae85-4e51-81da-51fe456a9fb2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bivariate normal approximation - analytically", "Subsubsection",
 CellChangeTimes->{
  3.736776268057625*^9},ExpressionUUID->"486077ce-8a6d-4a30-93e7-\
f4f179fbbc70"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "FIT", " ", "BIVARIATE", " ", "NORMAL", " ", "DISTRIBUTION", " ", "TO", 
    " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ADDITIVE", " ", "ENERGY"}], ",", " ", 
      RowBox[{"EPISTATIC", " ", "ENERGY"}]}], "}"}], " ", "OF", " ", "A", " ",
     "RANDOMLY", " ", "DRAWN", " ", "SEQUENCE", " ", "USING", " ", 
    "ANALYTICAL", " ", "FORMULAS"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"varx", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"alpha", "-", "1"}], ")"}], "/", "alpha"}], " ", "l", " ", 
       "variance1"}], "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vary", "=", 
     RowBox[{"variancehoc", "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<parameters of analitically fitted bivariate normal distribution =\>\
\"", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"meanVec", ",", "covMatrix"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"varx", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "vary"}], "}"}]}], "}"}]}], "}"}]}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vec", "=", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"unnormalizedCutGauss", "=", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"vec", "-", "meanVec"}], ")"}], ".", 
         RowBox[{"Inverse", "[", "covMatrix", "]"}], ".", 
         RowBox[{"(", 
          RowBox[{"vec", "-", "meanVec"}], ")"}]}]}], "]"}], " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"energyCutoff", "-", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"norm", "=", 
     RowBox[{
      RowBox[{"1", "/", "unnormalizedCutGauss"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "\[Rule]", 
         RowBox[{"Mean", "[", 
          RowBox[{"walk", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1000"}], ";;"}], ",", "2"}], "]"}], "]"}], 
          "]"}]}], ",", 
        RowBox[{"y", "\[Rule]", 
         RowBox[{"Mean", "[", 
          RowBox[{"walk", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1000"}], ";;"}], ",", "3"}], "]"}], "]"}], 
          "]"}]}]}], "}"}]}]}], 
    RowBox[{"(*", 
     RowBox[{"/", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{"unnormalizedCutGauss", ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "\[Infinity]"}], ",", 
          RowBox[{"energyCutoff", "-", "y"}]}], "}"}]}], "]"}]}], "*)"}], 
    ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Normalization", " ", "takes", " ", "too", " ", "long", " ", "on", " ", 
      "my", " ", "computer", " ", "for", " ", "some", " ", "reason"}], ",", 
     " ", 
     RowBox[{
     "so", " ", "just", " ", "set", " ", "density", " ", "at", " ", 
      "expected", " ", "mean", " ", "to", " ", "1"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"cutGaussDensity", "=", 
    RowBox[{"norm", " ", "unnormalizedCutGauss"}]}]}]}]], "Input",
 CellChangeTimes->{{3.735999069430941*^9, 3.735999110642622*^9}, {
   3.7359992935867023`*^9, 3.735999359812723*^9}, {3.7359993943534193`*^9, 
   3.735999407532209*^9}, {3.735999694503731*^9, 3.7359998463581743`*^9}, {
   3.7360000972615557`*^9, 3.736000117131439*^9}, {3.736003771134399*^9, 
   3.7360037719094963`*^9}, {3.7360043952201443`*^9, 3.736004397590323*^9}, {
   3.7360045137607727`*^9, 3.736004514163857*^9}, {3.736115720712201*^9, 
   3.7361157468623037`*^9}, {3.736248160711125*^9, 3.736248180838785*^9}, {
   3.736248834152248*^9, 3.73624886123881*^9}, {3.736248957835306*^9, 
   3.736249074599868*^9}, {3.736332660394045*^9, 3.73633266219065*^9}, {
   3.7363328518437843`*^9, 3.736332862848887*^9}, 3.740963426196772*^9, 
   3.7409636422255917`*^9},
 CellLabel->
  "In[329]:=",ExpressionUUID->"ccd2c39f-8109-491b-b426-e7ff0e841ea5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"parameters of analitically fitted bivariate normal \
distribution =\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"400.`", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.01`"}], "}"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "parameters of analitically fitted bivariate normal distribution =", {{0, 
    0}, {{400., 0}, {0, 0.01}}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7360001180711193`*^9, {3.736003748626285*^9, 3.7360037729071417`*^9}, 
   3.736067638386717*^9, 3.736115873577963*^9, 3.736178856999033*^9, 
   3.736248738122796*^9, 3.736248862242145*^9, {3.736248961029578*^9, 
   3.736248975134996*^9}, {3.7362490647743607`*^9, 3.736249075133238*^9}, 
   3.736250166017733*^9, 3.736251404095696*^9, 3.736253134325486*^9, 
   3.7362713075673122`*^9, 3.736272028861128*^9, 3.736293545943941*^9, 
   3.736294327538059*^9, 3.736295194014512*^9, 3.736296121723184*^9, 
   3.736332669825014*^9, 3.736336528824416*^9, 3.736336689334441*^9, 
   3.736337042172803*^9, 3.73637195938169*^9, 3.7364482442651587`*^9, 
   3.73653077751016*^9, 3.736601816955759*^9, 3.736604772027679*^9, 
   3.736624685862444*^9, 3.736630350583447*^9, 3.73663106048597*^9, 
   3.73663870170033*^9, 3.736724206050103*^9, 3.736766901825276*^9, 
   3.7367756834843273`*^9, 3.740840793963237*^9, 3.7409158841593657`*^9, 
   3.7409621852259417`*^9, 3.740999500356763*^9, 3.741002527579981*^9, 
   3.741435763687078*^9, 3.741523413576189*^9, 3.741525857653194*^9, 
   3.741526575329918*^9, 3.7415268874618387`*^9, 3.741527427044984*^9, 
   3.741529860800622*^9, 3.7416889864605083`*^9, 3.741690502210403*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"2b551754-093f-467d-8d2e-1a8830a3e403"],

Cell[BoxData[
 RowBox[{"1.6029455586074588`*^87", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.0025`", " ", "x"}]}], ")"}]}], " ", "x"}], "-", 
      RowBox[{"y", " ", 
       RowBox[{"(", 
        RowBox[{"0.`", "\[VeryThinSpace]", "+", 
         RowBox[{"100.`", " ", "y"}]}], ")"}]}]}], ")"}]}]], " ", 
  RowBox[{"UnitStep", "[", 
   RowBox[{
    RowBox[{"-", "400"}], "-", "x", "-", "y"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.735999792820609*^9, 3.735999847607314*^9}, 
   3.73600011808501*^9, {3.736003749202795*^9, 3.7360037730798264`*^9}, 
   3.736067639513176*^9, 3.7361158747099457`*^9, 3.736178857012473*^9, 
   3.7362487381369753`*^9, 3.736248862251943*^9, {3.736248961040125*^9, 
   3.736248975144142*^9}, {3.7362490648838053`*^9, 3.736249075145441*^9}, 
   3.736250166027701*^9, 3.7362514041036654`*^9, 3.7362531343338623`*^9, 
   3.736271307580934*^9, 3.736272028868565*^9, 3.736293545960244*^9, 
   3.736294327545326*^9, 3.736295194022214*^9, 3.7362961217306843`*^9, 
   3.736332669836027*^9, 3.736336528836916*^9, 3.7363366893454514`*^9, 
   3.736337042181262*^9, 3.736371960569446*^9, 3.736448244277129*^9, 
   3.736530777521943*^9, 3.736601816969617*^9, 3.736604772039093*^9, 
   3.736624685874487*^9, 3.736630350605597*^9, 3.7366310604987183`*^9, 
   3.7366387017119226`*^9, 3.736724206338037*^9, 3.7367669018380737`*^9, 
   3.736775683497437*^9, 3.740840793973468*^9, 3.740915884170429*^9, 
   3.740962185237623*^9, 3.740999500371174*^9, 3.74100252759475*^9, 
   3.741435763701407*^9, 3.741523413592292*^9, 3.741525857664177*^9, 
   3.7415265753429413`*^9, 3.741526887474225*^9, 3.741527427058875*^9, 
   3.741529860812421*^9, 3.741688986470766*^9, 3.741690502222311*^9},
 CellLabel->
  "Out[335]=",ExpressionUUID->"b7016425-2040-4135-8e99-616226fa064f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "PLOTS", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"numPointsToPlot", "=", 
     RowBox[{"numIter", "-", "10000"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"walk", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "2"}], "]"}], "]"}],
        "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ";;", "1000"}], "]"}], "]"}], "-", 
      "energyCutoff"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"walk", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], "]"}],
        "[", 
       RowBox[{"[", 
        RowBox[{";;", " ", ";;", "1000"}], "]"}], "]"}], "-", 
      "energyCutoff"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"E1", ",", "E2"}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"plot", " ", "diagonal"}], ",", " ", "vertical", ",", " ", 
     RowBox[{"and", " ", "horizontal", " ", "lines"}], ",", " ", 
     RowBox[{"set", " ", "axes", " ", "settings"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p21", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"GrayLevel", "[", "0.05", "]"}], "]"}]}], "}"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"GrayLevel", "[", "0.05", "]"}], "]"}]}], "}"}], 
           "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<\!\(\*SubscriptBox[\(\[CapitalDelta]G\), \(add\)]\) \
(kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\[CapitalDelta]G (kcal/mol)\>\"", ",", "fontSize"}], 
           "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRangePadding", "\[Rule]", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"plot", " ", "data", " ", "from", " ", "random", " ", "walk"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "plot", " ", "level", " ", "curve", " ", "corresponding", " ", "to", " ", 
     "the", " ", "bivariate", " ", "normal", " ", "distribution", " ", 
     "having", " ", "95", "%", " ", "of", " ", "the", " ", "total", " ", 
     "mass", " ", "within", " ", "the", " ", "curve"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p23", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", "vary", "]"}]}], " ", 
            RowBox[{"Sqrt", "[", " ", 
             RowBox[{
              RowBox[{"rr", "^", "2"}], "-", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", "varx"}]}], "]"}]}], "+", 
           "xpx"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "vary", "]"}], " ", 
            RowBox[{"Sqrt", "[", " ", 
             RowBox[{
              RowBox[{"rr", "^", "2"}], "-", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", "varx"}]}], "]"}]}], "+", 
           "xpx"}]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"rr", "\[Rule]", "20.194000000000003`"}], ",", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{"xpx", "+", "energyCutoff"}]}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"xpx", ",", 
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", " ", "Dashed", ",", "Thick"}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "40"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "15"}], ",", "0"}], "}"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"p2", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p21", ",", "p22", ",", "p23"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<means = (\>\"", ",", " ", 
      RowBox[{"Mean", "[", "E1", "]"}], ",", "\"\<, \>\"", ",", 
      RowBox[{"Mean", "[", "E2", "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", " ", 
      RowBox[{"r", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.735412831357107*^9, 3.735412849615079*^9}, {
   3.7354129249880667`*^9, 3.7354129253447247`*^9}, {3.735424538250537*^9, 
   3.735424539213098*^9}, {3.735424677387294*^9, 3.735424679032227*^9}, {
   3.7354247136188917`*^9, 3.7354247796832542`*^9}, {3.735424843973234*^9, 
   3.735424880271336*^9}, {3.735424911893446*^9, 3.73542491317771*^9}, {
   3.735424954078555*^9, 3.7354251707473297`*^9}, {3.7354252352486153`*^9, 
   3.73542524561959*^9}, {3.7354252801285667`*^9, 3.73542534191889*^9}, {
   3.735429020804513*^9, 3.735429032650975*^9}, {3.73542931545623*^9, 
   3.73542933399789*^9}, {3.736003847234289*^9, 3.736003878886956*^9}, {
   3.736003970981271*^9, 3.736003990128168*^9}, {3.736004032474021*^9, 
   3.73600403687866*^9}, {3.73600408056672*^9, 3.7360040862720003`*^9}, {
   3.736178883372156*^9, 3.7361788840891657`*^9}, {3.736250222036336*^9, 
   3.736250305459711*^9}, {3.736250582403352*^9, 3.736250616294293*^9}, {
   3.736258599319038*^9, 3.736258626946412*^9}, {3.736258658861917*^9, 
   3.73625870507393*^9}, {3.73625880363244*^9, 3.73625881059883*^9}, {
   3.736294602600832*^9, 3.736294622644697*^9}, {3.736294673013468*^9, 
   3.736294715458859*^9}, {3.736295525104875*^9, 3.736295530101733*^9}, {
   3.736336548732193*^9, 3.736336560966937*^9}, {3.736363364838408*^9, 
   3.7363633689711*^9}, {3.736372039958021*^9, 3.736372048802713*^9}, {
   3.736372995624157*^9, 3.7363729994990177`*^9}, {3.736530638068324*^9, 
   3.736530639132617*^9}, 3.7365307583134604`*^9, {3.736530824999298*^9, 
   3.73653084742519*^9}, {3.736530877794409*^9, 3.736530878323539*^9}, {
   3.736600839627861*^9, 3.7366008789489613`*^9}, {3.736600924999946*^9, 
   3.736600956370164*^9}, {3.7366044644939404`*^9, 3.736604469294973*^9}, {
   3.736604517840789*^9, 3.736604521628819*^9}, {3.736624237349208*^9, 
   3.7366242510284986`*^9}, {3.736630136623637*^9, 3.736630144637703*^9}, {
   3.736631574807796*^9, 3.736631576635056*^9}, {3.736631612826285*^9, 
   3.7366316143947773`*^9}, {3.736632147406299*^9, 3.736632189812558*^9}, {
   3.736632265162531*^9, 3.736632303809518*^9}, {3.7366323500012093`*^9, 
   3.736632365716881*^9}, {3.736636400146103*^9, 3.7366364038001213`*^9}, {
   3.7366381178917828`*^9, 3.736638118323741*^9}, {3.736638619529559*^9, 
   3.73663863400708*^9}, {3.736724031646699*^9, 3.736724065938054*^9}, {
   3.736724221489995*^9, 3.7367242221627817`*^9}, {3.73672426846768*^9, 
   3.73672431934336*^9}, {3.736724351684999*^9, 3.736724353570837*^9}, {
   3.736724392310707*^9, 3.736724507128559*^9}, {3.7367245822921247`*^9, 
   3.736724606090119*^9}, {3.736724706658132*^9, 3.736724707091918*^9}, {
   3.7367247396840277`*^9, 3.736724799369845*^9}, {3.7367248520179577`*^9, 
   3.7367249042360497`*^9}, {3.7367249458664494`*^9, 3.736724947452544*^9}, {
   3.736724986312778*^9, 3.736725005296792*^9}, {3.736725179829853*^9, 
   3.736725216619564*^9}, {3.7367252550788517`*^9, 3.736725259051778*^9}, {
   3.73672531299715*^9, 3.7367254363361177`*^9}, {3.736765693459713*^9, 
   3.736765716379293*^9}, {3.736765809120586*^9, 3.736766070097254*^9}, {
   3.736766104202183*^9, 3.7367661239265833`*^9}, {3.736766154092596*^9, 
   3.736766413562147*^9}, {3.736766445217441*^9, 3.736766448920887*^9}, {
   3.736766858659515*^9, 3.736766880677058*^9}, {3.736768874854333*^9, 
   3.7367688773403473`*^9}, {3.736775428931566*^9, 3.7367754344536467`*^9}, {
   3.736775857977914*^9, 3.736775898109812*^9}, {3.736776079745289*^9, 
   3.736776080474386*^9}, {3.740840087765523*^9, 3.740840088785573*^9}, 
   3.740913764855566*^9, {3.740959915959641*^9, 3.740959931368165*^9}, 
   3.7409998367750607`*^9},
 CellLabel->
  "In[336]:=",ExpressionUUID->"368fb884-6ffb-47ef-8e3a-c6a373fa4d50"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[{{-15., -15.}, {5., 5.}}]},
      Annotation[#, "Charting`Private`Tag$24591276#1"]& ]}, {}, {}}, {{}, {{}, 
     {GrayLevel[0], PointSize[0.0055000000000000005`], AbsoluteThickness[1.6],
       PointBox[CompressedData["
1:eJwdW3k8Ft8XHkuyFQlJKgkhla9shUhZkj3JVpaQoixJKstUkkQJ2bNlDWXL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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], Thickness[Large], Opacity[1.], Dashing[{Small, Small}],
        LineBox[{{-3.8592920728393496`, -3.879741159875861}, \
{-3.4944537365989685`, -3.5826694103485397`}, {-2.886389842865, \
-3.027953545785544}, {-0.45413426792912404`, -0.716600491838193}, {
        0.27779954723859523`, 0.}}], 
       LineBox[{{-3.8592920728393496`, -3.838842985802838}, \
{-3.4944537365989685`, -3.4062380628493973`}, {-2.886389842865, \
-2.744826139944456}, {-0.45413426792912404`, -0.19166804402005505`}, \
{-0.2663990986997463, 0.}}]},
      Annotation[#, "Charting`Private`Tag$24591359#1"]& ]}, {}, {}}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox["\"\[CapitalDelta]G (kcal/mol)\"", 13, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]G\\), \\(add\\)]\\) \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
     Automatic, {{-15., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-13., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-11., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-9., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {24., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {26., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {28., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {32., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {34., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {36., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {38., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{{{0, 
      Directive[
       GrayLevel[0.05]]}}, {{0, 
      Directive[
       GrayLevel[0.05]]}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{843.5859375, Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-15, 40}, {-15, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7367661246199503`*^9, 3.7367661779038754`*^9, {3.736766383936762*^9, 
   3.736766414061975*^9}, 3.73676684964765*^9, {3.7367668834271708`*^9, 
   3.736766906531955*^9}, 3.7367673434351*^9, 3.736775683770876*^9, 
   3.736775899514619*^9, 3.7367760830574837`*^9, 3.7408407941249323`*^9, 
   3.740915884390341*^9, 3.740962185461529*^9, 3.7409998378848133`*^9, 
   3.741002527820054*^9, 3.741435763965157*^9, 3.741523413801653*^9, 
   3.7415258578604507`*^9, 3.741526575534564*^9, 3.74152688766669*^9, 
   3.7415274272591343`*^9, 3.741529861012466*^9, 3.741688986627864*^9, 
   3.741690502413178*^9},
 CellLabel->
  "Out[343]=",ExpressionUUID->"ef1d7e64-2cdd-4af4-8e7a-6903873f59ee"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"means = (\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.853342728168653`"}], "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.864892791670387`"}], "\[InvisibleSpace]", "\<\")\"\>"}],
  SequenceForm["means = (", -0.853342728168653, ", ", -0.864892791670387, ")"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.736766384051529*^9, 3.736766414164297*^9}, 
   3.7367668498181*^9, {3.736766883538101*^9, 3.736766906638865*^9}, 
   3.736767343544127*^9, 3.7367756838817*^9, 3.736775899624049*^9, 
   3.736776083162842*^9, 3.740840794138068*^9, 3.7409158844000187`*^9, 
   3.740962185472028*^9, 3.7409998379890947`*^9, 3.7410025278309526`*^9, 
   3.7414357639752083`*^9, 3.7415234138138857`*^9, 3.741525857872398*^9, 
   3.741526575641993*^9, 3.741526887773431*^9, 3.741527427367663*^9, 
   3.741529861026742*^9, 3.741688986638987*^9, 3.74169050242544*^9},
 CellLabel->
  "During evaluation of \
In[336]:=",ExpressionUUID->"622e2ead-502c-49e2-997f-02bd72dbc734"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", "0.9932118860295519`"}],
  SequenceForm["r = ", 0.9932118860295519],
  Editable->False]], "Print",
 CellChangeTimes->{{3.736766384051529*^9, 3.736766414164297*^9}, 
   3.7367668498181*^9, {3.736766883538101*^9, 3.736766906638865*^9}, 
   3.736767343544127*^9, 3.7367756838817*^9, 3.736775899624049*^9, 
   3.736776083162842*^9, 3.740840794138068*^9, 3.7409158844000187`*^9, 
   3.740962185472028*^9, 3.7409998379890947`*^9, 3.7410025278309526`*^9, 
   3.7414357639752083`*^9, 3.7415234138138857`*^9, 3.741525857872398*^9, 
   3.741526575641993*^9, 3.741526887773431*^9, 3.741527427367663*^9, 
   3.741529861026742*^9, 3.741688986638987*^9, 3.7416905024323397`*^9},
 CellLabel->
  "During evaluation of \
In[336]:=",ExpressionUUID->"153cac91-577f-4cb9-a5f4-b22c2eed26fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.9864698505503796`"}],
  SequenceForm["r^2 = ", 0.9864698505503796],
  Editable->False]], "Print",
 CellChangeTimes->{{3.736766384051529*^9, 3.736766414164297*^9}, 
   3.7367668498181*^9, {3.736766883538101*^9, 3.736766906638865*^9}, 
   3.736767343544127*^9, 3.7367756838817*^9, 3.736775899624049*^9, 
   3.736776083162842*^9, 3.740840794138068*^9, 3.7409158844000187`*^9, 
   3.740962185472028*^9, 3.7409998379890947`*^9, 3.7410025278309526`*^9, 
   3.7414357639752083`*^9, 3.7415234138138857`*^9, 3.741525857872398*^9, 
   3.741526575641993*^9, 3.741526887773431*^9, 3.741527427367663*^9, 
   3.741529861026742*^9, 3.741688986638987*^9, 3.74169050245354*^9},
 CellLabel->
  "During evaluation of \
In[336]:=",ExpressionUUID->"f1de19aa-fc10-4298-a736-d7f8b8ec7a82"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distribution of energies at stationarity", "Subsubsection",
 CellChangeTimes->{{3.7367762755326757`*^9, 
  3.736776282137519*^9}},ExpressionUUID->"918a7bbd-9b7a-4719-9dfb-\
6cc8a17ac546"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"numPointsToPlot", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"walk", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "numPointsToPlot"}], ";;"}], ",", "4"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"p3", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{
    RowBox[{"data", "-", "energyCutoff"}], ",", "50", ",", "\"\<PDF\>\"", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotRangeClipping", "\[Rule]", "True"}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\[CapitalDelta]G of folding (kcal/mol)\>\"", ",", "fontSize"}], 
        "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Probability density\>\"", ",", "fontSize"}], "]"}]}], 
      "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<mean = \>\"", ",", " ", 
    RowBox[{"data", "//", "Mean"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<std = \>\"", ",", " ", 
    RowBox[{"data", "//", "StandardDeviation"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NotebookSave", "[", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.735391937106286*^9, 3.735391944632491*^9}, {
   3.7353920061842947`*^9, 3.735392055768449*^9}, {3.735392108783545*^9, 
   3.7353921370371437`*^9}, {3.735392195288419*^9, 3.735392213868832*^9}, {
   3.7353924998610764`*^9, 3.735392500127347*^9}, {3.735392582469503*^9, 
   3.735392594878294*^9}, {3.735392640276363*^9, 3.735392653813802*^9}, {
   3.73542546739634*^9, 3.7354254719487133`*^9}, {3.735997773271573*^9, 
   3.7359978108729057`*^9}, {3.735998422293809*^9, 3.735998426499139*^9}, {
   3.735998583562201*^9, 3.735998583930787*^9}, {3.736068997207417*^9, 
   3.73606901598698*^9}, {3.736116103608083*^9, 3.736116103791065*^9}, {
   3.736116317646946*^9, 3.736116346830327*^9}, {3.736116457766818*^9, 
   3.736116477465858*^9}, {3.7361697813583384`*^9, 3.7361697900768147`*^9}, 
   3.736169993961195*^9, {3.736460194718577*^9, 3.736460203124095*^9}, {
   3.736531070585575*^9, 3.736531087493795*^9}, {3.7366010716761293`*^9, 
   3.7366010721489162`*^9}, {3.736766672716083*^9, 3.736766673152273*^9}, {
   3.736767038776095*^9, 3.736767039007186*^9}, {3.740959937395855*^9, 
   3.7409599533831787`*^9}, {3.7416905203690863`*^9, 3.7416905565452557`*^9}},
 
 CellLabel->
  "In[361]:=",ExpressionUUID->"aae17c63-0922-48be-9e1c-ef2bec3aea3b"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.85], EdgeForm[{Opacity[0.44099999999999995`], Thickness[
    Small]}], {}, 
    {GrayLevel[0.85], EdgeForm[{Opacity[0.44099999999999995`], Thickness[
     Small]}], RectangleBox[{-8.4, 0}, {-8.2, 0.0005},
      RoundingRadius->0], RectangleBox[{-8., 0}, {-7.8, 0.0005},
      RoundingRadius->0], RectangleBox[{-7.6, 0}, {-7.4, 0.0005},
      RoundingRadius->0], RectangleBox[{-7.2, 0}, {-7., 0.0005},
      RoundingRadius->0], RectangleBox[{-6.4, 0}, {-6.2, 0.0005},
      RoundingRadius->0], RectangleBox[{-6.2, 0}, {-6., 0.0005},
      RoundingRadius->0], RectangleBox[{-6., 0}, {-5.8, 0.002},
      RoundingRadius->0], RectangleBox[{-5.8, 0}, {-5.6, 0.001},
      RoundingRadius->0], RectangleBox[{-5.6, 0}, {-5.4, 0.001},
      RoundingRadius->0], RectangleBox[{-5.4, 0}, {-5.2, 0.002},
      RoundingRadius->0], RectangleBox[{-5.2, 0}, {-5., 0.003},
      RoundingRadius->0], RectangleBox[{-5., 0}, {-4.8, 0.0035},
      RoundingRadius->0], RectangleBox[{-4.8, 0}, {-4.6, 0.0025},
      RoundingRadius->0], RectangleBox[{-4.6, 0}, {-4.4, 0.0085},
      RoundingRadius->0], RectangleBox[{-4.4, 0}, {-4.2, 0.009},
      RoundingRadius->0], RectangleBox[{-4.2, 0}, {-4., 0.012},
      RoundingRadius->0], RectangleBox[{-4., 0}, {-3.8, 0.007},
      RoundingRadius->0], RectangleBox[{-3.8, 0}, {-3.6, 0.016},
      RoundingRadius->0], RectangleBox[{-3.6, 0}, {-3.4, 0.017},
      RoundingRadius->0], RectangleBox[{-3.4, 0}, {-3.2, 0.0255},
      RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3., 0.03},
      RoundingRadius->0], RectangleBox[{-3., 0}, {-2.8, 0.0495},
      RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.6, 0.0435},
      RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.4, 0.056},
      RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.2, 0.076},
      RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 0.101},
      RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 0.1265},
      RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.6, 0.1605},
      RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.4, 0.199},
      RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.2, 0.2575},
      RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 0.3365},
      RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 0.3655},
      RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.6, 0.544},
      RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.4, 0.673},
      RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.2, 0.8035},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 1.065},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-7.14, 0},
  Frame->True,
  FrameLabel->{{
     FormBox[
      StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\[CapitalDelta]G of folding (kcal/mol)\"", 13, StripOnInput -> 
       False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-7, 0}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.736460192038158*^9, 3.736460201105859*^9}, 
   3.736460973733778*^9, 3.736531088512539*^9, 3.7366018382102957`*^9, 
   3.736631143639599*^9, 3.736638703285396*^9, 3.736725034374984*^9, 
   3.7367669325050287`*^9, 3.7367671722875443`*^9, 3.736775684365645*^9, 
   3.740840794827136*^9, 3.740915884947184*^9, 3.740962186163924*^9, 
   3.741002528577828*^9, 3.741435764432932*^9, 3.741523414501111*^9, 
   3.7415258584480543`*^9, 3.741526576231221*^9, 3.741526888292626*^9, 
   3.741527427949133*^9, 3.7415298625593557`*^9, 3.741688986933506*^9, 
   3.741689035923542*^9, 3.741690502868495*^9, {3.74169054766673*^9, 
   3.741690557434513*^9}},
 CellLabel->
  "Out[363]=",ExpressionUUID->"7256d87b-0e23-4dc5-8536-b9863b6d1028"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "400.8485226105154`"}]}],
  SequenceForm["mean = ", -400.8485226105154],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736460973746792*^9, 3.736531088529861*^9, 3.736601838226886*^9, 
   3.736631143656567*^9, 3.736638703296166*^9, 3.7367250343899317`*^9, 
   3.7367669325229263`*^9, 3.736767172306184*^9, 3.736775684376595*^9, 
   3.740840794836751*^9, 3.740915884956778*^9, 3.74096218617562*^9, 
   3.741002528589567*^9, 3.741435764446104*^9, 3.741523414513425*^9, 
   3.7415258584598227`*^9, 3.7415265762498837`*^9, 3.741526888309938*^9, 
   3.741527427969051*^9, 3.7415298625707197`*^9, 3.741688986949441*^9, 
   3.74168903593878*^9, 3.741690502886413*^9, {3.7416905476755342`*^9, 
   3.741690557451577*^9}},
 CellLabel->
  "During evaluation of \
In[361]:=",ExpressionUUID->"b65af1d6-f550-412a-8528-304d09aa95d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"std = \"\>", "\[InvisibleSpace]", "0.8448906744313569`"}],
  SequenceForm["std = ", 0.8448906744313569],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736460973746792*^9, 3.736531088529861*^9, 3.736601838226886*^9, 
   3.736631143656567*^9, 3.736638703296166*^9, 3.7367250343899317`*^9, 
   3.7367669325229263`*^9, 3.736767172306184*^9, 3.736775684376595*^9, 
   3.740840794836751*^9, 3.740915884956778*^9, 3.74096218617562*^9, 
   3.741002528589567*^9, 3.741435764446104*^9, 3.741523414513425*^9, 
   3.7415258584598227`*^9, 3.7415265762498837`*^9, 3.741526888309938*^9, 
   3.741527427969051*^9, 3.7415298625707197`*^9, 3.741688986949441*^9, 
   3.74168903593878*^9, 3.741690502886413*^9, {3.7416905476755342`*^9, 
   3.741690557459715*^9}},
 CellLabel->
  "During evaluation of \
In[361]:=",ExpressionUUID->"37969ddf-e5d8-4f38-87f7-f9a1d109c739"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distribution of mutational effects of random mutations", "Subsubsection",
 CellChangeTimes->{3.736776589248293*^9, 
  3.740840017538163*^9},ExpressionUUID->"fa9959a4-e0bc-4bde-a7e4-\
d38fedfd6ae1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"numMutants", "=", "8000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutationalEffects", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"seq", "=", 
       RowBox[{"walk", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"-", "k"}], ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"mutant", "=", "seq"}], ";", "\[IndentingNewLine]", 
      RowBox[{"positionToMutate", "=", 
       RowBox[{"RandomChoice", "[", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"mutant", "[", 
        RowBox[{"[", "positionToMutate", "]"}], "]"}], "=", 
       RowBox[{"RandomChoice", "[", 
        RowBox[{"Complement", "[", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", 
            RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"mutant", "[", 
            RowBox[{"[", "positionToMutate", "]"}], "]"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutEffect", "=", 
       RowBox[{"getSingleMutationsEffectInTotalEnergyHoc", "[", 
        RowBox[{"seq", ",", "positionToMutate", ",", 
         RowBox[{"mutant", "[", 
          RowBox[{"[", "positionToMutate", "]"}], "]"}], ",", "l", ",", 
         "alpha", ",", "\[Beta]", ",", "variancehoc"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"mutationalEffects", ",", "mutEffect"}], "]"}], ";"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "numMutants"}], "}"}]}], "]"}], ",", "k"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"mutationalEffects", ";"}], "\[IndentingNewLine]", 
 RowBox[{"p4", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{"mutationalEffects", ",", "50", ",", "\"\<PDF\>\"", ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.35"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotRangeClipping", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\[CapitalDelta]\[CapitalDelta]G of random mutations (kcal/mol)\>\
\"", ",", "fontSize"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Probability density\>\"", ",", "fontSize"}], "]"}]}], 
      "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<mean = \>\"", ",", " ", 
    RowBox[{"mutationalEffects", "//", "Mean"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<std = \>\"", ",", " ", 
    RowBox[{"mutationalEffects", "//", "StandardDeviation"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NotebookSave", "[", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.735479510187269*^9, 3.7354796214564333`*^9}, {
   3.7354796739130898`*^9, 3.7354796807718973`*^9}, {3.7359978971653214`*^9, 
   3.735997897569105*^9}, {3.735998471104659*^9, 3.735998480606639*^9}, {
   3.7361164982476788`*^9, 3.736116534834334*^9}, {3.736169956860944*^9, 
   3.736169982233983*^9}, {3.736206458079257*^9, 3.736206532628809*^9}, {
   3.7362065717564707`*^9, 3.736206593402062*^9}, 3.736248306310055*^9, {
   3.736461612500551*^9, 3.7364616486815853`*^9}, {3.73646224050984*^9, 
   3.736462254027861*^9}, {3.736531154435362*^9, 3.736531168258157*^9}, {
   3.7365334004135027`*^9, 3.736533417725308*^9}, {3.736601187235157*^9, 
   3.7366011876477537`*^9}, {3.7367670477370358`*^9, 
   3.7367670482774687`*^9}, {3.7367671815551577`*^9, 3.736767222905118*^9}, {
   3.740840117383045*^9, 3.740840120014125*^9}, {3.740959964232353*^9, 
   3.740959977902742*^9}, {3.741526318048699*^9, 3.741526320113304*^9}, {
   3.741526853527122*^9, 3.741526861617858*^9}, {3.7415271985822487`*^9, 
   3.7415272012368793`*^9}, {3.74169058732997*^9, 3.7416905890669203`*^9}},
 CellLabel->
  "In[367]:=",ExpressionUUID->"746ee873-11d5-436d-8fd9-aa4484b7e949"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.85], EdgeForm[{Opacity[0.34299999999999997`], Thickness[
    Small]}], {}, 
    {GrayLevel[0.85], EdgeForm[{Opacity[0.34299999999999997`], Thickness[
     Small]}], RectangleBox[{-4.2, 0}, {-4., 0.001875},
      RoundingRadius->0], RectangleBox[{-3.8, 0}, {-3.6, 0.00125},
      RoundingRadius->0], RectangleBox[{-3.4, 0}, {-3.2, 0.0025},
      RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3., 0.004375},
      RoundingRadius->0], RectangleBox[{-3., 0}, {-2.8, 0.004375},
      RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.6, 0.005625},
      RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.4, 0.005},
      RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.2, 0.0125},
      RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 0.024375},
      RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 0.025625},
      RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.6, 0.0325},
      RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.4, 0.05875},
      RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.2, 0.058125},
      RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 0.09},
      RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 0.095625},
      RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.6, 0.12125},
      RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.4, 0.15625},
      RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.2, 0.189375},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 0.204375},
      RoundingRadius->0], RectangleBox[{0., 0}, {0.2, 0.23},
      RoundingRadius->0], RectangleBox[{0.2, 0}, {0.4, 0.248125},
      RoundingRadius->0], RectangleBox[{0.4, 0}, {0.6, 0.254375},
      RoundingRadius->0], RectangleBox[{0.6, 0}, {0.8, 0.295625},
      RoundingRadius->0], RectangleBox[{0.8, 0}, {1., 0.278125},
      RoundingRadius->0], RectangleBox[{1., 0}, {1.2, 0.29375},
      RoundingRadius->0], RectangleBox[{1.2, 0}, {1.4, 0.284375},
      RoundingRadius->0], RectangleBox[{1.4, 0}, {1.6, 0.27375},
      RoundingRadius->0], RectangleBox[{1.6, 0}, {1.8, 0.269375},
      RoundingRadius->0], RectangleBox[{1.8, 0}, {2., 0.251875},
      RoundingRadius->0], RectangleBox[{2., 0}, {2.2, 0.21},
      RoundingRadius->0], RectangleBox[{2.2, 0}, {2.4, 0.1875},
      RoundingRadius->0], RectangleBox[{2.4, 0}, {2.6, 0.183125},
      RoundingRadius->0], RectangleBox[{2.6, 0}, {2.8, 0.13875},
      RoundingRadius->0], RectangleBox[{2.8, 0}, {3., 0.12375},
      RoundingRadius->0], RectangleBox[{3., 0}, {3.2, 0.081875},
      RoundingRadius->0], RectangleBox[{3.2, 0}, {3.4, 0.07375},
      RoundingRadius->0], RectangleBox[{3.4, 0}, {3.6, 0.066875},
      RoundingRadius->0], RectangleBox[{3.6, 0}, {3.8, 0.053125},
      RoundingRadius->0], RectangleBox[{3.8, 0}, {4., 0.03875},
      RoundingRadius->0], RectangleBox[{4., 0}, {4.2, 0.0225},
      RoundingRadius->0], RectangleBox[{4.2, 0}, {4.4, 0.01625},
      RoundingRadius->0], RectangleBox[{4.4, 0}, {4.6, 0.01},
      RoundingRadius->0], RectangleBox[{4.6, 0}, {4.8, 0.008125},
      RoundingRadius->0], RectangleBox[{4.8, 0}, {5., 0.005},
      RoundingRadius->0], RectangleBox[{5., 0}, {5.2, 0.0025},
      RoundingRadius->0], RectangleBox[{5.2, 0}, {5.4, 0.001875},
      RoundingRadius->0], RectangleBox[{5.4, 0}, {5.6, 0.0025},
      RoundingRadius->0], RectangleBox[{5.6, 0}, {5.8, 0.000625},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-4.2, 0},
  Frame->True,
  FrameLabel->{{
     FormBox[
      StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\[CapitalDelta]\[CapitalDelta]G of random mutations (kcal/mol)\"", 
       13, StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-4, 6}, {0, 0.35}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.736461056993496*^9, {3.736461623858569*^9, 3.736461649430065*^9}, {
   3.736462245577273*^9, 3.736462254875915*^9}, 3.7365311700071573`*^9, 
   3.7365320996163263`*^9, {3.736533408141198*^9, 3.7365334189422197`*^9}, 
   3.73660184356636*^9, 3.736631148602063*^9, 3.736632223107752*^9, 
   3.736638703842271*^9, 3.7367250350857887`*^9, 3.736766937572439*^9, {
   3.736767176516827*^9, 3.736767224894981*^9}, 3.736775685672995*^9, 
   3.740840796512733*^9, 3.7409158861576014`*^9, 3.74096218756164*^9, 
   3.741002529981943*^9, 3.741435765596891*^9, 3.741523415918764*^9, 
   3.741525859713313*^9, 3.74152657758184*^9, 3.7415268895637627`*^9, 
   3.741527118865178*^9, 3.741527429313285*^9, 3.7415298642803373`*^9, 
   3.741690592097191*^9},
 CellLabel->
  "Out[371]=",ExpressionUUID->"05489153-66c3-43f1-ab04-a7ef2f36a554"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean = \"\>", "\[InvisibleSpace]", "1.06469525478853`"}],
  SequenceForm["mean = ", 1.06469525478853],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736461057127961*^9, {3.736461623874585*^9, 3.7364616494406157`*^9}, {
   3.736462245587379*^9, 3.736462254885808*^9}, 3.736531170016481*^9, 
   3.7365320996261797`*^9, {3.7365334081497583`*^9, 3.736533418950644*^9}, 
   3.7366018435769463`*^9, 3.736631148611883*^9, 3.73663222311744*^9, 
   3.736638703850716*^9, 3.736725035094385*^9, 3.73676693758222*^9, {
   3.736767176526325*^9, 3.736767224904071*^9}, 3.73677568568137*^9, 
   3.7408407965208282`*^9, 3.740915886164886*^9, 3.740962187569809*^9, 
   3.741002529990884*^9, 3.7414357656055593`*^9, 3.741523415927168*^9, 
   3.74152585972161*^9, 3.741526577597418*^9, 3.7415268895725403`*^9, 
   3.7415271188755617`*^9, 3.74152742932867*^9, 3.7415298642894382`*^9, 
   3.741690592108611*^9},
 CellLabel->
  "During evaluation of \
In[367]:=",ExpressionUUID->"f2ca1bde-516f-4f29-8a84-8632ad73219e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"std = \"\>", "\[InvisibleSpace]", "1.360709453785824`"}],
  SequenceForm["std = ", 1.360709453785824],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736461057127961*^9, {3.736461623874585*^9, 3.7364616494406157`*^9}, {
   3.736462245587379*^9, 3.736462254885808*^9}, 3.736531170016481*^9, 
   3.7365320996261797`*^9, {3.7365334081497583`*^9, 3.736533418950644*^9}, 
   3.7366018435769463`*^9, 3.736631148611883*^9, 3.73663222311744*^9, 
   3.736638703850716*^9, 3.736725035094385*^9, 3.73676693758222*^9, {
   3.736767176526325*^9, 3.736767224904071*^9}, 3.73677568568137*^9, 
   3.7408407965208282`*^9, 3.740915886164886*^9, 3.740962187569809*^9, 
   3.741002529990884*^9, 3.7414357656055593`*^9, 3.741523415927168*^9, 
   3.74152585972161*^9, 3.741526577597418*^9, 3.7415268895725403`*^9, 
   3.7415271188755617`*^9, 3.74152742932867*^9, 3.7415298642894382`*^9, 
   3.741690592118658*^9},
 CellLabel->
  "During evaluation of \
In[367]:=",ExpressionUUID->"eb0be401-3eb8-4a25-ad61-2518b8430fc4"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Distribution of mutational effects of fixed mutations (i.e. effect of \
mutations along the random walk)\
\>", "Subsubsection",
 CellChangeTimes->{
  3.736776311014843*^9},ExpressionUUID->"b0286870-1f31-48f3-8773-\
8bbb1b594987"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Differences", "[", 
   RowBox[{
    RowBox[{"Split", "[", 
     RowBox[{"walk", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"5000", ";;"}], ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"p8", " ", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{"%", ",", "50", ",", "\"\<PDF\>\"", ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotRangeClipping", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<\[CapitalDelta]\[CapitalDelta]G of fixed mutations \
(kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<Probability density\>\"", ",", "fontSize"}], "]"}]}], 
      "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<mean = \>\"", ",", 
   RowBox[{"Mean", "[", "%%", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<std = \>\"", ",", 
   RowBox[{"StandardDeviation", "[", "%%%", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NotebookSave", "[", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.736257690925364*^9, 3.736257741938539*^9}, {
   3.736257934159856*^9, 3.7362579345062513`*^9}, {3.73625797897139*^9, 
   3.73625800057959*^9}, {3.736258440634775*^9, 3.736258443480323*^9}, {
   3.7362707698107243`*^9, 3.7362708190894327`*^9}, {3.736463461052702*^9, 
   3.736463461588932*^9}, {3.736532015509863*^9, 3.736532037121187*^9}, {
   3.736533469329324*^9, 3.73653350299712*^9}, {3.7366015544652233`*^9, 
   3.736601555310087*^9}, 3.7366020980169888`*^9, {3.736767391907804*^9, 
   3.736767392354809*^9}, {3.740840128223916*^9, 3.7408401306087933`*^9}, {
   3.7409599851230593`*^9, 3.74096000351824*^9}, {3.741690600095037*^9, 
   3.741690600549347*^9}},
 CellLabel->
  "In[375]:=",ExpressionUUID->"3aaf67bc-8799-45cc-9696-2c1daafb91d8"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.85], EdgeForm[{Opacity[0.33599999999999997`], Thickness[
    Small]}], {}, 
    {GrayLevel[0.85], EdgeForm[{Opacity[0.33599999999999997`], Thickness[
     Small]}], RectangleBox[{-5.8, 0}, {-5.6, 0.000011447489222188897},
      RoundingRadius->0], 
     RectangleBox[{-5.4, 0}, {-5.2, 0.000022894978444377794},
      RoundingRadius->0], 
     RectangleBox[{-5.2, 0}, {-5., 0.000057237446110944485},
      RoundingRadius->0], 
     RectangleBox[{-5., 0}, {-4.8, 0.00010302740299970007},
      RoundingRadius->0], 
     RectangleBox[{-4.8, 0}, {-4.6, 0.00006868493533313338},
      RoundingRadius->0], 
     RectangleBox[{-4.6, 0}, {-4.4, 0.00019460731677721125},
      RoundingRadius->0], 
     RectangleBox[{-4.4, 0}, {-4.2, 0.0003090822089991002},
      RoundingRadius->0], 
     RectangleBox[{-4.2, 0}, {-4., 0.0006181644179982004},
      RoundingRadius->0], 
     RectangleBox[{-4., 0}, {-3.8, 0.0009844840731082452},
      RoundingRadius->0], 
     RectangleBox[{-3.8, 0}, {-3.6, 0.0016369909587730122},
      RoundingRadius->0], 
     RectangleBox[{-3.6, 0}, {-3.4, 0.0025298951181037463},
      RoundingRadius->0], 
     RectangleBox[{-3.4, 0}, {-3.2, 0.004132543609210192},
      RoundingRadius->0], 
     RectangleBox[{-3.2, 0}, {-3., 0.006628096259647371},
      RoundingRadius->0], RectangleBox[{-3., 0}, {-2.8, 0.01121853943774512},
      RoundingRadius->0], 
     RectangleBox[{-2.8, 0}, {-2.6, 0.016782019199728923},
      RoundingRadius->0], 
     RectangleBox[{-2.6, 0}, {-2.4, 0.024234334683373895},
      RoundingRadius->0], 
     RectangleBox[{-2.4, 0}, {-2.2, 0.031469147871797276},
      RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 0.04712931312775169},
      RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 0.06677320463302784},
      RoundingRadius->0], 
     RectangleBox[{-1.8, 0}, {-1.6, 0.08924462597618464},
      RoundingRadius->0], 
     RectangleBox[{-1.6, 0}, {-1.4, 0.11660412521721611},
      RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.2, 0.1477298484123477},
      RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 0.1908296453338889},
      RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 0.23635630997053417},
      RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.6, 0.2914988655538181},
      RoundingRadius->0], 
     RectangleBox[{-0.6, 0}, {-0.4, 0.34762590521021025},
      RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.2, 0.4014176570652759},
      RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 0.46536333186042306},
      RoundingRadius->0], RectangleBox[{0., 0}, {0.2, 0.46260448695787554},
      RoundingRadius->0], RectangleBox[{0.2, 0}, {0.4, 0.40190989910183},
      RoundingRadius->0], RectangleBox[{0.4, 0}, {0.6, 0.34486706030766273},
      RoundingRadius->0], RectangleBox[{0.6, 0}, {0.8, 0.29027398420704387},
      RoundingRadius->0], RectangleBox[{0.8, 0}, {1., 0.2378673785478631},
      RoundingRadius->0], RectangleBox[{1., 0}, {1.2, 0.19090977775844423},
      RoundingRadius->0], RectangleBox[{1.2, 0}, {1.4, 0.14896617724834413},
      RoundingRadius->0], RectangleBox[{1.4, 0}, {1.6, 0.11718794716754774},
      RoundingRadius->0], RectangleBox[{1.6, 0}, {1.8, 0.09038937489840353},
      RoundingRadius->0], RectangleBox[{1.8, 0}, {2., 0.06762031883546982},
      RoundingRadius->0], RectangleBox[{2., 0}, {2.2, 0.04617917152231001},
      RoundingRadius->0], RectangleBox[{2.2, 0}, {2.4, 0.03220178718201737},
      RoundingRadius->0], RectangleBox[{2.4, 0}, {2.6, 0.022860635976711226},
      RoundingRadius->0], RectangleBox[{2.6, 0}, {2.8, 0.016564516904507335},
      RoundingRadius->0], RectangleBox[{2.8, 0}, {3., 0.010314187789192197},
      RoundingRadius->0], RectangleBox[{3., 0}, {3.2, 0.0064220414536479715},
      RoundingRadius->0], RectangleBox[{3.2, 0}, {3.4, 0.004247018501432081},
      RoundingRadius->0], RectangleBox[{3.4, 0}, {3.6, 0.002632922521103446},
      RoundingRadius->0], RectangleBox[{3.6, 0}, {3.8, 0.001877388232438979},
      RoundingRadius->0], RectangleBox[{3.8, 0}, {4., 0.0011676439006632676},
      RoundingRadius->0], RectangleBox[{4., 0}, {4.2, 0.0005723744611094448},
      RoundingRadius->0], 
     RectangleBox[{4.2, 0}, {4.4, 0.0002861872305547224},
      RoundingRadius->0], 
     RectangleBox[{4.4, 0}, {4.6, 0.00019460731677721125},
      RoundingRadius->0], 
     RectangleBox[{4.6, 0}, {4.8, 0.00019460731677721125},
      RoundingRadius->0], 
     RectangleBox[{4.8, 0}, {5., 0.000057237446110944485},
      RoundingRadius->0], 
     RectangleBox[{5., 0}, {5.2, 0.000011447489222188897},
      RoundingRadius->0], 
     RectangleBox[{5.2, 0}, {5.4, 0.000011447489222188897},
      RoundingRadius->0], 
     RectangleBox[{5.4, 0}, {5.6, 0.00003434246766656669},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-5.2, 0},
  Frame->True,
  FrameLabel->{{
     FormBox[
      StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
      TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"\[CapitalDelta]\[CapitalDelta]G of fixed mutations (kcal/mol)\"", 13,
        StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-5, 5}, {0, 0.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7362577328837852`*^9, 3.7362577425396967`*^9}, 
   3.7362579353306293`*^9, 3.736258000998872*^9, 3.736258444565838*^9, {
   3.736270791902913*^9, 3.736270819722124*^9}, 3.736271461623057*^9, 
   3.736272265027722*^9, 3.736293792562477*^9, 3.736294559287798*^9, 
   3.736295420902969*^9, 3.7362963507346992`*^9, 3.736463419918353*^9, 
   3.736463462896882*^9, {3.736532023523046*^9, 3.736532039210053*^9}, {
   3.736533473995832*^9, 3.736533503487042*^9}, {3.736602090279317*^9, 
   3.736602098738596*^9}, 3.736632241559485*^9, 3.736638707949553*^9, 
   3.736725041766018*^9, 3.736766971786407*^9, 3.7367673025644407`*^9, 
   3.7367756887869263`*^9, 3.740840797623551*^9, 3.740915887033195*^9, 
   3.740960079562056*^9, 3.7409621885790462`*^9, 3.741002530992296*^9, 
   3.741435766393388*^9, 3.741523416840685*^9, 3.74152586057332*^9, 
   3.741526578470286*^9, 3.7415268904150467`*^9, 3.741527430441257*^9, 
   3.7415298656121483`*^9, 3.741690602146338*^9},
 CellLabel->
  "Out[376]=",ExpressionUUID->"74b7c508-3240-4f32-b39d-92dfd0f098ec"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean = \"\>", "\[InvisibleSpace]", "3.0998548490039974`*^-7"}],
  
  SequenceForm["mean = ", 3.0998548490039974`*^-7],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736258001015006*^9, 3.73625844457926*^9, {3.7362707919226303`*^9, 
   3.7362708197377987`*^9}, 3.73627146163542*^9, 3.736272265040868*^9, 
   3.7362937925767517`*^9, 3.7362945593047647`*^9, 3.736295420917163*^9, 
   3.736296350751348*^9, 3.736463419934198*^9, 3.7364634629114523`*^9, {
   3.736532023544154*^9, 3.736532039228591*^9}, {3.736533474010826*^9, 
   3.736533503502166*^9}, {3.736602090295557*^9, 3.73660209875412*^9}, 
   3.736632241577787*^9, 3.736638707959544*^9, 3.736725041779628*^9, 
   3.736766971802306*^9, 3.7367673025813837`*^9, 3.736775688799326*^9, 
   3.7408407976341352`*^9, 3.7409158870439053`*^9, 3.740960079579414*^9, 
   3.740962188591435*^9, 3.741002531002542*^9, 3.7414357664053907`*^9, 
   3.741523416854599*^9, 3.741525860584464*^9, 3.7415265784871883`*^9, 
   3.741526890430834*^9, 3.741527430459402*^9, 3.7415298656237307`*^9, 
   3.741690602161736*^9},
 CellLabel->
  "During evaluation of \
In[375]:=",ExpressionUUID->"2f425b10-f0c7-48f2-a1c1-324896da669c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"std = \"\>", "\[InvisibleSpace]", "1.0276141437804676`"}],
  SequenceForm["std = ", 1.0276141437804676`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.736258001015006*^9, 3.73625844457926*^9, {3.7362707919226303`*^9, 
   3.7362708197377987`*^9}, 3.73627146163542*^9, 3.736272265040868*^9, 
   3.7362937925767517`*^9, 3.7362945593047647`*^9, 3.736295420917163*^9, 
   3.736296350751348*^9, 3.736463419934198*^9, 3.7364634629114523`*^9, {
   3.736532023544154*^9, 3.736532039228591*^9}, {3.736533474010826*^9, 
   3.736533503502166*^9}, {3.736602090295557*^9, 3.73660209875412*^9}, 
   3.736632241577787*^9, 3.736638707959544*^9, 3.736725041779628*^9, 
   3.736766971802306*^9, 3.7367673025813837`*^9, 3.736775688799326*^9, 
   3.7408407976341352`*^9, 3.7409158870439053`*^9, 3.740960079579414*^9, 
   3.740962188591435*^9, 3.741002531002542*^9, 3.7414357664053907`*^9, 
   3.741523416854599*^9, 3.741525860584464*^9, 3.7415265784871883`*^9, 
   3.741526890430834*^9, 3.741527430459402*^9, 3.7415298656237307`*^9, 
   3.741690602169551*^9},
 CellLabel->
  "During evaluation of \
In[375]:=",ExpressionUUID->"7e07a9d8-9d48-432c-b80b-559624a72ce9"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Expected (= sum of single mutant \[CapitalDelta]\[CapitalDelta]Gs) vs. \
observed (= double mutant \[CapitalDelta]\[CapitalDelta]G) energy differences \
for random double mutants\
\>", "Subsubsection",
 CellChangeTimes->{
  3.736776293797352*^9, {3.7408401656677637`*^9, 
   3.740840166015751*^9}},ExpressionUUID->"bb6307a9-13c8-405d-8510-\
4c3dd397a219"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"energy", " ", "of", " ", "double", " ", "mutant"}], " ", "-", 
    " ", 
    RowBox[{
    "energy", " ", "of", " ", "initial", " ", "seq", " ", "vs", " ", "energy",
      " ", "of", " ", "mut1"}], " ", "+", " ", 
    RowBox[{"energy", " ", "of", " ", "mut2"}], " ", "-", " ", 
    RowBox[{
    "2", " ", "x", " ", "energy", " ", "of", " ", "initial", " ", "seq"}]}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"numOfDoubleMutants", "=", "500"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"seq", "=", 
     RowBox[{"walk", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eSeq", "=", 
     RowBox[{"walk", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "4"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"pos1", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", "l"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"pos2", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "l"}], "]"}], ",", 
            RowBox[{"{", "pos1", "}"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newletter1", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", 
              RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"seq", "[", 
              RowBox[{"[", "pos1", "]"}], "]"}], "}"}]}], "]"}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"newletter2", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", 
              RowBox[{"alpha", "-", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"seq", "[", 
              RowBox[{"[", "pos2", "]"}], "]"}], "}"}]}], "]"}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"eMut1", "=", 
         RowBox[{"eSeq", "+", 
          RowBox[{"getSingleMutationsEffectInTotalEnergyHoc", "[", 
           RowBox[{
           "seq", ",", "pos1", ",", "newletter1", ",", "l", ",", "alpha", ",",
             "\[Beta]", ",", "variancehoc"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"eMut2", "=", 
         RowBox[{"eSeq", "+", 
          RowBox[{"getSingleMutationsEffectInTotalEnergyHoc", "[", 
           RowBox[{
           "seq", ",", "pos2", ",", "newletter2", ",", "l", ",", "alpha", ",",
             "\[Beta]", ",", "variancehoc"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"eDoubleMut", "=", 
         RowBox[{"eSeq", "+", 
          RowBox[{"getSingleMutationsEffectInTotalEnergyHoc", "[", 
           RowBox[{
           "seq", ",", "pos1", ",", "newletter1", ",", "l", ",", "alpha", ",",
             "\[Beta]", ",", "variancehoc"}], "]"}], "+", 
          RowBox[{"getSingleMutationsEffectInTotalEnergyHoc", "[", 
           RowBox[{
            RowBox[{"ReplacePart", "[", 
             RowBox[{"seq", ",", 
              RowBox[{"pos1", "\[Rule]", "newletter1"}]}], "]"}], ",", "pos2",
             ",", "newletter2", ",", "l", ",", "alpha", ",", "\[Beta]", ",", 
            "variancehoc"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"data", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"eDoubleMut", "-", "eSeq"}], ",", 
            RowBox[{"eMut1", "+", "eMut2", "-", 
             RowBox[{"2", "eSeq"}]}]}], "}"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", "numOfDoubleMutants", "}"}]}], "]"}], ",", 
     "numOfDoubleMutants"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p61", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "Small", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "9"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "9"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Sum of single mutant \[CapitalDelta]\[CapitalDelta]Gs \
(kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Double mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\>\"",
             ",", "fontSize"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p62", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "9"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p6", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p61", ",", "p62"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r2", "=", " ", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r2"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", 
      RowBox[{"r2", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<mean difference = \>\"", ",", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<RMS error = \>\"", ",", 
      SqrtBox[
       RowBox[{"Mean", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ")"}], "^", "2"}], 
        "]"}]]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.735406686971858*^9, 3.7354067168543043`*^9}, {
   3.73540678345205*^9, 3.735406826739255*^9}, {3.73540685901604*^9, 
   3.735406859746942*^9}, {3.7354069399079123`*^9, 3.735407274974471*^9}, {
   3.73540736062433*^9, 3.735407421088765*^9}, {3.73540749252798*^9, 
   3.73540763371446*^9}, {3.735407677655581*^9, 3.7354077606036663`*^9}, {
   3.735407813247394*^9, 3.735407813658518*^9}, {3.735407853576527*^9, 
   3.735407854677855*^9}, {3.7354079265357723`*^9, 3.7354079278991413`*^9}, {
   3.735407981005075*^9, 3.735407989270031*^9}, {3.735425651859332*^9, 
   3.73542565942015*^9}, {3.7354265837063923`*^9, 3.7354265974561167`*^9}, {
   3.735426638421446*^9, 3.7354266744583406`*^9}, 3.735428959303252*^9, {
   3.735429006669067*^9, 3.7354290095521917`*^9}, {3.736001792360701*^9, 
   3.736001819156699*^9}, {3.736004287271104*^9, 3.736004311783555*^9}, {
   3.736170047728489*^9, 3.7361700642962627`*^9}, {3.736170108209219*^9, 
   3.736170135840767*^9}, {3.7361791248422318`*^9, 3.736179131073225*^9}, {
   3.736179162999592*^9, 3.736179165825145*^9}, {3.7364620759833803`*^9, 
   3.736462114421009*^9}, {3.736462191949552*^9, 3.736462205635243*^9}, {
   3.7364622698407784`*^9, 3.736462270014674*^9}, {3.7365318341467533`*^9, 
   3.736531864920845*^9}, {3.736601417562611*^9, 3.7366014179599733`*^9}, {
   3.736602039262439*^9, 3.7366020723638487`*^9}, {3.736602185127561*^9, 
   3.73660218961693*^9}, {3.736621817399724*^9, 3.7366218178882723`*^9}, {
   3.736624307159446*^9, 3.736624315854735*^9}, {3.73676672764604*^9, 
   3.7367667296275673`*^9}, {3.736767127866691*^9, 3.736767134118078*^9}, {
   3.740840192265012*^9, 3.740840196682089*^9}, {3.74096001430921*^9, 
   3.7409600369991693`*^9}, 3.7415228981092463`*^9, 3.741522947234211*^9, {
   3.741523006532221*^9, 3.741523040918178*^9}, {3.741526335646133*^9, 
   3.741526336109029*^9}, {3.741689313346081*^9, 3.74168932761931*^9}},
 CellLabel->
  "In[380]:=",ExpressionUUID->"39537c62-a501-4910-97ca-24dacb51e5e0"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJwVWXc8V28Ufu2RQiQVGSEZpUJUupcKSUgaSFFCIiRR+emmRKi0jPaQkNmQ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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxFxW0w03EcAPDlIVvyMKdFeTxZx0ltnZqn/l7oqIisG0PTxGnJw5m4CicP
l84L4TJd3EkvdC2r02pMeajOcu6kabdjhPOsZiM226xVL/b9vfjcxzs9LyHT
AofDxf7zfz45Y8pkchgwf/lWSKlMi/7zydGDr0InsD+kMWbQ+iek+Zd96HPE
4VVmKXrZcEz7Rm8P+3zTEq9v28GTwXQ3RZ8tTGkOujfRSYDxx9M4tA4b2KMq
ntxeaA3LRr+E87Is4RE53p8XuAeuoHqdVJmM/eYFbWGSIaUOZtauWAkrt+FI
drtWlLEBs+JlczrhGkyRVx19pZ6DbTltAp/qcViafCnK0NgCX/u9w4jAvmLm
7VJPnfadmoFpZOao3/sVeOtZ6Qjhjhq+SMP2riq34OcpBSE2sTp4sJHXY882
woKOpqjyJVyEeUXdpFypsYBrMPmCftcK1pzY724MtIE/B4j13FACTL/RZjnL
tYXT87AHP5/awWNlicLsFw4wboVena9yhCWPaJWLGiIc13Eb89c5waIJRj2H
6AzH1auD5kkHYAmHnJ9IJcF5EhejdehBWF6TFV11xgX2yk7wMya6ws1SXepr
1iF4IzmczLp7GN4XNd2paHCD6d3BNY08d7jkPHXnbJcHLGMvi6liT7god7e1
mOUFc8PofuNraHws/sdIjjesr7spcM5HK6VjZVcK0NKkx56qInRLhj/bqRxN
KYlZSGpAJ/Mfri2+Q8esb4kDe9AYhVlb3Is+IvIOIAyg1z925QQMoysmv6sL
FOhC9+DB3ml01tXWeqtZdMxSJrVpAU3a1HB7lGh8UEqkhRptKO53vrCJnjXe
fzulQY9H/Kr21aGHKuMZuQZ095CQLDKi+QRXrcmE/gujClCz
        "]]},
      Annotation[#, "Charting`Private`Tag$24623384#1"]& ]}, {}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
      "\"Double mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\"", 13, 
       StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"Sum of single mutant \[CapitalDelta]\[CapitalDelta]Gs (kcal/mol)\"", 
       13, StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-4, 9}, {-4, 9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.741522899864092*^9, 3.741522948008112*^9, {3.741523007264183*^9, 
   3.741523041475934*^9}, 3.741523418100019*^9, 3.741525861251824*^9, 
   3.741526579232546*^9, 3.7415268911372213`*^9, 3.741527431589897*^9, 
   3.741529866549169*^9, 3.741690609310198*^9},
 CellLabel->
  "Out[387]=",ExpressionUUID->"29029f18-4469-4564-b053-08e647d4b1fe"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", "0.9967650269970001`"}],
  SequenceForm["r = ", 0.9967650269970001],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741522899873067*^9, 3.7415229480177307`*^9, {3.741523007273263*^9, 
   3.7415230414850082`*^9}, 3.741523418114657*^9, 3.741525861260014*^9, 
   3.7415265792438793`*^9, 3.741526891148431*^9, 3.741527431606084*^9, 
   3.741529866558577*^9, 3.741690609318885*^9},
 CellLabel->
  "During evaluation of \
In[380]:=",ExpressionUUID->"bde605f3-d6d6-43b4-a5f1-8a67de7c5eba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.9935405190443303`"}],
  SequenceForm["r^2 = ", 0.9935405190443303],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741522899873067*^9, 3.7415229480177307`*^9, {3.741523007273263*^9, 
   3.7415230414850082`*^9}, 3.741523418114657*^9, 3.741525861260014*^9, 
   3.7415265792438793`*^9, 3.741526891148431*^9, 3.741527431606084*^9, 
   3.741529866558577*^9, 3.741690609326552*^9},
 CellLabel->
  "During evaluation of \
In[380]:=",ExpressionUUID->"2cff9e53-fdc7-46b1-b2ed-ff42d0dccb9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean difference = \"\>", "\[InvisibleSpace]", 
   "0.021824792312624366`"}],
  SequenceForm["mean difference = ", 0.021824792312624366`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741522899873067*^9, 3.7415229480177307`*^9, {3.741523007273263*^9, 
   3.7415230414850082`*^9}, 3.741523418114657*^9, 3.741525861260014*^9, 
   3.7415265792438793`*^9, 3.741526891148431*^9, 3.741527431606084*^9, 
   3.741529866558577*^9, 3.741690609339312*^9},
 CellLabel->
  "During evaluation of \
In[380]:=",ExpressionUUID->"c1124e22-e473-4c9c-b141-bddc10ce26b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RMS error = \"\>", "\[InvisibleSpace]", "0.1663744146293535`"}],
  SequenceForm["RMS error = ", 0.1663744146293535],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741522899873067*^9, 3.7415229480177307`*^9, {3.741523007273263*^9, 
   3.7415230414850082`*^9}, 3.741523418114657*^9, 3.741525861260014*^9, 
   3.7415265792438793`*^9, 3.741526891148431*^9, 3.741527431606084*^9, 
   3.741529866558577*^9, 3.741690609349029*^9},
 CellLabel->
  "During evaluation of \
In[380]:=",ExpressionUUID->"c10013de-94ce-4300-a232-11b6f5572943"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Difference in effect of fixed mutations at 50% sequence divergence\
\>", "Subsubsection",
 CellChangeTimes->{
  3.736776303252851*^9},ExpressionUUID->"1d6de586-1687-4c92-83a5-\
3ef7a8c23e1e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"seq1", " ", "=", " ", 
     RowBox[{
     "drawn", " ", "from", " ", "stationary", " ", "dist", " ", "of", " ", 
      "random", " ", "walk"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"seq2", " ", "=", " ", 
     RowBox[{
     "random", " ", "walk", " ", "continued", " ", "from", " ", "seq1", " ", 
      "until", " ", "seq1", " ", "and", " ", "seq2", " ", "differ", " ", "in",
       " ", "half", " ", "of", " ", "sites"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"data", " ", "=", " ", 
     RowBox[{"list", " ", "of", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "mutEffect", " ", "on", " ", "energy", " ", "of", " ", "seq1"}], ",", 
        " ", 
        RowBox[{
        "mutEffect", " ", "on", " ", "energy", " ", "of", " ", "seq2"}]}], 
       "}"}], " ", "pairs", " ", "for", " ", "mutations", " ", "specified", 
      " ", "by", " ", "the", " ", "sites", " ", "that", " ", "differ", " ", 
      "in", " ", "the", " ", "two", " ", "sequences"}]}]}], " ", 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SeedRandom", "[", "1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numPairsOfSeqs", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numDifferentSites", "=", 
     RowBox[{"l", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Monitor", "[", 
      RowBox[{
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"seq1", "=", 
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"seq2", "=", 
           RowBox[{
            RowBox[{
            "RandomWalkBasedOnTotalEnergyHocUntilGivenSeqDivergence", "[", 
             RowBox[{
             "seq1", ",", "energyCutoff", ",", "l", ",", "alpha", ",", 
              "\[Beta]", ",", "variancehoc", ",", "numDifferentSites"}], 
             "]"}], "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"positions", "=", 
           RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"seq1", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "\[NotEqual]", 
               RowBox[{"seq2", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], ",", " ", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"positions", ",", "k"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "1", ",", "l"}], "}"}]}], "]"}], ";", " ", 
          RowBox[{"(*", 
           RowBox[{
           "list", " ", "of", " ", "positions", " ", "in", " ", "which", " ", 
            "seq1", " ", "and", " ", "seq2", " ", "differ"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"data", "=", 
           RowBox[{"data", "~", "Join", "~", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"getSingleMutationsEffectInTotalEnergyHoc", "[", 
                 RowBox[{"seq1", ",", 
                  RowBox[{"positions", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], ",", 
                  RowBox[{"seq2", "[", 
                   RowBox[{"[", 
                    RowBox[{"positions", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], "]"}], ",", 
                  "l", ",", "alpha", ",", "\[Beta]", ",", "variancehoc"}], 
                 "]"}], ",", 
                RowBox[{"getSingleMutationsEffectInTotalEnergyHoc", "[", 
                 RowBox[{"seq2", ",", 
                  RowBox[{"positions", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], ",", 
                  RowBox[{"seq1", "[", 
                   RowBox[{"[", 
                    RowBox[{"positions", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], "]"}], ",", 
                  "l", ",", "alpha", ",", "\[Beta]", ",", "variancehoc"}], 
                 "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "1", ",", "numDifferentSites"}], "}"}]}], 
             "]"}]}]}], ";"}], "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "numPairsOfSeqs"}], "}"}]}], "]"}], ",",
        "n"}], "]"}], ";"}], "//", "AbsoluteTiming"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"scatter", " ", "plot", " ", "of", " ", 
     RowBox[{"(", 
      RowBox[{"mutEffect", " ", "on", " ", "energy", " ", "of", " ", "seq1"}],
       ")"}], " ", 
     RowBox[{"vs", ".", " ", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
        "mutEffect", " ", "on", " ", "energy", " ", "of", " ", "seq2"}], 
        ")"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p71", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"data", ".", 
        RowBox[{"(", GridBox[{
           {"1", "0"},
           {"0", 
            RowBox[{"-", "1"}]}
          }], ")"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "Small", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Single mutant \[CapitalDelta]\[CapitalDelta]G background \
1\>\"", ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Single mutant \[CapitalDelta]\[CapitalDelta]G background \
2\>\"", ",", "fontSize"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p72", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p7", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p71", ",", "p72"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", " ", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", 
      RowBox[{"r", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<mean difference = \>\"", ",", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<RMS error = \>\"", ",", 
      SqrtBox[
       RowBox[{"Mean", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ")"}], "^", "2"}], 
        "]"}]]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.736206709882655*^9, 3.7362067874243593`*^9}, {
   3.7362068442805643`*^9, 3.736206890573965*^9}, 3.736206961713521*^9, 
   3.736248118577738*^9, {3.7364623338966093`*^9, 3.736462336612712*^9}, {
   3.736462865611753*^9, 3.736462920191926*^9}, {3.736463048865144*^9, 
   3.736463050875103*^9}, {3.7364631356854343`*^9, 3.73646316127034*^9}, {
   3.736463291647645*^9, 3.736463336988015*^9}, {3.736531897633972*^9, 
   3.736531906953158*^9}, {3.736624359984582*^9, 3.7366244156636477`*^9}, {
   3.7367672966030283`*^9, 3.7367672970071173`*^9}, {3.736767387363892*^9, 
   3.7367673877767143`*^9}, {3.74084032073287*^9, 3.7408403217660437`*^9}, {
   3.740960045580608*^9, 3.74096010213207*^9}, {3.741435545054734*^9, 
   3.741435549824452*^9}, 3.741522197737258*^9, 3.741522826809081*^9, {
   3.7415230893561153`*^9, 3.741523177460721*^9}, {3.741523612468555*^9, 
   3.7415236127885303`*^9}, {3.741523649544703*^9, 3.741523657340041*^9}, {
   3.7415236973729687`*^9, 3.741523697784567*^9}, {3.74152387037576*^9, 
   3.741523873189238*^9}, {3.7415239338984756`*^9, 3.741523935150627*^9}, {
   3.7415247677967176`*^9, 3.7415247717078238`*^9}, {3.741524802948488*^9, 
   3.741524839609745*^9}, {3.741526118896616*^9, 3.741526148030258*^9}, {
   3.7415266640485983`*^9, 3.741526664331661*^9}, {3.74168941194538*^9, 
   3.7416894169196672`*^9}},
 CellLabel->
  "In[394]:=",ExpressionUUID->"0c320bc9-6757-4b71-8062-c61e70f39539"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.168107`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.741529867623281*^9, 3.741690614619561*^9},
 CellLabel->
  "Out[398]=",ExpressionUUID->"46b87613-af60-4a75-aa29-5681d578d4fd"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJwVVnk0FAofRWVL9RTa1ENJtIi8nq1+tG/SYolU9koLlddiKduzFQlNSNr1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       
       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxF1O0vFAAcwPG74xhxL7rO1tku7nba0fQwT3MqTDFjxSHWVbccye6mmTw1
mkZcoZuhOi21PBNJWapDXDqTTrFMGi4x5yHGdWd3nGrrfr8X333+g6/zxZTI
BBKBQAj/2z/j26SrOzvWvWb3GOku3C1UcbKWn76Jukx1DS6voYt2s08m1OiV
ZM/Yjn40l/2tN7EQlVWxyoYpaPV0UUqEjRXoMMI7xaGRQeVpXtAQ2xIM4bDT
WEwL0LeVX6c6SAINtxKpRzhE8Le+puL8fgKoYJZ5dItNPWa55OsdbsItsNzf
2zsgxwDGP4idW6zeBFX1DBuiTAcy7J4d7unUgrZO8ypN0zooiiq419CwBgr6
p4cYZSsg86gp4n2eBmxM6lC/6ZwDkzfa+bdlatA9lxxnxZoEqVljuyqrRsFx
oci1bXYAzMh2LR2saAWb7vj41xx6etxs6eW8r4IbH0B7bRi3JWIUnEkb8EjP
nwR/dYX3ZSjVYF3hY4FQMgeydc3UzCoNOPV8n5ybtAJG350pWpKugQ9ri+Vh
leug5VnxCjlLC34SNNZH5uvAl/b0c3rRJugic16wDjOAhvT87WbeFrhkcKQ0
+JjAR5cKxxxZBH+z0oCPxXvZRJCS0hzYTyOB3UGv5J10C3BbfMErhmIJEq2/
3HfbRr1CUvtCCVag4XvLAm0dDRIppeE6tMQ461NgQJ3ojhItyRoMPiPhjFLR
8s8JyVJP1H2AsWybhWZG+5YH5qDvfkb7ZeehURYlxRoJes3feEApQ5Wvx8UF
b9HdoRs0eS/Kn6B0axXoqv4ERTiMOni+aA2cQgUKVUz2D7SRt2Rqn0f9Upmn
nFfRm8Rj+tgNdEQaVy3Vo3Snq8FKI/r/W+AfYipULQ==
        "]]},
      Annotation[#, "Charting`Private`Tag$24626533#1"]& ]}, {}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
      "\"Single mutant \[CapitalDelta]\[CapitalDelta]G background 2\"", 13, 
       StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"Single mutant \[CapitalDelta]\[CapitalDelta]G background 1\"", 13, 
       StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-3, 3}, {-3, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.741529867623281*^9, 3.7416906147091827`*^9},
 CellLabel->
  "Out[401]=",ExpressionUUID->"5e0bb305-c59f-473f-94a7-0a2a41701b6e"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.989640264583075`"}]}],
  SequenceForm["r = ", -0.989640264583075],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741524249956237*^9, {3.741524773131616*^9, 3.741524780440929*^9}, {
   3.7415248133815947`*^9, 3.741524846524272*^9}, {3.7415248910713787`*^9, 
   3.741524898342989*^9}, 3.741525862045244*^9, 3.741525907961968*^9, {
   3.741526005848649*^9, 3.741526017016214*^9}, {3.741526122879918*^9, 
   3.741526161278919*^9}, 3.7415265799214363`*^9, 3.741526891632402*^9, 
   3.741527432653824*^9, 3.741529867814582*^9, 3.741690614717898*^9},
 CellLabel->
  "During evaluation of \
In[394]:=",ExpressionUUID->"be1346ba-8afa-4f94-aa1a-46132b82106c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.9793878532840586`"}],
  SequenceForm["r^2 = ", 0.9793878532840586],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741524249956237*^9, {3.741524773131616*^9, 3.741524780440929*^9}, {
   3.7415248133815947`*^9, 3.741524846524272*^9}, {3.7415248910713787`*^9, 
   3.741524898342989*^9}, 3.741525862045244*^9, 3.741525907961968*^9, {
   3.741526005848649*^9, 3.741526017016214*^9}, {3.741526122879918*^9, 
   3.741526161278919*^9}, 3.7415265799214363`*^9, 3.741526891632402*^9, 
   3.741527432653824*^9, 3.741529867814582*^9, 3.74169061472565*^9},
 CellLabel->
  "During evaluation of \
In[394]:=",ExpressionUUID->"16f2586b-81ad-4e9d-8d2a-df57e5d69c05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mean difference = \"\>", "\[InvisibleSpace]", 
   "0.014933163412644865`"}],
  SequenceForm["mean difference = ", 0.014933163412644865`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741524249956237*^9, {3.741524773131616*^9, 3.741524780440929*^9}, {
   3.7415248133815947`*^9, 3.741524846524272*^9}, {3.7415248910713787`*^9, 
   3.741524898342989*^9}, 3.741525862045244*^9, 3.741525907961968*^9, {
   3.741526005848649*^9, 3.741526017016214*^9}, {3.741526122879918*^9, 
   3.741526161278919*^9}, 3.7415265799214363`*^9, 3.741526891632402*^9, 
   3.741527432653824*^9, 3.741529867814582*^9, 3.741690614736677*^9},
 CellLabel->
  "During evaluation of \
In[394]:=",ExpressionUUID->"eb91f525-1e58-4e84-9edb-2f50b4aaf4b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RMS error = \"\>", "\[InvisibleSpace]", "2.123175909813311`"}],
  
  SequenceForm["RMS error = ", 2.123175909813311],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741524249956237*^9, {3.741524773131616*^9, 3.741524780440929*^9}, {
   3.7415248133815947`*^9, 3.741524846524272*^9}, {3.7415248910713787`*^9, 
   3.741524898342989*^9}, 3.741525862045244*^9, 3.741525907961968*^9, {
   3.741526005848649*^9, 3.741526017016214*^9}, {3.741526122879918*^9, 
   3.741526161278919*^9}, 3.7415265799214363`*^9, 3.741526891632402*^9, 
   3.741527432653824*^9, 3.741529867814582*^9, 3.741690614742023*^9},
 CellLabel->
  "During evaluation of \
In[394]:=",ExpressionUUID->"e63c2601-10fe-4f67-862e-e9376b5f8b56"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Expected vs. observed energy differences for random single mutants\
\>", "Subsubsection",
 CellChangeTimes->{
  3.7367762857557373`*^9},ExpressionUUID->"b6c1e804-941a-406f-ab4c-\
a524a7005548"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "additive", " ", "energy", " ", "of", " ", "single", " ", "mutant"}], 
      " ", "-", " ", 
      RowBox[{
      "additive", " ", "energy", " ", "of", " ", "initial", " ", "seq"}]}], 
     ")"}], " ", "vs", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "total", " ", "energy", " ", "of", " ", "single", " ", "mutant"}], " ", 
      "-", " ", 
      RowBox[{
      "total", " ", "energy", " ", "of", " ", "initial", " ", "seq"}]}], 
     ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"getAllSingleMutationEffectsInTotalEnergyHoc", "[", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], ",", "l", ",", 
           "alpha", ",", "\[Beta]", ",", "variancehoc"}], "]"}], ",", 
         RowBox[{"getAllSingleMutationEffectsInAdditiveEnergy", "[", 
          RowBox[{
           RowBox[{"walk", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], ",", "l", ",", 
           "alpha", ",", "\[Beta]"}], "]"}]}], "}"}], "]"}]}], ";"}], "//", 
    "AbsoluteTiming"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p51", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"GrayLevel", "[", 
           RowBox[{"0", ",", ".3"}], "]"}], ",", 
          RowBox[{"PointSize", "[", "Small", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Single mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\>\"",
             ",", "fontSize"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Single mutant \!\(\*SubscriptBox[\(\[CapitalDelta]\
\[CapitalDelta]G\), \(add\)]\) (kcal/mol)\>\"", ",", " ", "fontSize"}], 
           "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p52", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p5", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"p51", ",", "p52"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r1", "=", 
     RowBox[{
      RowBox[{"Correlation", "[", "data", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r = \>\"", ",", " ", "r1"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<r^2 = \>\"", ",", " ", 
      RowBox[{"r1", "^", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookSave", "[", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.733583115424968*^9, 3.733583116358807*^9}, {
   3.733583152281767*^9, 3.733583217010763*^9}, {3.733583261312031*^9, 
   3.733583296169827*^9}, {3.7335833796123047`*^9, 3.733583388958243*^9}, {
   3.733583659606741*^9, 3.7335836837873287`*^9}, {3.733583729114402*^9, 
   3.733583729606626*^9}, {3.7335837806521263`*^9, 3.733583781982383*^9}, {
   3.733583970749329*^9, 3.733583974821103*^9}, {3.7335841622311573`*^9, 
   3.733584162715805*^9}, {3.733588069899384*^9, 3.733588077051388*^9}, {
   3.73358821427737*^9, 3.733588215581525*^9}, {3.7335883814861593`*^9, 
   3.733588383603224*^9}, {3.733588461799924*^9, 3.7335884619778147`*^9}, {
   3.7335885025379667`*^9, 3.733588513800107*^9}, {3.7335917778105183`*^9, 
   3.73359178141014*^9}, {3.733592651986177*^9, 3.733592671910652*^9}, {
   3.733593066600316*^9, 3.7335930667616034`*^9}, 3.733593111160495*^9, {
   3.733593297310863*^9, 3.733593299191543*^9}, {3.733657891505787*^9, 
   3.733657891671327*^9}, {3.733657929372137*^9, 3.733657931195569*^9}, 
   3.733658094288237*^9, {3.733658675344146*^9, 3.733658675659107*^9}, {
   3.733659174717407*^9, 3.733659177504285*^9}, {3.733659301528618*^9, 
   3.733659339515543*^9}, {3.733659676859182*^9, 3.7336597183845778`*^9}, {
   3.733659886771686*^9, 3.7336598877181787`*^9}, {3.733660069506083*^9, 
   3.733660094362658*^9}, {3.733660285504599*^9, 3.7336602860457697`*^9}, {
   3.733660840783239*^9, 3.733660841076806*^9}, {3.7336667238541107`*^9, 
   3.733666738652791*^9}, {3.733666852864674*^9, 3.733666882013753*^9}, {
   3.733666922836958*^9, 3.7336669710592527`*^9}, {3.7336670026256742`*^9, 
   3.733667026202958*^9}, 3.733668188631052*^9, {3.733668233428771*^9, 
   3.733668258827982*^9}, {3.733737479149582*^9, 3.73373747953655*^9}, {
   3.733763327720726*^9, 3.733763352601877*^9}, {3.7337633918981123`*^9, 
   3.733763462899085*^9}, {3.73382604389401*^9, 3.7338260552987347`*^9}, {
   3.7338321501512413`*^9, 3.733832270097473*^9}, 3.733832410897613*^9, {
   3.733832596748477*^9, 3.73383259710463*^9}, {3.7338327264930973`*^9, 
   3.733832726639556*^9}, {3.733833223152149*^9, 3.7338332854949007`*^9}, {
   3.733833316910149*^9, 3.733833330645504*^9}, {3.733833361853006*^9, 
   3.733833393900714*^9}, {3.7338335354116993`*^9, 3.733833539962077*^9}, {
   3.733833844151991*^9, 3.733833853728457*^9}, {3.733834363716586*^9, 
   3.733834371505727*^9}, {3.733835099042873*^9, 3.733835107212995*^9}, {
   3.733835233338505*^9, 3.733835243190394*^9}, {3.733836805345208*^9, 
   3.7338368064822206`*^9}, {3.7338369197486753`*^9, 3.733836926247864*^9}, {
   3.733837582410274*^9, 3.733837602367157*^9}, {3.733837654850156*^9, 
   3.7338376848947077`*^9}, {3.733837716315324*^9, 3.7338377530850573`*^9}, {
   3.7338378468400307`*^9, 3.733837847226482*^9}, {3.733837985491539*^9, 
   3.733838014287347*^9}, {3.7338381819136963`*^9, 3.733838185252846*^9}, {
   3.733838237402279*^9, 3.733838240231554*^9}, {3.733838291363535*^9, 
   3.733838293671496*^9}, {3.733838391121719*^9, 3.7338383996764727`*^9}, {
   3.733838456425789*^9, 3.733838456803849*^9}, {3.733838649422038*^9, 
   3.733838658896624*^9}, {3.733838950066908*^9, 3.733838953420376*^9}, {
   3.733839109866453*^9, 3.733839110168044*^9}, {3.733839382359494*^9, 
   3.7338394123252287`*^9}, {3.733839544989499*^9, 3.733839545288739*^9}, {
   3.733839668465499*^9, 3.7338400372994967`*^9}, {3.733840165306419*^9, 
   3.7338401767113333`*^9}, {3.733840546982991*^9, 3.733840547353941*^9}, {
   3.7338405777761993`*^9, 3.733840603331613*^9}, {3.7338409216478853`*^9, 
   3.7338409233686247`*^9}, {3.733841538407444*^9, 3.73384164033465*^9}, {
   3.7338418621373253`*^9, 3.7338419079342613`*^9}, 3.733842004483383*^9, {
   3.73384209732076*^9, 3.733842103391017*^9}, {3.733842142985736*^9, 
   3.733842168623827*^9}, {3.733842283827477*^9, 3.733842316128294*^9}, {
   3.733842426451214*^9, 3.733842441217456*^9}, {3.733842553824792*^9, 
   3.7338426088721657`*^9}, {3.733842712167193*^9, 3.733842727548883*^9}, {
   3.733843399984416*^9, 3.733843424664056*^9}, {3.7338434634228897`*^9, 
   3.7338434701661797`*^9}, {3.733843520350079*^9, 3.7338435683418903`*^9}, {
   3.733844698410262*^9, 3.733844698894375*^9}, {3.7340132115399523`*^9, 
   3.734013302980185*^9}, {3.734013735601467*^9, 3.7340137390410624`*^9}, {
   3.734014264491007*^9, 3.734014276902588*^9}, {3.734014461244384*^9, 
   3.734014464823503*^9}, {3.734015464938335*^9, 3.734015662469603*^9}, {
   3.7340162283857517`*^9, 3.734016267617688*^9}, {3.734024490481786*^9, 
   3.734024509057356*^9}, 3.734024626439251*^9, 3.7340246852759447`*^9, {
   3.73402475762873*^9, 3.7340247604394083`*^9}, 3.73402481807113*^9, {
   3.734024861913638*^9, 3.73402487647447*^9}, {3.734027586102557*^9, 
   3.734027635733383*^9}, {3.734027673408737*^9, 3.73402777783447*^9}, {
   3.734027829002275*^9, 3.7340278693942423`*^9}, {3.734027920378541*^9, 
   3.734028007479664*^9}, {3.734028068596333*^9, 3.73402820691041*^9}, {
   3.734028241283469*^9, 3.734028270358124*^9}, {3.734028440140842*^9, 
   3.734028442566586*^9}, {3.734028473457741*^9, 3.734028473630776*^9}, {
   3.734028675819725*^9, 3.734028812508513*^9}, {3.7340288543139467`*^9, 
   3.734028870819304*^9}, {3.734028935732287*^9, 3.734029021963951*^9}, {
   3.734029443838529*^9, 3.734029445770215*^9}, {3.734029477264106*^9, 
   3.734029514453198*^9}, {3.734029583353898*^9, 3.734029585392456*^9}, {
   3.734029661313583*^9, 3.734029684653665*^9}, {3.734029787145205*^9, 
   3.7340297932283897`*^9}, {3.7340299000690002`*^9, 
   3.7340299081882963`*^9}, {3.734034149940214*^9, 3.734034150542972*^9}, {
   3.734034192106454*^9, 3.734034237543085*^9}, {3.734034381180319*^9, 
   3.7340344615448713`*^9}, {3.734034506142136*^9, 3.734034515803239*^9}, 
   3.734034605771186*^9, 3.734040128876388*^9, {3.7340405579658947`*^9, 
   3.7340405643957043`*^9}, {3.7340407030347147`*^9, 3.734040704595113*^9}, {
   3.7340412478797207`*^9, 3.734041291044943*^9}, {3.734041409709605*^9, 
   3.7340414892246513`*^9}, {3.734041659244462*^9, 3.734041792562768*^9}, {
   3.734716124626233*^9, 3.734716142512377*^9}, {3.7347161798451643`*^9, 
   3.734716228156747*^9}, {3.734716597331767*^9, 3.7347166365365973`*^9}, {
   3.734716960102572*^9, 3.734716962318602*^9}, {3.734717298787504*^9, 
   3.734717299463696*^9}, {3.7347175088738937`*^9, 3.734717511960382*^9}, {
   3.734717914172818*^9, 3.734717915847685*^9}, {3.734718278920136*^9, 
   3.73471829940199*^9}, {3.73471864422125*^9, 3.734718683449205*^9}, {
   3.7347187588321733`*^9, 3.7347187607208157`*^9}, {3.734720054800376*^9, 
   3.7347200627602673`*^9}, {3.734782858713868*^9, 3.734782859092993*^9}, {
   3.734791498104195*^9, 3.7347915148066683`*^9}, {3.734791547005097*^9, 
   3.734791556717767*^9}, {3.734791992041707*^9, 3.734792097943027*^9}, {
   3.7347927863250637`*^9, 3.734792788562153*^9}, {3.735309088512621*^9, 
   3.735309094139842*^9}, 3.7353091756799583`*^9, {3.7353092406305237`*^9, 
   3.735309260968574*^9}, {3.735309302918127*^9, 3.735309314315504*^9}, 
   3.735338286286254*^9, {3.7353383872365026`*^9, 3.735338396693616*^9}, {
   3.7353389314411507`*^9, 3.7353389761082497`*^9}, {3.735339045041912*^9, 
   3.735339139628769*^9}, {3.73533926145936*^9, 3.735339310052595*^9}, {
   3.735339341942754*^9, 3.7353393423546047`*^9}, {3.735341439780465*^9, 
   3.735341496879216*^9}, {3.735344075941908*^9, 3.735344087834072*^9}, 
   3.735344300839237*^9, {3.7354266532368*^9, 3.735426665125949*^9}, {
   3.73542895193019*^9, 3.7354289543382807`*^9}, {3.736001802248063*^9, 
   3.7360018063238792`*^9}, {3.736249329521846*^9, 3.7362493403758*^9}, {
   3.7362590981930428`*^9, 3.7362591638136597`*^9}, {3.736462053432773*^9, 
   3.736462059569652*^9}, {3.736531605276581*^9, 3.736531615463661*^9}, 
   3.736531655635006*^9, {3.736533065969746*^9, 3.736533147326613*^9}, {
   3.736533239223473*^9, 3.736533275277964*^9}, {3.736601398441634*^9, 
   3.736601398929497*^9}, {3.736624283617741*^9, 3.7366242878257713`*^9}, {
   3.736766752231848*^9, 3.736766821596497*^9}, {3.736767054868001*^9, 
   3.736767061447974*^9}, {3.740840233510496*^9, 3.740840233916997*^9}, {
   3.740960111924993*^9, 3.7409601267110453`*^9}, {3.74168942527662*^9, 
   3.74168942936408*^9}},
 CellLabel->
  "In[408]:=",ExpressionUUID->"b36ccbe3-52cf-47ec-b847-d762896ff5d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.70513`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{
  3.735425699698062*^9, 3.736000189250023*^9, 3.736001722649634*^9, 
   3.7360680058383303`*^9, 3.7362492376662703`*^9, 3.736249523636978*^9, 
   3.736250257513464*^9, 3.736251488973936*^9, 3.736253220184881*^9, 
   3.736259103834094*^9, 3.73625924990403*^9, 3.7362713790877733`*^9, 
   3.736272113675346*^9, 3.736293637019443*^9, 3.736294408056141*^9, 
   3.736295274106791*^9, 3.73629620401882*^9, 3.736462062090673*^9, 
   3.736531617869508*^9, 3.7365316567277946`*^9, {3.7365330772019997`*^9, 
   3.7365331483394537`*^9}, {3.736533241624836*^9, 3.736533276228815*^9}, 
   3.73660185043937*^9, 3.7366311545170527`*^9, 3.736632228074242*^9, 
   3.736638705373378*^9, 3.73672503618801*^9, 3.7367669443455763`*^9, 
   3.736767231862249*^9, 3.736775686817679*^9, 3.740840802328025*^9, 
   3.7409158895491133`*^9, 3.740962191651249*^9, 3.741002534201961*^9, 
   3.741435768622738*^9, 3.741523422046145*^9, 3.741525863862585*^9, 
   3.741526581517579*^9, 3.7415268986804123`*^9, 3.741527444821988*^9, 
   3.74152986953579*^9, 3.741690618743651*^9},
 CellLabel->
  "Out[408]=",ExpressionUUID->"0384708c-961d-4b6e-a1bd-8ab411d30d72"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], Opacity[0.3], 
      PointBox[CompressedData["
1:eJwcm3k0ld/bxs85jnkskaS+miQiqYhw71BExhKppEJCKZnSpIEkCRkqUoaU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       "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
     
     TagBox[
      {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJxFxX0w03EcAOCZbWymNWEn3eXl7HTsOpzVvGSdnF+Y3YaTuOtyrXOuQziU
lC62K91yCTHruopoiavzUqgV2R1ZS3GVOkq2Zi4va5mX86v+2Of7x3OPd2au
WEIkEAiCf/6/rlX8wHGG2vab1cD5njW00uv5Yq4Zzc+fWZ/Wo6Vufkz1GJqZ
8SiyXIH2N6rrCPvQqfZ6zC5nG+w0Ij8R/IwOszurPh3ydYKbpaEa8Q0qXLoY
eap61gHuLW7M7hBS4MTrKV5bDSQ4VjmQiC0Q4RbNmcmCdDu433FPwC0R/sL2
hpqSwWJvwnjagfMy2hr8hBXCSFVZYK6rTmysXIHHs5Np3bxf8MucfpFMZoCF
S4VbX7Fv8NkiIdNAnoD9GA9neK/UcLK4b3IA64qy3cZJcL/9ehwur8IWyOJp
OCGg1b64SA/zaqZUEt0C/LapfX9I5TIsiu8M/DD3Gyb10XIe062wA6WVH1S8
AcfkmbyfvtuCPwui/aPWCHzbPFGwY76KCAeFjskH+SRY49/X5KElw+Qrceao
Mgd4arRyqYJBhdNKM7mNgzQ4z8nkoz1Kh31Vw3WUeWf4Qm90EkPBgMOSuOmK
+u2w40XPoPp8JtzMfRBXe9gFln+R9/i47IDjeUPYTRM6WSrkKLtd4cD0ipR7
ZW7wRz31Tk2KO6zLnDvospsFz5LuW2t90H9asjo82GhPk2mXNwd9smBldW84
euMS3i5IRbObPXZevobmxU7p6DXoBGOTrLoOfZrjZalXovu72LoWFVo8HCId
0qAlWZYIbBRdQusxj2rRysSw4+8n0D8n+RHfZ9HrJUSzxIB29hxqM86jg4/F
spaX0TF2VG2hBX3k7kiF1YrOjrkafm4TXWYQrOA4+i88TTkH
        "]]},
      Annotation[#, "Charting`Private`Tag$24626922#1"]& ]}, {}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
      "\"Single mutant \
\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]\[CapitalDelta]G\\), \\(add\\)]\\) \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
      "\"Single mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\"", 13, 
       StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-4, 6}, {-4, 6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.735425699698062*^9, 3.736000189250023*^9, 3.736001722649634*^9, 
   3.7360680058383303`*^9, 3.7362492376662703`*^9, 3.736249523636978*^9, 
   3.736250257513464*^9, 3.736251488973936*^9, 3.736253220184881*^9, 
   3.736259103834094*^9, 3.73625924990403*^9, 3.7362713790877733`*^9, 
   3.736272113675346*^9, 3.736293637019443*^9, 3.736294408056141*^9, 
   3.736295274106791*^9, 3.73629620401882*^9, 3.736462062090673*^9, 
   3.736531617869508*^9, 3.7365316567277946`*^9, {3.7365330772019997`*^9, 
   3.7365331483394537`*^9}, {3.736533241624836*^9, 3.736533276228815*^9}, 
   3.73660185043937*^9, 3.7366311545170527`*^9, 3.736632228074242*^9, 
   3.736638705373378*^9, 3.73672503618801*^9, 3.7367669443455763`*^9, 
   3.736767231862249*^9, 3.736775686817679*^9, 3.740840802328025*^9, 
   3.7409158895491133`*^9, 3.740962191651249*^9, 3.741002534201961*^9, 
   3.741435768622738*^9, 3.741523422046145*^9, 3.741525863862585*^9, 
   3.741526581517579*^9, 3.7415268986804123`*^9, 3.741527444821988*^9, 
   3.74152986953579*^9, 3.741690618859646*^9},
 CellLabel->"Out[411]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"f559ed7b-d4d6-418d-8c9f-bde719b51a2a"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r = \"\>", "\[InvisibleSpace]", "0.9973262403785221`"}],
  SequenceForm["r = ", 0.9973262403785221],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.73542569970583*^9, 3.736000189763381*^9, 3.736001722661662*^9, 
   3.736068006140327*^9, 3.736249237794592*^9, 3.736249523768631*^9, 
   3.73625025762964*^9, 3.736251489140732*^9, 3.7362532203518553`*^9, 
   3.736259103967874*^9, 3.73625925031986*^9, 3.7362713791883163`*^9, 
   3.736272113884128*^9, 3.73629363719707*^9, 3.7362944081888027`*^9, 
   3.736295274249386*^9, 3.736296204163766*^9, 3.736462062757862*^9, 
   3.7365316180764637`*^9, 3.736531656863339*^9, {3.73653307766179*^9, 
   3.7365331487787123`*^9}, {3.7365332418409157`*^9, 3.7365332763750877`*^9}, 
   3.73660185080326*^9, 3.736631154651142*^9, 3.736632228220337*^9, 
   3.736638705448513*^9, 3.736725036760631*^9, 3.736766944640503*^9, 
   3.73676723198141*^9, 3.736775686939855*^9, 3.740840802633141*^9, 
   3.740915889651339*^9, 3.740962191746869*^9, 3.7410025343017*^9, 
   3.7414357687303543`*^9, 3.741523422129071*^9, 3.741525863995987*^9, 
   3.741526581616705*^9, 3.741526898780065*^9, 3.7415274449137573`*^9, 
   3.741529869611558*^9, 3.741690618870805*^9},
 CellLabel->
  "During evaluation of \
In[408]:=",ExpressionUUID->"725f226f-67cb-4c9e-9eb5-1cf04aa54af3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"r^2 = \"\>", "\[InvisibleSpace]", "0.9946596297475577`"}],
  SequenceForm["r^2 = ", 0.9946596297475577],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.73542569970583*^9, 3.736000189763381*^9, 3.736001722661662*^9, 
   3.736068006140327*^9, 3.736249237794592*^9, 3.736249523768631*^9, 
   3.73625025762964*^9, 3.736251489140732*^9, 3.7362532203518553`*^9, 
   3.736259103967874*^9, 3.73625925031986*^9, 3.7362713791883163`*^9, 
   3.736272113884128*^9, 3.73629363719707*^9, 3.7362944081888027`*^9, 
   3.736295274249386*^9, 3.736296204163766*^9, 3.736462062757862*^9, 
   3.7365316180764637`*^9, 3.736531656863339*^9, {3.73653307766179*^9, 
   3.7365331487787123`*^9}, {3.7365332418409157`*^9, 3.7365332763750877`*^9}, 
   3.73660185080326*^9, 3.736631154651142*^9, 3.736632228220337*^9, 
   3.736638705448513*^9, 3.736725036760631*^9, 3.736766944640503*^9, 
   3.73676723198141*^9, 3.736775686939855*^9, 3.740840802633141*^9, 
   3.740915889651339*^9, 3.740962191746869*^9, 3.7410025343017*^9, 
   3.7414357687303543`*^9, 3.741523422129071*^9, 3.741525863995987*^9, 
   3.741526581616705*^9, 3.741526898780065*^9, 3.7415274449137573`*^9, 
   3.741529869611558*^9, 3.741690618880822*^9},
 CellLabel->
  "During evaluation of \
In[408]:=",ExpressionUUID->"be6f5db8-c5d4-4a64-933f-41ad35fa6548"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics for paper", "Subsubsection",
 CellChangeTimes->{
  3.736776318321474*^9, {3.741529590509632*^9, 
   3.741529593497601*^9}},ExpressionUUID->"76618243-2f7d-46be-85d2-\
883be9bc60f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p3", ",", "p4", ",", "p8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p6", ",", "p7", ",", "p5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p2", ",", "SpanFromLeft", ",", "SpanFromLeft"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "900"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.736632334813952*^9, 3.7366377619023743`*^9, 3.736638138254583*^9, 
   3.73672546875056*^9, {3.736767069202591*^9, 3.7367671081079617`*^9}, {
   3.736767146503669*^9, 3.7367671467121887`*^9}},
 CellLabel->
  "In[416]:=",ExpressionUUID->"e2633c41-17b7-4d43-8c5d-e2d319f1d7ab"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {GrayLevel[0.85], EdgeForm[{Opacity[0.44099999999999995`], Thickness[
         Small]}], {}, 
         {GrayLevel[0.85], EdgeForm[{Opacity[0.44099999999999995`], Thickness[
          Small]}], RectangleBox[{-8.4, 0}, {-8.2, 0.0005},
           RoundingRadius->0], RectangleBox[{-8., 0}, {-7.8, 0.0005},
           RoundingRadius->0], RectangleBox[{-7.6, 0}, {-7.4, 0.0005},
           RoundingRadius->0], RectangleBox[{-7.2, 0}, {-7., 0.0005},
           RoundingRadius->0], RectangleBox[{-6.4, 0}, {-6.2, 0.0005},
           RoundingRadius->0], RectangleBox[{-6.2, 0}, {-6., 0.0005},
           RoundingRadius->0], RectangleBox[{-6., 0}, {-5.8, 0.002},
           RoundingRadius->0], RectangleBox[{-5.8, 0}, {-5.6, 0.001},
           RoundingRadius->0], RectangleBox[{-5.6, 0}, {-5.4, 0.001},
           RoundingRadius->0], RectangleBox[{-5.4, 0}, {-5.2, 0.002},
           RoundingRadius->0], RectangleBox[{-5.2, 0}, {-5., 0.003},
           RoundingRadius->0], RectangleBox[{-5., 0}, {-4.8, 0.0035},
           RoundingRadius->0], RectangleBox[{-4.8, 0}, {-4.6, 0.0025},
           RoundingRadius->0], RectangleBox[{-4.6, 0}, {-4.4, 0.0085},
           RoundingRadius->0], RectangleBox[{-4.4, 0}, {-4.2, 0.009},
           RoundingRadius->0], RectangleBox[{-4.2, 0}, {-4., 0.012},
           RoundingRadius->0], RectangleBox[{-4., 0}, {-3.8, 0.007},
           RoundingRadius->0], RectangleBox[{-3.8, 0}, {-3.6, 0.016},
           RoundingRadius->0], RectangleBox[{-3.6, 0}, {-3.4, 0.017},
           RoundingRadius->0], RectangleBox[{-3.4, 0}, {-3.2, 0.0255},
           RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3., 0.03},
           RoundingRadius->0], RectangleBox[{-3., 0}, {-2.8, 0.0495},
           RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.6, 0.0435},
           RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.4, 0.056},
           RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.2, 0.076},
           RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 0.101},
           RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 0.1265},
           RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.6, 0.1605},
           RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.4, 0.199},
           RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.2, 0.2575},
           RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 0.3365},
           RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 0.3655},
           RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.6, 0.544},
           RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.4, 0.673},
           RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.2, 0.8035},
           RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 1.065},
           
           RoundingRadius->
            0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-7.14, 0},
       Frame->True,
       FrameLabel->{{
          FormBox[
           StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\[CapitalDelta]G of folding (kcal/mol)\"", 13, StripOnInput -> 
            False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{-7, 0}, {0, 1}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {193.5, -155.18137409255002}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}], InsetBox[
      GraphicsBox[{
        {GrayLevel[0.85], EdgeForm[{Opacity[0.34299999999999997`], Thickness[
         Small]}], {}, 
         {GrayLevel[0.85], EdgeForm[{Opacity[0.34299999999999997`], Thickness[
          Small]}], RectangleBox[{-4.2, 0}, {-4., 0.001875},
           RoundingRadius->0], RectangleBox[{-3.8, 0}, {-3.6, 0.00125},
           RoundingRadius->0], RectangleBox[{-3.4, 0}, {-3.2, 0.0025},
           RoundingRadius->0], RectangleBox[{-3.2, 0}, {-3., 0.004375},
           RoundingRadius->0], RectangleBox[{-3., 0}, {-2.8, 0.004375},
           RoundingRadius->0], RectangleBox[{-2.8, 0}, {-2.6, 0.005625},
           RoundingRadius->0], RectangleBox[{-2.6, 0}, {-2.4, 0.005},
           RoundingRadius->0], RectangleBox[{-2.4, 0}, {-2.2, 0.0125},
           RoundingRadius->0], RectangleBox[{-2.2, 0}, {-2., 0.024375},
           RoundingRadius->0], RectangleBox[{-2., 0}, {-1.8, 0.025625},
           RoundingRadius->0], RectangleBox[{-1.8, 0}, {-1.6, 0.0325},
           RoundingRadius->0], RectangleBox[{-1.6, 0}, {-1.4, 0.05875},
           RoundingRadius->0], RectangleBox[{-1.4, 0}, {-1.2, 0.058125},
           RoundingRadius->0], RectangleBox[{-1.2, 0}, {-1., 0.09},
           RoundingRadius->0], RectangleBox[{-1., 0}, {-0.8, 0.095625},
           RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.6, 0.12125},
           RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.4, 0.15625},
           RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.2, 0.189375},
           RoundingRadius->0], RectangleBox[{-0.2, 0}, {0., 0.204375},
           RoundingRadius->0], RectangleBox[{0., 0}, {0.2, 0.23},
           RoundingRadius->0], RectangleBox[{0.2, 0}, {0.4, 0.248125},
           RoundingRadius->0], RectangleBox[{0.4, 0}, {0.6, 0.254375},
           RoundingRadius->0], RectangleBox[{0.6, 0}, {0.8, 0.295625},
           RoundingRadius->0], RectangleBox[{0.8, 0}, {1., 0.278125},
           RoundingRadius->0], RectangleBox[{1., 0}, {1.2, 0.29375},
           RoundingRadius->0], RectangleBox[{1.2, 0}, {1.4, 0.284375},
           RoundingRadius->0], RectangleBox[{1.4, 0}, {1.6, 0.27375},
           RoundingRadius->0], RectangleBox[{1.6, 0}, {1.8, 0.269375},
           RoundingRadius->0], RectangleBox[{1.8, 0}, {2., 0.251875},
           RoundingRadius->0], RectangleBox[{2., 0}, {2.2, 0.21},
           RoundingRadius->0], RectangleBox[{2.2, 0}, {2.4, 0.1875},
           RoundingRadius->0], RectangleBox[{2.4, 0}, {2.6, 0.183125},
           RoundingRadius->0], RectangleBox[{2.6, 0}, {2.8, 0.13875},
           RoundingRadius->0], RectangleBox[{2.8, 0}, {3., 0.12375},
           RoundingRadius->0], RectangleBox[{3., 0}, {3.2, 0.081875},
           RoundingRadius->0], RectangleBox[{3.2, 0}, {3.4, 0.07375},
           RoundingRadius->0], RectangleBox[{3.4, 0}, {3.6, 0.066875},
           RoundingRadius->0], RectangleBox[{3.6, 0}, {3.8, 0.053125},
           RoundingRadius->0], RectangleBox[{3.8, 0}, {4., 0.03875},
           RoundingRadius->0], RectangleBox[{4., 0}, {4.2, 0.0225},
           RoundingRadius->0], RectangleBox[{4.2, 0}, {4.4, 0.01625},
           RoundingRadius->0], RectangleBox[{4.4, 0}, {4.6, 0.01},
           RoundingRadius->0], RectangleBox[{4.6, 0}, {4.8, 0.008125},
           RoundingRadius->0], RectangleBox[{4.8, 0}, {5., 0.005},
           RoundingRadius->0], RectangleBox[{5., 0}, {5.2, 0.0025},
           RoundingRadius->0], RectangleBox[{5.2, 0}, {5.4, 0.001875},
           RoundingRadius->0], RectangleBox[{5.4, 0}, {5.6, 0.0025},
           RoundingRadius->0], RectangleBox[{5.6, 0}, {5.8, 0.000625},
           
           RoundingRadius->
            0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-4.2, 0},
       Frame->True,
       FrameLabel->{{
          FormBox[
           StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\[CapitalDelta]\[CapitalDelta]G of random mutations \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{-4, 6}, {0, 0.35}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {580.5, -155.18137409255002}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}], InsetBox[
      GraphicsBox[{
        {GrayLevel[0.85], EdgeForm[{Opacity[0.33599999999999997`], Thickness[
         Small]}], {}, 
         {GrayLevel[0.85], EdgeForm[{Opacity[0.33599999999999997`], Thickness[
          Small]}], RectangleBox[{-5.8, 0}, {-5.6, 0.000011447489222188897},
           RoundingRadius->0], 
          RectangleBox[{-5.4, 0}, {-5.2, 0.000022894978444377794},
           RoundingRadius->0], 
          RectangleBox[{-5.2, 0}, {-5., 0.000057237446110944485},
           RoundingRadius->0], 
          RectangleBox[{-5., 0}, {-4.8, 0.00010302740299970007},
           RoundingRadius->0], 
          RectangleBox[{-4.8, 0}, {-4.6, 0.00006868493533313338},
           RoundingRadius->0], 
          RectangleBox[{-4.6, 0}, {-4.4, 0.00019460731677721125},
           RoundingRadius->0], 
          RectangleBox[{-4.4, 0}, {-4.2, 0.0003090822089991002},
           RoundingRadius->0], 
          RectangleBox[{-4.2, 0}, {-4., 0.0006181644179982004},
           RoundingRadius->0], 
          RectangleBox[{-4., 0}, {-3.8, 0.0009844840731082452},
           RoundingRadius->0], 
          RectangleBox[{-3.8, 0}, {-3.6, 0.0016369909587730122},
           RoundingRadius->0], 
          RectangleBox[{-3.6, 0}, {-3.4, 0.0025298951181037463},
           RoundingRadius->0], 
          RectangleBox[{-3.4, 0}, {-3.2, 0.004132543609210192},
           RoundingRadius->0], 
          RectangleBox[{-3.2, 0}, {-3., 0.006628096259647371},
           RoundingRadius->0], 
          RectangleBox[{-3., 0}, {-2.8, 0.01121853943774512},
           RoundingRadius->0], 
          RectangleBox[{-2.8, 0}, {-2.6, 0.016782019199728923},
           RoundingRadius->0], 
          RectangleBox[{-2.6, 0}, {-2.4, 0.024234334683373895},
           RoundingRadius->0], 
          RectangleBox[{-2.4, 0}, {-2.2, 0.031469147871797276},
           RoundingRadius->0], 
          RectangleBox[{-2.2, 0}, {-2., 0.04712931312775169},
           RoundingRadius->0], 
          RectangleBox[{-2., 0}, {-1.8, 0.06677320463302784},
           RoundingRadius->0], 
          RectangleBox[{-1.8, 0}, {-1.6, 0.08924462597618464},
           RoundingRadius->0], 
          RectangleBox[{-1.6, 0}, {-1.4, 0.11660412521721611},
           RoundingRadius->0], 
          RectangleBox[{-1.4, 0}, {-1.2, 0.1477298484123477},
           RoundingRadius->0], 
          RectangleBox[{-1.2, 0}, {-1., 0.1908296453338889},
           RoundingRadius->0], 
          RectangleBox[{-1., 0}, {-0.8, 0.23635630997053417},
           RoundingRadius->0], 
          RectangleBox[{-0.8, 0}, {-0.6, 0.2914988655538181},
           RoundingRadius->0], 
          RectangleBox[{-0.6, 0}, {-0.4, 0.34762590521021025},
           RoundingRadius->0], 
          RectangleBox[{-0.4, 0}, {-0.2, 0.4014176570652759},
           RoundingRadius->0], 
          RectangleBox[{-0.2, 0}, {0., 0.46536333186042306},
           RoundingRadius->0], 
          RectangleBox[{0., 0}, {0.2, 0.46260448695787554},
           RoundingRadius->0], 
          RectangleBox[{0.2, 0}, {0.4, 0.40190989910183},
           RoundingRadius->0], 
          RectangleBox[{0.4, 0}, {0.6, 0.34486706030766273},
           RoundingRadius->0], 
          RectangleBox[{0.6, 0}, {0.8, 0.29027398420704387},
           RoundingRadius->0], 
          RectangleBox[{0.8, 0}, {1., 0.2378673785478631},
           RoundingRadius->0], 
          RectangleBox[{1., 0}, {1.2, 0.19090977775844423},
           RoundingRadius->0], 
          RectangleBox[{1.2, 0}, {1.4, 0.14896617724834413},
           RoundingRadius->0], 
          RectangleBox[{1.4, 0}, {1.6, 0.11718794716754774},
           RoundingRadius->0], 
          RectangleBox[{1.6, 0}, {1.8, 0.09038937489840353},
           RoundingRadius->0], 
          RectangleBox[{1.8, 0}, {2., 0.06762031883546982},
           RoundingRadius->0], 
          RectangleBox[{2., 0}, {2.2, 0.04617917152231001},
           RoundingRadius->0], 
          RectangleBox[{2.2, 0}, {2.4, 0.03220178718201737},
           RoundingRadius->0], 
          RectangleBox[{2.4, 0}, {2.6, 0.022860635976711226},
           RoundingRadius->0], 
          RectangleBox[{2.6, 0}, {2.8, 0.016564516904507335},
           RoundingRadius->0], 
          RectangleBox[{2.8, 0}, {3., 0.010314187789192197},
           RoundingRadius->0], 
          RectangleBox[{3., 0}, {3.2, 0.0064220414536479715},
           RoundingRadius->0], 
          RectangleBox[{3.2, 0}, {3.4, 0.004247018501432081},
           RoundingRadius->0], 
          RectangleBox[{3.4, 0}, {3.6, 0.002632922521103446},
           RoundingRadius->0], 
          RectangleBox[{3.6, 0}, {3.8, 0.001877388232438979},
           RoundingRadius->0], 
          RectangleBox[{3.8, 0}, {4., 0.0011676439006632676},
           RoundingRadius->0], 
          RectangleBox[{4., 0}, {4.2, 0.0005723744611094448},
           RoundingRadius->0], 
          RectangleBox[{4.2, 0}, {4.4, 0.0002861872305547224},
           RoundingRadius->0], 
          RectangleBox[{4.4, 0}, {4.6, 0.00019460731677721125},
           RoundingRadius->0], 
          RectangleBox[{4.6, 0}, {4.8, 0.00019460731677721125},
           RoundingRadius->0], 
          RectangleBox[{4.8, 0}, {5., 0.000057237446110944485},
           RoundingRadius->0], 
          RectangleBox[{5., 0}, {5.2, 0.000011447489222188897},
           RoundingRadius->0], 
          RectangleBox[{5.2, 0}, {5.4, 0.000011447489222188897},
           RoundingRadius->0], 
          RectangleBox[{5.4, 0}, {5.6, 0.00003434246766656669},
           
           RoundingRadius->
            0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-5.2, 0},
       Frame->True,
       FrameLabel->{{
          FormBox[
           StyleBox["\"Probability density\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\[CapitalDelta]\[CapitalDelta]G of fixed mutations \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{-5, 5}, {0, 0.5}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {967.5, -155.18137409255002}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}]}, {InsetBox[
      GraphicsBox[{{{}, {{}, 
          {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVWXc8V28Ufu2RQiQVGSEZpUJUupcKSUgaSFFCIiRR+emmRKi0jPaQkNmQ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            
            "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJxFxW0w03EcAPDlIVvyMKdFeTxZx0ltnZqn/l7oqIisG0PTxGnJw5m4CicP
l84L4TJd3EkvdC2r02pMeajOcu6kabdjhPOsZiM226xVL/b9vfjcxzs9LyHT
AofDxf7zfz45Y8pkchgwf/lWSKlMi/7zydGDr0InsD+kMWbQ+iek+Zd96HPE
4VVmKXrZcEz7Rm8P+3zTEq9v28GTwXQ3RZ8tTGkOujfRSYDxx9M4tA4b2KMq
ntxeaA3LRr+E87Is4RE53p8XuAeuoHqdVJmM/eYFbWGSIaUOZtauWAkrt+FI
drtWlLEBs+JlczrhGkyRVx19pZ6DbTltAp/qcViafCnK0NgCX/u9w4jAvmLm
7VJPnfadmoFpZOao3/sVeOtZ6Qjhjhq+SMP2riq34OcpBSE2sTp4sJHXY882
woKOpqjyJVyEeUXdpFypsYBrMPmCftcK1pzY724MtIE/B4j13FACTL/RZjnL
tYXT87AHP5/awWNlicLsFw4wboVena9yhCWPaJWLGiIc13Eb89c5waIJRj2H
6AzH1auD5kkHYAmHnJ9IJcF5EhejdehBWF6TFV11xgX2yk7wMya6ws1SXepr
1iF4IzmczLp7GN4XNd2paHCD6d3BNY08d7jkPHXnbJcHLGMvi6liT7god7e1
mOUFc8PofuNraHws/sdIjjesr7spcM5HK6VjZVcK0NKkx56qInRLhj/bqRxN
KYlZSGpAJ/Mfri2+Q8esb4kDe9AYhVlb3Is+IvIOIAyg1z925QQMoysmv6sL
FOhC9+DB3ml01tXWeqtZdMxSJrVpAU3a1HB7lGh8UEqkhRptKO53vrCJnjXe
fzulQY9H/Kr21aGHKuMZuQZ095CQLDKi+QRXrcmE/gujClCz
             "]]},
           Annotation[#, "Charting`Private`Tag$24623384#1"]& ]}, {}, {}}},
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Double mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\"", 13,
             StripOnInput -> False], TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"Sum of single mutant \[CapitalDelta]\[CapitalDelta]Gs \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{-4, 9}, {-4, 9}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {193.5, -465.54412227765005}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}], InsetBox[
      GraphicsBox[{{{}, {{}, 
          {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVVnk0FAofRWVL9RTa1ENJtIi8nq1+tG/SYolU9koLlddiKduzFQlNSNr1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            
            "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJxF1O0vFAAcwPG74xhxL7rO1tku7nba0fQwT3MqTDFjxSHWVbccye6mmTw1
mkZcoZuhOi21PBNJWapDXDqTTrFMGi4x5yHGdWd3nGrrfr8X333+g6/zxZTI
BBKBQAj/2z/j26SrOzvWvWb3GOku3C1UcbKWn76Jukx1DS6voYt2s08m1OiV
ZM/Yjn40l/2tN7EQlVWxyoYpaPV0UUqEjRXoMMI7xaGRQeVpXtAQ2xIM4bDT
WEwL0LeVX6c6SAINtxKpRzhE8Le+puL8fgKoYJZ5dItNPWa55OsdbsItsNzf
2zsgxwDGP4idW6zeBFX1DBuiTAcy7J4d7unUgrZO8ypN0zooiiq419CwBgr6
p4cYZSsg86gp4n2eBmxM6lC/6ZwDkzfa+bdlatA9lxxnxZoEqVljuyqrRsFx
oci1bXYAzMh2LR2saAWb7vj41xx6etxs6eW8r4IbH0B7bRi3JWIUnEkb8EjP
nwR/dYX3ZSjVYF3hY4FQMgeydc3UzCoNOPV8n5ybtAJG350pWpKugQ9ri+Vh
leug5VnxCjlLC34SNNZH5uvAl/b0c3rRJugic16wDjOAhvT87WbeFrhkcKQ0
+JjAR5cKxxxZBH+z0oCPxXvZRJCS0hzYTyOB3UGv5J10C3BbfMErhmIJEq2/
3HfbRr1CUvtCCVag4XvLAm0dDRIppeE6tMQ461NgQJ3ojhItyRoMPiPhjFLR
8s8JyVJP1H2AsWybhWZG+5YH5qDvfkb7ZeehURYlxRoJes3feEApQ5Wvx8UF
b9HdoRs0eS/Kn6B0axXoqv4ERTiMOni+aA2cQgUKVUz2D7SRt2Rqn0f9Upmn
nFfRm8Rj+tgNdEQaVy3Vo3Snq8FKI/r/W+AfYipULQ==
             "]]},
           Annotation[#, "Charting`Private`Tag$24626533#1"]& ]}, {}, {}}},
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Single mutant \[CapitalDelta]\[CapitalDelta]G background 2\"", 
            13, StripOnInput -> False], TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"Single mutant \[CapitalDelta]\[CapitalDelta]G background 1\"", 
            13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{-3, 3}, {-3, 3}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {580.5, -465.54412227765005}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}], InsetBox[
      GraphicsBox[{{{}, {{}, 
          {GrayLevel[0], PointSize[Small], AbsoluteThickness[1.6], Opacity[
           0.3], PointBox[CompressedData["
1:eJwcm3k0ld/bxs85jnkskaS+miQiqYhw71BExhKppEJCKZnSpIEkCRkqUoaU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            
            "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJxFxX0w03EcAOCZbWymNWEn3eXl7HTsOpzVvGSdnF+Y3YaTuOtyrXOuQziU
lC62K91yCTHruopoiavzUqgV2R1ZS3GVOkq2Zi4va5mX86v+2Of7x3OPd2au
WEIkEAiCf/6/rlX8wHGG2vab1cD5njW00uv5Yq4Zzc+fWZ/Wo6Vufkz1GJqZ
8SiyXIH2N6rrCPvQqfZ6zC5nG+w0Ij8R/IwOszurPh3ydYKbpaEa8Q0qXLoY
eap61gHuLW7M7hBS4MTrKV5bDSQ4VjmQiC0Q4RbNmcmCdDu433FPwC0R/sL2
hpqSwWJvwnjagfMy2hr8hBXCSFVZYK6rTmysXIHHs5Np3bxf8MucfpFMZoCF
S4VbX7Fv8NkiIdNAnoD9GA9neK/UcLK4b3IA64qy3cZJcL/9ehwur8IWyOJp
OCGg1b64SA/zaqZUEt0C/LapfX9I5TIsiu8M/DD3Gyb10XIe062wA6WVH1S8
AcfkmbyfvtuCPwui/aPWCHzbPFGwY76KCAeFjskH+SRY49/X5KElw+Qrceao
Mgd4arRyqYJBhdNKM7mNgzQ4z8nkoz1Kh31Vw3WUeWf4Qm90EkPBgMOSuOmK
+u2w40XPoPp8JtzMfRBXe9gFln+R9/i47IDjeUPYTRM6WSrkKLtd4cD0ipR7
ZW7wRz31Tk2KO6zLnDvospsFz5LuW2t90H9asjo82GhPk2mXNwd9smBldW84
euMS3i5IRbObPXZevobmxU7p6DXoBGOTrLoOfZrjZalXovu72LoWFVo8HCId
0qAlWZYIbBRdQusxj2rRysSw4+8n0D8n+RHfZ9HrJUSzxIB29hxqM86jg4/F
spaX0TF2VG2hBX3k7kiF1YrOjrkafm4TXWYQrOA4+i88TTkH
             "]]},
           Annotation[#, "Charting`Private`Tag$24626922#1"]& ]}, {}, {}}},
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Single mutant \\!\\(\\*SubscriptBox[\\(\[CapitalDelta]\
\[CapitalDelta]G\\), \\(add\\)]\\) (kcal/mol)\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"Single mutant \[CapitalDelta]\[CapitalDelta]G (kcal/mol)\"", 13,
             StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{-4, 6}, {-4, 6}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {967.5, -465.54412227765005}, 
      ImageScaled[{0.5, 0.5}], {360., 288.70953319544185}]}, {InsetBox[
      GraphicsBox[{{{{}, {}, 
          TagBox[
           {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[{{-15., -15.}, {5., 5.}}]},
           
           Annotation[#, 
            "Charting`Private`Tag$24591276#1"]& ]}, {}, {}}, {{}, {{}, 
          {GrayLevel[0], PointSize[0.0055000000000000005`], AbsoluteThickness[
           1.6], PointBox[CompressedData["
1:eJwdW3k8Ft8XHkuyFQlJKgkhla9shUhZkj3JVpaQoixJKstUkkQJ2bNlDWXL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            
            "]]}, {}}, {}, {}, {}, {}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0.5], Thickness[Large], Opacity[1.], 
            Dashing[{Small, Small}], 
            LineBox[{{-3.8592920728393496`, -3.879741159875861}, \
{-3.4944537365989685`, -3.5826694103485397`}, {-2.886389842865, \
-3.027953545785544}, {-0.45413426792912404`, -0.716600491838193}, {
             0.27779954723859523`, 0.}}], 
            LineBox[{{-3.8592920728393496`, -3.838842985802838}, \
{-3.4944537365989685`, -3.4062380628493973`}, {-2.886389842865, \
-2.744826139944456}, {-0.45413426792912404`, -0.19166804402005505`}, \
{-0.2663990986997463, 0.}}]},
           Annotation[#, "Charting`Private`Tag$24591359#1"]& ]}, {}, {}}},
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"\[CapitalDelta]G (kcal/mol)\"", 13, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]G\\), \\(add\\)]\\) \
(kcal/mol)\"", 13, StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->FrontEndValueCache[{{Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
          Automatic, {{-15., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {-10., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {-5., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {5., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {-14., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-13., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-12., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-11., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-9., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-8., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-7., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-6., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-4., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-3., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {3., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {4., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}, {Automatic, {{-10., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {10., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {20., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {30., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {40., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {-20., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-18., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-16., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-14., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-12., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-8., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-6., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-4., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {-2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {4., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {6., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {8., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {12., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {14., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {16., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {18., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {22., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {24., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {26., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {28., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {32., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {34., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {36., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {38., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}}],
       GridLines->{{{0, 
           Directive[
            GrayLevel[0.05]]}}, {{0, 
           Directive[
            GrayLevel[0.05]]}}},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       Method->{
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{-15, 40}, {-15, 5}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {580.5, -775.90687046275}, 
      ImageScaled[{0.5, 0.5}], {1134., 288.70953319544185}], {}, {}}}, {}},
  ContentSelectable->True,
  ImageSize->900,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.741002534995282*^9, 3.741435769474448*^9, 
  3.74152342271453*^9, 3.741525864617259*^9, 3.741526582203508*^9, 
  3.741526899410845*^9, 3.741527445599113*^9, 3.741529596387257*^9, 
  3.741529870667555*^9, 3.741690621775144*^9},
 CellLabel->"Out[416]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"b2819940-1729-48eb-8f57-737eb2b216bc"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expected sample variance", "Section",
 CellChangeTimes->{{3.7367020801054697`*^9, 
  3.736702105485073*^9}},ExpressionUUID->"41f16578-bbcd-4894-bebc-\
b417a1137ae8"],

Cell[CellGroupData[{

Cell["Sequence space: 400 loci; 20 amino acids.", "Subsection",
 CellChangeTimes->{{3.735998610959505*^9, 
  3.735998637049609*^9}},ExpressionUUID->"85f57c3e-496d-415b-8173-\
e6f911f6852d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"l", "=", "400"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alpha", "=", "20"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"Range", "[", 
    RowBox[{"0", ",", 
     RowBox[{"alpha", "-", "1"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.717670727741705*^9, 3.717670758653535*^9}, {
   3.717755766286398*^9, 3.7177557690956583`*^9}, {3.7177559338168383`*^9, 
   3.717755934051709*^9}, {3.71775780727096*^9, 3.7177578098712187`*^9}, 
   3.7177582500526123`*^9, 3.717758977003735*^9, {3.717759266861182*^9, 
   3.717759267428767*^9}, {3.7177593582626963`*^9, 3.717759360448138*^9}, {
   3.717759451073578*^9, 3.717759451759461*^9}, {3.717759535546482*^9, 
   3.7177595378953648`*^9}, {3.717759691297868*^9, 3.717759691531331*^9}, {
   3.717761457737994*^9, 3.717761479665387*^9}, 3.717761953427936*^9, {
   3.717767691074654*^9, 3.717767691630986*^9}, {3.717767832250927*^9, 
   3.717767832720751*^9}, {3.717768751511504*^9, 3.717768752094515*^9}, {
   3.717772312591278*^9, 3.717772312781801*^9}, {3.7177743055064373`*^9, 
   3.717774308483384*^9}, {3.717775178564692*^9, 3.717775178760976*^9}, {
   3.717775347064378*^9, 3.71777534728085*^9}, {3.7177754344246197`*^9, 
   3.717775437071499*^9}, {3.717777658581249*^9, 3.717777658847302*^9}, {
   3.7177783388762836`*^9, 3.717778339290881*^9}, 3.717779230448475*^9, 
   3.717783863144587*^9, 3.717784223686734*^9, {3.7359972350218697`*^9, 
   3.735997235465951*^9}},ExpressionUUID->"cb51f225-8389-4ada-a609-\
449e1f1d1ee3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"alpha", "^", "l"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Log10", "@", "%"}], " ", "//", "N"}]}], "Input",
 CellChangeTimes->{{3.730031692132732*^9, 3.730031693345459*^9}, {
   3.735997256557901*^9, 3.73599726692633*^9}, 
   3.735999082062578*^9},ExpressionUUID->"cf64c5f3-5885-4ab7-9fd7-\
cf9fe556af4c"],

Cell[BoxData["520.4119982655925`"], "Output",
 CellChangeTimes->{
  3.730031693680377*^9, {3.7359972443689003`*^9, 3.735997267275536*^9}, 
   3.735999082450927*^9},ExpressionUUID->"41427d9e-578e-4f5d-ab89-\
f574e9dc95b9"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions", "Subsection",
 CellChangeTimes->{{3.7359986458027983`*^9, 
  3.735998648014771*^9}},ExpressionUUID->"5eadfe9e-8d0e-4a07-8995-\
1d03f9b481ed"],

Cell[CellGroupData[{

Cell["Krawchouk polynomial", "Subsubsection",
 CellChangeTimes->{{3.735998650229087*^9, 3.735998660163167*^9}},
 FontSize->18,ExpressionUUID->"d55539c8-0c5d-4a5b-9410-b34246456e49"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"w", "[", 
    RowBox[{"k_", ",", "d_"}], "]"}], ":=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"q", "=", "0"}], 
     RowBox[{"Min", "[", 
      RowBox[{"k", ",", "d"}], "]"}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"alpha", "^", 
       RowBox[{"(", 
        RowBox[{"-", "l"}], ")"}]}], ")"}], "  ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "q"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"alpha", "-", "1"}], ")"}], 
      RowBox[{"k", "-", "q"}]], 
     RowBox[{"Binomial", "[", 
      RowBox[{"d", ",", "q"}], "]"}], 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"l", "-", "d"}], ",", 
       RowBox[{"k", "-", "q"}]}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.717669692165331*^9, {3.7176712809945927`*^9, 3.7176712829679813`*^9}, 
   3.71775640951001*^9, {3.729853770457546*^9, 3.72985377807736*^9}, {
   3.729853831809708*^9, 
   3.72985383771169*^9}},ExpressionUUID->"87299e97-955e-4691-bd76-\
fadd73ee89b7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
N(d,d\[CloseCurlyQuote]): number of genotypes at d\[CloseCurlyQuote] to focal \
type which is at d to WT\
\>", "Subsubsection",
 CellChangeTimes->{{3.7176709194320927`*^9, 3.717670971787402*^9}, {
  3.717757653099289*^9, 3.717757718994488*^9}, {3.73599867734767*^9, 
  3.7359987150180387`*^9}, {3.735999207886245*^9, 3.735999222804105*^9}, {
  3.735999256207159*^9, 3.735999257098791*^9}},
 FontSize->18,ExpressionUUID->"2336b7a5-9d55-4b9f-82b6-4a1a70f82f3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Nd", "[", 
    RowBox[{"d0_", ",", "dx_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"alpha", "\[Equal]", "2"}], ",", 
     RowBox[{
      RowBox[{"Boole", "[", 
       RowBox[{"EvenQ", "[", "dx", "]"}], "]"}], "*", 
      RowBox[{"Binomial", "[", 
       RowBox[{"d0", ",", 
        RowBox[{"dx", "/", "2"}]}], "]"}], "*", 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{"l", "-", "d0"}], ",", 
        RowBox[{"dx", "/", "2"}]}], "]"}]}], ",", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"s", "=", "0"}], 
       RowBox[{"Min", "[", 
        RowBox[{"d0", ",", 
         RowBox[{"Floor", "[", 
          RowBox[{"dx", "/", "2"}], "]"}]}], "]"}]], 
      RowBox[{
       RowBox[{"Binomial", "[", 
        RowBox[{"d0", ",", "s"}], "]"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Binomial", "[", 
          RowBox[{
           RowBox[{"l", "-", "d0"}], ",", "s"}], "]"}], "*", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"alpha", "-", "1"}], ")"}], "s"]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Binomial", "[", 
          RowBox[{
           RowBox[{"d0", "-", "s"}], ",", 
           RowBox[{"dx", "-", 
            RowBox[{"2", "s"}]}]}], "]"}], "*", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"alpha", "-", "2"}], ")"}], 
          RowBox[{"dx", "-", 
           RowBox[{"2", "s"}]}]]}], ")"}]}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.717670122387937*^9, 3.717670137374436*^9}, {
   3.717670178615444*^9, 3.7176701881275167`*^9}, {3.7176702563487377`*^9, 
   3.717670411524596*^9}, 3.717670448578582*^9, 3.71767078111933*^9, {
   3.7177559226293697`*^9, 3.717755925469337*^9}, {3.7177561859272833`*^9, 
   3.7177561889881268`*^9}, {3.717758214703203*^9, 3.717758218667903*^9}, {
   3.717758369309272*^9, 3.717758369716612*^9}, {3.717758613247785*^9, 
   3.717758660582608*^9}, {3.7177589030382023`*^9, 3.717758917794209*^9}, {
   3.7177589566266823`*^9, 3.717758971047765*^9}, 3.717759094449156*^9, {
   3.7177675341295977`*^9, 3.717767538584354*^9}, 3.730031412318553*^9, {
   3.735999224925724*^9, 
   3.735999225865882*^9}},ExpressionUUID->"0e6e0fcc-010e-4f52-a6ca-\
75fcdec7bfa4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
SigmaMean: Mean covariance between genotypes that are at Hamming distance d \
to WT\
\>", "Subsubsection",
 CellChangeTimes->{{3.7359987555806093`*^9, 3.735998804216975*^9}, {
  3.735999259051598*^9, 3.735999260688925*^9}},
 FontSize->18,ExpressionUUID->"b9d024c0-520f-4559-9114-413fe301c52a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmamean", "[", 
    RowBox[{"d0_", ",", "k_", ",", "sigmaA_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["sigmaA", 
     RowBox[{
      RowBox[{
       RowBox[{"Binomial", "[", 
        RowBox[{"l", ",", "d0"}], "]"}], "*", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"alpha", "-", "1"}], ")"}], "^", "d0"}]}], "-", "1"}]], 
    RowBox[{"(", 
     RowBox[{"Total", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Nd", "[", 
          RowBox[{"d0", ",", "dx"}], "]"}], "*", 
         RowBox[{"w", "[", 
          RowBox[{"k", ",", "dx"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"dx", ",", "1", ",", 
          RowBox[{"2", "d0"}]}], "}"}]}], "]"}], "]"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.717671115052485*^9, 3.717671172711791*^9}, {
   3.717671384535552*^9, 3.717671459752172*^9}, 3.7176716129106092`*^9, {
   3.7176717519639397`*^9, 3.71767176193795*^9}, {3.7176718230404882`*^9, 
   3.7176718235139437`*^9}, {3.7177560799249477`*^9, 3.717756081203288*^9}, {
   3.7177635599337873`*^9, 3.7177635669087353`*^9}, {3.717764861714169*^9, 
   3.717764864018264*^9}, {3.736100301686366*^9, 3.7361003018206043`*^9}, {
   3.736100935247257*^9, 3.736100935378481*^9}, {3.736100975761136*^9, 
   3.736100980645513*^9}, {3.736101865361998*^9, 3.736101882438547*^9}, {
   3.736101930288507*^9, 3.736101941768241*^9}, {3.736102098083618*^9, 
   3.7361021055324697`*^9}, {3.736102176067143*^9, 3.736102203846374*^9}, {
   3.73610638220919*^9, 
   3.736106387580371*^9}},ExpressionUUID->"a076c1e2-1c01-47a4-84fc-\
90464c0e514d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
SigmaSquredMean: Mean variance of genotypes (independent of d, due to random \
field assumption)\
\>", "Subsubsection",
 CellChangeTimes->{{3.735998807973833*^9, 3.7359988581583147`*^9}},
 FontSize->18,ExpressionUUID->"d12aa902-891f-467b-9e55-315906372c62"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmasqmean", "[", 
    RowBox[{"k_", ",", "sigmaA_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"alpha", "^", 
     RowBox[{"(", 
      RowBox[{"-", "l"}], ")"}]}], "  ", 
    RowBox[{"Binomial", "[", 
     RowBox[{"l", ",", "k"}], "]"}], "*", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"alpha", "-", "1"}], ")"}], "k"], "*", "sigmaA"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.717671585375497*^9, 3.717671654713111*^9}, {
   3.717671707733324*^9, 3.717671728123906*^9}, {3.7176718808791723`*^9, 
   3.7176719263162537`*^9}, 3.7176725325151043`*^9, {3.717673406514697*^9, 
   3.7176734066801977`*^9}, {3.717764878641025*^9, 3.7177648800156403`*^9}, {
   3.729853817442254*^9, 3.729853826888797*^9}, 3.73599800302931*^9, 
   3.7361066923130503`*^9},ExpressionUUID->"e3ce3223-e921-4286-9c99-\
3792cf5c8bd2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmasqmean", "[", 
   RowBox[{"2", ",", "1"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.7361061829516563`*^9, 
  3.736106189505254*^9}},ExpressionUUID->"8db165ac-7841-4511-b23a-\
7cb5d9833e93"],

Cell[BoxData["1.1156085336459619093968726287758656675443336044`15.\
954589770191005*^-513"], "Output",
 CellChangeTimes->{{3.736106185837449*^9, 
  3.736106189804604*^9}},ExpressionUUID->"a9139eae-b9db-4ddc-b747-\
2a97da8bb043"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Binomial", "[", 
   RowBox[{"l", ",", "2"}], "]"}], "*", ".001"}]], "Input",
 CellChangeTimes->{{3.736106249127565*^9, 
  3.736106256593939*^9}},ExpressionUUID->"c306862d-6360-443f-946b-\
26251c8d1810"],

Cell[BoxData["79.8`"], "Output",
 CellChangeTimes->{{3.736106254556118*^9, 
  3.7361062569764557`*^9}},ExpressionUUID->"31a8033a-f491-4864-a349-\
26dd2d4caf45"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pairwise epistasis", "Subsection",
 CellChangeTimes->{{3.735998067989347*^9, 3.735998084209803*^9}, {
  3.735999283623279*^9, 3.735999284314618*^9}, {3.736104457678712*^9, 
  3.736104465043292*^9}},ExpressionUUID->"5aad7646-d516-4b28-bde3-\
8031eb556793"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sA", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Binomial", "[", 
       RowBox[{"l", ",", "2"}], "]"}], "*", ".001"}], ")"}], "/", 
    RowBox[{"sigmasqmean", "[", 
     RowBox[{"2", ",", "1"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.736106426077544*^9, 3.7361064331822243`*^9}, {
   3.736106516356943*^9, 3.736106540765676*^9}, 
   3.736106695456822*^9},ExpressionUUID->"39d2d7a1-b4c4-4ede-9d91-\
5678cc5fb5a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sigmameanPairwise", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"sigmamean", "[", 
       RowBox[{"d0", ",", "2", ",", "sA"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"d0", ",", "1", ",", "l"}], "}"}]}], "]"}]}], ";"}], "//", 
  "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{{3.735997366496626*^9, 3.7359974219645*^9}, {
   3.735998032259674*^9, 3.7359980349602823`*^9}, {3.736098409709125*^9, 
   3.7360984167856617`*^9}, 3.736098880024302*^9, 3.7361045092805243`*^9, {
   3.73610641337747*^9, 3.7361064186251993`*^9}, 
   3.736106554789098*^9},ExpressionUUID->"9efbaf4b-8aea-4986-ab6a-\
1d8f0e5b60f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"263.286505`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.736098701395033*^9, 3.736102575525466*^9, 
  3.736103185036069*^9},ExpressionUUID->"69602860-08fe-4f15-9612-\
8c83ec86c41d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExpectedSampleVariancePairWise", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"1", "-", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Binomial", "[", 
           RowBox[{"l", ",", "d"}], "]"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"alpha", "-", "1"}], ")"}], "^", "d"}]}], ")"}]}]}], ",", 
      
      RowBox[{"{", 
       RowBox[{"d", ",", "1", ",", "l"}], "}"}]}], "]"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"sigmasqmean", "[", 
       RowBox[{"2", ",", "sigmaA"}], "]"}], "-", "sigmameanPairwise"}], 
     ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.735998448190694*^9, 3.735998454800427*^9}, {
   3.735998549084716*^9, 3.735998560568119*^9}, {3.7360979995191917`*^9, 
   3.7360980027708797`*^9}, {3.7360980568172283`*^9, 3.736098090946375*^9}, {
   3.7360981811913977`*^9, 3.7360982134883347`*^9}, {3.736098265405019*^9, 
   3.7360982676897917`*^9}, {3.736098721627089*^9, 3.736098725375885*^9}, 
   3.736098812338365*^9, 3.736098889032218*^9, {3.736102691505692*^9, 
   3.736102695150629*^9}},ExpressionUUID->"f2a13650-abb7-48c0-8234-\
e1ae368486ec"],

Cell[CellGroupData[{

Cell[BoxData["ExpectedSampleVariancePairWise"], "Input",ExpressionUUID->"cf16a1cd-ddf0-4409-8a9e-884eb9d6829f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.83778947368421049647693109661185923045`15.954589770191005", ",", 
   "1.66896513988526377886232991845737247921`15.954589770191005", ",", 
   "2.4935618968154572668346305373057946847`15.954589770191005", ",", 
   "3.31161455037598588722825582515976458398`15.954589770191005", ",", 
   "4.12315781415694207403361745425530471268`15.954589770191005", ",", 
   "4.92822630943731576839711589706182140505`15.954589770191005", ",", 
   "5.72685456518499441862114042628210479394`15.954589770191005", ",", 
   "6.51907701805676298016406911485232881079`15.954589770191005", ",", 
   "7.30492801239830391564026883594205118567`15.954589770191005", ",", 
   "8.08444180024419719482009526295421344721`15.954589770191005", ",", 
   "8.85765254131792029462989286952514092269`15.954589770191005", ",", 
   "9.62459430303184819915199492952454273796`15.954589770191005", ",", 
   "10.38530106048725339962472351705551181747`15.954589770191005", ",", 
   "11.1398066964743058944423895064545248843`15.954589770191005", ",", 
   "11.88814500147207318915529257229144246011`15.954589770191005", ",", 
   "12.63034967364852029646972118936950886516`15.954589770191005", ",", 
   "13.36645431886050973624795263272535221833`15.954589770191005", ",", 
   "14.09649245065380153550825297762898443708`15.954589770191005", ",", 
   "14.8204974902630532284248770995838012375`15.954589770191005", ",", 
   "15.53850276661181985632806867432658213425`15.954589770191005", ",", 
   "16.25054151631255396770406017782749044062`15.954589770191005", ",", 
   "16.95664688366660561819507288629007326848`15.954589770191005", ",", 
   "17.65685192066422237059931687615126152833`15.954589770191005", ",", 
   "18.35118958698454929487099102408136992924`15.954589770191005", ",", 
   "19.0396927499956289681202830069840969789`15.954589770191005", ",", 
   "19.7223941847544014746133693019965249836`15.954589770191005", ",", 
   "20.39932657400670440577241518648912004823`15.954589770191005", ",", 
   "21.0705225081872728601755747380657320763`15.954589770191005", ",", 
   "21.73601448541973944355699083456359476988`15.954589770191005", ",", 
   "22.39583491151663426880679515405332562968`15.954589770191005", ",", 
   "23.05001609997938495597110817483892595501`15.954589770191005", ",", 
   "23.69859027199831663225203917545778084376`15.954589770191005", ",", 
   "24.34158955645265193200768623468065919244`15.954589770191005", ",", 
   "24.97904598991051099675213623151171369615`15.954589770191005", ",", 
   "25.61099151662891147515546484518848084861`15.954589770191005", ",", 
   "26.23745798855376852304373655518188094213`15.954589770191005", ",", 
   "26.85847716531989480339900464119621806762`15.954589770191005", ",", 
   "27.47408071425100048635931118316918011459`15.954589770191005", ",", 
   "28.08430021035969324921868706127183877117`15.954589770191005", ",", 
   "28.68916713634747827642715195590864952407`15.954589770191005", ",", 
   "29.28871288260475825959071434771745165862`15.954589770191005", ",", 
   "29.88296874721083339747137151756946825874`15.954589770191005", ",", 
   "30.47196593593390139598710954656930620696`15.954589770191005", ",", 
   "31.0557355622310574682119033160549561844`15.954589770191005", ",", 
   "31.63430864724829433437571650759779267081`15.954589770191005", ",", 
   "32.20771611982050222186450160300257394451`15.954589770191005", ",", 
   "32.77598881647146886522019988430744208243`15.954589770191005", ",", 
   "33.33915748141387950614074143378392296012`15.954589770191005", ",", 
   "33.89725276654931689348004513393692625171`15.954589770191005", ",", 
   "34.45030523146826128324801866750474542995`15.954589770191005", ",", 
   "34.99834534345009043861055851745905776619`15.954589770191005", ",", 
   "35.54140347746307962988954996700492433036`15.954589770191005", ",", 
   "36.07950991616440163456286709958078999102`15.954589770191005", ",", 
   "36.61269484990012673726437279885848341532`15.954589770191005", ",", 
   "37.14098837670522272978391874874321706901`15.954589770191005", ",", 
   "37.66442050230355491106734543337358721645`15.954589770191005", ",", 
   "38.18302114010788608721648213712157392059`15.954589770191005", ",", 
   "38.696820111219876571489146944592541043`15.954589770191005", ",", 
   "39.20584714443008418429914674062523624383`15.954589770191005", ",", 
   "39.71013187621796425321627721029179098186`15.954589770191005", ",", 
   "40.20970385075186961296632283889772051443`15.954589770191005", ",", 
   "40.70459251988905060543105691198192389754`15.954589770191005", ",", 
   "41.19482724317565507964824151531668398575`15.954589770191005", ",", 
   "41.68043728784672839181162753490766743222`15.954589770191005", ",", 
   "42.16145182882621340527095465699392468874`15.954589770191005", ",", 
   "42.63789994872695049053195136804789000568`15.954589770191005", ",", 
   "43.10981063785067752525633495477538143202`15.954589770191005", ",", 
   "43.57721279418802989426181150411560081535`15.954589770191005", ",", 
   "44.04013522341854048952207590324113380184`15.954589770191005", ",", 
   "44.49860663891063971016681183955794983628`15.954589770191005", ",", 
   "44.95265566172165546248169180070540216207`15.954589770191005", ",", 
   "45.40231082059781315990837707455622782119`15.954589770191005", ",", 
   "45.84760055197423572304451774921654765424`15.954589770191005", ",", 
   "46.28855319997494357964375271302586630041`15.954589770191005", ",", 
   "46.72519701641285466461570965455707219749`15.954589770191005", ",", 
   "47.15756016078978442002600506261643758189`15.954589770191005", ",", 
   "47.58567070029644579509624422624361848861`15.954589770191005", ",", 
   "48.00955660981244924620402123471165475125`15.954589770191005", ",", 
   "48.42924577190630273688291897752697000203`15.954589770191005", ",", 
   "48.84476597683541173782250914442937167172`15.954589770191005", ",", 
   "49.25614492254607922686835222539205098979`15.954589770191005", ",", 
   "49.6634102146735056890219975106215829842`15.954589770191005", ",", 
   "50.06658936654178911644098309055792648159`15.954589770191005", ",", 
   "50.46570979916392500843883585587442410716`15.954589770191005", ",", 
   "50.86079884124180637148507149747780228475`15.954589770191005", ",", 
   "51.25188372916622371920519450650817123678`15.954589770191005", ",", 
   "51.63899160701686507238069817433902498425`15.954589770191005", ",", 
   "52.02214952656231595894906459257724134681`15.954589770191005", ",", 
   "52.40138444726005941400376465306308194267`15.954589770191005", ",", 
   "52.77672323625647597979425804787019218868`15.954589770191005", ",", 
   "53.14819266838684370572599326930560130026`15.954589770191005", ",", 
   "53.51581942617533814836040760990972229144`15.954589770191005", ",", 
   "53.87963009983503237141492716245635197486`15.954589770191005", ",", 
   "54.23965118726789694576296681995267096177`15.954589770191005", ",", 
   "54.595909094064799949433930275639243662`15.954589770191005", ",", 
   "54.948430133505506967613210022990018284`15.954589770191005", ",", 
   "55.2972405265586810926421873557123268348`15.954589770191005", ",", 
   "55.64236640188188292401823236774688512007`15.954589770191005", ",", 
   "55.98383379582157056839470395326779274404`15.954589770191005", ",", 
   "56.32166865241309963958094980668253310958`15.954589770191005", ",", 
   "56.65589682338072325854230642263197341814`15.954589770191005", ",", 
   "56.98654406813759205340009909599036466976`15.954589770191005", ",", 
   "57.31363605378575415943164192186534166312`15.954589770191005", ",", 
   "57.63719835511615521907023779559792299547`15.954589770191005", ",", 
   "57.95725645460863838190517841276251106267`15.954589770191005", ",", 
   "58.2738357424319443046817442691668920592`15.954589770191005", ",", 
   "58.58696151644371115130120466085223597811`15.954589770191005", ",", 
   "58.89665898219047459282081768409309661108`15.954589770191005", ",", 
   "59.20295325290766780745383023539741154838`15.954589770191005", ",", 
   "59.50586934951962148056947801150650217889`15.954589770191005", ",", 
   "59.80543220063956380469298550939507369008`15.954589770191005", ",", 
   "60.10166664256962047950556602627121506802`15.954589770191005", ",", 
   "60.3945974193008147118444216595763990974`15.954589770191005", ",", 
   "60.68424918251306721570274330698548236151`15.954589770191005", ",", 
   "60.97064649157519621222971066640670524222`15.954589770191005", ",", 
   "61.25381381354491742973049223598169192003`15.954589770191005", ",", 
   "61.53377552316884410366624531408545037402`15.954589770191005", ",", 
   "61.81055590288248697665411599932637238189`15.954589770191005", ",", 
   "62.08417914281025429846723919054623351993`15.954589770191005", ",", 
   "62.35466934076545182603473858682019316303`15.954589770191005", ",", 
   "62.62205050225028282344172668745679448469`15.954589770191005", ",", 
   "62.88634654045584806192930479199796445703`15.954589770191005", ",", 
   "63.14758127626214581989456300021901385073`15.954589770191005", ",", 
   "63.4057784382380718828905802121286372351`15.954589770191005", ",", 
   "63.66096166264141954362642412796891297805`15.954589770191005", ",", 
   "63.9131544934188796019671512482153032461`15.954589770191005", ",", 
   "64.16238038220604036493380687357665400434`15.954589770191005", ",", 
   "64.40866268832738764670342510499519501649`15.954589770191005", ",", 
   "64.65202467879630476860902884364653984488`15.954589770191005", ",", 
   "64.89248952831507255913962979093968585041`15.954589770191005", ",", 
   "65.13008031927486935394022844851701419261`15.954589770191005", ",", 
   "65.3648200417557709958118141182542898296`15.954589770191005", ",", 
   "65.59673159352675083471136490226066151811`15.954589770191005", ",", 
   "65.82583778004567972775184770287866181346`15.954589770191005", ",", 
   "66.05216131445932603920221822268420706958`15.954589770191005", ",", 
   "66.27572481760335564048742096448659743901`15.954589770191005", ",", 
   "66.49655081800233191018838923132851687287`15.954589770191005", ",", 
   "66.7146617518697157340420451264860331209`15.954589770191005", ",", 
   "66.93007996310786550494129955346859773144`15.954589770191005", ",", 
   "67.14282770330803712293505221601904605143`15.954589770191005", ",", 
   "67.35292713175038399522819161811359722642`15.954589770191005", ",", 
   "67.56040031540395703618159506396185420054`15.954589770191005", ",", 
   "67.76526922892670466731212865800680371654`15.954589770191005", ",", 
   "67.96755575466547281729264730492481631578`15.954589770191005", ",", 
   "68.16728168265600492195199470962564633819`15.954589770191005", ",", 
   "68.36446871062294192427500337725243192235`15.954589770191005", ",", 
   "68.5591384439798222744024946131816950054`15.954589770191005", ",", 
   "68.7513123958290819296312785230233413231`15.954589770191005", ",", 
   "68.9410119869620543544141540126206604098`15.954589770191005", ",", 
   "69.12825854585897052035990878805032559848`15.954589770191005", ",", 
   "69.31307330868895890623331935562239402069`15.954589770191005", ",", 
   "69.49547741931004549795515102188030660661`15.954589770191005", ",", 
   "69.67549192926915378860215789360088808499`15.954589770191005", ",", 
   "69.85313779780210477840708287779434698322`15.954589770191005", ",", 
   "70.02843589183361697475865768170427562726`15.954589770191005", ",", 
   "70.2014069859773063922016028128076501417`15.954589770191005", ",", 
   "70.3720717625356865524366275788148304497`15.954589770191005", ",", 
   "70.54045081150016848432043008766956027305`15.954589770191005", ",", 
   "70.70656463055106072386569724754896713212`15.954589770191005", ",", 
   "70.87043362505756931424110476686356234591`15.954589770191005", ",", 
   "71.032078108077797805771317154257241032`15.954589770191005", ",", 
   "71.19151830035874725593698771860728210658`15.954589770191005", ",", 
   "71.34877433033631622937475856902434828443`15.954589770191005", ",", 
   "71.50386623413530079787726061485248607895`15.954589770191005", ",", 
   "71.65681395556939454039311356566912580215`15.954589770191005", ",", 
   "71.8076373461411885430269259312850815646`15.954589770191005", ",", 
   "71.95635616504217139903929502174455127552`15.954589770191005", ",", 
   "72.1029900791527292088468069473251166427`15.954589770191005", ",", 
   "72.24755866304214558002203661853774317255`15.954589770191005", ",", 
   "72.39008139896860162729354774612678017008`15.954589770191005", ",", 
   "72.53057767687917597254589284106996073888`15.954589770191005", ",", 
   "72.66906679440984474481961321457840178118`15.954589770191005", ",", 
   "72.80556795688548158031123897809660399779`15.954589770191005", ",", 
   "72.94010027731985762237328904330245188812`15.954589770191005", ",", 
   "73.07268277641564152151427112210721375018`15.954589770191005", ",", 
   "73.2033343825643994353986817266555416806`15.954589770191005", ",", 
   "73.3320739318465950288470061693254715746`15.954589770191005", ",", 
   "73.458920168031589473835718562728423126`15.954589770191005", ",", 
   "73.58389174257764144949728181970919982723`15.954589770191005", ",", 
   "73.70700721463190714212014765334598896931`15.954589770191005", ",", 
   "73.82828505103044024514875657695036164188`15.954589770191005", ",", 
   "73.94774362629819195918353790406727273317`15.954589770191005", ",", 
   "74.06540122264901099198090974847506093001`15.954589770191005", ",", 
   "74.18127602998564355845327902418544871784`15.954589770191005", ",", 
   "74.2953861458997333806690414454435423807`15.954589770191005", ",", 
   "74.40774957567182168785258152672783200123`15.954589770191005", ",", 
   "74.51838423227134721638427258275019146067`15.954589770191005", ",", 
   "74.62730793635664620980047672845587843887`15.954589770191005", ",", 
   "74.73453841627495241879354487902353441427`15.954589770191005", ",", 
   "74.84009330806239710121181674986518466392`15.954589770191005", ",", 
   "74.94399015544400902205962085662623826351`15.954589770191005", ",", 
   "75.04624640983371445349727451518548808724`15.954589770191005", ",", 
   "75.14687943033433717484108384165511080799`15.954589770191005", ",", 
   "75.24590648373759847256334375238066689723`15.954589770191005", ",", 
   "75.343344744524117140292337963941100625`15.954589770191005", ",", 
   "75.43921129486340947881233899314874005998`15.954589770191005", ",", 
   "75.53352312461388929606360815704929706942`15.954589770191005", ",", 
   "75.6262971313228679071423955729218673192`15.954589770191005", ",", 
   "75.71755012022655413430094015827893027378`15.954589770191005", ",", 
   "75.80729880425005430694746963086634919624`15.954589770191005", ",", 
   "75.89555980400737226164620050866337114826`15.954589770191005", ",", 
   "75.98234964780140934211733810988262699009`15.954589770191005", ",", 
   "76.06768477162396439923707655297013138064`15.954589770191005", ",", 
   "76.15158151915573379103759875660528277738`15.954589770191005", ",", 
   "76.23405614176631138270707643970086343638`15.954589770191005", ",", 
   "76.31512479851418854658967012140303941234`15.954589770191005", ",", 
   "76.39480355614675416218552912109136055855`15.954589770191005", ",", 
   "76.47310838910029461615079155837876052688`15.954589770191005", ",", 
   "76.55005517949999380229758435311155676784`15.954589770191005", ",", 
   "76.62565971715993312159402322536945053052`15.954589770191005", ",", 
   "76.69993769958309148216421269546552686261`15.954589770191005", ",", 
   "76.77290473196134529928824608394625461042`15.954589770191005", ",", 
   "76.84457632717546849540220551159148641884`15.954589770191005", ",", 
   "76.91496790579513250009816189941445873137`15.954589770191005", ",", 
   "76.98409479607890625012417496866179179013`15.954589770191005", ",", 
   "77.05197223397425618938429324081348963581`15.954589770191005", ",", 
   "77.11861536311754626893855403758294010773`15.954589770191005", ",", 
   "77.1840392348340379470029834809169148438`15.954589770191005", ",", 
   "77.24825880813789018894959649299556928053`15.954589770191005", ",", 
   "77.31128894973215946730639679623244265304`15.954589770191005", ",", 
   "77.37314443400879976175737691327445799505`15.954589770191005", ",", 
   "77.43383994304866255914251816700192213887`15.954589770191005", ",", 
   "77.49339006662149685345779068052852571544`15.954589770191005", ",", 
   "77.55180930218594914585515337720134315426`15.954589770191005", ",", 
   "77.60911205488956344464255398060083268348`15.954589770191005", ",", 
   "77.66531263756878126528392901454083632983`15.954589770191005", ",", 
   "77.72042527074894163039920380306857991862`15.954589770191005", ",", 
   "77.77446408264428106976429247046467307379`15.954589770191005", ",", 
   "77.82744310915793362031109794124310921789`15.954589770191005", ",", 
   "77.87937629388193082612751194015126557205`15.954589770191005", ",", 
   "77.93027748809720173845741499216990315601`15.954589770191005", ",", 
   "77.98016045077357291570067642251316678811`15.954589770191005", ",", 
   "78.02903884856976842341315435662858508529`15.954589770191005", ",", 
   "78.07692625583340983430669572019707046311`15.954589770191005", ",", 
   "78.12383615460101622824913623913291913571`15.954589770191005", ",", 
   "78.16978193459800419226430043958381111584`15.954589770191005", ",", 
   "78.21477689323868782053200164793081021486`15.954589770191005", ",", 
   "78.25883423562627871438804199078836404272`15.954589770191005", ",", 
   "78.30196707455288598232421239500430400798`15.954589770191005", ",", 
   "78.34418843049951623998829258765984531779`15.954589770191005", ",", 
   "78.38551123163607361018405109606958697793`15.954589770191005", ",", 
   "78.42594831382135972287124524778151179276`15.954589770191005", ",", 
   "78.46551242060307371516562117057698636524`15.954589770191005", ",", 
   "78.50421620321781223133891379247076109693`15.954589770191005", ",", 
   "78.54207222059106942281884684171097018802`15.954589770191005", ",", 
   "78.57909293933723694818913284677913163728`15.954589770191005", ",", 
   "78.61529073375960397318947313639014724207`15.954589770191005", ",", 
   "78.65067788585035717071555783949230259839`15.954589770191005", ",", 
   "78.6852665852905807208190658852672671008`15.954589770191005", ",", 
   "78.71906892945025631070766500313009394249`15.954589770191005", ",", 
   "78.75209692338826313474501172272922011524`15.954589770191005", ",", 
   "78.78436247985237789445075137394646640944`15.954589770191005", ",", 
   "78.81587741927927479850051808689703741408`15.954589770191005", ",", 
   "78.84665346979452556272593479192952151676`15.954589770191005", ",", 
   "78.87670226721259941011461321962589090364`15.954589770191005", ",", 
   "78.90603535503686307081015390080150155955`15.954589770191005", ",", 
   "78.93466418445958078211214616650509326788`15.954589770191005", ",", 
   "78.96260011436191428847616814801878961062`15.954589770191005", ",", 
   "78.98985441131392284151378677685809796836`15.954589770191005", ",", 
   "79.01643824957456319999255778477190952034`15.954589770191005", ",", 
   "79.04236271109168962983602570374249924433`15.954589770191005", ",", 
   "79.06763878550205390412372386598552591676`15.954589770191005", ",", 
   "79.09227737013130530309117440395003211264`15.954589770191005", ",", 
   "79.11628926999399061412988825031844420557`15.954589770191005", ",", 
   "79.13968519779355413178736513800657236777`15.954589770191005", ",", 
   "79.16247577392233765776709360016361057006`15.954589770191005", ",", 
   "79.18467152646158050092855097017213658186`15.954589770191005", ",", 
   "79.20628289118141947728720338164811197119`15.954589770191005", ",", 
   "79.22732021154088891001450576844088210467`15.954589770191005", ",", 
   "79.24779373868792062943790186463317614753`15.954589770191005", ",", 
   "79.2677136314593439730408242045411070636`15.954589770191005", ",", 
   "79.28708995638088578546269412271417161531`15.954589770191005", ",", 
   "79.30593268766717041849892175393525036368`15.954589770191005", ",", 
   "79.32425170722171973110090603322060766836`15.954589770191005", ",", 
   "79.34205680463695308937603469581989168758`15.954589770191005", ",", 
   "79.35935767719418736658768427721613437818`15.954589770191005", ",", 
   "79.3761639298636369431552201131257514956`15.954589770191005", ",", 
   "79.39248507530441370665399633949854259389`15.954589770191005", ",", 
   "79.40833053386452705181535589251769102569`15.954589770191005", ",", 
   "79.42370963358088388052663050859976394225`15.954589770191005", ",", 
   "79.43863161017928860183114072439471229341`15.954589770191005", ",", 
   "79.45310560707444313192819587678587082764`15.954589770191005", ",", 
   "79.46714067536994689417309410288995809198`15.954589770191005", ",", 
   "79.48074577385829681907712234005707643209`15.954589770191005", ",", 
   "79.49392976902088734430755632587071199224`15.954589770191005", ",", 
   "79.50670143502801041468766059814773471527`15.954589770191005", ",", 
   "79.51906945373885548219668849493839834266`15.954589770191005", ",", 
   "79.53104241470150950596988215452634041447`15.954589770191005", ",", 
   "79.54262881515295695229847251542858226938`15.954589770191005", ",", 
   "79.55383706001907979462967931639552904464`15.954589770191005", ",", 
   "79.56467546191465751356671109641096967612`15.954589770191005", ",", 
   "79.57515224114336709686876519469207689832`15.954589770191005", ",", 
   "79.58527552569778303945102775068940724429`15.954589770191005", ",", 
   "79.59505335125937734338467370408690104572`15.954589770191005", ",", 
   "79.60449366119851951789686679480188243289`15.954589770191005", ",", 
   "79.61360430657447657937075956298505933469`15.954589770191005", ",", 
   "79.62239304613541305134549334902052347859`15.954589770191005", ",", 
   "79.63086754631839096451619829352575039069`15.954589770191005", ",", 
   "79.63903538124936985673399333735159939568`15.954589770191005", ",", 
   "79.64690403274320677300598622158231361684`15.954589770191005", ",", 
   "79.65448089030365626549527348753551997607`15.954589770191005", ",", 
   "79.66177325112337039352094047676222919387`15.954589770191005", ",", 
   "79.66878832008389872355806133104683578934`15.954589770191005", ",", 
   "79.67553320975568832923769899240711808018`15.954589770191005", ",", 
   "79.68201494039808379134690520309423818268`15.954589770191005", ",", 
   "79.68824043995932719782872050559274201176`15.954589770191005", ",", 
   "79.69421654407655814378217424262055928092`15.954589770191005", ",", 
   "79.69994999607581373146228455712900350227`15.954589770191005", ",", 
   "79.70544744697202857028005839230277198652`15.954589770191005", ",", 
   "79.71071545546903477680249149155994584299`15.954589770191005", ",", 
   "79.71576048795956197475256839855198997959`15.954589770191005", ",", 
   "79.72058891852523729500926245716375310284`15.954589770191005", ",", 
   "79.72520702893658537560753581151346771786`15.954589770191005", ",", 
   "79.72962100865302836173833940595275012838`15.954589770191005", ",", 
   "79.73383695482288590574861298506660043671`15.954589770191005", ",", 
   "79.73786087228337516714128509367340254379`15.954589770191005", ",", 
   "79.74169867356061081257527307682492414915`15.954589770191005", ",", 
   "79.74535617886960501586548307980631675091`15.954589770191005", ",", 
   "79.74883911611426745798281004813611564581`15.954589770191005", ",", 
   "79.75215312088740532705413772756623992919`15.954589770191005", ",", 
   "79.75530373647072331836233866408199249497`15.954589770191005", ",", 
   "79.75829641383482363434627420390206003572`15.954589770191005", ",", 
   "79.76113651163920598460079449347851304255`15.954589770191005", ",", 
   "79.76382929623226758587673847949680580523`15.954589770191005", ",", 
   "79.7663799416513031620809339088757764121`15.954589770191005", ",", 
   "79.7687935296225049442761973287676467501`15.954589770191005", ",", 
   "79.77107504956096267068133408655802250479`15.954589770191005", ",", 
   "79.77322939857066358667113832986589316032`15.954589770191005", ",", 
   "79.77526138144449244477639300654363199945`15.954589770191005", ",", 
   "79.77717571066423150468386986467699610353`15.954589770191005", ",", 
   "79.77897700640056053323632945258512635252`15.954589770191005", ",", 
   "79.78066979651305680443252111882054742499`15.954589770191005", ",", 
   "79.7822585165501950994271830121691677981`15.954589770191005", ",", 
   "79.78374750974934770653104208165027974762`15.954589770191005", ",", 
   "79.78514102703678442121081407651655934792`15.954589770191005", ",", 
   "79.78644322702767254608920354625406647196`15.954589770191005", ",", 
   "79.78765817602607689094490384058224479132`15.954589770191005", ",", 
   "79.78878984802495977271259710945392177618`15.954589770191005", ",", 
   "79.7898421247061810154829543030553086953`15.954589770191005", ",", 
   "79.79081879544049795050263517180600061609`15.954589770191005", ",", 
   "79.79172355728756541617428826635897640451`15.954589770191005", ",", 
   "79.79256001499593575805655093760059872514`15.954589770191005", ",", 
   "79.79333168100305882886404933665061404118`15.954589770191005", ",", 
   "79.79404197543528198846739841486215261442`15.954589770191005", ",", 
   "79.79469422610785010389320192382172850524`15.954589770191005", ",", 
   "79.79529166852490554932405241534923957264`15.954589770191005", ",", 
   "79.7958374458794882060985312414979674742`15.954589770191005", ",", 
   "79.79633460905353546271120855455457766615`15.954589770191005", ",", 
   "79.79678611661788221481264330703911940325`15.954589770191005", ",", 
   "79.79719483483226086520938325170502573893`15.954589770191005", ",", 
   "79.79756353764530132386396494153911352519`15.954589770191005", ",", 
   "79.79789490669453100789491372976158341263`15.954589770191005", ",", 
   "79.79819153130637484157674376982601985045`15.954589770191005", ",", 
   "79.79845590849615525633995801541939108648`15.954589770191005", ",", 
   "79.79869044296809219077104822046204916712`15.954589770191005", ",", 
   "79.79889744711530309061249493910772993739`15.954589770191005", ",", 
   "79.7990791410198029087627675257435530409`15.954589770191005", ",", 
   "79.79923765245250410527632413499002191987`15.954589770191005", ",", 
   "79.79937501687321664736361172170102381514`15.954589770191005", ",", 
   "79.79949317743064800939106604096382976611`15.954589770191005", ",", 
   "79.79959398496240317288111164809909461081`15.954589770191005", ",", 
   "79.79967919799498462651216189866085698588`15.954589770191005", ",", 
   "79.79975048274379236611861894843653932655`15.954589770191005", ",", 
   "79.79980941311312389469087375344694786664`15.954589770191005", ",", 
   "79.79985747069617422237530606994627263859`15.954589770191005", ",", 
   "79.79989604477503586647428445442208747344`15.954589770191005", ",", 
   "79.79992643232069885144616626359535000083`15.954589770191005", ",", 
   "79.79994983799305070890529765442040164899`15.954589770191005", ",", 
   "79.79996737414087647762201358408496764478`15.954589770191005", ",", 
   "79.79998006080185870352263781001015701364`15.954589770191005", ",", 
   "79.79998882570257743968948288985046257961`15.954589770191005", ",", 
   "79.79999450425851024636085018149376096534`15.954589770191005", ",", 
   "79.7999978395740321909310298430613125921`15.954589770191005", ",", 
   "79.79999948244241584795030083290776167972`15.954589770191005", ",", 
   "79.79999999134583129912493090962113624668`15.954589770191005", ",", 
   "79.79999983245534613331717663202284811003`15.954589770191005", ",", 
   "79.79999937963092544654528335916769288542`15.954589770191005", ",", 
   "79.79999891442143184198348525034384998712`15.954589770191005", ",", 
   "79.79999862606462542996200526507288262801`15.954589770191005", ",", 
   "79.79999861148716382796705516310973781954`15.954589770191005", ",", 
   "79.79999887530460216064083550444274637178`15.954589770191005", ",", 
   "79.79999932982139305978153564929362289342`15.954589770191005", ",", 
   "79.79999979503088666434333375811746579171`15.954589770191005", ",", 
   "79.79999999861533062043639679160275727254`15.954589770191005", ",", 
   "79.79999957594587008132688051067136334039`15.954589770191005", ",", 
   "79.79999807008254770743692947647853379834`15.954589770191005", ",", 
   "79.79999493177430366634467705041290224807`15.954589770191005", ",", 
   "79.79998951945897563278424539409648608986`15.954589770191005", ",", 
   "79.79998109926329878864574546938468652261`15.954589770191005", ",", 
   "79.7999688450029058229752770383662885438`15.954589770191005", ",", 
   "79.79995183818232693197492866336346094953`15.954589770191005", ",", 
   "79.79992906799498981900277770693175633449`15.954589770191005", ",", 
   "79.79989943132321969457289033186011109197`15.954589770191005", ",", 
   "79.79986173273823927635532150117084541388`15.954589770191005", ",", 
   "79.79981468450016878917611497811966329071`15.954589770191005", ",", 
   "79.79975690655802596501730332619565251157`15.954589770191005", ",", 
   "79.79968692654972604301690790912128466416`15.954589770191005", ",", 
   "79.79960317980208176946893889085241513479`15.954589770191005", ",", 
   "79.79950400933080339782339523557828310838`15.954589770191005", ",", 
   "79.79938766584049868868626470772151156808`15.954589770191005"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.736106583956026*^9},ExpressionUUID->"91296af9-c3b0-4bfe-9c73-\
71de0c0eafe4"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Independent epistasis", "Subsection",
 CellChangeTimes->{{3.736098844271955*^9, 3.736098859714843*^9}, {
  3.736702121857424*^9, 
  3.736702123047564*^9}},ExpressionUUID->"90fd7add-5ec5-45e9-88a1-\
807a6861d1d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmasqmean", "[", 
   RowBox[{"l", ",", "1"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.736107652501748*^9, 
  3.736107652876802*^9}},ExpressionUUID->"fb086f02-f167-4daa-8489-\
a572fa79f461"],

Cell[BoxData["1.2286894111517974`*^-9"], "Output",
 CellChangeTimes->{{3.736107647546185*^9, 
  3.736107653205063*^9}},ExpressionUUID->"fbd16dc9-935f-4436-86a7-\
800dc8f6a69d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExpectedSampleVarianceIE", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"1", "-", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Binomial", "[", 
           RowBox[{"l", ",", "d"}], "]"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"alpha", "-", "1"}], ")"}], "^", "d"}]}], ")"}]}]}], ",", 
      
      RowBox[{"{", 
       RowBox[{"d", ",", "1", ",", "l"}], "}"}]}], "]"}], "*", "1"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.735997366496626*^9, 3.7359974219645*^9}, {
   3.735998032259674*^9, 3.7359980349602823`*^9}, {3.736098409709125*^9, 
   3.7360984167856617`*^9}, {3.736098864477249*^9, 3.736098882177731*^9}, 
   3.7361026322736387`*^9, {3.73610271141705*^9, 3.736102725997904*^9}, {
   3.736103640029139*^9, 3.7361036427705584`*^9}, 3.736104506803574*^9, {
   3.736107826312049*^9, 
   3.736107828072843*^9}},ExpressionUUID->"e518efd4-5a71-4b2e-8486-\
77e8d88e4e89"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "@", "ExpectedSampleVarianceIE"}]], "Input",
 CellChangeTimes->{{3.73610365315294*^9, 3.736103655755226*^9}, {
  3.736105847315239*^9, 
  3.736105848345854*^9}},ExpressionUUID->"c8ecbc49-2bd4-464d-abba-\
889589eee616"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9998684210526316`", ",", "0.9999999652871792`", ",", 
   "0.9999999999862287`", ",", "0.9999999999999927`", ",", 
   "0.9999999999999999`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",",
    "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
   "1.`"}], "}"}]], "Output",
 CellChangeTimes->{3.736105848830317*^9, 3.736106608869363*^9, 
  3.73610782987893*^9},ExpressionUUID->"97330a2f-bccd-493c-8fbc-e8189b2ce63d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plotting Expected Sample Variance E[V(d)] as function of Hamming distance d \
to WT\
\>", "Subsection",
 CellChangeTimes->{
  3.736702095376854*^9},ExpressionUUID->"3379b5d6-a27c-4e28-bae3-\
da9a2b43f102"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", "ExpectedSampleVariancePairWise", ")"}], "/", 
      RowBox[{"ExpectedSampleVariancePairWise", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"(", "ExpectedSampleVarianceIE", ")"}], "/", 
      RowBox[{"ExpectedSampleVarianceIE", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "l"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "50"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Hamming distance to focal genotype\>\"", ",", 
      "\"\<Expected variance due to epistasis\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", "Gray"}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{
      RowBox[{"PointLegend", "[", 
       RowBox[{"Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Pairwise epistasis\>\"", ",", "\"\<Independent epistasis\>\""}],
          "}"}], ",", 
        RowBox[{"LegendMarkerSize", "\[Rule]", "5"}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Darker", "[", "Gray", "]"}]}], ",", 
        RowBox[{"LegendMarkers", "\[Rule]", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
            RowBox[{"Point", "[", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}]}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{".75", ",", ".17"}], "}"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.736107539223629*^9, 
  3.736107545725868*^9}},ExpressionUUID->"b8635ee5-2cfb-4273-a436-\
6965f9ff359c"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{}, {{}, 
      {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJxF1ntYzPn7x/Gx8RWFWCnniiIlgyxq0ytKNqXzgYrpNJ2nOTSHRe3YnNZF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        "]]}, 
      {GrayLevel[0.5], PointSize[0.007333333333333334], AbsoluteThickness[
       1.6], PointBox[CompressedData["
1:eJxdzznOHUUUBeALEWQOCAgI2gghCyHUzDN/MU8G2maeC4MZDW7MnN0lvCXU
El5KVkt4S6gFINErQAiZ6X2dtL46Ojq6py9cPn/x2ojYXRPx1//qt52M9dfT
v/3x+8nfD+Wf96v/68qZXK7/z6fK2Svn/ucbyqUj34hvwhO+Gd+Cb8Vn8G34
dnwHnvGd+C58N74H34vvw/fjB/CD+CH8MH4EP4ofwye4HDtxPE6O4wlyHE+S
43iKHMfT5DieIcfxLDmO58hxPE+O4wVyHC+S4zhLjuMlchwvk+N4hRzHcuyC
E3cc5+jjxB3Hefo4ccfxKn2cuON4jT5O3HG8Th8n7jjeoI8Tdxxv0seJO463
6OPEHcfb9HHijuMd+jhxx/EufZy443iPPk7ccbxPHyfuOD6gjxN3HB/Sx4k7
jnrsCRdcceKGOx44PmIfF1xx4oY7HjgusI8Lrjhxwx0PHB+zjwuuOHHDHQ8c
n7CPC644ccMdDxwX2ccFV5y44Y4Hjk/ZxwVXnLjhjgeOz9jHBVecuOGOB47P
2ccFV5y44Y4Hji/YxwVXnLjhjgeOL9nHBVecuOGOB46v2McFV5y44Y4Hjkvs
44IrTtxwxwPH1+zjgitO3HDHA8c37OOCK07ccMcDx2X2ccEVJ26444FjPfYp
POEZF7zgileceIcb3uOOD3jgDce33I8nPOOCF1zxihPvcMN73PEBD7zhuML9
eMIzLnjBFa848Q43vMcdH/DAG47vuB9PeMYFL7jiFSfe4Yb3uOMDHnjD8T33
4wnPuOAFV7zixDvc8B53fMADbzh+4H484RkXvOCKV5x4hxve444PeOANx4/c
jyc844IXXPGKE+9ww3vc8QEPvOH4ifvxhGdc8IIrXnHiHW54jzs+4IE3HD9z
P57wjAtecMUrTrzDDe9xxwc88Ibjl3/9Jx+lXo4=
        "]]}, {}}, {}}, InsetBox[
     TemplateBox[{"\"Pairwise epistasis\"","\"Independent epistasis\""},
      "PointLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.528], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    InsetBox[
                    GraphicsBox[{
                    PointSize[Medium], 
                    PointBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.528], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {5, 5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.21] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.528], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]], {
                    InsetBox[
                    GraphicsBox[{
                    PointSize[Medium], 
                    PointBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.528], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0.5]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {5, 5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.21] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          RGBColor[
          0.33333333333333337`, 0.33333333333333337`, 0.33333333333333337`], 
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.007333333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.007333333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0.5]"], Appearance -> None,
                     BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0.5], Editable -> False, Selectable -> False]}],
                  "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             GraphicsBox[{
               PointSize[Medium], 
               PointBox[{0, 0}]}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                   0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[
                  0.22222222222222227`, 0.22222222222222227`, 
                   0.22222222222222227`], FrameTicks -> None, 
                 PlotRangePadding -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                "RGBColor[0.33333333333333337, 0.33333333333333337, \
0.33333333333333337]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.33333333333333337`, 0.33333333333333337`, 
               0.33333333333333337`], Editable -> False, Selectable -> 
              False]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"LegendMarkerSize", "\[Rule]", "5"}]}], "]"}]& )], 
     Scaled[{0.75, 0.17}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{True, True}, {True, True}},
   FrameLabel->{{
      FormBox["\"Expected variance due to epistasis\"", TraditionalForm], 
      None}, {
      FormBox["\"Hamming distance to focal genotype\"", TraditionalForm], 
      None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   LabelStyle->Medium,
   Method->{},
   PlotRange->{{0, 400}, {0, 50}},
   PlotRangeClipping->True,
   PlotRangePadding->{{0, 0}, {0, 0}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.007333333333333334], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         Point[CompressedData["
1:eJxF1ntYzPn7x/Gx8RWFWCnniiIlgyxq0ytKNqXzgYrpNJ2nOTSHRe3YnNZF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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[0.007333333333333334], 
          AbsoluteThickness[1.6], 
          GrayLevel[0.5]], 
         Point[CompressedData["
1:eJxdzznOHUUUBeALEWQOCAgI2gghCyHUzDN/MU8G2maeC4MZDW7MnN0lvCXU
El5KVkt4S6gFINErQAiZ6X2dtL46Ojq6py9cPn/x2ojYXRPx1//qt52M9dfT
v/3x+8nfD+Wf96v/68qZXK7/z6fK2Svn/ucbyqUj34hvwhO+Gd+Cb8Vn8G34
dnwHnvGd+C58N74H34vvw/fjB/CD+CH8MH4EP4ofwye4HDtxPE6O4wlyHE+S
43iKHMfT5DieIcfxLDmO58hxPE+O4wVyHC+S4zhLjuMlchwvk+N4hRzHcuyC
E3cc5+jjxB3Hefo4ccfxKn2cuON4jT5O3HG8Th8n7jjeoI8Tdxxv0seJO463
6OPEHcfb9HHijuMd+jhxx/EufZy443iPPk7ccbxPHyfuOD6gjxN3HB/Sx4k7
jnrsCRdcceKGOx44PmIfF1xx4oY7HjgusI8Lrjhxwx0PHB+zjwuuOHHDHQ8c
n7CPC644ccMdDxwX2ccFV5y44Y4Hjk/ZxwVXnLjhjgeOz9jHBVecuOGOB47P
2ccFV5y44Y4Hji/YxwVXnLjhjgeOL9nHBVecuOGOB46v2McFV5y44Y4Hjkvs
44IrTtxwxwPH1+zjgitO3HDHA8c37OOCK07ccMcDx2X2ccEVJ26444FjPfYp
POEZF7zgileceIcb3uOOD3jgDce33I8nPOOCF1zxihPvcMN73PEBD7zhuML9
eMIzLnjBFa848Q43vMcdH/DAG47vuB9PeMYFL7jiFSfe4Yb3uOMDHnjD8T33
4wnPuOAFV7zixDvc8B53fMADbzh+4H484RkXvOCKV5x4hxve444PeOANx4/c
jyc844IXXPGKE+9ww3vc8QEPvOH4ifvxhGdc8IIrXnHiHW54jzs+4IE3HD9z
P57wjAtecMUrTrzDDe9xxwc88Ibjl3/9Jx+lXo4=
          "]]}, {}}}, {}}, {
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
      AxesOrigin -> {0, 0}, PlotRange -> {{0, 400}, {0, 50}}, DisplayFunction -> 
      Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
      Identity, Frame -> {{True, True}, {True, True}}, 
      FrameLabel -> {{"Expected variance due to epistasis", None}, {
        "Hamming distance to focal genotype", None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], LabelStyle -> Medium, Method -> {}, 
      PlotRange -> {{0, 400}, {0, 50}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {{0, 0}, {0, 0}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      PointLegend[{
        Directive[
         PointSize[0.007333333333333334], 
         AbsoluteThickness[1.6], 
         GrayLevel[0]], 
        Directive[
         PointSize[0.007333333333333334], 
         AbsoluteThickness[1.6], 
         GrayLevel[0.5]]}, {"Pairwise epistasis", "Independent epistasis"}, 
       LegendMarkers -> Graphics[{
          PointSize[Medium], 
          Point[{0, 0}]}], Joined -> {False, False}, LabelStyle -> 
       RGBColor[
        0.33333333333333337`, 0.33333333333333337`, 0.33333333333333337`], 
       LegendLayout -> "Column", LegendMarkerSize -> 5]], {0.75, 0.17}, 
     Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.736107546400529*^9, 
  3.736108009281608*^9},ExpressionUUID->"980bd926-b667-4f65-bedd-\
7e4b1c19a341"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Normal approximation explains that epistasis is crucial for protein folding\
\>", "Section",
 CellChangeTimes->{{3.740960997629117*^9, 3.7409610216475687`*^9}, {
  3.740961962904228*^9, 3.740961970153821*^9}, {3.741534632845545*^9, 
  3.7415346390824614`*^9}, {3.7416908148309917`*^9, 
  3.741690815304369*^9}},ExpressionUUID->"fa626e77-dba2-4760-a30d-\
64a8e93c14e6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fontSize", "=", "16"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"400", ",", 
         SqrtBox["380"]}], "]"}], ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "50"}], ",", "50"}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<x (kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<P(\!\(\*SubscriptBox[\(\[CapitalDelta]G\), \(add\)]\)=x)\>\"", 
          ",", "fontSize"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"CDF", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"x", ",", 
         SqrtBox[
          RowBox[{
          "\[InvisibleSpace]\[InvisibleSpace]", "21.605849999999997`"}]]}], 
        "]"}], ",", "0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "50"}], ",", "50"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<x (kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<P(\[CapitalDelta]G<0 | \!\(\*SubscriptBox[\(\[CapitalDelta]G\), \
\(add\)]\)=x)\>\"", ",", " ", "fontSize"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CDF", "[", 
       RowBox[{
        RowBox[{"NormalDistribution", "[", 
         RowBox[{"x", ",", 
          SqrtBox[
           RowBox[{
           "\[InvisibleSpace]\[InvisibleSpace]", "21.605849999999997`"}]]}], 
         "]"}], ",", "0"}], "]"}], 
      RowBox[{"PDF", "[", 
       RowBox[{
        RowBox[{"NormalDistribution", "[", 
         RowBox[{"400", ",", 
          SqrtBox["380"]}], "]"}], ",", "x"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "50"}], ",", "50"}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<x (kcal/mol)\>\"", ",", "fontSize"}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<P(\[CapitalDelta]G<0 \[Intersection] \!\(\*SubscriptBox[\(\
\[CapitalDelta]G\), \(add\)]\)=x)\>\"", ",", " ", "fontSize"}], "]"}]}], 
       "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Gray"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{"{", 
   RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.736791874396793*^9, 3.7367919136302147`*^9}, {
  3.736792335213284*^9, 3.7367923833172483`*^9}, {3.736792452914904*^9, 
  3.7367925428120213`*^9}, {3.7367930782094173`*^9, 3.7367930814745398`*^9}, {
  3.7409610963236313`*^9, 3.74096109791966*^9}, {3.740961173169691*^9, 
  3.740961363065782*^9}, {3.740961429522689*^9, 3.7409614381824093`*^9}, {
  3.740961501216804*^9, 3.740961501962276*^9}, {3.74096153863811*^9, 
  3.740961549907239*^9}, {3.740961580653211*^9, 3.74096159600518*^9}, {
  3.7409617178915567`*^9, 3.7409617235706244`*^9}, {3.740962258361171*^9, 
  3.7409623195202417`*^9}, {3.740962389027183*^9, 3.740962402695384*^9}, {
  3.740962553473456*^9, 3.74096256232828*^9}, {3.740962655673792*^9, 
  3.740962655921864*^9}},ExpressionUUID->"b6409cbe-e220-4234-a6a0-\
9470b9d5913d"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwtlH001XcAhxWiEnc4itgmpdwwb9dLiq+37k+TSqvhqLx8cV33ulccMS/l
hpo6pXnJjqlbIS9laWtOhT7oWA2XebltyDutOeeSURrW7Jz98TnPef57/voY
h4r8wlcrKSntX9l/DAoZUXz4wKBG7XZfyIQYQwZBs9pLDMw93Ta1j4sR2iOf
37bAIPN9nL/jivO4bUufzzB4Ibs5rDkmRpxF7brCYQbzJqasumExst9fNLVq
ZKCT2DylNyDGwyuOx4MlDIZ+9s+XdYmh13S5HSoMqlQVNV4Qg+vye9qJub0o
dK4McCoUQ9/3ndr6t17o+2gySSlOjB3x6XU/LHkiMe1tT5WvGNUPyjx2KTyg
2uNuErtdjN5s6c32N+74JtiWpaS80pPM6XEZdsObK+zs0FoRfCX21ne7CfzN
5C25fBHynDa1HbzvCrvQeB1PExGSSt/3rc7dA71Xn1bul8dA6pjxreyqM8bN
XNXbLsXAfWGyOq/MCW4Cj3IV7xh0KU5H6V1wwGZL7vPKZSFKNJq6a3I5yB9x
1rhfK0RYyK4x9ZO2iFx+JHQQCFE8mu0dGGiN/KzeqNQtQtjqrX2S3W4JS+dG
HmtQAPVeHue3K2y8qW+xts8TIHjUYH3ANVOcCYiru3ZAgLxjTjsPHd2CpaTF
xkpVAVLCWLPJnobIjT1TIKqPhrzcz6dOoAu296W3oV9FQ5bbnyB/oQb288o8
TZto/OUq8FYbmH5yUX9v7KCCjxnXHKEST+E6YPyLxO8uH1mJsUNbU9UJyT+i
nRvBh6TbQKfhE10SK9WzGd/Kh7pWifFihSFJ6US89mAUDvlE8LdnbSG6rXLu
VGEUitzLx41EpuQDe9dZ+EdhbWuqbvEdNnlWYlRwTicKcyqrJv64YUksvIpa
STcP87OvlaVu1qTR5uM1OXk8SMyNZi4H2ZITslTviYM8yFxum0cc5pCA41RL
X5sHc4PF5jPxDsQswOxUmCwSjKy0Kj3WiVRrjGpJLkfi9ZHE3eepM4mxfzxr
6ReJ78p0d3Sn7yGDhnFYw4qEZqcaVUl2JVs3blC/3hUBJiR0eXcHIc/9GyZP
5kTA5+kXxX/3uxGjZ8PC/gMR+D73ZHiV3J18fcfOZUYnAkXc+cC0SQ+SGeQS
dqQ7HJORtxI9xz1Jh96ec0FXwzEXO8Hf8NKLeJjZPRkLCseF4IvZC3/uJRVs
r6wOo3CkPz7eJZ/kkt6rolveYxSbWjoTnKe45FfOlJbXKMW9TvfN0mkuyWO9
kpARisEJUxq1wCUJKSdSHIYodrOm5xfXMqTY4nD9tn6KBXpa39iCIZJ5r1PK
3RQxmtLg6DiG3Ngc0NrcRLFGX1u18xRDKvwG1NBIUWySUWGXwpDklqF9daBo
c+TNLmcwJJFGjv/YQMEOs8rIKWBIX1JSeNkjiola3H7wkCFW6yquZ9+nSGmy
8TFoYAg2WHmeq6HQbS+ZSWtiiKGvw/TZexTuo+edmFaGbM9s8U+tppBqHGrt
G1jpaXuVJK6kcNzYLHIdYUjCT2I/YQVFhzFHt2SCIdovk6z55RT/2OsfEyoY
UjqsoUzLKArcLqzqmmVIUX3BfHAphYXPcqn9O4YEvJAqjpVQPD0q2le0yJBR
i52KwFsU//8X+ayRM/flTYp/AZqdZak=
           "]]},
         Annotation[#, "Charting`Private`Tag$198873386#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -270.3363901638614},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          StyleBox[
          "\"P(\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]G\\), \\(add\\)]\\)=x)\
\"", 16, StripOnInput -> False], TraditionalForm], None}, {
         FormBox[
          StyleBox["\"x (kcal/mol)\"", 16, StripOnInput -> False], 
          TraditionalForm], None}},
      FrameTicks->FrontEndValueCache[{{
          Charting`ScaledTicks[{Log, Exp}], 
          Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Automatic, Automatic}}, {{{{-274.00762606629144`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "119"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-250.981775136351, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "109"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-227.95592420641051`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "99"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-204.93007327647007`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "89"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-181.90422234652962`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "79"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-158.87837141658915`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "69"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-271.7050409732974, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-269.40245588030336`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-267.09987078730927`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-264.79728569431524`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-262.4947006013212, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-260.19211550832716`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-257.8895304153331, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-255.58694532233906`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-253.28436022934503`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-248.67919004335693`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-246.3766049503629, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-244.07401985736885`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-241.7714347643748, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-239.46884967138075`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-237.16626457838672`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-234.86367948539265`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-232.56109439239862`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-230.25850929940458`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-225.65333911341648`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-223.35075402042244`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-221.04816892742838`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-218.74558383443434`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-216.4429987414403, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-214.14041364844624`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-211.8378285554522, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-209.53524346245817`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-207.2326583694641, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-202.62748818347603`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-200.32490309048197`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-198.02231799748793`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-195.7197329044939, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-193.41714781149983`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-191.1145627185058, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-188.81197762551176`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-186.5093925325177, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-184.20680743952366`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-179.60163725353556`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-177.29905216054152`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-174.99646706754748`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-172.69388197455342`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-170.39129688155938`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-168.08871178856535`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-165.78612669557128`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-163.48354160257725`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-161.1809565095832, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}, {{-274.00762606629144`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-250.981775136351, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-227.95592420641051`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-204.93007327647007`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-181.90422234652962`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-158.87837141658915`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-271.7050409732974, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-269.40245588030336`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-267.09987078730927`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-264.79728569431524`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-262.4947006013212, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-260.19211550832716`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-257.8895304153331, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-255.58694532233906`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-253.28436022934503`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-248.67919004335693`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-246.3766049503629, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-244.07401985736885`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-241.7714347643748, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-239.46884967138075`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-237.16626457838672`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-234.86367948539265`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-232.56109439239862`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-230.25850929940458`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-225.65333911341648`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-223.35075402042244`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-221.04816892742838`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-218.74558383443434`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-216.4429987414403, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-214.14041364844624`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-211.8378285554522, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-209.53524346245817`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-207.2326583694641, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-202.62748818347603`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-200.32490309048197`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-198.02231799748793`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-195.7197329044939, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-193.41714781149983`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-191.1145627185058, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-188.81197762551176`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-186.5093925325177, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-184.20680743952366`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-179.60163725353556`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-177.29905216054152`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-174.99646706754748`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-172.69388197455342`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-170.39129688155938`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-168.08871178856535`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-165.78612669557128`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-163.48354160257725`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-161.1809565095832, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, Automatic}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{-50, 50}, {-270.3363901638614, -165.0732365655799}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}], {193.5, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJxFmnk4lFH7x8eaLYRs2cmWfR3rPCOyZCepKIqi7EukhYQUQimUJLKmLKVF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           "]]},
         Annotation[#, "Charting`Private`Tag$198873672#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -61.157639228346525`},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          StyleBox[
          "\"P(\[CapitalDelta]G<0 | \\!\\(\\*SubscriptBox[\\(\[CapitalDelta]G\
\\), \\(add\\)]\\)=x)\"", 16, StripOnInput -> False], TraditionalForm], 
         None}, {
         FormBox[
          StyleBox["\"x (kcal/mol)\"", 16, StripOnInput -> False], 
          TraditionalForm], None}},
      FrameTicks->FrontEndValueCache[{{
          Charting`ScaledTicks[{Log, Exp}], 
          Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Automatic, Automatic}}, {{{{-64.47238260383328, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "28"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-52.95945713886305, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-41.44653167389282, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "18"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-6.907755278982137, 
            FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {4.605170185988092, 
            FormBox[
             TagBox[
              InterpretationBox["\"100.000\"", 100., AutoDelete -> True], 
              NumberForm[#, {
                DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-62.16979751083923, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-59.86721241784519, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-50.65687204586901, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-48.35428695287496, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-43.74911676688687, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-20.72326583694641, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-16.11809565095832, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-9.210340371976182, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-4.605170185988091, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {2.302585092994046, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}, {{-64.47238260383328, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-52.95945713886305, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-41.44653167389282, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-6.907755278982137, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {4.605170185988092, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-62.16979751083923, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-59.86721241784519, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-50.65687204586901, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-48.35428695287496, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-43.74911676688687, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-39.14394658089878, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-32.23619130191664, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-20.72326583694641, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-16.11809565095832, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-9.210340371976182, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-4.605170185988091, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {2.302585092994046, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, Automatic}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}], {580.5, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {GrayLevel[0.5], AbsoluteThickness[1.6], Opacity[1.], 
          LineBox[CompressedData["
1:eJwt2Hk0lN0fAHCyExEpElkSopjN2L+MZQpZ0qJkJ7MUIVuWQt6iBSmV9Eqy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           "]]},
         Annotation[#, "Charting`Private`Tag$198873726#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -270.3363901638614},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          StyleBox[
          "\"P(\[CapitalDelta]G<0 \[Intersection] \\!\\(\\*SubscriptBox[\\(\
\[CapitalDelta]G\\), \\(add\\)]\\)=x)\"", 16, StripOnInput -> False], 
          TraditionalForm], None}, {
         FormBox[
          StyleBox["\"x (kcal/mol)\"", 16, StripOnInput -> False], 
          TraditionalForm], None}},
      FrameTicks->FrontEndValueCache[{{
          Charting`ScaledTicks[{Log, Exp}], 
          Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Automatic, Automatic}}, {{{{-271.7050409732974, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "118"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-248.67919004335693`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "108"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-225.65333911341648`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "98"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-202.62748818347603`, 
            FormBox[
             TemplateBox[{"10", 
               RowBox[{"-", "88"}]}, "Superscript", SyntaxForm -> 
              SuperscriptBox], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-269.40245588030336`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-267.09987078730927`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-264.79728569431524`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-262.4947006013212, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-260.19211550832716`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-257.8895304153331, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-255.58694532233906`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-253.28436022934503`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-250.981775136351, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-246.3766049503629, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-244.07401985736885`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-241.7714347643748, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-239.46884967138075`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-237.16626457838672`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-234.86367948539265`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-232.56109439239862`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-230.25850929940458`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-227.95592420641051`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-223.35075402042244`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-221.04816892742838`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-218.74558383443434`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-216.4429987414403, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-214.14041364844624`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-211.8378285554522, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-209.53524346245817`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-207.2326583694641, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-204.93007327647007`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-200.32490309048197`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}, {{-271.7050409732974, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-248.67919004335693`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-225.65333911341648`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-202.62748818347603`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-269.40245588030336`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-267.09987078730927`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-264.79728569431524`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-262.4947006013212, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-260.19211550832716`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-257.8895304153331, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-255.58694532233906`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-253.28436022934503`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-250.981775136351, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-246.3766049503629, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-244.07401985736885`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-241.7714347643748, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-239.46884967138075`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-237.16626457838672`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-234.86367948539265`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-232.56109439239862`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-230.25850929940458`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-227.95592420641051`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-223.35075402042244`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-221.04816892742838`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-218.74558383443434`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-216.4429987414403, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-214.14041364844624`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-211.8378285554522, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-209.53524346245817`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-207.2326583694641, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-204.93007327647007`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-200.32490309048197`, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, Automatic}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{-50, 50}, {-270.3363901638614, -205.56338384016712`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}], {967.5, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageMargins->0.,
  ImageSize->{996.40625, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.740962274695835*^9, 3.740962320312231*^9, 3.740962403660551*^9, {
   3.740962557929791*^9, 3.740962562936089*^9}, 
   3.740962656679241*^9},ExpressionUUID->"223fd6c6-87a0-44ee-9cea-\
5aae82b7cfee"]
}, Open  ]]
}, Closed]]
},
WindowSize->{1500, 905},
WindowMargins->{{Automatic, 0}, {Automatic, 35}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 448, 8, 67, "Section",ExpressionUUID->"fe593be3-cf31-4429-a5f4-bf3d7063ee30"],
Cell[CellGroupData[{
Cell[1053, 34, 163, 3, 54, "Subsection",ExpressionUUID->"30962d63-d6ac-485b-a49d-3a75475c5994"],
Cell[1219, 39, 97056, 2294, 6491, "Input",ExpressionUUID->"886ee175-aea8-4d5b-bc03-1458b4c7d048"]
}, Closed]],
Cell[CellGroupData[{
Cell[98312, 2338, 742, 10, 38, "Subsection",ExpressionUUID->"91e4fa93-5340-4aca-a28f-542f7ac12593"],
Cell[CellGroupData[{
Cell[99079, 2352, 207, 4, 45, "Subsubsection",ExpressionUUID->"f4d3075d-28ac-432b-8516-bed5df28a6a8"],
Cell[CellGroupData[{
Cell[99311, 2360, 10790, 276, 1011, "Input",ExpressionUUID->"d56f1544-4f74-4bfd-b87c-cf81c55a58f3"],
Cell[CellGroupData[{
Cell[110126, 2640, 2044, 33, 24, "Print",ExpressionUUID->"fefd9620-74a5-4417-ae5b-5c187f102406"],
Cell[112173, 2675, 2038, 33, 24, "Print",ExpressionUUID->"52bc76fe-08d0-4616-89a8-e7efcfd1b89a"],
Cell[114214, 2710, 2073, 35, 40, "Print",ExpressionUUID->"dc8cb510-050c-4286-a25c-c2847a9fdc84"],
Cell[116290, 2747, 2076, 34, 24, "Print",ExpressionUUID->"99d6698d-ae7f-4aa2-b154-a83efaa8cce0"],
Cell[118369, 2783, 2060, 34, 24, "Print",ExpressionUUID->"627f049a-993f-4287-965b-12e26c3beb25"],
Cell[120432, 2819, 6491, 95, 120, "Print",ExpressionUUID->"6d8ab2de-371b-4d9a-9a42-ca8dc4a1db34"],
Cell[126926, 2916, 1902, 29, 24, "Print",ExpressionUUID->"fc6dcd09-fa43-4ad0-8dd0-4b07441548f3"],
Cell[128831, 2947, 2072, 34, 24, "Print",ExpressionUUID->"def3182c-bbb9-4bb0-87ea-fb17dc94ae58"],
Cell[130906, 2983, 2106, 34, 24, "Print",ExpressionUUID->"f873b53a-4ad8-4e9a-98f9-a8254938155f"],
Cell[133015, 3019, 2153, 36, 24, "Print",ExpressionUUID->"3d2831bb-08b8-4b9b-84bc-dbcb917ac58a"],
Cell[135171, 3057, 2145, 36, 24, "Print",ExpressionUUID->"8e6fbc6c-56b6-44f4-8d05-0baa44c54aed"],
Cell[137319, 3095, 1902, 29, 24, "Print",ExpressionUUID->"cb6dc3c2-d576-4e07-aa7e-a1f4ed98111a"],
Cell[139224, 3126, 1921, 29, 24, "Print",ExpressionUUID->"0807e1de-49f3-4888-8bd1-29f1c0104868"],
Cell[141148, 3157, 1953, 31, 24, "Print",ExpressionUUID->"f94f13fb-f090-49b9-ad4e-a0a6f89bd510"],
Cell[143104, 3190, 1921, 29, 24, "Print",ExpressionUUID->"c7232721-8196-454c-9524-0f470dd6c070"],
Cell[145028, 3221, 1952, 31, 24, "Print",ExpressionUUID->"56a9eb55-74fd-4c3b-8e63-8905b0ef38e8"],
Cell[146983, 3254, 1902, 29, 24, "Print",ExpressionUUID->"921f2430-fc7b-48e1-8601-1ef90bd9be96"],
Cell[148888, 3285, 2107, 34, 24, "Print",ExpressionUUID->"b7ed717b-461d-4ab7-b453-e9e5d347388a"],
Cell[150998, 3321, 2109, 34, 24, "Print",ExpressionUUID->"42884f7c-1690-4a99-bbb4-7f3da9460f6d"],
Cell[153110, 3357, 2094, 34, 24, "Print",ExpressionUUID->"fa50ce18-4e08-4dba-aa2a-29b8ccb33982"],
Cell[155207, 3393, 1902, 29, 24, "Print",ExpressionUUID->"0e6a5f50-6bbe-42c8-a270-ecb07924df58"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[157170, 3429, 224, 4, 37, "Subsubsection",ExpressionUUID->"8ffdcba4-206e-4abf-9c66-3331fca5a2c1"],
Cell[CellGroupData[{
Cell[157419, 3437, 6711, 170, 430, "Input",ExpressionUUID->"32ea725d-e61a-4400-812e-6fe7506c55d9"],
Cell[CellGroupData[{
Cell[164155, 3611, 701, 14, 24, "Print",ExpressionUUID->"01eeff84-f0be-4598-b5ae-f768675fbcfe"],
Cell[164859, 3627, 727, 16, 24, "Print",ExpressionUUID->"818387ca-48ff-40f4-89e1-d1b6f877c182"],
Cell[165589, 3645, 676, 14, 24, "Print",ExpressionUUID->"462acd55-5c61-473a-b833-9f5da9529fff"]
}, Open  ]],
Cell[166280, 3662, 91168, 1515, 367, 68393, 1139, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"0853b278-d088-4bcf-b03c-06d3c47603ea"],
Cell[257451, 5179, 82893, 1379, 367, 34706, 587, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"5d5010c2-4dee-4b30-bc88-c8560f34cefa"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[340393, 6564, 195, 3, 37, "Subsubsection",ExpressionUUID->"9a15c958-6982-4c3c-9975-466b615358c5"],
Cell[CellGroupData[{
Cell[340613, 6571, 4671, 127, 199, "Input",ExpressionUUID->"cff6a22d-b895-4428-b294-a41793612ab2"],
Cell[345287, 6700, 909, 23, 24, "Print",ExpressionUUID->"9e5dd58e-6bef-4f52-9b25-7667536ed980"],
Cell[346199, 6725, 1898, 38, 41, "Output",ExpressionUUID->"2ad6f1d3-f546-4669-a962-96a987a355dd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348134, 6768, 7344, 199, 472, "Input",ExpressionUUID->"1cf07552-30d1-4e08-871c-48a74e7f835e"],
Cell[355481, 6969, 22541, 433, 177, "Output",ExpressionUUID->"94d564a4-62a2-45bb-b746-ff0a042a3bf3"],
Cell[CellGroupData[{
Cell[378047, 7406, 1062, 19, 24, "Print",ExpressionUUID->"68417eee-b4e8-4147-af0a-b1626975f434"],
Cell[379112, 7427, 883, 16, 24, "Print",ExpressionUUID->"44ea66f5-99b2-47af-bf24-2cb02a15b3d6"],
Cell[379998, 7445, 889, 16, 24, "Print",ExpressionUUID->"f8155ae1-c5b9-401c-9ecd-49ba5e11aa39"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[380948, 7468, 318, 5, 37, "Subsubsection",ExpressionUUID->"5fe804c3-839c-4c9c-88f7-a07f39eb3790"],
Cell[CellGroupData[{
Cell[381291, 7477, 3043, 72, 178, "Input",ExpressionUUID->"40b39378-b1fb-4735-a377-b40a4a79da9c"],
Cell[384337, 7551, 5899, 104, 254, "Output",ExpressionUUID->"483d314b-8132-49f1-854b-9e5ae335a26d"],
Cell[CellGroupData[{
Cell[390261, 7659, 779, 15, 24, "Print",ExpressionUUID->"95d681ab-fe31-46b4-a031-f54ef23785e4"],
Cell[391043, 7676, 758, 14, 24, "Print",ExpressionUUID->"eb9a3fc5-561c-461f-8af4-2aafb945560e"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[391862, 7697, 256, 4, 37, "Subsubsection",ExpressionUUID->"5a36ffe4-1ae1-4b00-a625-f473c3d935a7"],
Cell[CellGroupData[{
Cell[392143, 7705, 4582, 111, 388, "Input",ExpressionUUID->"56a159f6-8251-45de-938d-3e7f2e4a75b4"],
Cell[396728, 7818, 5596, 100, 249, "Output",ExpressionUUID->"01e546f6-9b2d-47d4-83b5-33f30f635396"],
Cell[CellGroupData[{
Cell[402349, 7922, 1418, 24, 24, "Print",ExpressionUUID->"7dc28dfa-77b0-4259-aa40-24ff6bbcc807"],
Cell[403770, 7948, 1416, 24, 24, "Print",ExpressionUUID->"e9347e00-3afb-42ae-8d13-00e868e74e7d"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[405247, 7979, 362, 7, 37, "Subsubsection",ExpressionUUID->"f689051e-54a0-437d-99db-a842552775fa"],
Cell[CellGroupData[{
Cell[405634, 7990, 2136, 52, 115, "Input",ExpressionUUID->"8d3c4fbd-37db-45a7-aa98-917f23fa43cd"],
Cell[407773, 8044, 4829, 91, 252, "Output",ExpressionUUID->"e435c740-f3ca-4f57-89b5-2ecf4b01f380"],
Cell[CellGroupData[{
Cell[412627, 8139, 710, 14, 24, "Print",ExpressionUUID->"5fbd9f8b-e8cd-4406-823c-845d1de35431"],
Cell[413340, 8155, 681, 13, 24, "Print",ExpressionUUID->"a426f9bb-716a-41f2-9b08-75e47a54940d"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[414082, 8175, 835, 14, 37, "Subsubsection",ExpressionUUID->"9b85df32-362b-40c2-8394-323064b2510f"],
Cell[CellGroupData[{
Cell[414942, 8193, 9451, 230, 631, "Input",ExpressionUUID->"160cea86-ed3e-4bba-b356-bb2ddb70dda7"],
Cell[424396, 8425, 13190, 233, 380, "Output",ExpressionUUID->"43ad24e9-206f-4480-8868-942e612aac3c"],
Cell[CellGroupData[{
Cell[437611, 8662, 1285, 22, 24, "Print",ExpressionUUID->"f45fb495-b823-49bd-86b7-b81f23faade3"],
Cell[438899, 8686, 1291, 22, 24, "Print",ExpressionUUID->"e14f4de5-14ab-4ef5-ac19-9fe473db044f"],
Cell[440193, 8710, 1326, 23, 24, "Print",ExpressionUUID->"571d9079-8299-4379-b728-e045d485644b"],
Cell[441522, 8735, 1309, 23, 24, "Print",ExpressionUUID->"736cb7d2-8802-430d-9a46-b4ab430f7986"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[442892, 8765, 400, 7, 37, "Subsubsection",ExpressionUUID->"bf451520-7dca-44fe-be1e-43d3319e5533"],
Cell[CellGroupData[{
Cell[443317, 8776, 11161, 275, 731, "Input",ExpressionUUID->"49859d39-60ff-4cce-9a44-30019168fa94"],
Cell[454481, 9053, 233, 5, 34, "Output",ExpressionUUID->"2119b27c-5fbf-4c5a-b77e-513600e8c886"],
Cell[454717, 9060, 6792, 130, 382, "Output",ExpressionUUID->"65b1f6ea-4428-4edd-acbd-6adb15d8f8bd"],
Cell[CellGroupData[{
Cell[461534, 9194, 349, 8, 24, "Print",ExpressionUUID->"be6940cc-5d14-499d-8928-b822a2f50933"],
Cell[461886, 9204, 353, 8, 24, "Print",ExpressionUUID->"159be604-15de-45b0-a2aa-b8fe76fc97e8"],
Cell[462242, 9214, 384, 9, 24, "Print",ExpressionUUID->"3a5e41c1-968f-4509-8da7-dae03ee9e25d"],
Cell[462629, 9225, 366, 9, 24, "Print",ExpressionUUID->"0f43f056-d934-4666-8940-9004594178be"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[463056, 9241, 573, 10, 37, "Subsubsection",ExpressionUUID->"7f509ed3-5979-4fad-9ea3-f02e1f3873f4"],
Cell[CellGroupData[{
Cell[463654, 9255, 4105, 112, 241, "Input",ExpressionUUID->"1f21178e-89b3-434c-8a7e-0e554c6a4ae3"],
Cell[467762, 9369, 532, 10, 34, "Output",ExpressionUUID->"cacb99eb-7d76-4677-9c1f-1d8a9564bda4"],
Cell[468297, 9381, 218709, 3604, 382, 161470, 2665, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"e7db313c-1782-4ed3-92b8-2f972511c0ca"],
Cell[CellGroupData[{
Cell[687031, 12989, 659, 13, 24, "Print",ExpressionUUID->"db5b0f82-4e31-4416-89b9-9c2a17f51b9a"],
Cell[687693, 13004, 664, 13, 24, "Print",ExpressionUUID->"a5b80f1e-7e26-4840-890c-92ed4137a73f"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[688418, 13024, 171, 3, 37, "Subsubsection",ExpressionUUID->"975a4972-3b6a-4873-9e71-d3509a8afec9"],
Cell[CellGroupData[{
Cell[688614, 13031, 493, 14, 30, "Input",ExpressionUUID->"6d8771b1-b807-4a13-a0a0-558cdb31726f"],
Cell[689110, 13047, 390879, 6565, 739, 220351, 3769, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"071c91ba-3e01-4939-9396-84b1bdb10ccc"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1080062, 19620, 272, 6, 67, "Section",ExpressionUUID->"095f0ade-4f0c-46e5-a6d4-ab3f9475f734"],
Cell[CellGroupData[{
Cell[1080359, 19630, 142, 3, 54, "Subsection",ExpressionUUID->"a896100c-1d30-4d88-bed2-d2b59e696c63"],
Cell[1080504, 19635, 122616, 2871, 8318, "Input",ExpressionUUID->"92975bbb-56f4-40bf-9d5c-e52ae81537f0"]
}, Closed]],
Cell[CellGroupData[{
Cell[1203157, 22511, 313, 8, 38, "Subsection",ExpressionUUID->"f94a2216-bf30-4caa-8492-0b296dfb0c83"],
Cell[CellGroupData[{
Cell[1203495, 22523, 184, 4, 45, "Subsubsection",ExpressionUUID->"ba2c611a-9093-42cb-accc-f217cd4b85ad"],
Cell[CellGroupData[{
Cell[1203704, 22531, 8755, 207, 864, "Input",ExpressionUUID->"1ee6d2ca-df5a-42c2-a30d-ee9daa0e2312"],
Cell[CellGroupData[{
Cell[1212484, 22742, 466, 10, 24, "Print",ExpressionUUID->"4d50fc40-6ca7-44e1-b83c-06f34533447b"],
Cell[1212953, 22754, 458, 10, 24, "Print",ExpressionUUID->"092b4515-8079-4edd-8794-08a9bb89c465"],
Cell[1213414, 22766, 491, 12, 40, "Print",ExpressionUUID->"fd1035ab-ff76-4446-8864-454956306ce1"],
Cell[1213908, 22780, 461, 10, 24, "Print",ExpressionUUID->"5c5edaea-201d-4de5-8102-7f94cbe5de88"],
Cell[1214372, 22792, 480, 11, 24, "Print",ExpressionUUID->"947dbb3d-075b-4693-a78f-58e28db0e1b5"],
Cell[1214855, 22805, 4911, 72, 139, "Print",ExpressionUUID->"a5cd18da-9fd0-4ce8-b21a-779314aa0cf8"],
Cell[1219769, 22879, 322, 6, 24, "Print",ExpressionUUID->"24c46b62-10b1-45fa-adc6-c0ce8f186c82"],
Cell[1220094, 22887, 492, 11, 24, "Print",ExpressionUUID->"b474b105-8cc2-4de1-a941-bc04bbb89f11"],
Cell[1220589, 22900, 499, 11, 24, "Print",ExpressionUUID->"13014cfe-0086-489a-b16d-53eeb45abcfd"],
Cell[1221091, 22913, 575, 13, 24, "Print",ExpressionUUID->"8366f6dc-c688-44ce-8f67-e99663f9f9d4"],
Cell[1221669, 22928, 567, 13, 24, "Print",ExpressionUUID->"4d04e80a-dba9-473b-8b13-8f9a6b05d212"],
Cell[1222239, 22943, 322, 6, 24, "Print",ExpressionUUID->"497bb5a0-831e-4665-b8fa-ed2b143beeff"],
Cell[1222564, 22951, 341, 6, 24, "Print",ExpressionUUID->"5ef2c1fa-6ee2-483d-a6e9-785e946abd20"],
Cell[1222908, 22959, 371, 8, 24, "Print",ExpressionUUID->"e2b9d275-d9eb-4401-a9a7-635b882514ee"],
Cell[1223282, 22969, 322, 6, 24, "Print",ExpressionUUID->"1bfda0d2-9d39-45f3-afef-7a19bfa8dead"],
Cell[1223607, 22977, 358, 6, 24, "Print",ExpressionUUID->"8b431093-bd56-4387-b2c9-c15cd9787ec7"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1224026, 22990, 147, 3, 37, "Subsubsection",ExpressionUUID->"f62bbd2c-eb3e-49e4-a346-ea588c9ff5a6"],
Cell[CellGroupData[{
Cell[1224198, 22997, 7394, 182, 446, "Input",ExpressionUUID->"d41ea980-71e7-455a-8229-65ed2153c46b"],
Cell[CellGroupData[{
Cell[1231617, 23183, 599, 10, 24, "Print",ExpressionUUID->"1a19149e-2782-4e75-8298-e0bf87a97a3a"],
Cell[1232219, 23195, 625, 12, 24, "Print",ExpressionUUID->"eaee2bc8-de06-4533-879c-3bb91dfc3ea3"],
Cell[1232847, 23209, 574, 10, 24, "Print",ExpressionUUID->"3074956b-054f-4431-8105-e8efe6d117c2"]
}, Open  ]],
Cell[1233436, 23222, 11450, 206, 367, "Output",ExpressionUUID->"829bbedc-d377-4d63-b3cf-16fe3293340e"],
Cell[1244889, 23430, 11435, 206, 367, "Output",ExpressionUUID->"fb22c61d-639e-4bf8-b094-ed0bca33ce26"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1256373, 23642, 172, 3, 37, "Subsubsection",ExpressionUUID->"6faea0e3-acfa-48f7-9b77-0e1046efcfa9"],
Cell[CellGroupData[{
Cell[1256570, 23649, 4581, 123, 220, "Input",ExpressionUUID->"14ed8d0c-a9f0-4e16-ba84-385408ca3757"],
Cell[1261154, 23774, 1716, 35, 24, "Print",ExpressionUUID->"160c7dd4-1e52-4f0f-a00e-65908e6313e7"],
Cell[1262873, 23811, 1790, 36, 41, "Output",ExpressionUUID->"cab82c63-ab51-4fba-ac4f-e137749c64d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1264700, 23852, 7665, 207, 493, "Input",ExpressionUUID->"7d94ed0a-12fb-4d8e-aaa2-1477751986c8"],
Cell[1272368, 24061, 62418, 1090, 175, 42079, 757, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"f9f5e4fa-096b-4289-8d75-0280b405c259"],
Cell[CellGroupData[{
Cell[1334811, 25155, 975, 18, 24, "Print",ExpressionUUID->"bfa3645a-871b-4c7f-bc98-550470edaa9d"],
Cell[1335789, 25175, 793, 15, 24, "Print",ExpressionUUID->"aafd517b-0ca0-45d2-882b-2055a0d726b6"],
Cell[1336585, 25192, 796, 15, 24, "Print",ExpressionUUID->"bfb61ec3-db6f-4041-ab19-c1d5a48fad02"]
}, Open  ]]
}, Open  ]],
Cell[1337408, 25211, 588, 17, 30, "Input",ExpressionUUID->"154fa66f-6100-40a1-aa33-84f2f2312b16"],
Cell[CellGroupData[{
Cell[1338021, 25232, 273, 7, 30, "Input",ExpressionUUID->"0f089365-e66e-49bd-b7ac-56c8ddea9fc5"],
Cell[1338297, 25241, 175, 3, 34, "Output",ExpressionUUID->"77e72420-a982-4980-88cc-265dce0e0794"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1338509, 25249, 693, 20, 30, "Input",ExpressionUUID->"a524c213-c64e-4b4e-a8ab-944874a2a541"],
Cell[1339205, 25271, 11081, 318, 329, "Output",ExpressionUUID->"95d0aa70-3977-447f-8d7b-d8bcae57e66d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1350323, 25594, 188, 3, 30, "Input",ExpressionUUID->"aa56f9da-ba35-4a85-ab7a-0f583cae51c9"],
Cell[1350514, 25599, 158, 3, 34, "Output",ExpressionUUID->"551cc91d-8226-483b-bc23-1abb23c158ca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1350709, 25607, 222, 5, 30, "Input",ExpressionUUID->"9e02516a-1cd1-4230-bb02-1709b6ecd796"],
Cell[1350934, 25614, 187, 4, 34, "Output",ExpressionUUID->"00048bd1-1328-4eec-b63b-70fb7920d5f0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1351158, 25623, 229, 5, 30, "Input",ExpressionUUID->"340ab8c2-1233-4e31-a414-3dfccc56e731"],
Cell[1351390, 25630, 176, 4, 34, "Output",ExpressionUUID->"6c9737ce-fa5c-4078-968c-68779b43681c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1351603, 25639, 232, 5, 30, "Input",ExpressionUUID->"f23040ff-0180-44b7-bd58-0079c9c0d0a8"],
Cell[1351838, 25646, 170, 3, 34, "Output",ExpressionUUID->"56896ecd-44a8-4926-a039-4a85646f3cfe"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1352057, 25655, 145, 3, 37, "Subsubsection",ExpressionUUID->"7ff62521-3f1b-43f8-81f9-2c2b8171857e"],
Cell[CellGroupData[{
Cell[1352227, 25662, 724, 11, 30, "Input",ExpressionUUID->"a4b954dd-3e80-43ba-9626-dbe9f70bbd07"],
Cell[1352954, 25675, 62018, 1084, 175, 42080, 757, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"bb1cc43b-5864-4440-8086-6778ee8345cf"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1415033, 26766, 311, 7, 54, "Subsection",ExpressionUUID->"2b8b4376-df99-4a78-aa2c-1d0c65e2cefa"],
Cell[CellGroupData[{
Cell[1415369, 26777, 184, 4, 45, "Subsubsection",ExpressionUUID->"53738ac6-22f5-494a-bb20-ac729b83b0f2"],
Cell[CellGroupData[{
Cell[1415578, 26785, 8841, 208, 885, "Input",ExpressionUUID->"2e1494eb-f7ce-4f63-93d5-522c111553f5"],
Cell[CellGroupData[{
Cell[1424444, 26997, 2595, 40, 24, "Print",ExpressionUUID->"9a118b8c-65c7-4dbb-979d-f46dae4f7e98"],
Cell[1427042, 27039, 2587, 40, 24, "Print",ExpressionUUID->"f474c6ce-8f03-48e1-996c-80c5cee47af5"],
Cell[1429632, 27081, 2622, 42, 40, "Print",ExpressionUUID->"18207e67-ae37-42cc-ade8-248c05bea6c9"],
Cell[1432257, 27125, 2587, 40, 24, "Print",ExpressionUUID->"52ea7e28-c140-41e7-b240-d331a8ba1d9a"],
Cell[1434847, 27167, 2609, 41, 24, "Print",ExpressionUUID->"cedd14b3-4678-4929-839a-301a96d4a7e6"],
Cell[1437459, 27210, 7039, 102, 120, "Print",ExpressionUUID->"ac880304-7754-4ee6-bdc8-18f449048aa3"],
Cell[1444501, 27314, 2451, 36, 24, "Print",ExpressionUUID->"cb03944f-57f6-42f4-add0-d362316d1a74"],
Cell[1446955, 27352, 2621, 41, 24, "Print",ExpressionUUID->"96973102-c732-42af-a279-e3dc2a675b72"],
Cell[1449579, 27395, 2626, 41, 24, "Print",ExpressionUUID->"4b9d1662-9376-4552-a951-40897ec033b2"],
Cell[1452208, 27438, 2702, 43, 24, "Print",ExpressionUUID->"46feecf3-9fd0-4dc4-abf0-0e794608e8a6"],
Cell[1454913, 27483, 2694, 43, 24, "Print",ExpressionUUID->"5d5b703c-cff5-4f2f-a604-ff072c7f26bc"],
Cell[1457610, 27528, 2451, 36, 24, "Print",ExpressionUUID->"80e8dce6-357b-40ab-97fb-db88c44b7b20"],
Cell[1460064, 27566, 2469, 36, 24, "Print",ExpressionUUID->"3f57ae6b-5b0b-49e8-88ba-36df05cf702a"],
Cell[1462536, 27604, 2500, 38, 24, "Print",ExpressionUUID->"588d0442-26fc-46ca-a17c-f5fb92158718"],
Cell[1465039, 27644, 2451, 36, 24, "Print",ExpressionUUID->"661e2f3e-9a9b-4f50-9252-903c4f7ff446"],
Cell[1467493, 27682, 2487, 36, 24, "Print",ExpressionUUID->"7f933427-18de-4257-99a7-bc0294d57e72"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1470041, 27725, 147, 3, 37, "Subsubsection",ExpressionUUID->"057ce5e3-8bfe-4f3e-a748-7618486898d2"],
Cell[CellGroupData[{
Cell[1470213, 27732, 7374, 181, 446, "Input",ExpressionUUID->"7c8db446-9298-4ab6-9ac1-468238bd6af8"],
Cell[CellGroupData[{
Cell[1477612, 27917, 895, 14, 24, "Print",ExpressionUUID->"1d07de75-2f87-40b2-851e-819f0181a8b3"],
Cell[1478510, 27933, 921, 16, 24, "Print",ExpressionUUID->"9d30e56a-c86c-4ddc-9f17-d0b05a6bc9ab"],
Cell[1479434, 27951, 872, 14, 24, "Print",ExpressionUUID->"e3e9c2e3-78be-4187-8eda-fe1f04b63472"]
}, Open  ]],
Cell[1480321, 27968, 21424, 369, 363, "Output",ExpressionUUID->"05d76dbc-46e6-4e81-bda0-e2448cc8bca8"],
Cell[1501748, 28339, 21247, 366, 367, "Output",ExpressionUUID->"f9bb1f34-ae85-4e51-81da-51fe456a9fb2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1523044, 28711, 172, 3, 37, "Subsubsection",ExpressionUUID->"486077ce-8a6d-4a30-93e7-f4f179fbbc70"],
Cell[CellGroupData[{
Cell[1523241, 28718, 4583, 123, 199, "Input",ExpressionUUID->"ccd2c39f-8109-491b-b426-e7ff0e841ea5"],
Cell[1527827, 28843, 1921, 38, 24, "Print",ExpressionUUID->"2b551754-093f-467d-8d2e-1a8830a3e403"],
Cell[1529751, 28883, 1984, 38, 41, "Output",ExpressionUUID->"b7016425-2040-4135-8e99-616226fa064f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1531772, 28926, 10425, 242, 493, "Input",ExpressionUUID->"368fb884-6ffb-47ef-8e3a-c6a373fa4d50"],
Cell[1542200, 29170, 28921, 537, 353, "Output",ExpressionUUID->"ef1d7e64-2cdd-4af4-8e7a-6903873f59ee"],
Cell[CellGroupData[{
Cell[1571146, 29711, 1042, 18, 24, "Print",ExpressionUUID->"622e2ead-502c-49e2-997f-02bd72dbc734"],
Cell[1572191, 29731, 851, 15, 24, "Print",ExpressionUUID->"153cac91-577f-4cb9-a5f4-b22c2eed26fd"],
Cell[1573045, 29748, 852, 15, 24, "Print",ExpressionUUID->"f1de19aa-fc10-4298-a736-d7f8b8ec7a82"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1573958, 29770, 193, 3, 37, "Subsubsection",ExpressionUUID->"918a7bbd-9b7a-4719-9dfb-6cc8a17ac546"],
Cell[CellGroupData[{
Cell[1574176, 29777, 2906, 66, 157, "Input",ExpressionUUID->"aae17c63-0922-48be-9e1c-ef2bec3aea3b"],
Cell[1577085, 29845, 4237, 80, 254, "Output",ExpressionUUID->"7256d87b-0e23-4dc5-8536-b9863b6d1028"],
Cell[CellGroupData[{
Cell[1581347, 29929, 926, 18, 24, "Print",ExpressionUUID->"b65af1d6-f550-412a-8528-304d09aa95d7"],
Cell[1582276, 29949, 906, 17, 24, "Print",ExpressionUUID->"37969ddf-e5d8-4f38-87f7-f9a1d109c739"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1583243, 29973, 203, 3, 37, "Subsubsection",ExpressionUUID->"fa9959a4-e0bc-4bde-a7e4-d38fedfd6ae1"],
Cell[CellGroupData[{
Cell[1583471, 29980, 4457, 103, 346, "Input",ExpressionUUID->"746ee873-11d5-436d-8fd9-aa4484b7e949"],
Cell[1587931, 30085, 5210, 94, 249, "Output",ExpressionUUID->"05489153-66c3-43f1-ab04-a7ef2f36a554"],
Cell[CellGroupData[{
Cell[1593166, 30183, 1053, 19, 24, "Print",ExpressionUUID->"f2ca1bde-516f-4f29-8a84-8632ad73219e"],
Cell[1594222, 30204, 1053, 19, 24, "Print",ExpressionUUID->"eb0be401-3eb8-4a25-ad61-2518b8430fc4"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1595336, 30230, 239, 6, 37, "Subsubsection",ExpressionUUID->"b0286870-1f31-48f3-8773-8bbb1b594987"],
Cell[CellGroupData[{
Cell[1595600, 30240, 2377, 58, 136, "Input",ExpressionUUID->"3aaf67bc-8799-45cc-9696-2c1daafb91d8"],
Cell[1597980, 30300, 6876, 130, 252, "Output",ExpressionUUID->"74b7c508-3240-4f32-b39d-92dfd0f098ec"],
Cell[CellGroupData[{
Cell[1604881, 30434, 1215, 22, 25, "Print",ExpressionUUID->"2f425b10-f0c7-48f2-a1c1-324896da669c"],
Cell[1606099, 30458, 1202, 21, 24, "Print",ExpressionUUID->"7e07a9d8-9d48-432c-b80b-559624a72ce9"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1607362, 30486, 365, 8, 37, "Subsubsection",ExpressionUUID->"bb6307a9-13c8-405d-8510-4c3dd397a219"],
Cell[CellGroupData[{
Cell[1607752, 30498, 9413, 228, 610, "Input",ExpressionUUID->"39537c62-a501-4910-97ca-24dacb51e5e0"],
Cell[1617168, 30728, 12416, 223, 380, "Output",ExpressionUUID->"29029f18-4469-4564-b053-08e647d4b1fe"],
Cell[CellGroupData[{
Cell[1629609, 30955, 570, 12, 24, "Print",ExpressionUUID->"bde605f3-d6d6-43b4-a5f1-8a67de7c5eba"],
Cell[1630182, 30969, 574, 12, 24, "Print",ExpressionUUID->"2cff9e53-fdc7-46b1-b2ed-ff42d0dccb9a"],
Cell[1630759, 30983, 607, 13, 24, "Print",ExpressionUUID->"c1124e22-e473-4c9c-b141-bddc10ce26b5"],
Cell[1631369, 30998, 586, 12, 24, "Print",ExpressionUUID->"c10013de-94ce-4300-a232-11b6f5572943"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1632016, 31017, 201, 5, 37, "Subsubsection",ExpressionUUID->"1d6de586-1687-4c92-83a5-3ef7a8c23e1e"],
Cell[CellGroupData[{
Cell[1632242, 31026, 9956, 241, 653, "Input",ExpressionUUID->"0c320bc9-6757-4b71-8062-c61e70f39539"],
Cell[1642201, 31269, 231, 5, 34, "Output",ExpressionUUID->"46b87613-af60-4a75-aa29-5681d578d4fd"],
Cell[1642435, 31276, 6768, 130, 382, "Output",ExpressionUUID->"5e0bb305-c59f-473f-94a7-0a2a41701b6e"],
Cell[CellGroupData[{
Cell[1649228, 31410, 758, 15, 24, "Print",ExpressionUUID->"be1346ba-8afa-4f94-aa1a-46132b82106c"],
Cell[1649989, 31427, 743, 14, 24, "Print",ExpressionUUID->"16f2586b-81ad-4e9d-8d2a-df57e5d69c05"],
Cell[1650735, 31443, 777, 15, 24, "Print",ExpressionUUID->"eb91f525-1e58-4e84-9edb-2f50b4aaf4b3"],
Cell[1651515, 31460, 757, 15, 24, "Print",ExpressionUUID->"e63c2601-10fe-4f67-862e-e9376b5f8b56"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1652333, 31482, 203, 5, 37, "Subsubsection",ExpressionUUID->"b6c1e804-941a-406f-ab4c-a524a7005548"],
Cell[CellGroupData[{
Cell[1652561, 31491, 12065, 220, 241, "Input",ExpressionUUID->"b36ccbe3-52cf-47ec-b847-d762896ff5d6"],
Cell[1664629, 31713, 1232, 20, 34, "Output",ExpressionUUID->"0384708c-961d-4b6e-a1bd-8ab411d30d72"],
Cell[1665864, 31735, 194443, 3205, 382, 161236, 2662, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"f559ed7b-d4d6-418d-8c9f-bde719b51a2a"],
Cell[CellGroupData[{
Cell[1860332, 34944, 1345, 23, 24, "Print",ExpressionUUID->"725f226f-67cb-4c9e-9eb5-1cf04aa54af3"],
Cell[1861680, 34969, 1349, 23, 24, "Print",ExpressionUUID->"be6f5db8-c5d4-4a64-933f-41ad35fa6548"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1863090, 34999, 195, 4, 37, "Subsubsection",ExpressionUUID->"76618243-2f7d-46be-85d2-883be9bc60f8"],
Cell[CellGroupData[{
Cell[1863310, 35007, 709, 18, 30, "Input",ExpressionUUID->"e2633c41-17b7-4d43-8c5d-e2d319f1d7ab"],
Cell[1864022, 35027, 374953, 6316, 773, 226351, 3880, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"b2819940-1729-48eb-8f57-737eb2b216bc"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2239048, 41351, 171, 3, 67, "Section",ExpressionUUID->"41f16578-bbcd-4894-bebc-b417a1137ae8"],
Cell[CellGroupData[{
Cell[2239244, 41358, 189, 3, 54, "Subsection",ExpressionUUID->"85f57c3e-496d-415b-8173-e6f911f6852d"],
Cell[2239436, 41363, 1540, 27, 73, "Input",ExpressionUUID->"cb51f225-8389-4ada-a609-449e1f1d1ee3"],
Cell[CellGroupData[{
Cell[2241001, 41394, 354, 8, 52, "Input",ExpressionUUID->"cf64c5f3-5885-4ab7-9fd7-cf9fe556af4c"],
Cell[2241358, 41404, 221, 4, 34, "Output",ExpressionUUID->"41427d9e-578e-4f5d-ab89-f574e9dc95b9"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2241628, 41414, 159, 3, 38, "Subsection",ExpressionUUID->"5eadfe9e-8d0e-4a07-8995-1d03f9b481ed"],
Cell[CellGroupData[{
Cell[2241812, 41421, 181, 2, 43, "Subsubsection",ExpressionUUID->"d55539c8-0c5d-4a5b-9410-b34246456e49"],
Cell[2241996, 41425, 1070, 33, 60, "Input",ExpressionUUID->"87299e97-955e-4691-bd76-fadd73ee89b7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2243103, 41463, 469, 8, 43, "Subsubsection",ExpressionUUID->"2336b7a5-9d55-4b9f-82b6-4a1a70f82f3a"],
Cell[2243575, 41473, 2312, 59, 119, "Input",ExpressionUUID->"0e6e0fcc-010e-4f52-a6ca-75fcdec7bfa4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2245924, 41537, 303, 6, 43, "Subsubsection",ExpressionUUID->"b9d024c0-520f-4559-9114-413fe301c52a"],
Cell[2246230, 41545, 1654, 39, 73, "Input",ExpressionUUID->"a076c1e2-1c01-47a4-84fc-90464c0e514d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2247921, 41589, 267, 5, 43, "Subsubsection",ExpressionUUID->"d12aa902-891f-467b-9e55-315906372c62"],
Cell[2248191, 41596, 865, 21, 31, "Input",ExpressionUUID->"e3ce3223-e921-4286-9c99-3792cf5c8bd2"],
Cell[CellGroupData[{
Cell[2249081, 41621, 240, 6, 30, "Input",ExpressionUUID->"8db165ac-7841-4511-b23a-7cb5d9833e93"],
Cell[2249324, 41629, 228, 4, 34, "Output",ExpressionUUID->"a9139eae-b9db-4ddc-b747-2a97da8bb043"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2249589, 41638, 237, 6, 30, "Input",ExpressionUUID->"c306862d-6360-443f-946b-26251c8d1810"],
Cell[2249829, 41646, 160, 3, 34, "Output",ExpressionUUID->"31a8033a-f491-4864-a349-26dd2d4caf45"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2250050, 41656, 261, 4, 38, "Subsection",ExpressionUUID->"5aad7646-d516-4b28-bde3-8031eb556793"],
Cell[2250314, 41662, 480, 13, 30, "Input",ExpressionUUID->"39d2d7a1-b4c4-4ede-9d91-5678cc5fb5a3"],
Cell[CellGroupData[{
Cell[2250819, 41679, 678, 16, 30, "Input",ExpressionUUID->"9efbaf4b-8aea-4986-ab6a-1d8f0e5b60f8"],
Cell[2251500, 41697, 232, 5, 34, "Output",ExpressionUUID->"69602860-08fe-4f15-9612-8c83ec86c41d"]
}, Open  ]],
Cell[2251747, 41705, 1214, 30, 52, "Input",ExpressionUUID->"f2a13650-abb7-48c0-8234-e1ae368486ec"],
Cell[CellGroupData[{
Cell[2252986, 41739, 111, 0, 30, "Input",ExpressionUUID->"cf16a1cd-ddf0-4409-8a9e-884eb9d6829f"],
Cell[2253100, 41741, 29295, 406, 1694, "Output",ExpressionUUID->"91296af9-c3b0-4bfe-9c73-71de0c0eafe4"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2282444, 42153, 218, 4, 38, "Subsection",ExpressionUUID->"90fd7add-5ec5-45e9-88a1-807a6861d1d0"],
Cell[CellGroupData[{
Cell[2282687, 42161, 238, 6, 30, "Input",ExpressionUUID->"fb086f02-f167-4daa-8489-a572fa79f461"],
Cell[2282928, 42169, 176, 3, 34, "Output",ExpressionUUID->"fbd16dc9-935f-4436-86a7-800dc8f6a69d"]
}, Open  ]],
Cell[2283119, 42175, 1010, 26, 30, "Input",ExpressionUUID->"e518efd4-5a71-4b2e-8486-77e8d88e4e89"],
Cell[CellGroupData[{
Cell[2284154, 42205, 246, 5, 30, "Input",ExpressionUUID->"c8ecbc49-2bd4-464d-abba-889589eee616"],
Cell[2284403, 42212, 5351, 73, 350, "Output",ExpressionUUID->"97330a2f-bccd-493c-8fbc-e8189b2ce63d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2289803, 42291, 215, 6, 38, "Subsection",ExpressionUUID->"3379b5d6-a27c-4e28-bae3-da9a2b43f102"],
Cell[CellGroupData[{
Cell[2290043, 42301, 2119, 56, 199, "Input",ExpressionUUID->"b8635ee5-2cfb-4273-a436-6965f9ff359c"],
Cell[2292165, 42359, 26837, 523, 256, "Output",ExpressionUUID->"980bd926-b667-4f65-bedd-7e4b1c19a341"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2319063, 42889, 378, 7, 67, "Section",ExpressionUUID->"fa626e77-dba2-4760-a30d-64a8e93c14e6"],
Cell[CellGroupData[{
Cell[2319466, 42900, 4181, 106, 232, "Input",ExpressionUUID->"b6409cbe-e220-4234-a6a0-9470b9d5913d"],
Cell[2323650, 43008, 65616, 1232, 232, "Output",ExpressionUUID->"223fd6c6-87a0-44ee-9cea-5aae82b7cfee"]
}, Open  ]]
}, Closed]]
}
]
*)

